@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$28)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$33)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$28 CALLBACK;
+	tmp$33 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$26)( void );
+typedef FBSTRING* (*tmp$27)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint32* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$28)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint32* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$26 PROC;
+	union {
+		tmp$27 DPROCZ;
+		tmp$28 MPROCZ;
+	};
+	union {
+		tmp$29 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -735,7 +774,8 @@ struct $7ASTNODE* ASTNEWCONSTI( int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWCONSTZ( int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL*, int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWBRANCH( int64, struct $8FBSYMBOL*, struct $7ASTNODE* );
-struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
+typedef int64 $15AST_LINK_RETURN;
+struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, $15AST_LINK_RETURN );
 struct $7ASTNODE* ASTNEWLABEL( struct $8FBSYMBOL*, int64 );
 struct $7ASTNODE* ASTNEWDECL( struct $8FBSYMBOL*, int64 );
 int64 ASTGETINVERSELOGOP( int64 );
@@ -746,11 +786,11 @@ struct $7ASTNODE* ASTBUILDFAKEWSTRINGASSIGN( struct $8FBSYMBOL*, struct $7ASTNOD
 typedef int64 $10FB_SYMBOPT;
 struct $8FBSYMBOL* SYMBADDLABEL( uint8*, $10FB_SYMBOPT );
 struct $8FBSYMBOL* SYMBADDIMPLICITVAR( int64, struct $8FBSYMBOL*, int64 );
-int64 HMATCH( int64 );
 int64 HFBRELOP2IRRELOP( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 struct $13FB_CMPSTMTSTK* CCOMPSTMTPUSH( $8FB_TOKEN, $15FB_CMPSTMT_MASK );
 struct $13FB_CMPSTMTSTK* CCOMPSTMTGETTOS( $8FB_TOKEN, int64 );
 void CCOMPSTMTPOP( struct $13FB_CMPSTMTSTK* );
@@ -781,10 +821,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$75$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$79$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -802,20 +843,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$80$;
 struct $8FBARRAY2IlE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2IlE ) == 88 );
-static struct $8FBARRAY2IlE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2IlE ) == 96 );
+static struct $8FBARRAY2IlE tmp$81$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -856,8 +899,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -865,8 +911,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -913,6 +960,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -934,16 +982,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $5FBCTX {
 	int64 BASE;
@@ -975,8 +1028,8 @@ void CSELECTSTMTBEGIN( void )
 	struct $8FBSYMBOL* EL$1;
 	struct $8FBSYMBOL* SUBTYPE$1;
 	struct $13FB_CMPSTMTSTK* STK$1;
-	LEXSKIPTOKEN( 0ll );
-	int64 vr$0 = HMATCH( 271ll );
+	LEXSKIPTOKEN( 2048ll );
+	int64 vr$0 = HMATCH( 271ll, 2048ll );
 	if( vr$0 != 0ll ) goto label$17;
 	{
 		ERRREPORT( 34ll, 0ll, (uint8*)0ull );
@@ -986,8 +1039,8 @@ void CSELECTSTMTBEGIN( void )
 	int64 vr$1 = LEXGETTOKEN( 0ll );
 	if( vr$1 != 376ll ) goto label$19;
 	{
-		LEXSKIPTOKEN( 0ll );
-		int64 vr$2 = HMATCH( 335ll );
+		LEXSKIPTOKEN( 2048ll );
+		int64 vr$2 = HMATCH( 335ll, 2048ll );
 		if( vr$2 == 0ll ) goto label$21;
 		{
 			CSELCONSTSTMTBEGIN(  );
@@ -1045,20 +1098,20 @@ void CSELECTSTMTBEGIN( void )
 	goto label$28;
 	label$29:;
 	{
-		int64 TMP$90$2;
+		int64 TMP$95$2;
 		{
-			int64 TMP$88$3;
-			int64 TMP$89$3;
+			int64 TMP$93$3;
+			int64 TMP$94$3;
 			if( (DTYPE$1 & 480ll) == 0ll ) goto label$30;
-			TMP$88$3 = 24ll;
+			TMP$93$3 = 24ll;
 			goto label$47;
 			label$30:;
-			TMP$88$3 = DTYPE$1 & 31ll;
+			TMP$93$3 = DTYPE$1 & 31ll;
 			label$47:;
-			TMP$89$3 = TMP$88$3;
-			if( TMP$89$3 == 18ll ) goto label$33;
+			TMP$94$3 = TMP$93$3;
+			if( TMP$94$3 == 18ll ) goto label$33;
 			label$34:;
-			if( TMP$89$3 != 4ll ) goto label$32;
+			if( TMP$94$3 != 4ll ) goto label$32;
 			label$33:;
 			{
 				DTYPE$1 = 17ll;
@@ -1067,32 +1120,32 @@ void CSELECTSTMTBEGIN( void )
 			label$31:;
 		}
 		OPTIONS$1 = 0ll;
-		if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 2ll) != 0ll ) goto label$36;
+		if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 2ll) != 0ll ) goto label$36;
 		{
 			OPTIONS$1 = OPTIONS$1 | 2ll;
 		}
 		label$36:;
 		label$35:;
 		if( (DTYPE$1 & 480ll) == 0ll ) goto label$37;
-		TMP$90$2 = 24ll;
+		TMP$95$2 = 24ll;
 		goto label$48;
 		label$37:;
-		TMP$90$2 = DTYPE$1 & 31ll;
+		TMP$95$2 = DTYPE$1 & 31ll;
 		label$48:;
-		if( TMP$90$2 == 7ll ) goto label$39;
+		if( TMP$95$2 == 7ll ) goto label$39;
 		{
-			int64 TMP$91$3;
+			int64 TMP$96$3;
 			struct $8FBSYMBOL* vr$23 = SYMBADDIMPLICITVAR( DTYPE$1, SUBTYPE$1, OPTIONS$1 );
 			SYM$1 = vr$23;
 			if( (DTYPE$1 & 480ll) == 0ll ) goto label$40;
-			TMP$91$3 = 24ll;
+			TMP$96$3 = 24ll;
 			goto label$49;
 			label$40:;
-			TMP$91$3 = DTYPE$1 & 31ll;
+			TMP$96$3 = DTYPE$1 & 31ll;
 			label$49:;
-			if( TMP$91$3 == 17ll ) goto label$42;
+			if( TMP$96$3 == 17ll ) goto label$42;
 			{
-				*($12FB_SYMBSTATS*)((uint8*)SYM$1 + 16ll) = *(int64*)((uint8*)SYM$1 + 16ll) | 2048ll;
+				*($12FB_SYMBSTATS*)((uint8*)SYM$1 + 24ll) = *(int64*)((uint8*)SYM$1 + 24ll) | 2048ll;
 			}
 			label$42:;
 			label$41:;
@@ -1110,7 +1163,7 @@ void CSELECTSTMTBEGIN( void )
 				struct $7ASTNODE* vr$33 = ASTNEWVAR( SYM$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 				struct $7ASTNODE* vr$34 = ASTNEWASSIGN( vr$33, EXPR$1, 64ll );
 				struct $7ASTNODE* vr$35 = ASTNEWDECL( SYM$1, 0ll );
-				struct $7ASTNODE* vr$36 = ASTNEWLINK( vr$35, vr$34, -1ll );
+				struct $7ASTNODE* vr$36 = ASTNEWLINK( vr$35, vr$34, 0ll );
 				ASTADD( vr$36 );
 			}
 			label$43:;
@@ -1120,7 +1173,7 @@ void CSELECTSTMTBEGIN( void )
 		{
 			struct $8FBSYMBOL* vr$37 = SYMBADDIMPLICITVAR( 39ll, (struct $8FBSYMBOL*)0ull, OPTIONS$1 );
 			SYM$1 = vr$37;
-			*($12FB_SYMBSTATS*)((uint8*)SYM$1 + 16ll) = *(int64*)((uint8*)SYM$1 + 16ll) | 16777216ll;
+			*($12FB_SYMBSTATS*)((uint8*)SYM$1 + 24ll) = *(int64*)((uint8*)SYM$1 + 24ll) | 16777216ll;
 			if( (OPTIONS$1 & 2ll) == 0ll ) goto label$46;
 			{
 				struct $7ASTNODE* vr$42 = ASTNEWDECL( SYM$1, -1ll );
@@ -1133,7 +1186,7 @@ void CSELECTSTMTBEGIN( void )
 			{
 				struct $7ASTNODE* vr$44 = ASTBUILDFAKEWSTRINGASSIGN( SYM$1, EXPR$1, 64ll );
 				struct $7ASTNODE* vr$45 = ASTNEWDECL( SYM$1, 0ll );
-				struct $7ASTNODE* vr$46 = ASTNEWLINK( vr$45, vr$44, -1ll );
+				struct $7ASTNODE* vr$46 = ASTNEWLINK( vr$45, vr$44, 0ll );
 				ASTADD( vr$46 );
 			}
 			label$45:;
@@ -1186,7 +1239,7 @@ void CSELECTSTMTNEXT( void )
 	}
 	label$84:;
 	label$83:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	if( *(struct $7ASTNODE**)((uint8*)STK$1 + 16ll) == (struct $7ASTNODE*)0ull ) goto label$86;
 	{
 		ASTSCOPEEND( *(struct $7ASTNODE**)((uint8*)STK$1 + 16ll) );
@@ -1208,7 +1261,7 @@ void CSELECTSTMTNEXT( void )
 	int64 vr$14 = LEXGETTOKEN( 0ll );
 	if( vr$14 != 268ll ) goto label$90;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		struct $7ASTNODE* vr$15 = ASTSCOPEBEGIN(  );
 		*(struct $7ASTNODE**)((uint8*)STK$1 + 16ll) = vr$15;
 		*(int64*)((uint8*)STK$1 + 40ll) = -1ll;
@@ -1239,8 +1292,8 @@ void CSELECTSTMTNEXT( void )
 	IL$1 = vr$26;
 	{
 		I$1 = 0ll;
-		int64 TMP$95$2;
-		TMP$95$2 = CNT$1 + -1ll;
+		int64 TMP$100$2;
+		TMP$100$2 = CNT$1 + -1ll;
 		goto label$96;
 		label$99:;
 		{
@@ -1278,7 +1331,7 @@ void CSELECTSTMTNEXT( void )
 		label$97:;
 		I$1 = I$1 + 1ll;
 		label$96:;
-		if( I$1 <= TMP$95$2 ) goto label$99;
+		if( I$1 <= TMP$100$2 ) goto label$99;
 		label$98:;
 	}
 	*(int64*)&CTX$ = *(int64*)&CTX$ - CNT$1;
@@ -1316,8 +1369,8 @@ void CSELECTSTMTEND( void )
 	}
 	label$115:;
 	label$114:;
-	LEXSKIPTOKEN( 0ll );
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
+	LEXSKIPTOKEN( 2048ll );
 	if( *(struct $7ASTNODE**)((uint8*)STK$1 + 16ll) == (struct $7ASTNODE*)0ull ) goto label$117;
 	{
 		ASTSCOPEEND( *(struct $7ASTNODE**)((uint8*)STK$1 + 16ll) );
@@ -1347,7 +1400,7 @@ __attribute__(( constructor )) static void fb_ctor__parserzcompoundzselect( void
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1359,7 +1412,7 @@ static void HCASEEXPRESSION( struct $9FBCASECTX* CASECTX$1, struct $8FBSYMBOL* S
 	int64 vr$1 = LEXGETTOKEN( 0ll );
 	if( vr$1 != 272ll ) goto label$53;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		int64 vr$2 = LEXGETTOKEN( 0ll );
 		int64 vr$3 = HFBRELOP2IRRELOP( vr$2 );
 		*(int64*)((uint8*)CASECTX$1 + 8ll) = vr$3;
@@ -1376,15 +1429,15 @@ static void HCASEEXPRESSION( struct $9FBCASECTX* CASECTX$1, struct $8FBSYMBOL* S
 	*(struct $7ASTNODE**)((uint8*)CASECTX$1 + 16ll) = vr$7;
 	if( *(struct $7ASTNODE**)((uint8*)CASECTX$1 + 16ll) != (struct $7ASTNODE*)0ull ) goto label$55;
 	{
-		int64 TMP$92$2;
+		int64 TMP$97$2;
 		ERRREPORT( 9ll, 0ll, (uint8*)0ull );
-		if( (*(int64*)((uint8*)SYM$1 + 16ll) & 16777216ll) == 0ll ) goto label$56;
-		TMP$92$2 = 7ll;
+		if( (*(int64*)((uint8*)SYM$1 + 24ll) & 16777216ll) == 0ll ) goto label$56;
+		TMP$97$2 = 7ll;
 		goto label$120;
 		label$56:;
-		TMP$92$2 = *(int64*)((uint8*)SYM$1 + 48ll) & 511ll;
+		TMP$97$2 = *(int64*)((uint8*)SYM$1 + 56ll) & 511ll;
 		label$120:;
-		struct $7ASTNODE* vr$14 = ASTNEWCONSTZ( TMP$92$2, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$14 = ASTNEWCONSTZ( TMP$97$2, (struct $8FBSYMBOL*)0ull );
 		*(struct $7ASTNODE**)((uint8*)CASECTX$1 + 16ll) = vr$14;
 	}
 	label$55:;
@@ -1392,7 +1445,7 @@ static void HCASEEXPRESSION( struct $9FBCASECTX* CASECTX$1, struct $8FBSYMBOL* S
 	int64 vr$16 = LEXGETTOKEN( 0ll );
 	if( vr$16 != 284ll ) goto label$58;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		if( *(int64*)CASECTX$1 == 0ll ) goto label$60;
 		{
 			ERRREPORT( 17ll, 0ll, (uint8*)0ull );
@@ -1423,20 +1476,20 @@ static void HCASEEXPRESSION( struct $9FBCASECTX* CASECTX$1, struct $8FBSYMBOL* S
 
 static int64 HFLUSHCASEEXPR( struct $9FBCASECTX* CASECTX$1, struct $8FBSYMBOL* SYM$1, struct $8FBSYMBOL* INILABEL$1, struct $8FBSYMBOL* NXTLABEL$1, int64 ISLAST$1 )
 {
-	struct $7ASTNODE* TMP$93$1;
+	struct $7ASTNODE* TMP$98$1;
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$63:;
 	struct $7ASTNODE* EXPR$1;
-	if( (*(int64*)((uint8*)SYM$1 + 16ll) & 16777216ll) == 0ll ) goto label$65;
+	if( (*(int64*)((uint8*)SYM$1 + 24ll) & 16777216ll) == 0ll ) goto label$65;
 	struct $7ASTNODE* vr$3 = ASTBUILDFAKEWSTRINGACCESS( SYM$1 );
-	TMP$93$1 = vr$3;
+	TMP$98$1 = vr$3;
 	goto label$121;
 	label$65:;
 	struct $7ASTNODE* vr$4 = ASTNEWVAR( SYM$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-	TMP$93$1 = vr$4;
+	TMP$98$1 = vr$4;
 	label$121:;
-	EXPR$1 = TMP$93$1;
+	EXPR$1 = TMP$98$1;
 	if( *(int64*)CASECTX$1 == 1ll ) goto label$67;
 	{
 		if( ISLAST$1 == 0ll ) goto label$69;
@@ -1456,7 +1509,7 @@ static int64 HFLUSHCASEEXPR( struct $9FBCASECTX* CASECTX$1, struct $8FBSYMBOL* S
 	goto label$66;
 	label$67:;
 	{
-		struct $7ASTNODE* TMP$94$2;
+		struct $7ASTNODE* TMP$99$2;
 		struct $7ASTNODE* vr$14 = ASTNEWBOP( 47ll, EXPR$1, *(struct $7ASTNODE**)((uint8*)CASECTX$1 + 16ll), NXTLABEL$1, 0ll );
 		EXPR$1 = vr$14;
 		if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$71;
@@ -1467,15 +1520,15 @@ static int64 HFLUSHCASEEXPR( struct $9FBCASECTX* CASECTX$1, struct $8FBSYMBOL* S
 		label$71:;
 		label$70:;
 		ASTADD( EXPR$1 );
-		if( (*(int64*)((uint8*)SYM$1 + 16ll) & 16777216ll) == 0ll ) goto label$72;
+		if( (*(int64*)((uint8*)SYM$1 + 24ll) & 16777216ll) == 0ll ) goto label$72;
 		struct $7ASTNODE* vr$17 = ASTBUILDFAKEWSTRINGACCESS( SYM$1 );
-		TMP$94$2 = vr$17;
+		TMP$99$2 = vr$17;
 		goto label$122;
 		label$72:;
 		struct $7ASTNODE* vr$18 = ASTNEWVAR( SYM$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-		TMP$94$2 = vr$18;
+		TMP$99$2 = vr$18;
 		label$122:;
-		EXPR$1 = TMP$94$2;
+		EXPR$1 = TMP$99$2;
 		if( ISLAST$1 == 0ll ) goto label$74;
 		{
 			struct $7ASTNODE* vr$20 = ASTNEWBOP( 46ll, EXPR$1, *(struct $7ASTNODE**)((uint8*)CASECTX$1 + 24ll), NXTLABEL$1, 0ll );
