@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,13 +636,23 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $16__FB_ARRAYDIMTB$ {
 	int64 ELEMENTS;
 	int64 LBOUND;
 	int64 UBOUND;
 };
 __FB_STATIC_ASSERT( sizeof( struct $16__FB_ARRAYDIMTB$ ) == 24 );
+struct $8FBARRAY1I10FBARRAYDIME {
+	struct $10FBARRAYDIM* DATA;
+	struct $10FBARRAYDIM* PTR;
+	int64 SIZE;
+	int64 ELEMENT_LEN;
+	int64 DIMENSIONS;
+	int64 FLAGS;
+	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
+};
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10FBARRAYDIME ) == 72 );
 struct $7FBTOKEN;
 struct $7FBTOKEN {
 	int64 ID;
@@ -619,29 +668,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -674,7 +713,7 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -722,10 +761,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -743,20 +783,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -797,8 +839,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -806,8 +851,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -854,6 +900,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -875,58 +922,55 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 
 void ASTGOSUBADDINIT( struct $8FBSYMBOL* PROC$1 )
 {
 	label$10:;
 	struct $10FBARRAYDIM DTB$1[1];
-	struct $8FBARRAY1I10FBARRAYDIME {
-		struct $10FBARRAYDIM* DATA;
-		struct $10FBARRAYDIM* PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10FBARRAYDIME ) == 64 );
-	struct $8FBARRAY1I10FBARRAYDIME tmp$88$1;
-	*(struct $10FBARRAYDIM**)&tmp$88$1 = (struct $10FBARRAYDIM*)DTB$1;
-	*(struct $10FBARRAYDIM**)((uint8*)&tmp$88$1 + 8ll) = (struct $10FBARRAYDIM*)DTB$1;
-	*(int64*)((uint8*)&tmp$88$1 + 16ll) = 16ll;
-	*(int64*)((uint8*)&tmp$88$1 + 24ll) = 16ll;
-	*(int64*)((uint8*)&tmp$88$1 + 32ll) = 1ll;
-	*(int64*)((uint8*)&tmp$88$1 + 40ll) = 1ll;
-	*(int64*)((uint8*)&tmp$88$1 + 48ll) = 0ll;
-	*(int64*)((uint8*)&tmp$88$1 + 56ll) = 0ll;
+	struct $8FBARRAY1I10FBARRAYDIME tmp$93$1;
+	*(struct $10FBARRAYDIM**)&tmp$93$1 = (struct $10FBARRAYDIM*)DTB$1;
+	*(struct $10FBARRAYDIM**)((uint8*)&tmp$93$1 + 8ll) = (struct $10FBARRAYDIM*)DTB$1;
+	*(int64*)((uint8*)&tmp$93$1 + 16ll) = 16ll;
+	*(int64*)((uint8*)&tmp$93$1 + 24ll) = 16ll;
+	*(int64*)((uint8*)&tmp$93$1 + 32ll) = 1ll;
+	*(int64*)((uint8*)&tmp$93$1 + 40ll) = 49ll;
+	*(int64*)((uint8*)&tmp$93$1 + 48ll) = 1ll;
+	*(int64*)((uint8*)&tmp$93$1 + 56ll) = 0ll;
+	*(int64*)((uint8*)&tmp$93$1 + 64ll) = 0ll;
 	struct $8FBSYMBOL* SYM$1;
 	struct $7ASTNODE* VAR_DECL$1;
 	int64 DTYPE$1;
 	SYMBPROCALLOCEXT( PROC$1 );
-	if( (*(int64*)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 96ll) & 4ll) == 0ll ) goto label$13;
+	if( (*(int64*)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 96ll) & 4ll) == 0ll ) goto label$13;
 	{
 		goto label$11;
 	}
 	label$13:;
 	label$12:;
-	if( ((int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 0ll) & (int64)-(*(int64*)((uint8*)&ENV$ + 400ll) == 0ll)) == 0ll ) goto label$15;
+	if( (((int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 0ll) | (int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 3ll)) & (int64)-(*(int64*)((uint8*)&ENV$ + 400ll) == 0ll)) == 0ll ) goto label$15;
 	{
 		DTYPE$1 = 8ll;
 	}
@@ -936,14 +980,14 @@ void ASTGOSUBADDINIT( struct $8FBSYMBOL* PROC$1 )
 		DTYPE$1 = 32ll;
 	}
 	label$14:;
-	struct $8FBSYMBOL* vr$8 = SYMBADDIMPLICITVAR( DTYPE$1, (struct $8FBSYMBOL*)0ull, 2ll );
-	SYM$1 = vr$8;
-	struct $7ASTNODE* vr$9 = ASTNEWDECL( SYM$1, -1ll );
-	VAR_DECL$1 = vr$9;
-	*($12FB_SYMBSTATS*)((uint8*)SYM$1 + 16ll) = *(int64*)((uint8*)SYM$1 + 16ll) | 8ll;
+	struct $8FBSYMBOL* vr$10 = SYMBADDIMPLICITVAR( DTYPE$1, (struct $8FBSYMBOL*)0ull, 2ll );
+	SYM$1 = vr$10;
+	struct $7ASTNODE* vr$11 = ASTNEWDECL( SYM$1, -1ll );
+	VAR_DECL$1 = vr$11;
+	*($12FB_SYMBSTATS*)((uint8*)SYM$1 + 24ll) = *(int64*)((uint8*)SYM$1 + 24ll) | 8ll;
 	ASTADDUNSCOPED( VAR_DECL$1 );
-	*(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 120ll) = SYM$1;
-	*($12FB_PROCSTATS*)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 96ll) = *(int64*)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 96ll) | 4ll;
+	*(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 120ll) = SYM$1;
+	*($12FB_PROCSTATS*)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 96ll) = *(int64*)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 96ll) | 4ll;
 	label$11:;
 }
 
@@ -952,30 +996,31 @@ void ASTGOSUBADDJMP( struct $8FBSYMBOL* PROC$1, struct $8FBSYMBOL* L$1 )
 	label$16:;
 	struct $8FBSYMBOL* LABEL$1;
 	ASTGOSUBADDINIT( PROC$1 );
-	if( ((int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 0ll) & (int64)-(*(int64*)((uint8*)&ENV$ + 400ll) == 0ll)) == 0ll ) goto label$19;
+	if( (((int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 0ll) | (int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 3ll)) & (int64)-(*(int64*)((uint8*)&ENV$ + 400ll) == 0ll)) == 0ll ) goto label$19;
 	{
-		struct $7ASTNODE* vr$5 = ASTBUILDVARINC( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 120ll), 1ll );
-		ASTADD( vr$5 );
-		struct $7ASTNODE* vr$6 = ASTNEWBRANCH( 99ll, L$1, (struct $7ASTNODE*)0ull );
-		ASTADD( vr$6 );
+		struct $7ASTNODE* vr$7 = ASTBUILDVARINC( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 120ll), 1ll );
+		ASTADD( vr$7 );
+		struct $7ASTNODE* vr$8 = ASTNEWBRANCH( 99ll, L$1, (struct $7ASTNODE*)0ull );
+		ASTADD( vr$8 );
+		*(boolean*)((uint8*)L$1 + 120ll) = (boolean)1ll;
 	}
 	goto label$18;
 	label$19:;
 	{
-		struct $8FBSYMBOL* vr$7 = SYMBADDLABEL( (uint8*)0ull, 4ll );
-		LABEL$1 = vr$7;
-		struct $7ASTNODE* vr$8 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
-		struct $7ASTNODE* vr$11 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-		struct $7ASTNODE* vr$12 = ASTNEWADDROF( vr$11 );
-		struct $7ASTNODE* vr$13 = RTLGOSUBPUSH( vr$12 );
-		struct $7ASTNODE* vr$14 = RTLSETJMP( vr$13 );
-		struct $7ASTNODE* vr$15 = ASTNEWBOP( 45ll, vr$14, vr$8, (struct $8FBSYMBOL*)0ull, 1ll );
-		struct $7ASTNODE* vr$16 = ASTBUILDBRANCH( vr$15, LABEL$1, 0ll, 0ll );
-		ASTADD( vr$16 );
-		struct $7ASTNODE* vr$17 = ASTNEWBRANCH( 98ll, L$1, (struct $7ASTNODE*)0ull );
-		ASTADD( vr$17 );
-		struct $7ASTNODE* vr$18 = ASTNEWLABEL( LABEL$1, -1ll );
-		ASTADD( vr$18 );
+		struct $8FBSYMBOL* vr$10 = SYMBADDLABEL( (uint8*)0ull, 4ll );
+		LABEL$1 = vr$10;
+		struct $7ASTNODE* vr$11 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$14 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$15 = ASTNEWADDROF( vr$14 );
+		struct $7ASTNODE* vr$16 = RTLGOSUBPUSH( vr$15 );
+		struct $7ASTNODE* vr$17 = RTLSETJMP( vr$16 );
+		struct $7ASTNODE* vr$18 = ASTNEWBOP( 45ll, vr$17, vr$11, (struct $8FBSYMBOL*)0ull, 1ll );
+		struct $7ASTNODE* vr$19 = ASTBUILDBRANCH( vr$18, LABEL$1, 0ll, 0ll );
+		ASTADD( vr$19 );
+		struct $7ASTNODE* vr$20 = ASTNEWBRANCH( 98ll, L$1, (struct $7ASTNODE*)0ull );
+		ASTADD( vr$20 );
+		struct $7ASTNODE* vr$21 = ASTNEWLABEL( LABEL$1, -1ll );
+		ASTADD( vr$21 );
 	}
 	label$18:;
 	label$17:;
@@ -986,35 +1031,35 @@ void ASTGOSUBADDJUMPPTR( struct $8FBSYMBOL* PROC$1, struct $7ASTNODE* JUMPTB$1,
 	label$20:;
 	struct $8FBSYMBOL* LABEL$1;
 	ASTGOSUBADDINIT( PROC$1 );
-	if( ((int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 0ll) & (int64)-(*(int64*)((uint8*)&ENV$ + 400ll) == 0ll)) == 0ll ) goto label$23;
+	if( (((int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 0ll) | (int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 3ll)) & (int64)-(*(int64*)((uint8*)&ENV$ + 400ll) == 0ll)) == 0ll ) goto label$23;
 	{
-		struct $7ASTNODE* vr$5 = ASTBUILDVARINC( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 120ll), 1ll );
-		ASTADD( vr$5 );
-		struct $7ASTNODE* vr$6 = ASTNEWVAR( EXITLABEL$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-		struct $7ASTNODE* vr$7 = ASTNEWADDROF( vr$6 );
-		struct $7ASTNODE* vr$8 = ASTNEWSTACK( 88ll, vr$7 );
-		ASTADD( vr$8 );
+		struct $7ASTNODE* vr$7 = ASTBUILDVARINC( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 120ll), 1ll );
+		ASTADD( vr$7 );
+		struct $7ASTNODE* vr$8 = ASTNEWVAR( EXITLABEL$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$9 = ASTNEWADDROF( vr$8 );
+		struct $7ASTNODE* vr$10 = ASTNEWSTACK( 88ll, vr$9 );
+		ASTADD( vr$10 );
 		ASTADD( JUMPTB$1 );
 	}
 	goto label$22;
 	label$23:;
 	{
 		ASTGOSUBADDINIT( PROC$1 );
-		struct $8FBSYMBOL* vr$9 = SYMBADDLABEL( (uint8*)0ull, 4ll );
-		LABEL$1 = vr$9;
-		struct $7ASTNODE* vr$10 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
-		struct $7ASTNODE* vr$13 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-		struct $7ASTNODE* vr$14 = ASTNEWADDROF( vr$13 );
-		struct $7ASTNODE* vr$15 = RTLGOSUBPUSH( vr$14 );
-		struct $7ASTNODE* vr$16 = RTLSETJMP( vr$15 );
-		struct $7ASTNODE* vr$17 = ASTNEWBOP( 45ll, vr$16, vr$10, (struct $8FBSYMBOL*)0ull, 1ll );
-		struct $7ASTNODE* vr$18 = ASTBUILDBRANCH( vr$17, LABEL$1, 0ll, 0ll );
-		ASTADD( vr$18 );
-		ASTADD( JUMPTB$1 );
-		struct $7ASTNODE* vr$19 = ASTNEWLABEL( LABEL$1, -1ll );
-		ASTADD( vr$19 );
-		struct $7ASTNODE* vr$20 = ASTNEWBRANCH( 98ll, EXITLABEL$1, (struct $7ASTNODE*)0ull );
+		struct $8FBSYMBOL* vr$11 = SYMBADDLABEL( (uint8*)0ull, 4ll );
+		LABEL$1 = vr$11;
+		struct $7ASTNODE* vr$12 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$15 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$16 = ASTNEWADDROF( vr$15 );
+		struct $7ASTNODE* vr$17 = RTLGOSUBPUSH( vr$16 );
+		struct $7ASTNODE* vr$18 = RTLSETJMP( vr$17 );
+		struct $7ASTNODE* vr$19 = ASTNEWBOP( 45ll, vr$18, vr$12, (struct $8FBSYMBOL*)0ull, 1ll );
+		struct $7ASTNODE* vr$20 = ASTBUILDBRANCH( vr$19, LABEL$1, 0ll, 0ll );
 		ASTADD( vr$20 );
+		ASTADD( JUMPTB$1 );
+		struct $7ASTNODE* vr$21 = ASTNEWLABEL( LABEL$1, -1ll );
+		ASTADD( vr$21 );
+		struct $7ASTNODE* vr$22 = ASTNEWBRANCH( 98ll, EXITLABEL$1, (struct $7ASTNODE*)0ull );
+		ASTADD( vr$22 );
 	}
 	label$22:;
 	label$21:;
@@ -1027,40 +1072,40 @@ int64 ASTGOSUBADDRETURN( struct $8FBSYMBOL* PROC$1, struct $8FBSYMBOL* L$1 )
 	label$24:;
 	struct $8FBSYMBOL* LABEL$1;
 	ASTGOSUBADDINIT( PROC$1 );
-	if( ((int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 0ll) & (int64)-(*(int64*)((uint8*)&ENV$ + 400ll) == 0ll)) == 0ll ) goto label$27;
+	if( (((int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 0ll) | (int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 3ll)) & (int64)-(*(int64*)((uint8*)&ENV$ + 400ll) == 0ll)) == 0ll ) goto label$27;
 	{
-		struct $8FBSYMBOL* vr$4 = SYMBADDLABEL( (uint8*)0ull, 4ll );
-		LABEL$1 = vr$4;
-		struct $7ASTNODE* vr$5 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
-		struct $7ASTNODE* vr$8 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-		struct $7ASTNODE* vr$9 = ASTNEWBOP( 48ll, vr$8, vr$5, (struct $8FBSYMBOL*)0ull, 1ll );
-		struct $7ASTNODE* vr$10 = ASTBUILDBRANCH( vr$9, LABEL$1, 0ll, 0ll );
-		ASTADD( vr$10 );
-		struct $7ASTNODE* vr$13 = ASTBUILDVARINC( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 120ll), -1ll );
-		ASTADD( vr$13 );
+		struct $8FBSYMBOL* vr$6 = SYMBADDLABEL( (uint8*)0ull, 4ll );
+		LABEL$1 = vr$6;
+		struct $7ASTNODE* vr$7 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$10 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$11 = ASTNEWBOP( 48ll, vr$10, vr$7, (struct $8FBSYMBOL*)0ull, 1ll );
+		struct $7ASTNODE* vr$12 = ASTBUILDBRANCH( vr$11, LABEL$1, 0ll, 0ll );
+		ASTADD( vr$12 );
+		struct $7ASTNODE* vr$15 = ASTBUILDVARINC( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 120ll), -1ll );
+		ASTADD( vr$15 );
 		if( L$1 != (struct $8FBSYMBOL*)0ull ) goto label$29;
 		{
-			struct $7ASTNODE* vr$14 = ASTNEWBRANCH( 101ll, (struct $8FBSYMBOL*)0ull, (struct $7ASTNODE*)0ull );
-			ASTADD( vr$14 );
+			struct $7ASTNODE* vr$16 = ASTNEWBRANCH( 101ll, (struct $8FBSYMBOL*)0ull, (struct $7ASTNODE*)0ull );
+			ASTADD( vr$16 );
 		}
 		goto label$28;
 		label$29:;
 		{
-			struct $7ASTNODE* vr$15 = ASTNEWCONSTI( *(int64*)((uint8*)&ENV$ + 544ll), 8ll, (struct $8FBSYMBOL*)0ull );
-			struct $7ASTNODE* vr$16 = ASTNEWSTACK( 89ll, vr$15 );
-			ASTADD( vr$16 );
-			struct $7ASTNODE* vr$17 = ASTNEWBRANCH( 98ll, L$1, (struct $7ASTNODE*)0ull );
-			ASTADD( vr$17 );
+			struct $7ASTNODE* vr$17 = ASTNEWCONSTI( *(int64*)((uint8*)&ENV$ + 576ll), 8ll, (struct $8FBSYMBOL*)0ull );
+			struct $7ASTNODE* vr$18 = ASTNEWSTACK( 89ll, vr$17 );
+			ASTADD( vr$18 );
+			struct $7ASTNODE* vr$19 = ASTNEWBRANCH( 98ll, L$1, (struct $7ASTNODE*)0ull );
+			ASTADD( vr$19 );
 		}
 		label$28:;
-		struct $7ASTNODE* vr$18 = ASTNEWLABEL( LABEL$1, -1ll );
-		ASTADD( vr$18 );
-		struct $7ASTNODE* vr$19 = ASTNEWCONSTI( 16ll, 8ll, (struct $8FBSYMBOL*)0ull );
-		RTLERRORSETNUM( vr$19 );
+		struct $7ASTNODE* vr$20 = ASTNEWLABEL( LABEL$1, -1ll );
+		ASTADD( vr$20 );
+		struct $7ASTNODE* vr$21 = ASTNEWCONSTI( 16ll, 8ll, (struct $8FBSYMBOL*)0ull );
+		RTLERRORSETNUM( vr$21 );
 		if( *(int64*)((uint8*)&ENV$ + 312ll) == 0ll ) goto label$31;
 		{
-			struct $7ASTNODE* vr$22 = ASTNEWCONSTI( 16ll, 8ll, (struct $8FBSYMBOL*)0ull );
-			RTLERRORTHROW( vr$22, *(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8520ll), (uint8*)((uint8*)&ENV$ + 560ll) );
+			struct $7ASTNODE* vr$24 = ASTNEWCONSTI( 16ll, 8ll, (struct $8FBSYMBOL*)0ull );
+			RTLERRORTHROW( vr$24, *(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8560ll), (uint8*)((uint8*)&ENV$ + 592ll) );
 		}
 		label$31:;
 		label$30:;
@@ -1071,33 +1116,33 @@ int64 ASTGOSUBADDRETURN( struct $8FBSYMBOL* PROC$1, struct $8FBSYMBOL* L$1 )
 	{
 		if( L$1 != (struct $8FBSYMBOL*)0ull ) goto label$33;
 		{
-			struct $7ASTNODE* vr$25 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-			struct $7ASTNODE* vr$26 = ASTNEWADDROF( vr$25 );
-			int64 vr$27 = RTLGOSUBRETURN( vr$26 );
-			fb$result$1 = vr$27;
+			struct $7ASTNODE* vr$27 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+			struct $7ASTNODE* vr$28 = ASTNEWADDROF( vr$27 );
+			int64 vr$29 = RTLGOSUBRETURN( vr$28 );
+			fb$result$1 = vr$29;
 		}
 		goto label$32;
 		label$33:;
 		{
-			struct $8FBSYMBOL* vr$28 = SYMBADDLABEL( (uint8*)0ull, 4ll );
-			LABEL$1 = vr$28;
-			struct $7ASTNODE* vr$29 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
-			struct $7ASTNODE* vr$32 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-			struct $7ASTNODE* vr$33 = ASTNEWADDROF( vr$32 );
-			struct $7ASTNODE* vr$34 = RTLGOSUBPOP( vr$33 );
-			struct $7ASTNODE* vr$35 = ASTNEWBOP( 45ll, vr$34, vr$29, (struct $8FBSYMBOL*)0ull, 1ll );
-			struct $7ASTNODE* vr$36 = ASTBUILDBRANCH( vr$35, LABEL$1, 0ll, 0ll );
-			ASTADD( vr$36 );
-			struct $7ASTNODE* vr$37 = ASTNEWBRANCH( 98ll, L$1, (struct $7ASTNODE*)0ull );
-			ASTADD( vr$37 );
-			struct $7ASTNODE* vr$38 = ASTNEWLABEL( LABEL$1, -1ll );
+			struct $8FBSYMBOL* vr$30 = SYMBADDLABEL( (uint8*)0ull, 4ll );
+			LABEL$1 = vr$30;
+			struct $7ASTNODE* vr$31 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
+			struct $7ASTNODE* vr$34 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+			struct $7ASTNODE* vr$35 = ASTNEWADDROF( vr$34 );
+			struct $7ASTNODE* vr$36 = RTLGOSUBPOP( vr$35 );
+			struct $7ASTNODE* vr$37 = ASTNEWBOP( 45ll, vr$36, vr$31, (struct $8FBSYMBOL*)0ull, 1ll );
+			struct $7ASTNODE* vr$38 = ASTBUILDBRANCH( vr$37, LABEL$1, 0ll, 0ll );
 			ASTADD( vr$38 );
-			struct $7ASTNODE* vr$39 = ASTNEWCONSTI( 16ll, 8ll, (struct $8FBSYMBOL*)0ull );
-			RTLERRORSETNUM( vr$39 );
+			struct $7ASTNODE* vr$39 = ASTNEWBRANCH( 98ll, L$1, (struct $7ASTNODE*)0ull );
+			ASTADD( vr$39 );
+			struct $7ASTNODE* vr$40 = ASTNEWLABEL( LABEL$1, -1ll );
+			ASTADD( vr$40 );
+			struct $7ASTNODE* vr$41 = ASTNEWCONSTI( 16ll, 8ll, (struct $8FBSYMBOL*)0ull );
+			RTLERRORSETNUM( vr$41 );
 			if( *(int64*)((uint8*)&ENV$ + 312ll) == 0ll ) goto label$35;
 			{
-				struct $7ASTNODE* vr$42 = ASTNEWCONSTI( 16ll, 8ll, (struct $8FBSYMBOL*)0ull );
-				RTLERRORTHROW( vr$42, *(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8520ll), (uint8*)((uint8*)&ENV$ + 560ll) );
+				struct $7ASTNODE* vr$44 = ASTNEWCONSTI( 16ll, 8ll, (struct $8FBSYMBOL*)0ull );
+				RTLERRORTHROW( vr$44, *(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8560ll), (uint8*)((uint8*)&ENV$ + 592ll) );
 			}
 			label$35:;
 			label$34:;
@@ -1113,14 +1158,14 @@ int64 ASTGOSUBADDRETURN( struct $8FBSYMBOL* PROC$1, struct $8FBSYMBOL* L$1 )
 void ASTGOSUBADDEXIT( struct $8FBSYMBOL* PROC$1 )
 {
 	label$36:;
-	if( (*(int64*)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 96ll) & 4ll) == 0ll ) goto label$39;
+	if( (*(int64*)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 96ll) & 4ll) == 0ll ) goto label$39;
 	{
-		if( ((int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 0ll) & (int64)-(*(int64*)((uint8*)&ENV$ + 400ll) == 0ll)) != 0ll ) goto label$41;
+		if( (((int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 0ll) | (int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 3ll)) & (int64)-(*(int64*)((uint8*)&ENV$ + 400ll) == 0ll)) != 0ll ) goto label$41;
 		{
-			struct $7ASTNODE* vr$8 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 200ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-			struct $7ASTNODE* vr$9 = ASTNEWADDROF( vr$8 );
-			struct $7ASTNODE* vr$10 = RTLGOSUBEXIT( vr$9 );
-			ASTADD( vr$10 );
+			struct $7ASTNODE* vr$10 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $10FB_PROCEXT**)((uint8*)PROC$1 + 208ll) + 120ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+			struct $7ASTNODE* vr$11 = ASTNEWADDROF( vr$10 );
+			struct $7ASTNODE* vr$12 = RTLGOSUBEXIT( vr$11 );
+			ASTADD( vr$12 );
 		}
 		label$41:;
 		label$40:;
@@ -1133,7 +1178,7 @@ void ASTGOSUBADDEXIT( struct $8FBSYMBOL* PROC$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
