@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -630,7 +669,8 @@ struct $7ASTNODE* ASTNEWARG( struct $7ASTNODE*, struct $7ASTNODE*, int64, int64
 void ASTREPLACEINSTANCEARG( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
 struct $7ASTNODE* ASTNEWADDROF( struct $7ASTNODE* );
 struct $7ASTNODE* ASTNEWBRANCH( int64, struct $8FBSYMBOL*, struct $7ASTNODE* );
-struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
+typedef int64 $15AST_LINK_RETURN;
+struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, $15AST_LINK_RETURN );
 struct $7ASTNODE* ASTNEWLABEL( struct $8FBSYMBOL*, int64 );
 struct $7ASTNODE* ASTNEWMEM( int64, struct $7ASTNODE*, struct $7ASTNODE*, int64 );
 struct $7ASTNODE* ASTBUILDPTRCHK( struct $7ASTNODE* );
@@ -667,7 +707,7 @@ int64 SYMBHASDTOR( struct $8FBSYMBOL* );
 int64 TYPEHASDTOR( int64, struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBGETCOMPCTORHEAD( struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBGETCOMPDEFCTOR( struct $8FBSYMBOL* );
-struct $8FBSYMBOL* SYMBGETCOMPDTOR( struct $8FBSYMBOL* );
+struct $8FBSYMBOL* SYMBGETCOMPDTOR1( struct $8FBSYMBOL* );
 int64 SYMBCHECKACCESS( struct $8FBSYMBOL* );
 struct $7ASTNODE* RTLSTRDELETE( struct $7ASTNODE* );
 struct $7ASTNODE* RTLWSTRALLOC( struct $7ASTNODE* );
@@ -696,10 +736,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -733,6 +774,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -741,11 +786,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -798,7 +844,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -817,20 +863,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -871,8 +919,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -880,8 +931,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -928,6 +980,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -949,16 +1002,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 
 struct $7ASTNODE* _Z17ASTBUILDVARASSIGNP8FBSYMBOLu7INTEGERS1_( struct $8FBSYMBOL* LHS$1, int64 RHS$1, int64 OPTIONS$1 )
@@ -1009,7 +1067,7 @@ struct $7ASTNODE* ASTBUILDFAKEWSTRINGASSIGN( struct $8FBSYMBOL* SYM$1, struct $7
 	if( vr$1 == 0ll ) goto label$19;
 	{
 		struct $7ASTNODE* vr$3 = ASTREMSIDEFX( &EXPR$1 );
-		struct $7ASTNODE* vr$4 = ASTNEWLINK( T$1, vr$3, 0ll );
+		struct $7ASTNODE* vr$4 = ASTNEWLINK( T$1, vr$3, 2ll );
 		T$1 = vr$4;
 	}
 	label$19:;
@@ -1022,7 +1080,7 @@ struct $7ASTNODE* ASTBUILDFAKEWSTRINGASSIGN( struct $8FBSYMBOL* SYM$1, struct $7
 	T$1 = vr$9;
 	struct $7ASTNODE* vr$10 = ASTBUILDFAKEWSTRINGACCESS( SYM$1 );
 	struct $7ASTNODE* vr$11 = ASTNEWASSIGN( vr$10, EXPR$1, OPTIONS$1 );
-	struct $7ASTNODE* vr$12 = ASTNEWLINK( T$1, vr$11, 0ll );
+	struct $7ASTNODE* vr$12 = ASTNEWLINK( T$1, vr$11, 2ll );
 	T$1 = vr$12;
 	fb$result$1 = T$1;
 	label$17:;
@@ -1037,7 +1095,7 @@ struct $7ASTNODE* ASTBUILDVARINC( struct $8FBSYMBOL* LHS$1, int64 RHS$1 )
 	$9AST_OPOPT OPTIONS$1;
 	$6AST_OP OP$1;
 	OPTIONS$1 = 1ll;
-	if( ((*(int64*)((uint8*)LHS$1 + 48ll) & 511ll) & 480ll) == 0ll ) goto label$23;
+	if( ((*(int64*)((uint8*)LHS$1 + 56ll) & 511ll) & 480ll) == 0ll ) goto label$23;
 	{
 		OPTIONS$1 = OPTIONS$1 | 2ll;
 	}
@@ -1116,7 +1174,7 @@ struct $7ASTNODE* _Z19ASTBUILDVARDTORCALLP8FBSYMBOLu7INTEGER( struct $8FBSYMBOL*
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$35:;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	if( *(int64*)((uint8*)S$1 + 96ll) == 0ll ) goto label$38;
+	if( *(int64*)((uint8*)S$1 + 104ll) == 0ll ) goto label$38;
 	{
 		struct $7ASTNODE* vr$5 = ASTNEWVAR( S$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$6 = RTLARRAYERASE( vr$5, (int64)-((*(int64*)((uint8*)S$1 + 8ll) & 4ll) != 0ll), CHECK_ACCESS$1 );
@@ -1126,9 +1184,9 @@ struct $7ASTNODE* _Z19ASTBUILDVARDTORCALLP8FBSYMBOLu7INTEGER( struct $8FBSYMBOL*
 	label$38:;
 	{
 		{
-			int64 TMP$88$3;
-			TMP$88$3 = *(int64*)((uint8*)S$1 + 48ll) & 511ll;
-			if( TMP$88$3 != 17ll ) goto label$40;
+			int64 TMP$93$3;
+			TMP$93$3 = *(int64*)((uint8*)S$1 + 56ll) & 511ll;
+			if( TMP$93$3 != 17ll ) goto label$40;
 			label$41:;
 			{
 				struct $7ASTNODE* vr$9 = ASTNEWVAR( S$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
@@ -1137,7 +1195,7 @@ struct $7ASTNODE* _Z19ASTBUILDVARDTORCALLP8FBSYMBOLu7INTEGER( struct $8FBSYMBOL*
 			}
 			goto label$39;
 			label$40:;
-			if( TMP$88$3 != 39ll ) goto label$42;
+			if( TMP$93$3 != 39ll ) goto label$42;
 			label$43:;
 			{
 				struct $7ASTNODE* vr$11 = ASTNEWVAR( S$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
@@ -1152,7 +1210,7 @@ struct $7ASTNODE* _Z19ASTBUILDVARDTORCALLP8FBSYMBOLu7INTEGER( struct $8FBSYMBOL*
 				{
 					if( CHECK_ACCESS$1 == 0ll ) goto label$48;
 					{
-						struct $8FBSYMBOL* vr$15 = SYMBGETCOMPDTOR( *(struct $8FBSYMBOL**)((uint8*)S$1 + 56ll) );
+						struct $8FBSYMBOL* vr$15 = SYMBGETCOMPDTOR1( *(struct $8FBSYMBOL**)((uint8*)S$1 + 64ll) );
 						int64 vr$16 = SYMBCHECKACCESS( vr$15 );
 						if( vr$16 != 0ll ) goto label$50;
 						{
@@ -1164,7 +1222,7 @@ struct $7ASTNODE* _Z19ASTBUILDVARDTORCALLP8FBSYMBOLu7INTEGER( struct $8FBSYMBOL*
 					label$48:;
 					label$47:;
 					struct $7ASTNODE* vr$17 = ASTNEWVAR( S$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-					struct $7ASTNODE* vr$19 = ASTBUILDDTORCALL( *(struct $8FBSYMBOL**)((uint8*)S$1 + 56ll), vr$17, 0ll );
+					struct $7ASTNODE* vr$19 = ASTBUILDDTORCALL( *(struct $8FBSYMBOL**)((uint8*)S$1 + 64ll), vr$17, 0ll );
 					fb$result$1 = vr$19;
 				}
 				label$46:;
@@ -1243,9 +1301,9 @@ struct $7ASTNODE* ASTBUILDVARFIELD( struct $8FBSYMBOL* SYM$1, struct $8FBSYMBOL*
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$63:;
 	struct $7ASTNODE* N$1;
-	if( ((int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 262144ll) != 0ll) | (int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 512ll) != 0ll)) == 0ll ) goto label$66;
+	if( ((int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 65536ll) != 0ll) | (int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 512ll) != 0ll)) == 0ll ) goto label$66;
 	{
-		struct $7ASTNODE* vr$22 = ASTNEWVAR( SYM$1, 0ll, (((*(int64*)((uint8*)SYM$1 + 48ll) & 31ll) | ((*(int64*)((uint8*)SYM$1 + 48ll) & 480ll) + 32ll)) | ((*(int64*)((uint8*)SYM$1 + 48ll) & 261632ll) << (1ll & 63ll))) | (*(int64*)((uint8*)SYM$1 + 48ll) & 32505856ll), *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 56ll) );
+		struct $7ASTNODE* vr$22 = ASTNEWVAR( SYM$1, 0ll, (((*(int64*)((uint8*)SYM$1 + 56ll) & 31ll) | ((*(int64*)((uint8*)SYM$1 + 56ll) & 480ll) + 32ll)) | ((*(int64*)((uint8*)SYM$1 + 56ll) & 261632ll) << (1ll & 63ll))) | (*(int64*)((uint8*)SYM$1 + 56ll) & 32505856ll), *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 64ll) );
 		struct $7ASTNODE* vr$23 = ASTNEWDEREF( vr$22, 2147483648ll, (struct $8FBSYMBOL*)0ull, 0ll );
 		N$1 = vr$23;
 	}
@@ -1258,14 +1316,14 @@ struct $7ASTNODE* ASTBUILDVARFIELD( struct $8FBSYMBOL* SYM$1, struct $8FBSYMBOL*
 	label$65:;
 	if( FLD$1 == (struct $8FBSYMBOL*)0ull ) goto label$68;
 	{
-		OFFSET$1 = OFFSET$1 + *(int64*)((uint8*)FLD$1 + 80ll);
-		struct $7ASTNODE* vr$29 = _Z19ASTBUILDDEREFADDROFP7ASTNODExu7INTEGERP8FBSYMBOLS3_( N$1, OFFSET$1, *(int64*)((uint8*)FLD$1 + 48ll), *(struct $8FBSYMBOL**)((uint8*)FLD$1 + 56ll), FLD$1 );
+		OFFSET$1 = OFFSET$1 + *(int64*)((uint8*)FLD$1 + 88ll);
+		struct $7ASTNODE* vr$29 = _Z19ASTBUILDDEREFADDROFP7ASTNODExu7INTEGERP8FBSYMBOLS3_( N$1, OFFSET$1, *(int64*)((uint8*)FLD$1 + 56ll), *(struct $8FBSYMBOL**)((uint8*)FLD$1 + 64ll), FLD$1 );
 		N$1 = vr$29;
 	}
 	goto label$67;
 	label$68:;
 	{
-		struct $7ASTNODE* vr$32 = _Z19ASTBUILDDEREFADDROFP7ASTNODExu7INTEGERP8FBSYMBOLS3_( N$1, OFFSET$1, *(int64*)((uint8*)SYM$1 + 48ll), *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 56ll), (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$32 = _Z19ASTBUILDDEREFADDROFP7ASTNODExu7INTEGERP8FBSYMBOLS3_( N$1, OFFSET$1, *(int64*)((uint8*)SYM$1 + 56ll), *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 64ll), (struct $8FBSYMBOL*)0ull );
 		N$1 = vr$32;
 	}
 	label$67:;
@@ -1286,7 +1344,7 @@ struct $7ASTNODE* ASTBUILDTEMPVARCLEAR( struct $8FBSYMBOL* SYM$1 )
 	}
 	label$72:;
 	label$71:;
-	struct $7ASTNODE* vr$4 = ASTNEWCONSTI( *(int64*)((uint8*)SYM$1 + 72ll), 8ll, (struct $8FBSYMBOL*)0ull );
+	struct $7ASTNODE* vr$4 = ASTNEWCONSTI( *(int64*)((uint8*)SYM$1 + 80ll), 8ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$5 = ASTNEWVAR( SYM$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$6 = ASTNEWMEM( 107ll, vr$5, vr$4, 0ll );
 	fb$result$1 = vr$6;
@@ -1300,16 +1358,16 @@ struct $7ASTNODE* ASTBUILDWHILECOUNTERBEGIN( struct $7ASTNODE* TREE$1, struct $8
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$73:;
 	struct $7ASTNODE* vr$1 = _Z17ASTBUILDVARASSIGNP8FBSYMBOLP7ASTNODEu7INTEGER( CNT$1, INITEXPR$1, 0ll );
-	struct $7ASTNODE* vr$2 = ASTNEWLINK( TREE$1, vr$1, -1ll );
+	struct $7ASTNODE* vr$2 = ASTNEWLINK( TREE$1, vr$1, 0ll );
 	TREE$1 = vr$2;
 	struct $7ASTNODE* vr$3 = ASTNEWLABEL( LABEL$1, FLUSH_LABEL$1 );
-	struct $7ASTNODE* vr$4 = ASTNEWLINK( TREE$1, vr$3, -1ll );
+	struct $7ASTNODE* vr$4 = ASTNEWLINK( TREE$1, vr$3, 0ll );
 	TREE$1 = vr$4;
 	struct $7ASTNODE* vr$5 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$6 = ASTNEWVAR( CNT$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$7 = ASTNEWBOP( 45ll, vr$6, vr$5, (struct $8FBSYMBOL*)0ull, 1ll );
 	struct $7ASTNODE* vr$8 = ASTBUILDBRANCH( vr$7, EXITLABEL$1, -1ll, 0ll );
-	struct $7ASTNODE* vr$9 = ASTNEWLINK( TREE$1, vr$8, -1ll );
+	struct $7ASTNODE* vr$9 = ASTNEWLINK( TREE$1, vr$8, 0ll );
 	TREE$1 = vr$9;
 	fb$result$1 = TREE$1;
 	label$74:;
@@ -1322,13 +1380,13 @@ struct $7ASTNODE* ASTBUILDWHILECOUNTEREND( struct $7ASTNODE* TREE$1, struct $8FB
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$75:;
 	struct $7ASTNODE* vr$1 = ASTBUILDVARINC( CNT$1, -1ll );
-	struct $7ASTNODE* vr$2 = ASTNEWLINK( TREE$1, vr$1, -1ll );
+	struct $7ASTNODE* vr$2 = ASTNEWLINK( TREE$1, vr$1, 0ll );
 	TREE$1 = vr$2;
 	struct $7ASTNODE* vr$3 = ASTNEWBRANCH( 98ll, LABEL$1, (struct $7ASTNODE*)0ull );
-	struct $7ASTNODE* vr$4 = ASTNEWLINK( TREE$1, vr$3, -1ll );
+	struct $7ASTNODE* vr$4 = ASTNEWLINK( TREE$1, vr$3, 0ll );
 	TREE$1 = vr$4;
 	struct $7ASTNODE* vr$5 = ASTNEWLABEL( EXITLABEL$1, FLUSH_LABEL$1 );
-	struct $7ASTNODE* vr$6 = ASTNEWLINK( TREE$1, vr$5, -1ll );
+	struct $7ASTNODE* vr$6 = ASTNEWLINK( TREE$1, vr$5, 0ll );
 	TREE$1 = vr$6;
 	fb$result$1 = TREE$1;
 	label$76:;
@@ -1341,10 +1399,10 @@ struct $7ASTNODE* ASTBUILDFORBEGIN( struct $7ASTNODE* TREE$1, struct $8FBSYMBOL*
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$77:;
 	struct $7ASTNODE* vr$1 = _Z17ASTBUILDVARASSIGNP8FBSYMBOLu7INTEGERS1_( CNT$1, INIVALUE$1, 0ll );
-	struct $7ASTNODE* vr$2 = ASTNEWLINK( TREE$1, vr$1, -1ll );
+	struct $7ASTNODE* vr$2 = ASTNEWLINK( TREE$1, vr$1, 0ll );
 	TREE$1 = vr$2;
 	struct $7ASTNODE* vr$3 = ASTNEWLABEL( LABEL$1, FLUSH_LABEL$1 );
-	struct $7ASTNODE* vr$4 = ASTNEWLINK( TREE$1, vr$3, -1ll );
+	struct $7ASTNODE* vr$4 = ASTNEWLINK( TREE$1, vr$3, 0ll );
 	TREE$1 = vr$4;
 	fb$result$1 = TREE$1;
 	label$78:;
@@ -1357,12 +1415,12 @@ struct $7ASTNODE* ASTBUILDFOREND( struct $7ASTNODE* TREE$1, struct $8FBSYMBOL* C
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$79:;
 	struct $7ASTNODE* vr$1 = ASTBUILDVARINC( CNT$1, 1ll );
-	struct $7ASTNODE* vr$2 = ASTNEWLINK( TREE$1, vr$1, -1ll );
+	struct $7ASTNODE* vr$2 = ASTNEWLINK( TREE$1, vr$1, 0ll );
 	TREE$1 = vr$2;
 	struct $7ASTNODE* vr$3 = ASTNEWVAR( CNT$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$4 = ASTNEWBOP( 45ll, vr$3, ENDVALUE$1, (struct $8FBSYMBOL*)0ull, 1ll );
 	struct $7ASTNODE* vr$5 = ASTBUILDBRANCH( vr$4, LABEL$1, 0ll, 0ll );
-	struct $7ASTNODE* vr$6 = ASTNEWLINK( TREE$1, vr$5, -1ll );
+	struct $7ASTNODE* vr$6 = ASTNEWLINK( TREE$1, vr$5, 0ll );
 	TREE$1 = vr$6;
 	fb$result$1 = TREE$1;
 	label$80:;
@@ -1376,7 +1434,7 @@ struct $7ASTNODE* ASTBUILDVTABLELOOKUP( struct $8FBSYMBOL* PROC$1, struct $7ASTN
 	label$81:;
 	struct $7ASTNODE* P$1;
 	int64 VTABLEINDEX$1;
-	if( (*(int64*)((uint8*)PROC$1 + 8ll) & 536870912ll) == 0ll ) goto label$84;
+	if( (*(int64*)((uint8*)PROC$1 + 16ll) & 256ll) == 0ll ) goto label$84;
 	{
 		int64 vr$3 = SYMBPROCGETVTABLEINDEX( PROC$1 );
 		VTABLEINDEX$1 = vr$3;
@@ -1398,7 +1456,7 @@ struct $7ASTNODE* ASTBUILDVTABLELOOKUP( struct $8FBSYMBOL* PROC$1, struct $7ASTN
 		P$1 = vr$13;
 		if( *(int64*)((uint8*)&ENV$ + 352ll) == 0ll ) goto label$86;
 		{
-			if( (*(int64*)((uint8*)PROC$1 + 8ll) & 1073741824ll) == 0ll ) goto label$88;
+			if( (*(int64*)((uint8*)PROC$1 + 16ll) & 512ll) == 0ll ) goto label$88;
 			{
 				struct $7ASTNODE* vr$16 = ASTBUILDPTRCHK( P$1 );
 				P$1 = vr$16;
@@ -1427,7 +1485,7 @@ struct $7ASTNODE* ASTBUILDCALL( struct $8FBSYMBOL* PROC$1, struct $7ASTNODE* ARG
 	label$89:;
 	struct $7ASTNODE* P$1;
 	struct $7ASTNODE* PTREXPR$1;
-	if( (*(int64*)((uint8*)PROC$1 + 8ll) & 536870912ll) == 0ll ) goto label$92;
+	if( (*(int64*)((uint8*)PROC$1 + 16ll) & 256ll) == 0ll ) goto label$92;
 	{
 		struct $7ASTNODE* vr$3 = ASTBUILDVTABLELOOKUP( PROC$1, ARG1$1 );
 		PTREXPR$1 = vr$3;
@@ -1506,7 +1564,7 @@ struct $7ASTNODE* ASTBUILDCTORCALL( struct $8FBSYMBOL* SYM$1, struct $7ASTNODE*
 	struct $7ASTNODE* vr$2 = ASTNEWCALL( CTOR$1, (struct $7ASTNODE*)0ull );
 	PROC$1 = vr$2;
 	ASTNEWARG( PROC$1, THISEXPR$1, 2147483648ll, -1ll );
-	PARAMS$1 = (int64)*(int16*)((uint8*)CTOR$1 + 112ll) + -1ll;
+	PARAMS$1 = (int64)*(int16*)((uint8*)CTOR$1 + 120ll) + -1ll;
 	label$109:;
 	if( PARAMS$1 <= 0ll ) goto label$110;
 	{
@@ -1527,7 +1585,7 @@ struct $7ASTNODE* ASTBUILDDTORCALL( struct $8FBSYMBOL* SYM$1, struct $7ASTNODE*
 	label$111:;
 	struct $8FBSYMBOL* DTOR$1;
 	struct $7ASTNODE* CALLEXPR$1;
-	struct $8FBSYMBOL* vr$1 = SYMBGETCOMPDTOR( SYM$1 );
+	struct $8FBSYMBOL* vr$1 = SYMBGETCOMPDTOR1( SYM$1 );
 	DTOR$1 = vr$1;
 	if( IGNORE_VIRTUAL$1 == 0ll ) goto label$114;
 	{
@@ -1568,7 +1626,7 @@ struct $7ASTNODE* ASTCALLCTORTOCALL( struct $7ASTNODE* N$1 )
 	struct $7ASTNODE* PROCEXPR$1;
 	SYM$1 = *(struct $8FBSYMBOL**)((uint8*)*(struct $7ASTNODE**)((uint8*)N$1 + 120ll) + 24ll);
 	PROCEXPR$1 = *(struct $7ASTNODE**)((uint8*)N$1 + 112ll);
-	struct $7ASTNODE* vr$5 = ASTFAKEINSTPTR( *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 56ll) );
+	struct $7ASTNODE* vr$5 = ASTFAKEINSTPTR( *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 64ll) );
 	ASTREPLACEINSTANCEARG( PROCEXPR$1, vr$5, 1ll );
 	ASTDELTREE( *(struct $7ASTNODE**)((uint8*)N$1 + 120ll) );
 	ASTDTORLISTDEL( SYM$1 );
@@ -1619,7 +1677,7 @@ struct $7ASTNODE* ASTBUILDIMPLICITCTORCALL( struct $8FBSYMBOL* SUBTYPE$1, struct
 	ASTNEWARG( PROCEXPR$1, vr$7, 2147483648ll, 1ll );
 	ASTNEWARG( PROCEXPR$1, EXPR$1, 2147483648ll, ARG_MODE$1 );
 	int64 PARAMS$1;
-	PARAMS$1 = (int64)*(int16*)((uint8*)PROC$1 + 112ll) + -2ll;
+	PARAMS$1 = (int64)*(int16*)((uint8*)PROC$1 + 120ll) + -2ll;
 	label$129:;
 	if( PARAMS$1 <= 0ll ) goto label$130;
 	{
@@ -1640,7 +1698,7 @@ struct $7ASTNODE* ASTBUILDIMPLICITCTORCALLEX( struct $8FBSYMBOL* SYM$1, struct $
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$131:;
 	struct $8FBSYMBOL* SUBTYPE$1;
-	SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 56ll);
+	SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 64ll);
 	if( *(int64*)EXPR$1 != 10ll ) goto label$134;
 	{
 		if( *(struct $8FBSYMBOL**)((uint8*)EXPR$1 + 16ll) != SUBTYPE$1 ) goto label$136;
@@ -1666,7 +1724,7 @@ struct $7ASTNODE* ASTBUILDPROCADDROF( struct $8FBSYMBOL* PROC$1 )
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$137:;
-	*($12FB_SYMBSTATS*)((uint8*)PROC$1 + 16ll) = *(int64*)((uint8*)PROC$1 + 16ll) | 2ll;
+	*($12FB_SYMBSTATS*)((uint8*)PROC$1 + 24ll) = *(int64*)((uint8*)PROC$1 + 24ll) | 2ll;
 	struct $7ASTNODE* vr$4 = ASTNEWVAR( PROC$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$5 = ASTNEWADDROF( vr$4 );
 	fb$result$1 = vr$5;
@@ -1682,7 +1740,7 @@ struct $7ASTNODE* ASTBUILDPROCRESULTVAR( struct $8FBSYMBOL* PROC$1, struct $8FBS
 	int64 vr$1 = SYMBPROCRETURNSONSTACK( PROC$1 );
 	if( vr$1 == 0ll ) goto label$142;
 	{
-		struct $7ASTNODE* vr$3 = ASTNEWVAR( RES$1, 0ll, 52ll, *(struct $8FBSYMBOL**)((uint8*)RES$1 + 56ll) );
+		struct $7ASTNODE* vr$3 = ASTNEWVAR( RES$1, 0ll, 52ll, *(struct $8FBSYMBOL**)((uint8*)RES$1 + 64ll) );
 		struct $7ASTNODE* vr$4 = ASTNEWDEREF( vr$3, 2147483648ll, (struct $8FBSYMBOL*)0ull, 0ll );
 		fb$result$1 = vr$4;
 	}
@@ -1704,9 +1762,9 @@ struct $7ASTNODE* ASTBUILDTYPEINICTORLIST( struct $8FBSYMBOL* SYM$1 )
 	label$143:;
 	struct $7ASTNODE* TREE$1;
 	__builtin_memset( &TREE$1, 0, 8ll );
-	struct $7ASTNODE* vr$4 = ASTTYPEINIBEGIN( *(int64*)((uint8*)SYM$1 + 48ll), *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 56ll), -1ll, 0ll );
+	struct $7ASTNODE* vr$4 = ASTTYPEINIBEGIN( *(int64*)((uint8*)SYM$1 + 56ll), *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 64ll), -1ll, 0ll );
 	TREE$1 = vr$4;
-	ASTTYPEINIADDCTORLIST( TREE$1, SYM$1, *(int64*)((uint8*)SYM$1 + 120ll), 2147483648ll, (struct $8FBSYMBOL*)0ull );
+	ASTTYPEINIADDCTORLIST( TREE$1, SYM$1, *(int64*)((uint8*)SYM$1 + 128ll), 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	ASTTYPEINIEND( TREE$1, -1ll );
 	fb$result$1 = TREE$1;
 	label$144:;
@@ -1723,7 +1781,7 @@ struct $7ASTNODE* ASTBUILDMULTIDEREF( int64 CNT$1, struct $7ASTNODE* EXPR$1, int
 	{
 		if( (DTYPE$1 & 480ll) != 0ll ) goto label$150;
 		{
-			if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 198776ll) != (struct $8FBSYMBOL*)0ull ) goto label$152;
+			if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 198816ll) != (struct $8FBSYMBOL*)0ull ) goto label$152;
 			{
 				ERRREPORT( 28ll, -1ll, (uint8*)0ull );
 				goto label$148;
@@ -1761,18 +1819,18 @@ struct $7ASTNODE* ASTBUILDMULTIDEREF( int64 CNT$1, struct $7ASTNODE* EXPR$1, int
 		{
 			DTYPE$1 = (((DTYPE$1 & 31ll) | ((DTYPE$1 & 480ll) + -32ll)) | (((DTYPE$1 & 261632ll) >> (1ll & 63ll)) & 261632ll)) | (DTYPE$1 & 32505856ll);
 			{
-				int64 TMP$89$4;
-				int64 TMP$90$4;
+				int64 TMP$94$4;
+				int64 TMP$95$4;
 				if( (DTYPE$1 & 480ll) == 0ll ) goto label$157;
-				TMP$89$4 = 24ll;
+				TMP$94$4 = 24ll;
 				goto label$166;
 				label$157:;
-				TMP$89$4 = DTYPE$1 & 31ll;
+				TMP$94$4 = DTYPE$1 & 31ll;
 				label$166:;
-				TMP$90$4 = TMP$89$4;
-				if( TMP$90$4 == 0ll ) goto label$160;
+				TMP$95$4 = TMP$94$4;
+				if( TMP$95$4 == 0ll ) goto label$160;
 				label$161:;
-				if( TMP$90$4 != 23ll ) goto label$159;
+				if( TMP$95$4 != 23ll ) goto label$159;
 				label$160:;
 				{
 					ERRREPORT( 71ll, -1ll, (uint8*)0ull );
@@ -1780,7 +1838,7 @@ struct $7ASTNODE* ASTBUILDMULTIDEREF( int64 CNT$1, struct $7ASTNODE* EXPR$1, int
 				}
 				goto label$158;
 				label$159:;
-				if( TMP$90$4 != 22ll ) goto label$162;
+				if( TMP$95$4 != 22ll ) goto label$162;
 				label$163:;
 				{
 					ERRREPORT( 20ll, -1ll, (uint8*)0ull );
@@ -1811,14 +1869,17 @@ struct $7ASTNODE* ASTBUILDMULTIDEREF( int64 CNT$1, struct $7ASTNODE* EXPR$1, int
 
 struct $7ASTNODE* ASTBUILDARRAYDESCINITREE( struct $8FBSYMBOL* DESC$1, struct $8FBSYMBOL* ARRAY$1, struct $7ASTNODE* ARRAY_EXPR$1 )
 {
-	int64 TMP$91$1;
-	int64 TMP$92$1;
+	int64 TMP$96$1;
+	int64 TMP$97$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$167:;
 	struct $7ASTNODE* TREE$1;
 	int64 DTYPE$1;
 	int64 DIMENSIONS$1;
+	int64 MAX_DIMENSIONS$1;
+	int64 FLAGS$1;
+	FLAGS$1 = 0ll;
 	struct $8FBSYMBOL* ELM$1;
 	struct $8FBSYMBOL* DIMTB$1;
 	struct $8FBSYMBOL* SUBTYPE$1;
@@ -1829,11 +1890,11 @@ struct $7ASTNODE* ASTBUILDARRAYDESCINITREE( struct $8FBSYMBOL* DESC$1, struct $8
 	}
 	label$170:;
 	label$169:;
-	struct $7ASTNODE* vr$13 = ASTTYPEINIBEGIN( *(int64*)((uint8*)DESC$1 + 48ll), *(struct $8FBSYMBOL**)((uint8*)DESC$1 + 56ll), (int64)-(*(int64*)DESC$1 != 12ll), *(int64*)((uint8*)DESC$1 + 80ll) );
+	struct $7ASTNODE* vr$13 = ASTTYPEINIBEGIN( *(int64*)((uint8*)DESC$1 + 56ll), *(struct $8FBSYMBOL**)((uint8*)DESC$1 + 64ll), (int64)-(*(int64*)DESC$1 != 12ll), *(int64*)((uint8*)DESC$1 + 88ll) );
 	TREE$1 = vr$13;
-	DTYPE$1 = *(int64*)((uint8*)ARRAY$1 + 48ll);
-	SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)ARRAY$1 + 56ll);
-	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)DESC$1 + 56ll) + 96ll);
+	DTYPE$1 = *(int64*)((uint8*)ARRAY$1 + 56ll);
+	SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)ARRAY$1 + 64ll);
+	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)DESC$1 + 64ll) + 104ll);
 	if( (*(int64*)((uint8*)ARRAY$1 + 8ll) & 4ll) == 0ll ) goto label$172;
 	{
 		struct $7ASTNODE* vr$29 = ASTNEWCONSTI( 0ll, (((DTYPE$1 & 31ll) | ((DTYPE$1 & 480ll) + 32ll)) | ((DTYPE$1 & 261632ll) << (1ll & 63ll))) | (DTYPE$1 & 32505856ll), SUBTYPE$1 );
@@ -1854,92 +1915,100 @@ struct $7ASTNODE* ASTBUILDARRAYDESCINITREE( struct $8FBSYMBOL* DESC$1, struct $8
 		label$173:;
 		struct $7ASTNODE* vr$31 = ASTNEWADDROF( ARRAY_EXPR$1 );
 		ARRAY_EXPR$1 = vr$31;
+		FLAGS$1 = FLAGS$1 | 32ll;
 	}
 	label$171:;
 	ASTTYPEINISCOPEBEGIN( TREE$1, DESC$1, 0ll );
 	if( (*(int64*)((uint8*)ARRAY$1 + 8ll) & 4ll) == 0ll ) goto label$175;
-	TMP$91$1 = 0ll;
+	TMP$96$1 = 0ll;
 	goto label$187;
 	label$175:;
-	TMP$91$1 = *(int64*)((uint8*)ARRAY$1 + 112ll);
+	TMP$96$1 = *(int64*)((uint8*)ARRAY$1 + 120ll);
 	label$187:;
-	struct $7ASTNODE* vr$35 = ASTNEWCONSTI( TMP$91$1, 8ll, (struct $8FBSYMBOL*)0ull );
-	struct $7ASTNODE* vr$36 = ASTCLONETREE( ARRAY_EXPR$1 );
-	struct $7ASTNODE* vr$37 = ASTNEWBOP( 28ll, vr$36, vr$35, (struct $8FBSYMBOL*)0ull, 1ll );
-	ASTTYPEINIADDASSIGN( TREE$1, vr$37, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 296ll);
+	struct $7ASTNODE* vr$36 = ASTNEWCONSTI( TMP$96$1, 8ll, (struct $8FBSYMBOL*)0ull );
+	struct $7ASTNODE* vr$37 = ASTCLONETREE( ARRAY_EXPR$1 );
+	struct $7ASTNODE* vr$38 = ASTNEWBOP( 28ll, vr$37, vr$36, (struct $8FBSYMBOL*)0ull, 1ll );
+	ASTTYPEINIADDASSIGN( TREE$1, vr$38, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 312ll);
 	ASTTYPEINIADDASSIGN( TREE$1, ARRAY_EXPR$1, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 296ll);
+	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 312ll);
 	if( (*(int64*)((uint8*)ARRAY$1 + 8ll) & 4ll) == 0ll ) goto label$176;
-	TMP$92$1 = 0ll;
+	TMP$97$1 = 0ll;
 	goto label$188;
 	label$176:;
-	int64 vr$42 = SYMBGETREALSIZE( ARRAY$1 );
-	TMP$92$1 = vr$42;
+	int64 vr$43 = SYMBGETREALSIZE( ARRAY$1 );
+	TMP$97$1 = vr$43;
 	label$188:;
-	struct $7ASTNODE* vr$43 = ASTNEWCONSTI( TMP$92$1, 8ll, (struct $8FBSYMBOL*)0ull );
-	ASTTYPEINIADDASSIGN( TREE$1, vr$43, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 296ll);
-	struct $7ASTNODE* vr$46 = ASTNEWCONSTI( *(int64*)((uint8*)ARRAY$1 + 72ll), 8ll, (struct $8FBSYMBOL*)0ull );
-	ASTTYPEINIADDASSIGN( TREE$1, vr$46, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 296ll);
-	DIMENSIONS$1 = *(int64*)((uint8*)ARRAY$1 + 96ll);
+	struct $7ASTNODE* vr$44 = ASTNEWCONSTI( TMP$97$1, 8ll, (struct $8FBSYMBOL*)0ull );
+	ASTTYPEINIADDASSIGN( TREE$1, vr$44, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 312ll);
+	struct $7ASTNODE* vr$47 = ASTNEWCONSTI( *(int64*)((uint8*)ARRAY$1 + 80ll), 8ll, (struct $8FBSYMBOL*)0ull );
+	ASTTYPEINIADDASSIGN( TREE$1, vr$47, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 312ll);
+	DIMENSIONS$1 = *(int64*)((uint8*)ARRAY$1 + 104ll);
 	if( DIMENSIONS$1 != -1ll ) goto label$178;
 	{
 		DIMENSIONS$1 = 0ll;
+		MAX_DIMENSIONS$1 = 8ll;
 	}
 	goto label$177;
 	label$178:;
 	{
+		MAX_DIMENSIONS$1 = DIMENSIONS$1;
+		FLAGS$1 = FLAGS$1 | 16ll;
 	}
 	label$177:;
-	struct $7ASTNODE* vr$49 = ASTNEWCONSTI( DIMENSIONS$1, 8ll, (struct $8FBSYMBOL*)0ull );
-	ASTTYPEINIADDASSIGN( TREE$1, vr$49, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 296ll);
+	struct $7ASTNODE* vr$51 = ASTNEWCONSTI( DIMENSIONS$1, 8ll, (struct $8FBSYMBOL*)0ull );
+	ASTTYPEINIADDASSIGN( TREE$1, vr$51, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 312ll);
+	FLAGS$1 = FLAGS$1 | (MAX_DIMENSIONS$1 & 15ll);
+	struct $7ASTNODE* vr$55 = ASTNEWCONSTI( FLAGS$1, 8ll, (struct $8FBSYMBOL*)0ull );
+	ASTTYPEINIADDASSIGN( TREE$1, vr$55, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+	ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 312ll);
 	struct $8FBSYMBOL* DIMTBFIELD$1;
 	DIMTBFIELD$1 = ELM$1;
-	DIMTB$1 = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)ELM$1 + 56ll) + 96ll);
+	DIMTB$1 = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)ELM$1 + 64ll) + 104ll);
 	ASTTYPEINISCOPEBEGIN( TREE$1, DIMTBFIELD$1, -1ll );
-	if( (*(int64*)((uint8*)ARRAY$1 + 8ll) & 65540ll) != 0ll ) goto label$180;
+	if( (*(int64*)((uint8*)ARRAY$1 + 8ll) & 16388ll) != 0ll ) goto label$180;
 	{
 		{
 			int64 I$3;
 			I$3 = 0ll;
-			int64 TMP$93$3;
-			TMP$93$3 = *(int64*)((uint8*)ARRAY$1 + 96ll) + -1ll;
+			int64 TMP$98$3;
+			TMP$98$3 = *(int64*)((uint8*)ARRAY$1 + 104ll) + -1ll;
 			goto label$181;
 			label$184:;
 			{
 				ELM$1 = DIMTB$1;
 				ASTTYPEINISCOPEBEGIN( TREE$1, DIMTBFIELD$1, 0ll );
-				struct $7ASTNODE* vr$65 = ASTNEWCONSTI( (*(int64*)((uint8*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 104ll) + (I$3 << (4ll & 63ll))) + 8ll) - *(int64*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 104ll) + (I$3 << (4ll & 63ll)))) + 1ll, 8ll, (struct $8FBSYMBOL*)0ull );
-				ASTTYPEINIADDASSIGN( TREE$1, vr$65, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-				ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 296ll);
-				struct $7ASTNODE* vr$70 = ASTNEWCONSTI( *(int64*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 104ll) + (I$3 << (4ll & 63ll))), 8ll, (struct $8FBSYMBOL*)0ull );
-				ASTTYPEINIADDASSIGN( TREE$1, vr$70, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-				ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 296ll);
-				struct $7ASTNODE* vr$75 = ASTNEWCONSTI( *(int64*)((uint8*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 104ll) + (I$3 << (4ll & 63ll))) + 8ll), 8ll, (struct $8FBSYMBOL*)0ull );
-				ASTTYPEINIADDASSIGN( TREE$1, vr$75, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+				struct $7ASTNODE* vr$71 = ASTNEWCONSTI( (*(int64*)((uint8*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 112ll) + (I$3 << (4ll & 63ll))) + 8ll) - *(int64*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 112ll) + (I$3 << (4ll & 63ll)))) + 1ll, 8ll, (struct $8FBSYMBOL*)0ull );
+				ASTTYPEINIADDASSIGN( TREE$1, vr$71, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+				ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 312ll);
+				struct $7ASTNODE* vr$76 = ASTNEWCONSTI( *(int64*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 112ll) + (I$3 << (4ll & 63ll))), 8ll, (struct $8FBSYMBOL*)0ull );
+				ASTTYPEINIADDASSIGN( TREE$1, vr$76, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+				ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 312ll);
+				struct $7ASTNODE* vr$81 = ASTNEWCONSTI( *(int64*)((uint8*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 112ll) + (I$3 << (4ll & 63ll))) + 8ll), 8ll, (struct $8FBSYMBOL*)0ull );
+				ASTTYPEINIADDASSIGN( TREE$1, vr$81, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 				ASTTYPEINISCOPEEND( TREE$1, DIMTBFIELD$1 );
 			}
 			label$182:;
 			I$3 = I$3 + 1ll;
 			label$181:;
-			if( I$3 <= TMP$93$3 ) goto label$184;
+			if( I$3 <= TMP$98$3 ) goto label$184;
 			label$183:;
 		}
 	}
 	goto label$179;
 	label$180:;
 	{
-		DIMENSIONS$1 = *(int64*)((uint8*)ARRAY$1 + 96ll);
+		DIMENSIONS$1 = *(int64*)((uint8*)ARRAY$1 + 104ll);
 		if( DIMENSIONS$1 != -1ll ) goto label$186;
 		{
 			DIMENSIONS$1 = 8ll;
 		}
 		label$186:;
 		label$185:;
-		ASTTYPEINIADDPAD( TREE$1, DIMENSIONS$1 * *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 199168ll) + 72ll) );
+		ASTTYPEINIADDPAD( TREE$1, DIMENSIONS$1 * *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 199208ll) + 80ll) );
 	}
 	label$179:;
 	ASTTYPEINISCOPEEND( TREE$1, DIMTBFIELD$1 );
@@ -1960,11 +2029,11 @@ struct $7ASTNODE* ASTBUILDARRAYBOUND( struct $7ASTNODE* ARRAYEXPR$1, struct $7AS
 	struct $7ASTNODE* vr$1 = ASTNEWCONV( 8ll, (struct $8FBSYMBOL*)0ull, DIMEXPR$1, 0ll, (int64*)0ull );
 	DIMEXPR$1 = vr$1;
 	ERRPOPPARAMLOCATION(  );
-	struct $7ASTNODE* vr$3 = HCONSTBOUND( ARRAYEXPR$1, DIMEXPR$1, (int64)-(TK$1 == 493ll) );
+	struct $7ASTNODE* vr$3 = HCONSTBOUND( ARRAYEXPR$1, DIMEXPR$1, (int64)-(TK$1 == 494ll) );
 	EXPR$1 = vr$3;
 	if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$215;
 	{
-		struct $7ASTNODE* vr$5 = RTLARRAYBOUND( ARRAYEXPR$1, DIMEXPR$1, (int64)-(TK$1 == 493ll) );
+		struct $7ASTNODE* vr$5 = RTLARRAYBOUND( ARRAYEXPR$1, DIMEXPR$1, (int64)-(TK$1 == 494ll) );
 		EXPR$1 = vr$5;
 	}
 	label$215:;
@@ -2003,7 +2072,7 @@ struct $7ASTNODE* ASTBUILDSTRPTR( struct $7ASTNODE* LHS$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -2029,11 +2098,11 @@ static struct $7ASTNODE* HCONSTBOUND( struct $7ASTNODE* ARRAYEXPR$1, struct $7AS
 	int64 BOUND$1;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
 	{
-		$13AST_NODECLASS TMP$94$2;
-		TMP$94$2 = *($13AST_NODECLASS*)ARRAYEXPR$1;
-		if( TMP$94$2 == 17ll ) goto label$193;
+		$13AST_NODECLASS TMP$99$2;
+		TMP$99$2 = *($13AST_NODECLASS*)ARRAYEXPR$1;
+		if( TMP$99$2 == 17ll ) goto label$193;
 		label$194:;
-		if( TMP$94$2 != 19ll ) goto label$192;
+		if( TMP$99$2 != 19ll ) goto label$192;
 		label$193:;
 		{
 		}
@@ -2052,7 +2121,7 @@ static struct $7ASTNODE* HCONSTBOUND( struct $7ASTNODE* ARRAYEXPR$1, struct $7AS
 	}
 	label$197:;
 	label$196:;
-	if( (*(int64*)((uint8*)ARRAY$1 + 8ll) & 65540ll) == 0ll ) goto label$199;
+	if( (*(int64*)((uint8*)ARRAY$1 + 8ll) & 16388ll) == 0ll ) goto label$199;
 	{
 		goto label$190;
 	}
@@ -2065,16 +2134,16 @@ static struct $7ASTNODE* HCONSTBOUND( struct $7ASTNODE* ARRAYEXPR$1, struct $7AS
 	label$201:;
 	label$200:;
 	DIMENSION$1 = *(int64*)((uint8*)DIMEXPR$1 + 40ll) + -1ll;
-	if( ((int64)-(DIMENSION$1 >= 0ll) & (int64)-(DIMENSION$1 < *(int64*)((uint8*)ARRAY$1 + 96ll))) == 0ll ) goto label$203;
+	if( ((int64)-(DIMENSION$1 >= 0ll) & (int64)-(DIMENSION$1 < *(int64*)((uint8*)ARRAY$1 + 104ll))) == 0ll ) goto label$203;
 	{
 		if( IS_LBOUND$1 == 0ll ) goto label$205;
 		{
-			BOUND$1 = *(int64*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 104ll) + (DIMENSION$1 << (4ll & 63ll)));
+			BOUND$1 = *(int64*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 112ll) + (DIMENSION$1 << (4ll & 63ll)));
 		}
 		goto label$204;
 		label$205:;
 		{
-			BOUND$1 = *(int64*)((uint8*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 104ll) + (DIMENSION$1 << (4ll & 63ll))) + 8ll);
+			BOUND$1 = *(int64*)((uint8*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)ARRAY$1 + 112ll) + (DIMENSION$1 << (4ll & 63ll))) + 8ll);
 			if( BOUND$1 != -9223372036854775808ull ) goto label$207;
 			{
 				goto label$190;
@@ -2089,26 +2158,26 @@ static struct $7ASTNODE* HCONSTBOUND( struct $7ASTNODE* ARRAYEXPR$1, struct $7AS
 	{
 		if( DIMENSION$1 != -1ll ) goto label$209;
 		{
-			int64 TMP$95$3;
+			int64 TMP$100$3;
 			if( IS_LBOUND$1 == 0ll ) goto label$210;
-			TMP$95$3 = 1ll;
+			TMP$100$3 = 1ll;
 			goto label$220;
 			label$210:;
-			TMP$95$3 = *(int64*)((uint8*)ARRAY$1 + 96ll);
+			TMP$100$3 = *(int64*)((uint8*)ARRAY$1 + 104ll);
 			label$220:;
-			BOUND$1 = TMP$95$3;
+			BOUND$1 = TMP$100$3;
 		}
 		goto label$208;
 		label$209:;
 		{
-			int64 TMP$96$3;
+			int64 TMP$101$3;
 			if( IS_LBOUND$1 == 0ll ) goto label$211;
-			TMP$96$3 = 0ll;
+			TMP$101$3 = 0ll;
 			goto label$221;
 			label$211:;
-			TMP$96$3 = -1ll;
+			TMP$101$3 = -1ll;
 			label$221:;
-			BOUND$1 = TMP$96$3;
+			BOUND$1 = TMP$101$3;
 		}
 		label$208:;
 	}
