@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +317,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +386,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +416,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +566,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -643,16 +658,26 @@ struct $6IRVREG {
 	struct $5IRTAC* TACLAST;
 };
 __FB_STATIC_ASSERT( sizeof( struct $6IRVREG ) == 120 );
-typedef void (*tmp$48)( struct $6IRVREG* );
-typedef void (*tmp$41)( int64 );
-typedef void (*tmp$52)( int64, struct $8FBSYMBOL* );
-typedef void (*tmp$53)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
+typedef void (*tmp$53)( struct $6IRVREG* );
+typedef void (*tmp$46)( int64 );
+typedef void (*tmp$56)( int64, struct $8FBSYMBOL* );
+typedef void (*tmp$57)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
 struct $16__FB_ARRAYDIMTB$ {
 	int64 ELEMENTS;
 	int64 LBOUND;
 	int64 UBOUND;
 };
 __FB_STATIC_ASSERT( sizeof( struct $16__FB_ARRAYDIMTB$ ) == 24 );
+struct $8FBARRAY1I10FBARRAYDIME {
+	struct $10FBARRAYDIM* DATA;
+	struct $10FBARRAYDIM* PTR;
+	int64 SIZE;
+	int64 ELEMENT_LEN;
+	int64 DIMENSIONS;
+	int64 FLAGS;
+	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
+};
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10FBARRAYDIME ) == 72 );
 typedef int64 $10FB_BACKEND;
 struct $7FBARRAYI10FBARRAYDIME {
 	struct $10FBARRAYDIM* DATA;
@@ -660,9 +685,10 @@ struct $7FBARRAYI10FBARRAYDIME {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[8];
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYI10FBARRAYDIME ) == 232 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYI10FBARRAYDIME ) == 240 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -682,129 +708,128 @@ int64 ASTCONSTFLUSHTOINT( struct $7ASTNODE*, int64 );
 struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL*, int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWIDX( struct $7ASTNODE*, struct $7ASTNODE* );
 struct $7ASTNODE* ASTNEWBRANCH( int64, struct $8FBSYMBOL*, struct $7ASTNODE* );
-struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
+typedef int64 $15AST_LINK_RETURN;
+struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, $15AST_LINK_RETURN );
 struct $7ASTNODE* ASTNEWNODE( int64, int64, struct $8FBSYMBOL* );
 struct $6IRVREG* ASTLOAD( struct $7ASTNODE* );
 typedef int64 $10FB_SYMBOPT;
-struct $8FBSYMBOL* SYMBADDVAR( uint8*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, struct $7FBARRAYI10FBARRAYDIME*, int64, $10FB_SYMBOPT );
+struct $8FBSYMBOL* SYMBADDVAR( uint8*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, struct $7FBARRAYI10FBARRAYDIME*, $13FB_SYMBATTRIB, $10FB_SYMBOPT );
 uint8* SYMBUNIQUELABEL( void );
 static struct $7ASTNODE* ASTNEWJMPTB( struct $7ASTNODE*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
 static int64 HPRECALCBIASOFFSET( uint64, int64 );
-typedef void (*tmp$33)( void );
-typedef int64 (*tmp$34)( void );
+typedef void (*tmp$38)( void );
+typedef int64 (*tmp$39)( void );
 typedef int64 $14IR_OPTIONVALUE;
-typedef int64 (*tmp$35)( $14IR_OPTIONVALUE );
-typedef int64 (*tmp$36)( int64, int64 );
-typedef void (*tmp$37)( struct $8FBSYMBOL* );
-typedef void (*tmp$38)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef uint8* (*tmp$39)( void );
-typedef void (*tmp$40)( struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$42)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$44)( struct $9ASTASMTOK* );
-typedef void (*tmp$45)( uint8* );
-typedef void (*tmp$46)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
-typedef void (*tmp$47)( int64, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$49)( int64, struct $6IRVREG* );
-typedef void (*tmp$50)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
-typedef void (*tmp$51)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$54)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
-typedef void (*tmp$55)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$56)( int64, struct $8FBSYMBOL*, int64, uint8* );
-typedef void (*tmp$57)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$58)( struct $8FBSYMBOL*, double );
-typedef void (*tmp$59)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$60)( int64, uint8*, int64 );
-typedef void (*tmp$61)( int64, uint16*, int64 );
-typedef void (*tmp$62)( int64 );
-typedef void (*tmp$63)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$64)( uint8* );
-typedef struct $6IRVREG* (*tmp$65)( int64, struct $8FBSYMBOL* );
-typedef struct $6IRVREG* (*tmp$66)( int64, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$67)( int64, struct $8FBSYMBOL*, double );
-typedef struct $6IRVREG* (*tmp$68)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
-typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
-typedef void (*tmp$71)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
-typedef uint64 (*tmp$72)( struct $6IRVREG* );
+typedef int64 (*tmp$40)( $14IR_OPTIONVALUE );
+typedef int64 (*tmp$41)( int64, int64 );
+typedef void (*tmp$42)( struct $8FBSYMBOL* );
+typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef uint8* (*tmp$44)( void );
+typedef void (*tmp$45)( struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$47)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef void (*tmp$48)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64, struct $6IRVREG* );
+typedef void (*tmp$49)( struct $9ASTASMTOK* );
+typedef void (*tmp$50)( uint8* );
+typedef void (*tmp$51)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
+typedef void (*tmp$52)( int64, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$54)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
+typedef void (*tmp$55)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
+typedef void (*tmp$58)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
+typedef void (*tmp$59)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$60)( int64, struct $8FBSYMBOL*, int64, uint8* );
+typedef void (*tmp$61)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$62)( struct $8FBSYMBOL*, double );
+typedef void (*tmp$63)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$64)( int64, uint8*, int64 );
+typedef void (*tmp$65)( int64, uint16*, int64 );
+typedef void (*tmp$66)( int64 );
+typedef void (*tmp$67)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$68)( uint8* );
+typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL* );
+typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$71)( int64, struct $8FBSYMBOL*, double );
+typedef struct $6IRVREG* (*tmp$72)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$73)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
+typedef struct $6IRVREG* (*tmp$74)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
+typedef void (*tmp$75)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
+typedef uint64 (*tmp$76)( struct $6IRVREG* );
 struct $7IR_VTBL {
-	tmp$33 INIT;
-	tmp$33 END;
-	tmp$34 EMITBEGIN;
-	tmp$33 EMITEND;
-	tmp$35 GETOPTIONVALUE;
-	tmp$36 SUPPORTSOP;
-	tmp$37 PROCBEGIN;
-	tmp$37 PROCEND;
-	tmp$38 PROCALLOCARG;
-	tmp$38 PROCALLOCLOCAL;
-	tmp$39 PROCGETFRAMEREGNAME;
-	tmp$37 SCOPEBEGIN;
-	tmp$37 SCOPEEND;
-	tmp$37 PROCALLOCSTATICVARS;
-	tmp$40 EMITCONVERT;
-	tmp$37 EMITLABEL;
-	tmp$37 EMITLABELNF;
-	tmp$41 EMITRETURN;
-	tmp$38 EMITPROCBEGIN;
-	tmp$42 EMITPROCEND;
-	tmp$43 EMITPUSHARG;
-	tmp$44 EMITASMLINE;
-	tmp$45 EMITCOMMENT;
-	tmp$46 EMITBOP;
-	tmp$47 EMITUOP;
-	tmp$40 EMITSTORE;
-	tmp$33 EMITSPILLREGS;
-	tmp$48 EMITLOAD;
-	tmp$40 EMITLOADRES;
-	tmp$49 EMITSTACK;
-	tmp$47 EMITADDR;
-	tmp$50 EMITCALL;
-	tmp$51 EMITCALLPTR;
-	tmp$41 EMITSTACKALIGN;
-	tmp$48 EMITJUMPPTR;
-	tmp$52 EMITBRANCH;
-	tmp$53 EMITJMPTB;
-	tmp$54 EMITMEM;
-	tmp$55 EMITMACRO;
-	tmp$37 EMITSCOPEBEGIN;
-	tmp$37 EMITSCOPEEND;
-	tmp$37 EMITDECL;
-	tmp$56 EMITDBG;
-	tmp$37 EMITVARINIBEGIN;
-	tmp$37 EMITVARINIEND;
-	tmp$57 EMITVARINII;
-	tmp$58 EMITVARINIF;
-	tmp$59 EMITVARINIOFS;
-	tmp$60 EMITVARINISTR;
-	tmp$61 EMITVARINIWSTR;
-	tmp$62 EMITVARINIPAD;
-	tmp$63 EMITVARINISCOPEBEGIN;
-	tmp$33 EMITVARINISCOPEEND;
-	tmp$33 EMITFBCTINFBEGIN;
-	tmp$64 EMITFBCTINFSTRING;
-	tmp$33 EMITFBCTINFEND;
-	tmp$65 ALLOCVREG;
-	tmp$66 ALLOCVRIMM;
-	tmp$67 ALLOCVRIMMF;
-	tmp$68 ALLOCVRVAR;
-	tmp$69 ALLOCVRIDX;
-	tmp$70 ALLOCVRPTR;
-	tmp$68 ALLOCVROFS;
-	tmp$71 SETVREGDATATYPE;
-	tmp$72 GETDISTANCE;
-	tmp$47 LOADVR;
-	tmp$40 STOREVR;
-	tmp$41 XCHGTOS;
+	tmp$38 INIT;
+	tmp$38 END;
+	tmp$39 EMITBEGIN;
+	tmp$38 EMITEND;
+	tmp$40 GETOPTIONVALUE;
+	tmp$41 SUPPORTSOP;
+	tmp$42 PROCBEGIN;
+	tmp$42 PROCEND;
+	tmp$43 PROCALLOCARG;
+	tmp$43 PROCALLOCLOCAL;
+	tmp$44 PROCGETFRAMEREGNAME;
+	tmp$42 SCOPEBEGIN;
+	tmp$42 SCOPEEND;
+	tmp$42 PROCALLOCSTATICVARS;
+	tmp$45 EMITCONVERT;
+	tmp$42 EMITLABEL;
+	tmp$42 EMITLABELNF;
+	tmp$46 EMITRETURN;
+	tmp$43 EMITPROCBEGIN;
+	tmp$47 EMITPROCEND;
+	tmp$48 EMITPUSHARG;
+	tmp$49 EMITASMLINE;
+	tmp$50 EMITCOMMENT;
+	tmp$51 EMITBOP;
+	tmp$52 EMITUOP;
+	tmp$45 EMITSTORE;
+	tmp$38 EMITSPILLREGS;
+	tmp$53 EMITLOAD;
+	tmp$45 EMITLOADRES;
+	tmp$52 EMITSTACK;
+	tmp$52 EMITADDR;
+	tmp$54 EMITCALL;
+	tmp$55 EMITCALLPTR;
+	tmp$46 EMITSTACKALIGN;
+	tmp$53 EMITJUMPPTR;
+	tmp$56 EMITBRANCH;
+	tmp$57 EMITJMPTB;
+	tmp$58 EMITMEM;
+	tmp$59 EMITMACRO;
+	tmp$42 EMITSCOPEBEGIN;
+	tmp$42 EMITSCOPEEND;
+	tmp$42 EMITDECL;
+	tmp$60 EMITDBG;
+	tmp$42 EMITVARINIBEGIN;
+	tmp$42 EMITVARINIEND;
+	tmp$61 EMITVARINII;
+	tmp$62 EMITVARINIF;
+	tmp$63 EMITVARINIOFS;
+	tmp$64 EMITVARINISTR;
+	tmp$65 EMITVARINIWSTR;
+	tmp$66 EMITVARINIPAD;
+	tmp$67 EMITVARINISCOPEBEGIN;
+	tmp$38 EMITVARINISCOPEEND;
+	tmp$38 EMITFBCTINFBEGIN;
+	tmp$68 EMITFBCTINFSTRING;
+	tmp$38 EMITFBCTINFEND;
+	tmp$69 ALLOCVREG;
+	tmp$70 ALLOCVRIMM;
+	tmp$71 ALLOCVRIMMF;
+	tmp$72 ALLOCVRVAR;
+	tmp$73 ALLOCVRIDX;
+	tmp$74 ALLOCVRPTR;
+	tmp$72 ALLOCVROFS;
+	tmp$75 SETVREGDATATYPE;
+	tmp$76 GETDISTANCE;
+	tmp$52 LOADVR;
+	tmp$45 STOREVR;
+	tmp$46 XCHGTOS;
 };
 __FB_STATIC_ASSERT( sizeof( struct $7IR_VTBL ) == 544 );
 typedef int64 $6IR_OPT;
 struct $5IRCTX {
-	int64 INITED;
 	struct $7IR_VTBL VTBL;
 	$6IR_OPT OPTIONS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 560 );
+__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 552 );
 extern struct $5IRCTX IR$;
 struct $12AST_PROC_CTX {
 	struct $7ASTNODE* HEAD;
@@ -868,10 +893,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -889,20 +915,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $13FB_COMPTARGET;
 typedef int64 $10FB_CPUTYPE;
@@ -942,8 +970,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -951,8 +982,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -999,6 +1031,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -1020,16 +1053,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 
 struct $7ASTNODE* ASTNEWBRANCH( int64 OP$1, struct $8FBSYMBOL* LABEL$1, struct $7ASTNODE* L$1 )
@@ -1085,19 +1123,19 @@ struct $6IRVREG* ASTLOADBRANCH( struct $7ASTNODE* N$1 )
 		if( *(struct $8FBSYMBOL**)((uint8*)N$1 + 56ll) != (struct $8FBSYMBOL*)0ull ) goto label$21;
 		{
 			{
-				int64 TMP$79$4;
-				TMP$79$4 = *(int64*)((uint8*)N$1 + 40ll);
-				if( TMP$79$4 != 104ll ) goto label$23;
+				int64 TMP$83$4;
+				TMP$83$4 = *(int64*)((uint8*)N$1 + 40ll);
+				if( TMP$83$4 != 104ll ) goto label$23;
 				label$24:;
 				{
-					(*(tmp$48*)((uint8*)&IR$ + 280ll))( VR$1 );
+					(*(tmp$53*)((uint8*)&IR$ + 272ll))( VR$1 );
 				}
 				goto label$22;
 				label$23:;
-				if( TMP$79$4 != 101ll ) goto label$25;
+				if( TMP$83$4 != 101ll ) goto label$25;
 				label$26:;
 				{
-					(*(tmp$41*)((uint8*)&IR$ + 144ll))( 0ll );
+					(*(tmp$46*)((uint8*)&IR$ + 136ll))( 0ll );
 				}
 				goto label$22;
 				label$25:;
@@ -1110,7 +1148,7 @@ struct $6IRVREG* ASTLOADBRANCH( struct $7ASTNODE* N$1 )
 		goto label$20;
 		label$21:;
 		{
-			(*(tmp$52*)((uint8*)&IR$ + 288ll))( *(int64*)((uint8*)N$1 + 40ll), *(struct $8FBSYMBOL**)((uint8*)N$1 + 56ll) );
+			(*(tmp$56*)((uint8*)&IR$ + 280ll))( *(int64*)((uint8*)N$1 + 40ll), *(struct $8FBSYMBOL**)((uint8*)N$1 + 56ll) );
 		}
 		label$20:;
 	}
@@ -1132,7 +1170,7 @@ struct $6IRVREG* ASTLOADJMPTB( struct $7ASTNODE* N$1 )
 	ASTDELNODE( *(struct $7ASTNODE**)((uint8*)N$1 + 112ll) );
 	if( *(int64*)((uint8*)&AST$ + 272ll) == 0ll ) goto label$39;
 	{
-		(*(tmp$53*)((uint8*)&IR$ + 296ll))( V1$1, *(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll), *(uint64**)((uint8*)N$1 + 40ll), *(struct $8FBSYMBOL***)((uint8*)N$1 + 48ll), *(int64*)((uint8*)N$1 + 56ll), *(struct $8FBSYMBOL**)((uint8*)N$1 + 64ll), *(uint64*)((uint8*)N$1 + 72ll), *(uint64*)((uint8*)N$1 + 80ll) );
+		(*(tmp$57*)((uint8*)&IR$ + 288ll))( V1$1, *(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll), *(uint64**)((uint8*)N$1 + 40ll), *(struct $8FBSYMBOL***)((uint8*)N$1 + 48ll), *(int64*)((uint8*)N$1 + 56ll), *(struct $8FBSYMBOL**)((uint8*)N$1 + 64ll), *(uint64*)((uint8*)N$1 + 72ll), *(uint64*)((uint8*)N$1 + 80ll) );
 	}
 	label$39:;
 	label$38:;
@@ -1151,26 +1189,17 @@ struct $7ASTNODE* ASTBUILDJMPTB( struct $8FBSYMBOL* TEMPVAR$1, uint64* VALUES1$1
 	struct $7ASTNODE* TREE$1;
 	struct $7ASTNODE* L$1;
 	static struct $10FBARRAYDIM DTB$1[1];
-	struct $8FBARRAY1I10FBARRAYDIME {
-		struct $10FBARRAYDIM* DATA;
-		struct $10FBARRAYDIM* PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10FBARRAYDIME ) == 64 );
-	static struct $8FBARRAY1I10FBARRAYDIME tmp$81$1 = { (struct $10FBARRAYDIM*)DTB$1, (struct $10FBARRAYDIM*)DTB$1, 16ll, 16ll, 1ll, { { 1ll, 0ll, 0ll } } };
+	static struct $8FBARRAY1I10FBARRAYDIME tmp$85$1 = { (struct $10FBARRAYDIM*)DTB$1, (struct $10FBARRAYDIM*)DTB$1, 16ll, 16ll, 1ll, 49ll, { { 1ll, 0ll, 0ll } } };
 	struct $8FBSYMBOL* TBSYM$1;
 	int64 DTYPE$1;
-	DTYPE$1 = *(int64*)((uint8*)TEMPVAR$1 + 48ll) & 511ll;
+	DTYPE$1 = *(int64*)((uint8*)TEMPVAR$1 + 56ll) & 511ll;
 	TREE$1 = (struct $7ASTNODE*)0ull;
 	{
-		$10FB_BACKEND TMP$82$2;
-		TMP$82$2 = *($10FB_BACKEND*)((uint8*)&ENV$ + 208ll);
-		if( TMP$82$2 == 0ll ) goto label$46;
+		$10FB_BACKEND TMP$86$2;
+		TMP$86$2 = *($10FB_BACKEND*)((uint8*)&ENV$ + 208ll);
+		if( TMP$86$2 == 0ll ) goto label$46;
 		label$47:;
-		if( TMP$82$2 != 2ll ) goto label$45;
+		if( TMP$86$2 != 2ll ) goto label$45;
 		label$46:;
 		{
 			if( LABELCOUNT$1 > 0ll ) goto label$49;
@@ -1188,24 +1217,24 @@ struct $7ASTNODE* ASTBUILDJMPTB( struct $8FBSYMBOL* TEMPVAR$1, uint64* VALUES1$1
 	if( *(int64*)((uint8*)&ENV$ + 208ll) != 0ll ) goto label$51;
 	{
 		uint8* vr$4 = SYMBUNIQUELABEL(  );
-		struct $8FBSYMBOL* vr$5 = SYMBADDVAR( (uint8*)vr$4, (uint8*)0ull, 32ll, (struct $8FBSYMBOL*)0ull, 0ll, 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$81$1, 1ll, 0ll );
+		struct $8FBSYMBOL* vr$5 = SYMBADDVAR( (uint8*)vr$4, (uint8*)0ull, 32ll, (struct $8FBSYMBOL*)0ull, 0ll, 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$85$1, 1ll, 0ll );
 		TBSYM$1 = vr$5;
-		*($12FB_SYMBSTATS*)((uint8*)TBSYM$1 + 16ll) = *(int64*)((uint8*)TBSYM$1 + 16ll) | 32768ll;
+		*($12FB_SYMBSTATS*)((uint8*)TBSYM$1 + 24ll) = *(int64*)((uint8*)TBSYM$1 + 24ll) | 32768ll;
 		struct $7ASTNODE* vr$9 = ASTNEWCONSTI( (int64)SPAN$1, DTYPE$1, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$10 = ASTNEWCONSTI( (int64)BIAS$1, DTYPE$1, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$11 = ASTNEWVAR( TEMPVAR$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$12 = ASTNEWBOP( 29ll, vr$11, vr$10, (struct $8FBSYMBOL*)0ull, 1ll );
 		struct $7ASTNODE* vr$13 = ASTNEWBOP( 46ll, vr$12, vr$9, DEFLABEL$1, 0ll );
-		struct $7ASTNODE* vr$14 = ASTNEWLINK( TREE$1, vr$13, -1ll );
+		struct $7ASTNODE* vr$14 = ASTNEWLINK( TREE$1, vr$13, 0ll );
 		TREE$1 = vr$14;
-		struct $7ASTNODE* vr$15 = ASTNEWCONSTI( *(int64*)((uint8*)&ENV$ + 544ll), DTYPE$1, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$15 = ASTNEWCONSTI( *(int64*)((uint8*)&ENV$ + 576ll), DTYPE$1, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$16 = ASTNEWVAR( TEMPVAR$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$17 = ASTNEWBOP( 30ll, vr$16, vr$15, (struct $8FBSYMBOL*)0ull, 1ll );
 		int64 vr$18 = HPRECALCBIASOFFSET( BIAS$1, DTYPE$1 );
 		struct $7ASTNODE* vr$19 = ASTNEWVAR( TBSYM$1, vr$18, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$20 = ASTNEWIDX( vr$19, vr$17 );
 		struct $7ASTNODE* vr$21 = ASTNEWBRANCH( 104ll, (struct $8FBSYMBOL*)0ull, vr$20 );
-		struct $7ASTNODE* vr$22 = ASTNEWLINK( TREE$1, vr$21, -1ll );
+		struct $7ASTNODE* vr$22 = ASTNEWLINK( TREE$1, vr$21, 0ll );
 		TREE$1 = vr$22;
 	}
 	goto label$50;
@@ -1216,7 +1245,7 @@ struct $7ASTNODE* ASTBUILDJMPTB( struct $8FBSYMBOL* TEMPVAR$1, uint64* VALUES1$1
 	label$50:;
 	struct $7ASTNODE* vr$23 = ASTNEWVAR( TEMPVAR$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$24 = ASTNEWJMPTB( vr$23, TBSYM$1, VALUES1$1, LABELS1$1, LABELCOUNT$1, DEFLABEL$1, BIAS$1, SPAN$1 );
-	struct $7ASTNODE* vr$25 = ASTNEWLINK( TREE$1, vr$24, -1ll );
+	struct $7ASTNODE* vr$25 = ASTNEWLINK( TREE$1, vr$24, 0ll );
 	TREE$1 = vr$25;
 	fb$result$1 = TREE$1;
 	label$43:;
@@ -1255,7 +1284,7 @@ struct $6IRVREG* ASTLOADLOOP( struct $7ASTNODE* N$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1279,8 +1308,8 @@ static struct $7ASTNODE* ASTNEWJMPTB( struct $7ASTNODE* L$1, struct $8FBSYMBOL*
 		{
 			int64 I$3;
 			I$3 = 0ll;
-			int64 TMP$80$3;
-			TMP$80$3 = LABELCOUNT$1 + -1ll;
+			int64 TMP$84$3;
+			TMP$84$3 = LABELCOUNT$1 + -1ll;
 			goto label$32;
 			label$35:;
 			{
@@ -1290,7 +1319,7 @@ static struct $7ASTNODE* ASTNEWJMPTB( struct $7ASTNODE* L$1, struct $8FBSYMBOL*
 			label$33:;
 			I$3 = I$3 + 1ll;
 			label$32:;
-			if( I$3 <= TMP$80$3 ) goto label$35;
+			if( I$3 <= TMP$84$3 ) goto label$35;
 			label$34:;
 		}
 	}
@@ -1311,7 +1340,7 @@ static struct $7ASTNODE* ASTNEWJMPTB( struct $7ASTNODE* L$1, struct $8FBSYMBOL*
 	*(struct $8FBSYMBOL**)((uint8*)N$1 + 64ll) = DEFLABEL$1;
 	*(uint64*)((uint8*)N$1 + 72ll) = BIAS$1;
 	*(uint64*)((uint8*)N$1 + 80ll) = SPAN$1;
-	struct $7ASTNODE* vr$24 = ASTNEWLINK( TREE$1, N$1, -1ll );
+	struct $7ASTNODE* vr$24 = ASTNEWLINK( TREE$1, N$1, 0ll );
 	fb$result$1 = vr$24;
 	label$29:;
 	return fb$result$1;
@@ -1328,7 +1357,7 @@ static int64 HPRECALCBIASOFFSET( uint64 BIAS$1, int64 DTYPE$1 )
 	T$1 = vr$2;
 	struct $7ASTNODE* vr$3 = ASTNEWUOP( 54ll, T$1 );
 	T$1 = vr$3;
-	struct $7ASTNODE* vr$4 = ASTNEWCONSTI( *(int64*)((uint8*)&ENV$ + 544ll), DTYPE$1, (struct $8FBSYMBOL*)0ull );
+	struct $7ASTNODE* vr$4 = ASTNEWCONSTI( *(int64*)((uint8*)&ENV$ + 576ll), DTYPE$1, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$5 = ASTNEWBOP( 30ll, T$1, vr$4, (struct $8FBSYMBOL*)0ull, 1ll );
 	T$1 = vr$5;
 	int64 vr$6 = ASTCONSTFLUSHTOINT( T$1, 11ll );
