@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +317,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +386,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +416,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +566,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -598,6 +613,17 @@ struct $7ASTNODE {
 	struct $7ASTNODE* NEXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $7ASTNODE ) == 144 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 typedef int64 $15IRVREGTYPE_ENUM;
 typedef int64 $12IR_REGFAMILY;
 struct $6IRVREG;
@@ -643,8 +669,8 @@ struct $6IRVREG {
 	struct $5IRTAC* TACLAST;
 };
 __FB_STATIC_ASSERT( sizeof( struct $6IRVREG ) == 120 );
-typedef struct $6IRVREG* (*tmp$67)( int64, struct $8FBSYMBOL*, double );
-typedef struct $6IRVREG* (*tmp$66)( int64, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$71)( int64, struct $8FBSYMBOL*, double );
+typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -689,123 +715,121 @@ struct $8FBSYMBOL* SYMBALLOCSTRCONST( uint8*, int64 );
 struct $8FBSYMBOL* SYMBALLOCWSTRCONST( uint16*, int64 );
 struct $8FBSYMBOL* SYMBUDTGETFIRSTFIELD( struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBUDTGETNEXTINITABLEFIELD( struct $8FBSYMBOL* );
-typedef void (*tmp$33)( void );
-typedef int64 (*tmp$34)( void );
+typedef void (*tmp$38)( void );
+typedef int64 (*tmp$39)( void );
 typedef int64 $14IR_OPTIONVALUE;
-typedef int64 (*tmp$35)( $14IR_OPTIONVALUE );
-typedef int64 (*tmp$36)( int64, int64 );
-typedef void (*tmp$37)( struct $8FBSYMBOL* );
-typedef void (*tmp$38)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef uint8* (*tmp$39)( void );
-typedef void (*tmp$40)( struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$41)( int64 );
-typedef void (*tmp$42)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$44)( struct $9ASTASMTOK* );
-typedef void (*tmp$45)( uint8* );
-typedef void (*tmp$46)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
-typedef void (*tmp$47)( int64, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$48)( struct $6IRVREG* );
-typedef void (*tmp$49)( int64, struct $6IRVREG* );
-typedef void (*tmp$50)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
-typedef void (*tmp$51)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$52)( int64, struct $8FBSYMBOL* );
-typedef void (*tmp$53)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
-typedef void (*tmp$54)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
-typedef void (*tmp$55)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$56)( int64, struct $8FBSYMBOL*, int64, uint8* );
-typedef void (*tmp$57)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$58)( struct $8FBSYMBOL*, double );
-typedef void (*tmp$59)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$60)( int64, uint8*, int64 );
-typedef void (*tmp$61)( int64, uint16*, int64 );
-typedef void (*tmp$62)( int64 );
-typedef void (*tmp$63)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$64)( uint8* );
-typedef struct $6IRVREG* (*tmp$65)( int64, struct $8FBSYMBOL* );
-typedef struct $6IRVREG* (*tmp$68)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
-typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
-typedef void (*tmp$71)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
-typedef uint64 (*tmp$72)( struct $6IRVREG* );
+typedef int64 (*tmp$40)( $14IR_OPTIONVALUE );
+typedef int64 (*tmp$41)( int64, int64 );
+typedef void (*tmp$42)( struct $8FBSYMBOL* );
+typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef uint8* (*tmp$44)( void );
+typedef void (*tmp$45)( struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$46)( int64 );
+typedef void (*tmp$47)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef void (*tmp$48)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64, struct $6IRVREG* );
+typedef void (*tmp$49)( struct $9ASTASMTOK* );
+typedef void (*tmp$50)( uint8* );
+typedef void (*tmp$51)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
+typedef void (*tmp$52)( int64, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$53)( struct $6IRVREG* );
+typedef void (*tmp$54)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
+typedef void (*tmp$55)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
+typedef void (*tmp$56)( int64, struct $8FBSYMBOL* );
+typedef void (*tmp$57)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
+typedef void (*tmp$58)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
+typedef void (*tmp$59)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$60)( int64, struct $8FBSYMBOL*, int64, uint8* );
+typedef void (*tmp$61)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$62)( struct $8FBSYMBOL*, double );
+typedef void (*tmp$63)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$64)( int64, uint8*, int64 );
+typedef void (*tmp$65)( int64, uint16*, int64 );
+typedef void (*tmp$66)( int64 );
+typedef void (*tmp$67)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$68)( uint8* );
+typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL* );
+typedef struct $6IRVREG* (*tmp$72)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$73)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
+typedef struct $6IRVREG* (*tmp$74)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
+typedef void (*tmp$75)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
+typedef uint64 (*tmp$76)( struct $6IRVREG* );
 struct $7IR_VTBL {
-	tmp$33 INIT;
-	tmp$33 END;
-	tmp$34 EMITBEGIN;
-	tmp$33 EMITEND;
-	tmp$35 GETOPTIONVALUE;
-	tmp$36 SUPPORTSOP;
-	tmp$37 PROCBEGIN;
-	tmp$37 PROCEND;
-	tmp$38 PROCALLOCARG;
-	tmp$38 PROCALLOCLOCAL;
-	tmp$39 PROCGETFRAMEREGNAME;
-	tmp$37 SCOPEBEGIN;
-	tmp$37 SCOPEEND;
-	tmp$37 PROCALLOCSTATICVARS;
-	tmp$40 EMITCONVERT;
-	tmp$37 EMITLABEL;
-	tmp$37 EMITLABELNF;
-	tmp$41 EMITRETURN;
-	tmp$38 EMITPROCBEGIN;
-	tmp$42 EMITPROCEND;
-	tmp$43 EMITPUSHARG;
-	tmp$44 EMITASMLINE;
-	tmp$45 EMITCOMMENT;
-	tmp$46 EMITBOP;
-	tmp$47 EMITUOP;
-	tmp$40 EMITSTORE;
-	tmp$33 EMITSPILLREGS;
-	tmp$48 EMITLOAD;
-	tmp$40 EMITLOADRES;
-	tmp$49 EMITSTACK;
-	tmp$47 EMITADDR;
-	tmp$50 EMITCALL;
-	tmp$51 EMITCALLPTR;
-	tmp$41 EMITSTACKALIGN;
-	tmp$48 EMITJUMPPTR;
-	tmp$52 EMITBRANCH;
-	tmp$53 EMITJMPTB;
-	tmp$54 EMITMEM;
-	tmp$55 EMITMACRO;
-	tmp$37 EMITSCOPEBEGIN;
-	tmp$37 EMITSCOPEEND;
-	tmp$37 EMITDECL;
-	tmp$56 EMITDBG;
-	tmp$37 EMITVARINIBEGIN;
-	tmp$37 EMITVARINIEND;
-	tmp$57 EMITVARINII;
-	tmp$58 EMITVARINIF;
-	tmp$59 EMITVARINIOFS;
-	tmp$60 EMITVARINISTR;
-	tmp$61 EMITVARINIWSTR;
-	tmp$62 EMITVARINIPAD;
-	tmp$63 EMITVARINISCOPEBEGIN;
-	tmp$33 EMITVARINISCOPEEND;
-	tmp$33 EMITFBCTINFBEGIN;
-	tmp$64 EMITFBCTINFSTRING;
-	tmp$33 EMITFBCTINFEND;
-	tmp$65 ALLOCVREG;
-	tmp$66 ALLOCVRIMM;
-	tmp$67 ALLOCVRIMMF;
-	tmp$68 ALLOCVRVAR;
-	tmp$69 ALLOCVRIDX;
-	tmp$70 ALLOCVRPTR;
-	tmp$68 ALLOCVROFS;
-	tmp$71 SETVREGDATATYPE;
-	tmp$72 GETDISTANCE;
-	tmp$47 LOADVR;
-	tmp$40 STOREVR;
-	tmp$41 XCHGTOS;
+	tmp$38 INIT;
+	tmp$38 END;
+	tmp$39 EMITBEGIN;
+	tmp$38 EMITEND;
+	tmp$40 GETOPTIONVALUE;
+	tmp$41 SUPPORTSOP;
+	tmp$42 PROCBEGIN;
+	tmp$42 PROCEND;
+	tmp$43 PROCALLOCARG;
+	tmp$43 PROCALLOCLOCAL;
+	tmp$44 PROCGETFRAMEREGNAME;
+	tmp$42 SCOPEBEGIN;
+	tmp$42 SCOPEEND;
+	tmp$42 PROCALLOCSTATICVARS;
+	tmp$45 EMITCONVERT;
+	tmp$42 EMITLABEL;
+	tmp$42 EMITLABELNF;
+	tmp$46 EMITRETURN;
+	tmp$43 EMITPROCBEGIN;
+	tmp$47 EMITPROCEND;
+	tmp$48 EMITPUSHARG;
+	tmp$49 EMITASMLINE;
+	tmp$50 EMITCOMMENT;
+	tmp$51 EMITBOP;
+	tmp$52 EMITUOP;
+	tmp$45 EMITSTORE;
+	tmp$38 EMITSPILLREGS;
+	tmp$53 EMITLOAD;
+	tmp$45 EMITLOADRES;
+	tmp$52 EMITSTACK;
+	tmp$52 EMITADDR;
+	tmp$54 EMITCALL;
+	tmp$55 EMITCALLPTR;
+	tmp$46 EMITSTACKALIGN;
+	tmp$53 EMITJUMPPTR;
+	tmp$56 EMITBRANCH;
+	tmp$57 EMITJMPTB;
+	tmp$58 EMITMEM;
+	tmp$59 EMITMACRO;
+	tmp$42 EMITSCOPEBEGIN;
+	tmp$42 EMITSCOPEEND;
+	tmp$42 EMITDECL;
+	tmp$60 EMITDBG;
+	tmp$42 EMITVARINIBEGIN;
+	tmp$42 EMITVARINIEND;
+	tmp$61 EMITVARINII;
+	tmp$62 EMITVARINIF;
+	tmp$63 EMITVARINIOFS;
+	tmp$64 EMITVARINISTR;
+	tmp$65 EMITVARINIWSTR;
+	tmp$66 EMITVARINIPAD;
+	tmp$67 EMITVARINISCOPEBEGIN;
+	tmp$38 EMITVARINISCOPEEND;
+	tmp$38 EMITFBCTINFBEGIN;
+	tmp$68 EMITFBCTINFSTRING;
+	tmp$38 EMITFBCTINFEND;
+	tmp$69 ALLOCVREG;
+	tmp$70 ALLOCVRIMM;
+	tmp$71 ALLOCVRIMMF;
+	tmp$72 ALLOCVRVAR;
+	tmp$73 ALLOCVRIDX;
+	tmp$74 ALLOCVRPTR;
+	tmp$72 ALLOCVROFS;
+	tmp$75 SETVREGDATATYPE;
+	tmp$76 GETDISTANCE;
+	tmp$52 LOADVR;
+	tmp$45 STOREVR;
+	tmp$46 XCHGTOS;
 };
 __FB_STATIC_ASSERT( sizeof( struct $7IR_VTBL ) == 544 );
 typedef int64 $6IR_OPT;
 struct $5IRCTX {
-	int64 INITED;
 	struct $7IR_VTBL VTBL;
 	$6IR_OPT OPTIONS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 560 );
+__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 552 );
 extern struct $5IRCTX IR$;
 struct $12AST_PROC_CTX {
 	struct $7ASTNODE* HEAD;
@@ -875,21 +899,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -897,34 +911,36 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
 int64 ASTCONSTEQZERO( struct $7ASTNODE* N$1 )
 {
-	int64 TMP$79$1;
+	int64 TMP$83$1;
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 480ll) == 0ll ) goto label$12;
-	TMP$79$1 = 24ll;
+	TMP$83$1 = 24ll;
 	goto label$15;
 	label$12:;
-	TMP$79$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
+	TMP$83$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
 	label$15:;
-	if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$79$1 * 56ll)) != 1ll ) goto label$14;
+	if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$83$1 * 56ll)) != 1ll ) goto label$14;
 	{
 		fb$result$1 = (int64)-(*(double*)((uint8*)N$1 + 40ll) == 0x0p+0);
 	}
@@ -940,30 +956,30 @@ int64 ASTCONSTEQZERO( struct $7ASTNODE* N$1 )
 
 int64 ASTCONSTGEZERO( struct $7ASTNODE* N$1 )
 {
-	int64 TMP$80$1;
-	int64 TMP$81$1;
+	int64 TMP$84$1;
+	int64 TMP$85$1;
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$16:;
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 480ll) == 0ll ) goto label$18;
-	TMP$80$1 = 24ll;
+	TMP$84$1 = 24ll;
 	goto label$23;
 	label$18:;
-	TMP$80$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
+	TMP$84$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
 	label$23:;
-	if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$80$1 * 56ll)) != 1ll ) goto label$20;
+	if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$84$1 * 56ll)) != 1ll ) goto label$20;
 	{
 		fb$result$1 = (int64)-(*(double*)((uint8*)N$1 + 40ll) >= 0x0p+0);
 	}
 	goto label$19;
 	label$20:;
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 480ll) == 0ll ) goto label$22;
-	TMP$81$1 = 24ll;
+	TMP$85$1 = 24ll;
 	goto label$24;
 	label$22:;
-	TMP$81$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
+	TMP$85$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
 	label$24:;
-	if( *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$81$1 * 56ll)) + 16ll) == 0ll ) goto label$21;
+	if( *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$85$1 * 56ll)) + 16ll) == 0ll ) goto label$21;
 	{
 		fb$result$1 = (int64)-(*(int64*)((uint8*)N$1 + 40ll) >= 0ll);
 	}
@@ -1076,17 +1092,17 @@ struct $7ASTNODE* ASTNEWCONSTF( double VALUE$1, int64 DTYPE$1 )
 
 struct $7ASTNODE* ASTNEWCONST( union $7FBVALUE* V$1, int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1 )
 {
-	int64 TMP$82$1;
+	int64 TMP$86$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$43:;
 	if( (DTYPE$1 & 480ll) == 0ll ) goto label$45;
-	TMP$82$1 = 24ll;
+	TMP$86$1 = 24ll;
 	goto label$48;
 	label$45:;
-	TMP$82$1 = DTYPE$1 & 31ll;
+	TMP$86$1 = DTYPE$1 & 31ll;
 	label$48:;
-	if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$82$1 * 56ll)) != 1ll ) goto label$47;
+	if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$86$1 * 56ll)) != 1ll ) goto label$47;
 	{
 		struct $7ASTNODE* vr$5 = ASTNEWCONSTF( *(double*)V$1, DTYPE$1 );
 		fb$result$1 = vr$5;
@@ -1110,8 +1126,8 @@ struct $7ASTNODE* ASTNEWCONSTZ( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1 )
 	struct $7ASTNODE* TREE$1;
 	struct $8FBSYMBOL* FLD$1;
 	{
-		uint64 TMP$83$2;
-		TMP$83$2 = (uint64)(DTYPE$1 & 511ll);
+		uint64 TMP$87$2;
+		TMP$87$2 = (uint64)(DTYPE$1 & 511ll);
 		goto label$52;
 		label$53:;
 		{
@@ -1141,7 +1157,7 @@ struct $7ASTNODE* ASTNEWCONSTZ( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1 )
 			label$57:;
 			if( FLD$1 == (struct $8FBSYMBOL*)0ull ) goto label$58;
 			{
-				struct $7ASTNODE* vr$9 = ASTNEWCONSTZ( *(int64*)((uint8*)FLD$1 + 48ll), *(struct $8FBSYMBOL**)((uint8*)FLD$1 + 56ll) );
+				struct $7ASTNODE* vr$9 = ASTNEWCONSTZ( *(int64*)((uint8*)FLD$1 + 56ll), *(struct $8FBSYMBOL**)((uint8*)FLD$1 + 64ll) );
 				ASTTYPEINIADDASSIGN( TREE$1, vr$9, FLD$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 				struct $8FBSYMBOL* vr$10 = SYMBUDTGETNEXTINITABLEFIELD( FLD$1 );
 				FLD$1 = vr$10;
@@ -1155,7 +1171,7 @@ struct $7ASTNODE* ASTNEWCONSTZ( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1 )
 		goto label$51;
 		label$59:;
 		{
-			int64 TMP$84$3;
+			int64 TMP$88$3;
 			if( DTYPE$1 != 2147483648ll ) goto label$61;
 			{
 				DTYPE$1 = 8ll;
@@ -1163,12 +1179,12 @@ struct $7ASTNODE* ASTNEWCONSTZ( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1 )
 			label$61:;
 			label$60:;
 			if( (DTYPE$1 & 480ll) == 0ll ) goto label$62;
-			TMP$84$3 = 24ll;
+			TMP$88$3 = 24ll;
 			goto label$65;
 			label$62:;
-			TMP$84$3 = DTYPE$1 & 31ll;
+			TMP$88$3 = DTYPE$1 & 31ll;
 			label$65:;
-			if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$84$3 * 56ll)) != 1ll ) goto label$64;
+			if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$88$3 * 56ll)) != 1ll ) goto label$64;
 			{
 				struct $7ASTNODE* vr$14 = ASTNEWCONSTF( 0x0p+0, DTYPE$1 );
 				fb$result$1 = vr$14;
@@ -1183,7 +1199,7 @@ struct $7ASTNODE* ASTNEWCONSTZ( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1 )
 		}
 		goto label$51;
 		label$52:;
-		static const void* tmp$85[21ll] = {
+		static const void* tmp$89[21ll] = {
 			&&label$53,
 			&&label$59,
 			&&label$59,
@@ -1206,8 +1222,8 @@ struct $7ASTNODE* ASTNEWCONSTZ( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1 )
 			&&label$59,
 			&&label$56,
 		};
-		if( TMP$83$2 > 20ull ) goto label$59;
-		goto *tmp$85[TMP$83$2 - 0ull];
+		if( TMP$87$2 > 20ull ) goto label$59;
+		goto *tmp$89[TMP$87$2 - 0ull];
 		label$51:;
 	}
 	label$50:;
@@ -1222,23 +1238,23 @@ struct $6IRVREG* ASTLOADCONST( struct $7ASTNODE* N$1 )
 	int64 DTYPE$1;
 	if( *(int64*)((uint8*)&AST$ + 272ll) == 0ll ) goto label$69;
 	{
-		int64 TMP$86$2;
+		int64 TMP$90$2;
 		DTYPE$1 = *(int64*)((uint8*)N$1 + 8ll) & 511ll;
 		if( (DTYPE$1 & 480ll) == 0ll ) goto label$70;
-		TMP$86$2 = 24ll;
+		TMP$90$2 = 24ll;
 		goto label$73;
 		label$70:;
-		TMP$86$2 = DTYPE$1 & 31ll;
+		TMP$90$2 = DTYPE$1 & 31ll;
 		label$73:;
-		if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$86$2 * 56ll)) != 1ll ) goto label$72;
+		if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$90$2 * 56ll)) != 1ll ) goto label$72;
 		{
-			struct $6IRVREG* vr$8 = (*(tmp$67*)((uint8*)&IR$ + 472ll))( DTYPE$1, *(struct $8FBSYMBOL**)((uint8*)N$1 + 16ll), *(double*)((uint8*)N$1 + 40ll) );
+			struct $6IRVREG* vr$8 = (*(tmp$71*)((uint8*)&IR$ + 464ll))( DTYPE$1, *(struct $8FBSYMBOL**)((uint8*)N$1 + 16ll), *(double*)((uint8*)N$1 + 40ll) );
 			fb$result$1 = vr$8;
 		}
 		goto label$71;
 		label$72:;
 		{
-			struct $6IRVREG* vr$11 = (*(tmp$66*)((uint8*)&IR$ + 464ll))( DTYPE$1, *(struct $8FBSYMBOL**)((uint8*)N$1 + 16ll), *(int64*)((uint8*)N$1 + 40ll) );
+			struct $6IRVREG* vr$11 = (*(tmp$70*)((uint8*)&IR$ + 456ll))( DTYPE$1, *(struct $8FBSYMBOL**)((uint8*)N$1 + 16ll), *(int64*)((uint8*)N$1 + 40ll) );
 			fb$result$1 = vr$11;
 		}
 		label$71:;
@@ -1264,29 +1280,29 @@ int64 ASTCONSTFLUSHTOINT( struct $7ASTNODE* N$1, int64 DTYPE$1 )
 
 FBSTRING* ASTCONSTFLUSHTOSTR( struct $7ASTNODE* N$1 )
 {
-	int64 TMP$87$1;
-	int64 TMP$88$1;
+	int64 TMP$91$1;
+	int64 TMP$92$1;
 	FBSTRING fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 24ll );
 	label$76:;
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 480ll) == 0ll ) goto label$78;
-	TMP$87$1 = 24ll;
+	TMP$91$1 = 24ll;
 	goto label$86;
 	label$78:;
-	TMP$87$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
+	TMP$91$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
 	label$86:;
-	if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$87$1 * 56ll)) != 1ll ) goto label$80;
+	if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$91$1 * 56ll)) != 1ll ) goto label$80;
 	{
 		if( (*(int64*)((uint8*)N$1 + 8ll) & 511ll) != 16ll ) goto label$82;
 		{
 			FBSTRING* vr$9 = fb_DoubleToStr( *(double*)((uint8*)N$1 + 40ll) );
-			FBSTRING* vr$11 = fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$9, -1ll, 0 );
+			fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$9, -1ll, 0 );
 		}
 		goto label$81;
 		label$82:;
 		{
-			FBSTRING* vr$14 = fb_FloatToStr( (float)*(double*)((uint8*)N$1 + 40ll) );
-			FBSTRING* vr$16 = fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$14, -1ll, 0 );
+			FBSTRING* vr$13 = fb_FloatToStr( (float)*(double*)((uint8*)N$1 + 40ll) );
+			fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$13, -1ll, 0 );
 		}
 		label$81:;
 	}
@@ -1294,67 +1310,67 @@ FBSTRING* ASTCONSTFLUSHTOSTR( struct $7ASTNODE* N$1 )
 	label$80:;
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 511ll) != 1ll ) goto label$83;
 	{
-		FBSTRING* vr$21 = fb_BoolToStr( (boolean)(*(int64*)((uint8*)N$1 + 40ll) != 0ll) );
-		FBSTRING* vr$23 = fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$21, -1ll, 0 );
+		FBSTRING* vr$19 = fb_BoolToStr( (boolean)(*(int64*)((uint8*)N$1 + 40ll) != 0ll) );
+		fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$19, -1ll, 0 );
 	}
 	goto label$79;
 	label$83:;
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 480ll) == 0ll ) goto label$85;
-	TMP$88$1 = 24ll;
+	TMP$92$1 = 24ll;
 	goto label$87;
 	label$85:;
-	TMP$88$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
+	TMP$92$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
 	label$87:;
-	if( *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$88$1 * 56ll)) + 16ll) == 0ll ) goto label$84;
+	if( *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$92$1 * 56ll)) + 16ll) == 0ll ) goto label$84;
 	{
-		FBSTRING* vr$30 = fb_LongintToStr( *(int64*)((uint8*)N$1 + 40ll) );
-		FBSTRING* vr$32 = fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$30, -1ll, 0 );
+		FBSTRING* vr$27 = fb_LongintToStr( *(int64*)((uint8*)N$1 + 40ll) );
+		fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$27, -1ll, 0 );
 	}
 	goto label$79;
 	label$84:;
 	{
-		FBSTRING* vr$34 = fb_ULongintToStr( *(uint64*)((uint8*)N$1 + 40ll) );
-		FBSTRING* vr$36 = fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$34, -1ll, 0 );
+		FBSTRING* vr$30 = fb_ULongintToStr( *(uint64*)((uint8*)N$1 + 40ll) );
+		fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$30, -1ll, 0 );
 	}
 	label$79:;
 	ASTDELNODE( N$1 );
 	label$77:;
-	FBSTRING* vr$38 = fb_StrAllocTempResult( (FBSTRING*)&fb$result$1 );
-	return vr$38;
+	FBSTRING* vr$33 = fb_StrAllocTempResult( (FBSTRING*)&fb$result$1 );
+	return vr$33;
 }
 
 uint16* ASTCONSTFLUSHTOWSTR( struct $7ASTNODE* N$1 )
 {
-	int64 TMP$89$1;
 	int64 TMP$93$1;
+	int64 TMP$97$1;
 	uint16* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$88:;
 	static uint16 W$1[65];
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 480ll) == 0ll ) goto label$90;
-	TMP$89$1 = 24ll;
+	TMP$93$1 = 24ll;
 	goto label$98;
 	label$90:;
-	TMP$89$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
+	TMP$93$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
 	label$98:;
-	if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$89$1 * 56ll)) != 1ll ) goto label$92;
+	if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$93$1 * 56ll)) != 1ll ) goto label$92;
 	{
 		if( (*(int64*)((uint8*)N$1 + 8ll) & 511ll) != 16ll ) goto label$94;
 		{
-			uint16* TMP$90$3;
+			uint16* TMP$94$3;
 			uint16* vr$9 = fb_DoubleToWstr( *(double*)((uint8*)N$1 + 40ll) );
-			TMP$90$3 = vr$9;
-			uint16* vr$10 = fb_WstrAssign( (uint16*)W$1, 65ll, (uint16*)TMP$90$3 );
-			fb_WstrDelete( (uint16*)TMP$90$3 );
+			TMP$94$3 = vr$9;
+			fb_WstrAssign( (uint16*)W$1, 65ll, (uint16*)TMP$94$3 );
+			fb_WstrDelete( (uint16*)TMP$94$3 );
 		}
 		goto label$93;
 		label$94:;
 		{
-			uint16* TMP$91$3;
-			uint16* vr$13 = fb_FloatToWstr( (float)*(double*)((uint8*)N$1 + 40ll) );
-			TMP$91$3 = vr$13;
-			uint16* vr$14 = fb_WstrAssign( (uint16*)W$1, 65ll, (uint16*)TMP$91$3 );
-			fb_WstrDelete( (uint16*)TMP$91$3 );
+			uint16* TMP$95$3;
+			uint16* vr$12 = fb_FloatToWstr( (float)*(double*)((uint8*)N$1 + 40ll) );
+			TMP$95$3 = vr$12;
+			fb_WstrAssign( (uint16*)W$1, 65ll, (uint16*)TMP$95$3 );
+			fb_WstrDelete( (uint16*)TMP$95$3 );
 		}
 		label$93:;
 	}
@@ -1362,36 +1378,36 @@ uint16* ASTCONSTFLUSHTOWSTR( struct $7ASTNODE* N$1 )
 	label$92:;
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 511ll) != 1ll ) goto label$95;
 	{
-		uint16* TMP$92$2;
-		uint16* vr$19 = fb_BoolToWstr( (boolean)(*(int64*)((uint8*)N$1 + 40ll) != 0ll) );
-		TMP$92$2 = vr$19;
-		uint16* vr$20 = fb_WstrAssign( (uint16*)W$1, 65ll, (uint16*)TMP$92$2 );
-		fb_WstrDelete( (uint16*)TMP$92$2 );
+		uint16* TMP$96$2;
+		uint16* vr$17 = fb_BoolToWstr( (boolean)(*(int64*)((uint8*)N$1 + 40ll) != 0ll) );
+		TMP$96$2 = vr$17;
+		fb_WstrAssign( (uint16*)W$1, 65ll, (uint16*)TMP$96$2 );
+		fb_WstrDelete( (uint16*)TMP$96$2 );
 	}
 	goto label$91;
 	label$95:;
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 480ll) == 0ll ) goto label$97;
-	TMP$93$1 = 24ll;
+	TMP$97$1 = 24ll;
 	goto label$99;
 	label$97:;
-	TMP$93$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
+	TMP$97$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
 	label$99:;
-	if( *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$93$1 * 56ll)) + 16ll) == 0ll ) goto label$96;
+	if( *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$97$1 * 56ll)) + 16ll) == 0ll ) goto label$96;
 	{
-		uint16* TMP$94$2;
-		uint16* vr$27 = fb_LongintToWstr( *(int64*)((uint8*)N$1 + 40ll) );
-		TMP$94$2 = vr$27;
-		uint16* vr$28 = fb_WstrAssign( (uint16*)W$1, 65ll, (uint16*)TMP$94$2 );
-		fb_WstrDelete( (uint16*)TMP$94$2 );
+		uint16* TMP$98$2;
+		uint16* vr$24 = fb_LongintToWstr( *(int64*)((uint8*)N$1 + 40ll) );
+		TMP$98$2 = vr$24;
+		fb_WstrAssign( (uint16*)W$1, 65ll, (uint16*)TMP$98$2 );
+		fb_WstrDelete( (uint16*)TMP$98$2 );
 	}
 	goto label$91;
 	label$96:;
 	{
-		uint16* TMP$95$2;
-		uint16* vr$30 = fb_ULongintToWstr( *(uint64*)((uint8*)N$1 + 40ll) );
-		TMP$95$2 = vr$30;
-		uint16* vr$31 = fb_WstrAssign( (uint16*)W$1, 65ll, (uint16*)TMP$95$2 );
-		fb_WstrDelete( (uint16*)TMP$95$2 );
+		uint16* TMP$99$2;
+		uint16* vr$26 = fb_ULongintToWstr( *(uint64*)((uint8*)N$1 + 40ll) );
+		TMP$99$2 = vr$26;
+		fb_WstrAssign( (uint16*)W$1, 65ll, (uint16*)TMP$99$2 );
+		fb_WstrDelete( (uint16*)TMP$99$2 );
 	}
 	label$91:;
 	ASTDELNODE( N$1 );
@@ -1402,17 +1418,17 @@ uint16* ASTCONSTFLUSHTOWSTR( struct $7ASTNODE* N$1 )
 
 int64 ASTCONSTGETASINT64( struct $7ASTNODE* N$1 )
 {
-	int64 TMP$96$1;
+	int64 TMP$100$1;
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$100:;
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 480ll) == 0ll ) goto label$102;
-	TMP$96$1 = 24ll;
+	TMP$100$1 = 24ll;
 	goto label$105;
 	label$102:;
-	TMP$96$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
+	TMP$100$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
 	label$105:;
-	if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$96$1 * 56ll)) != 1ll ) goto label$104;
+	if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$100$1 * 56ll)) != 1ll ) goto label$104;
 	{
 		fb$result$1 = fb_D2L( *(double*)((uint8*)N$1 + 40ll) );
 	}
@@ -1428,30 +1444,30 @@ int64 ASTCONSTGETASINT64( struct $7ASTNODE* N$1 )
 
 double ASTCONSTGETASDOUBLE( struct $7ASTNODE* N$1 )
 {
-	int64 TMP$97$1;
-	int64 TMP$98$1;
+	int64 TMP$101$1;
+	int64 TMP$102$1;
 	double fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$106:;
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 480ll) == 0ll ) goto label$108;
-	TMP$97$1 = 24ll;
+	TMP$101$1 = 24ll;
 	goto label$113;
 	label$108:;
-	TMP$97$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
+	TMP$101$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
 	label$113:;
-	if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$97$1 * 56ll)) != 1ll ) goto label$110;
+	if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$101$1 * 56ll)) != 1ll ) goto label$110;
 	{
 		fb$result$1 = *(double*)((uint8*)N$1 + 40ll);
 	}
 	goto label$109;
 	label$110:;
 	if( (*(int64*)((uint8*)N$1 + 8ll) & 480ll) == 0ll ) goto label$112;
-	TMP$98$1 = 24ll;
+	TMP$102$1 = 24ll;
 	goto label$114;
 	label$112:;
-	TMP$98$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
+	TMP$102$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
 	label$114:;
-	if( *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$98$1 * 56ll)) + 16ll) == 0ll ) goto label$111;
+	if( *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$102$1 * 56ll)) + 16ll) == 0ll ) goto label$111;
 	{
 		fb$result$1 = (double)*(int64*)((uint8*)N$1 + 40ll);
 	}
@@ -1472,23 +1488,23 @@ struct $7ASTNODE* ASTBUILDCONST( struct $8FBSYMBOL* SYM$1 )
 	label$115:;
 	int64 DTYPE$1;
 	struct $8FBSYMBOL* SUBTYPE$1;
-	DTYPE$1 = *(int64*)((uint8*)SYM$1 + 48ll);
-	SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 56ll);
+	DTYPE$1 = *(int64*)((uint8*)SYM$1 + 56ll);
+	SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 64ll);
 	{
-		int64 TMP$99$2;
-		TMP$99$2 = DTYPE$1 & 511ll;
-		if( TMP$99$2 == 4ll ) goto label$119;
+		int64 TMP$103$2;
+		TMP$103$2 = DTYPE$1 & 511ll;
+		if( TMP$103$2 == 4ll ) goto label$119;
 		label$120:;
-		if( TMP$99$2 != 7ll ) goto label$118;
+		if( TMP$103$2 != 7ll ) goto label$118;
 		label$119:;
 		{
-			struct $7ASTNODE* vr$5 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 88ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+			struct $7ASTNODE* vr$5 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 96ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 			fb$result$1 = vr$5;
 		}
 		goto label$117;
 		label$118:;
 		{
-			struct $7ASTNODE* vr$8 = ASTNEWCONST( (union $7FBVALUE*)((uint8*)SYM$1 + 88ll), DTYPE$1, SUBTYPE$1 );
+			struct $7ASTNODE* vr$8 = ASTNEWCONST( (union $7FBVALUE*)((uint8*)SYM$1 + 96ll), DTYPE$1, SUBTYPE$1 );
 			fb$result$1 = vr$8;
 		}
 		label$121:;
@@ -1500,24 +1516,24 @@ struct $7ASTNODE* ASTBUILDCONST( struct $8FBSYMBOL* SYM$1 )
 
 struct $7ASTNODE* ASTCONVERTRAWCONSTI( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, struct $7ASTNODE* L$1 )
 {
-	int64 TMP$100$1;
-	$11FB_DATATYPE TMP$101$1;
+	int64 TMP$104$1;
+	$11FB_DATATYPE TMP$105$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$122:;
 	if( (*(int64*)((uint8*)L$1 + 8ll) & 480ll) == 0ll ) goto label$124;
-	TMP$100$1 = 24ll;
+	TMP$104$1 = 24ll;
 	goto label$126;
 	label$124:;
-	TMP$100$1 = *(int64*)((uint8*)L$1 + 8ll) & 31ll;
+	TMP$104$1 = *(int64*)((uint8*)L$1 + 8ll) & 31ll;
 	label$126:;
-	if( *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$100$1 * 56ll)) + 16ll) == 0ll ) goto label$125;
-	TMP$101$1 = 13ll;
+	if( *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$104$1 * 56ll)) + 16ll) == 0ll ) goto label$125;
+	TMP$105$1 = 13ll;
 	goto label$127;
 	label$125:;
-	TMP$101$1 = 14ll;
+	TMP$105$1 = 14ll;
 	label$127:;
-	*(int64*)((uint8*)L$1 + 8ll) = TMP$101$1;
+	*(int64*)((uint8*)L$1 + 8ll) = TMP$105$1;
 	*(struct $8FBSYMBOL**)((uint8*)L$1 + 16ll) = (struct $8FBSYMBOL*)0ull;
 	*(int64*)((uint8*)&AST$ + 464ll) = *(int64*)((uint8*)&AST$ + 464ll) + 1ll;
 	struct $7ASTNODE* vr$9 = ASTNEWCONV( DTYPE$1, SUBTYPE$1, L$1, 8ll, (int64*)0ull );
@@ -1531,7 +1547,7 @@ struct $7ASTNODE* ASTCONVERTRAWCONSTI( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
