@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +513,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +582,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,22 +612,44 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 struct $16__FB_ARRAYDIMTB$ {
 	int64 ELEMENTS;
 	int64 LBOUND;
 	int64 UBOUND;
 };
 __FB_STATIC_ASSERT( sizeof( struct $16__FB_ARRAYDIMTB$ ) == 24 );
+struct $8FBARRAY1I10FBARRAYDIME {
+	struct $10FBARRAYDIM* DATA;
+	struct $10FBARRAYDIM* PTR;
+	int64 SIZE;
+	int64 ELEMENT_LEN;
+	int64 DIMENSIONS;
+	int64 FLAGS;
+	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
+};
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10FBARRAYDIME ) == 72 );
 struct $7FBARRAYI10FBARRAYDIME {
 	struct $10FBARRAYDIM* DATA;
 	struct $10FBARRAYDIM* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[8];
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYI10FBARRAYDIME ) == 232 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYI10FBARRAYDIME ) == 240 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -641,9 +678,9 @@ struct $7ASTNODE* ASTDATASTMTSTORE( struct $7ASTNODE*, struct $7ASTNODE* );
 struct $8FBSYMBOL* ASTDATASTMTADD( struct $8FBSYMBOL*, int64 );
 struct $8FBSYMBOL* SYMBLOOKUPBYNAMEANDCLASS( struct $8FBSYMBOL*, uint8*, int64, int64, int64 );
 typedef int64 $10FB_SYMBOPT;
-struct $8FBSYMBOL* SYMBADDVAR( uint8*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, struct $7FBARRAYI10FBARRAYDIME*, int64, $10FB_SYMBOPT );
-struct $8FBSYMBOL* SYMBSTRUCTBEGIN( struct $10FBSYMBOLTB*, struct $8FBHASHTB*, struct $8FBSYMBOL*, uint8*, uint8*, int64, int64, int64, int64, int64 );
-struct $8FBSYMBOL* SYMBADDFIELD( struct $8FBSYMBOL*, uint8*, int64, struct $7FBARRAYI10FBARRAYDIME*, int64, struct $8FBSYMBOL*, int64, int64, int64 );
+struct $8FBSYMBOL* SYMBADDVAR( uint8*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, struct $7FBARRAYI10FBARRAYDIME*, $13FB_SYMBATTRIB, $10FB_SYMBOPT );
+struct $8FBSYMBOL* SYMBSTRUCTBEGIN( struct $10FBSYMBOLTB*, struct $8FBHASHTB*, struct $8FBSYMBOL*, uint8*, uint8*, int64, int64, int64, $13FB_SYMBATTRIB, int64 );
+struct $8FBSYMBOL* SYMBADDFIELD( struct $8FBSYMBOL*, uint8*, int64, struct $7FBARRAYI10FBARRAYDIME*, int64, struct $8FBSYMBOL*, int64, int64, $13FB_SYMBATTRIB );
 void SYMBSTRUCTEND( struct $8FBSYMBOL*, int64 );
 void SYMBSETARRAYDIMTB( struct $8FBSYMBOL*, int64, struct $7FBARRAYI10FBARRAYDIME* );
 void SYMBMAYBEADDARRAYDESC( struct $8FBSYMBOL* );
@@ -711,10 +748,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -748,6 +786,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -756,11 +798,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -813,19 +856,8 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -833,20 +865,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
 void ASTDATASTMTINIT( void )
 {
@@ -902,11 +936,11 @@ struct $7ASTNODE* ASTDATASTMTSTORE( struct $7ASTNODE* TREE$1, struct $7ASTNODE*
 	{
 		struct $8FBSYMBOL* LITSYM$2;
 		{
-			int64 TMP$79$3;
-			TMP$79$3 = *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll;
-			if( TMP$79$3 == 4ll ) goto label$22;
+			int64 TMP$83$3;
+			TMP$83$3 = *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll;
+			if( TMP$83$3 == 4ll ) goto label$22;
 			label$23:;
-			if( TMP$79$3 != 7ll ) goto label$21;
+			if( TMP$83$3 != 7ll ) goto label$21;
 			label$22:;
 			{
 				struct $8FBSYMBOL* vr$12 = ASTGETSTRLITSYMBOL( EXPR$1 );
@@ -977,8 +1011,8 @@ void ASTDATASTMTEND( struct $7ASTNODE* TREE$1 )
 	N$1 = *(struct $7ASTNODE**)((uint8*)TREE$1 + 112ll);
 	{
 		I$1 = 0ll;
-		int64 TMP$80$2;
-		TMP$80$2 = *(int64*)((uint8*)TREE$1 + 40ll) + -1ll;
+		int64 TMP$84$2;
+		TMP$84$2 = *(int64*)((uint8*)TREE$1 + 40ll) + -1ll;
 		goto label$33;
 		label$36:;
 		{
@@ -986,56 +1020,56 @@ void ASTDATASTMTEND( struct $7ASTNODE* TREE$1 )
 			EXPR$1 = *(struct $7ASTNODE**)((uint8*)N$1 + 112ll);
 			ASTTYPEINISCOPEBEGIN( INITREE$1, ARRAY$1, 0ll );
 			{
-				int64 TMP$81$4;
-				TMP$81$4 = *(int64*)((uint8*)N$1 + 40ll);
-				if( TMP$81$4 != 1ll ) goto label$38;
+				int64 TMP$85$4;
+				TMP$85$4 = *(int64*)((uint8*)N$1 + 40ll);
+				if( TMP$85$4 != 1ll ) goto label$38;
 				label$39:;
 				{
 					struct $8FBSYMBOL* vr$10 = ASTGETSTRLITSYMBOL( EXPR$1 );
-					ID$1 = *(int64*)((uint8*)vr$10 + 72ll) + -1ll;
+					ID$1 = *(int64*)((uint8*)vr$10 + 80ll) + -1ll;
 					struct $7ASTNODE* vr$12 = ASTNEWADDROF( EXPR$1 );
 					EXPR$1 = vr$12;
 				}
 				goto label$37;
 				label$38:;
-				if( TMP$81$4 != 32768ll ) goto label$40;
+				if( TMP$85$4 != 32768ll ) goto label$40;
 				label$41:;
 				{
 					struct $8FBSYMBOL* vr$13 = ASTGETSTRLITSYMBOL( EXPR$1 );
-					ID$1 = (*(int64*)((uint8*)vr$13 + 72ll) / *(int64*)((uint8*)SYMB_DTYPETB$ + 400ll)) + 32767ll;
+					ID$1 = (*(int64*)((uint8*)vr$13 + 80ll) / *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 400ll)) + 32767ll;
 					struct $7ASTNODE* vr$16 = ASTNEWADDROF( EXPR$1 );
 					EXPR$1 = vr$16;
 				}
 				goto label$37;
 				label$40:;
-				if( TMP$81$4 != 2ll ) goto label$42;
+				if( TMP$85$4 != 2ll ) goto label$42;
 				label$43:;
 				{
 					FBSTRING* vr$17 = ASTCONSTFLUSHTOSTR( EXPR$1 );
-					FBSTRING* vr$19 = fb_StrAssign( (void*)&LITTEXT$1, -1ll, (void*)vr$17, -1ll, 0 );
-					int64 vr$21 = fb_StrLen( (void*)&LITTEXT$1, -1ll );
-					ID$1 = vr$21;
-					struct $7ASTNODE* vr$22 = ASTNEWCONSTSTR( (uint8*)*(uint8**)&LITTEXT$1 );
-					struct $7ASTNODE* vr$23 = ASTNEWADDROF( vr$22 );
-					EXPR$1 = vr$23;
+					fb_StrAssign( (void*)&LITTEXT$1, -1ll, (void*)vr$17, -1ll, 0 );
+					int64 vr$20 = fb_StrLen( (void*)&LITTEXT$1, -1ll );
+					ID$1 = vr$20;
+					struct $7ASTNODE* vr$21 = ASTNEWCONSTSTR( (uint8*)*(uint8**)&LITTEXT$1 );
+					struct $7ASTNODE* vr$22 = ASTNEWADDROF( vr$21 );
+					EXPR$1 = vr$22;
 				}
 				goto label$37;
 				label$42:;
-				if( TMP$81$4 == 0ll ) goto label$45;
+				if( TMP$85$4 == 0ll ) goto label$45;
 				label$46:;
-				if( TMP$81$4 != 65535ll ) goto label$44;
+				if( TMP$85$4 != 65535ll ) goto label$44;
 				label$45:;
 				{
-					struct $7ASTNODE* vr$24 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
-					EXPR$1 = vr$24;
+					struct $7ASTNODE* vr$23 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
+					EXPR$1 = vr$23;
 				}
 				label$44:;
 				label$37:;
 			}
-			ELM$1 = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&AST$ + 232ll) + 96ll);
-			struct $7ASTNODE* vr$26 = ASTNEWCONSTI( ID$1, 5ll, (struct $8FBSYMBOL*)0ull );
-			ASTTYPEINIADDASSIGN( INITREE$1, vr$26, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-			ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 296ll);
+			ELM$1 = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&AST$ + 232ll) + 104ll);
+			struct $7ASTNODE* vr$25 = ASTNEWCONSTI( ID$1, 5ll, (struct $8FBSYMBOL*)0ull );
+			ASTTYPEINIADDASSIGN( INITREE$1, vr$25, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+			ELM$1 = *(struct $8FBSYMBOL**)((uint8*)ELM$1 + 312ll);
 			ASTTYPEINIADDASSIGN( INITREE$1, EXPR$1, ELM$1, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 			ASTTYPEINISCOPEEND( INITREE$1, ARRAY$1 );
 			struct $7ASTNODE* NXT$3;
@@ -1046,15 +1080,15 @@ void ASTDATASTMTEND( struct $7ASTNODE* TREE$1 )
 		label$34:;
 		I$1 = I$1 + 1ll;
 		label$33:;
-		if( I$1 <= TMP$80$2 ) goto label$36;
+		if( I$1 <= TMP$84$2 ) goto label$36;
 		label$35:;
 	}
 	ASTTYPEINISCOPEEND( INITREE$1, ARRAY$1 );
 	ASTTYPEINIEND( INITREE$1, -1ll );
-	*(struct $7ASTNODE**)((uint8*)ARRAY$1 + 88ll) = INITREE$1;
+	*(struct $7ASTNODE**)((uint8*)ARRAY$1 + 96ll) = INITREE$1;
 	if( *(struct $8FBSYMBOL**)((uint8*)&AST$ + 240ll) == (struct $8FBSYMBOL*)0ull ) goto label$48;
 	{
-		INITREE$1 = *(struct $7ASTNODE**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&AST$ + 240ll) + 88ll);
+		INITREE$1 = *(struct $7ASTNODE**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&AST$ + 240ll) + 96ll);
 		N$1 = *(struct $7ASTNODE**)((uint8*)INITREE$1 + 112ll);
 		struct $7ASTNODE* TN$2;
 		TN$2 = N$1;
@@ -1072,13 +1106,13 @@ void ASTDATASTMTEND( struct $7ASTNODE* TREE$1 )
 		goto label$49;
 		label$50:;
 		ASTDELNODE( *(struct $7ASTNODE**)((uint8*)TN$2 + 112ll) );
-		struct $7ASTNODE* vr$37 = ASTNEWVAR( ARRAY$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-		struct $7ASTNODE* vr$38 = ASTNEWADDROF( vr$37 );
-		*(struct $7ASTNODE**)((uint8*)TN$2 + 112ll) = vr$38;
+		struct $7ASTNODE* vr$36 = ASTNEWVAR( ARRAY$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$37 = ASTNEWADDROF( vr$36 );
+		*(struct $7ASTNODE**)((uint8*)TN$2 + 112ll) = vr$37;
 	}
 	label$48:;
 	label$47:;
-	*(struct $8FBSYMBOL**)((uint8*)ARRAY$1 + 168ll) = *(struct $8FBSYMBOL**)((uint8*)&AST$ + 240ll);
+	*(struct $8FBSYMBOL**)((uint8*)ARRAY$1 + 176ll) = *(struct $8FBSYMBOL**)((uint8*)&AST$ + 240ll);
 	*(struct $8FBSYMBOL**)((uint8*)&AST$ + 240ll) = ARRAY$1;
 	if( *(struct $8FBSYMBOL**)((uint8*)&AST$ + 248ll) != (struct $8FBSYMBOL*)0ull ) goto label$54;
 	{
@@ -1097,21 +1131,12 @@ struct $8FBSYMBOL* ASTDATASTMTADD( struct $8FBSYMBOL* LABEL$1, int64 ELEMENTS$1
 	label$55:;
 	static FBSTRING ID$1;
 	static struct $10FBARRAYDIM DTB$1[1];
-	struct $8FBARRAY1I10FBARRAYDIME {
-		struct $10FBARRAYDIM* DATA;
-		struct $10FBARRAYDIM* PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10FBARRAYDIME ) == 64 );
-	static struct $8FBARRAY1I10FBARRAYDIME tmp$82$1 = { (struct $10FBARRAYDIM*)DTB$1, (struct $10FBARRAYDIM*)DTB$1, 16ll, 16ll, 1ll, { { 1ll, 0ll, 0ll } } };
+	static struct $8FBARRAY1I10FBARRAYDIME tmp$86$1 = { (struct $10FBARRAYDIM*)DTB$1, (struct $10FBARRAYDIM*)DTB$1, 16ll, 16ll, 1ll, 49ll, { { 1ll, 0ll, 0ll } } };
 	struct $8FBSYMBOL* SYM$1;
 	struct $8FBSYMBOL* LASTLABEL$1;
 	if( LABEL$1 != (struct $8FBSYMBOL*)0ull ) goto label$58;
 	{
-		LASTLABEL$1 = *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 198000ll);
+		LASTLABEL$1 = *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 198040ll);
 		if( ((int64)-(LASTLABEL$1 == (struct $8FBSYMBOL*)0ull) | (int64)-(*(struct $8FBSYMBOL**)((uint8*)&AST$ + 256ll) == LASTLABEL$1)) == 0ll ) goto label$60;
 		{
 			uint8* vr$4 = SYMBUNIQUELABEL(  );
@@ -1120,32 +1145,32 @@ struct $8FBSYMBOL* ASTDATASTMTADD( struct $8FBSYMBOL* LABEL$1, int64 ELEMENTS$1
 		goto label$59;
 		label$60:;
 		{
-			FBSTRING TMP$83$3;
+			FBSTRING TMP$87$3;
 			*(struct $8FBSYMBOL**)((uint8*)&AST$ + 256ll) = LASTLABEL$1;
-			__builtin_memset( &TMP$83$3, 0, 24ll );
-			FBSTRING* vr$8 = fb_StrConcat( &TMP$83$3, (void*)"_{fbdata}_", 11ll, *(void**)((uint8*)LASTLABEL$1 + 24ll), 0ll );
-			FBSTRING* vr$9 = fb_StrAssign( (void*)&ID$1, -1ll, (void*)vr$8, -1ll, 0 );
+			__builtin_memset( &TMP$87$3, 0, 24ll );
+			FBSTRING* vr$8 = fb_StrConcat( &TMP$87$3, (void*)"_{fbdata}_", 11ll, *(void**)((uint8*)LASTLABEL$1 + 32ll), 0ll );
+			fb_StrAssign( (void*)&ID$1, -1ll, (void*)vr$8, -1ll, 0 );
 		}
 		label$59:;
-		*(int64*)((uint8*)DTB$1 + 8ll) = ELEMENTS$1 + -1ll;
+		*(int64*)((int64)(struct $10FBARRAYDIM*)DTB$1 + 8ll) = ELEMENTS$1 + -1ll;
 	}
 	goto label$57;
 	label$58:;
 	{
-		FBSTRING TMP$84$2;
-		__builtin_memset( &TMP$84$2, 0, 24ll );
-		FBSTRING* vr$14 = fb_StrConcat( &TMP$84$2, (void*)"_{fbdata}_", 11ll, *(void**)((uint8*)LABEL$1 + 24ll), 0ll );
-		FBSTRING* vr$15 = fb_StrAssign( (void*)&ID$1, -1ll, (void*)vr$14, -1ll, 0 );
-		*(int64*)((uint8*)DTB$1 + 8ll) = 0ll;
+		FBSTRING TMP$88$2;
+		__builtin_memset( &TMP$88$2, 0, 24ll );
+		FBSTRING* vr$13 = fb_StrConcat( &TMP$88$2, (void*)"_{fbdata}_", 11ll, *(void**)((uint8*)LABEL$1 + 32ll), 0ll );
+		fb_StrAssign( (void*)&ID$1, -1ll, (void*)vr$13, -1ll, 0 );
+		*(int64*)((int64)(struct $10FBARRAYDIM*)DTB$1 + 8ll) = 0ll;
 	}
 	label$57:;
-	struct $8FBSYMBOL* vr$17 = SYMBLOOKUPBYNAMEANDCLASS( (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll), (uint8*)*(uint8**)&ID$1, 1ll, -1ll, 0ll );
-	SYM$1 = vr$17;
+	struct $8FBSYMBOL* vr$15 = SYMBLOOKUPBYNAMEANDCLASS( (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll), (uint8*)*(uint8**)&ID$1, 1ll, -1ll, 0ll );
+	SYM$1 = vr$15;
 	if( SYM$1 == (struct $8FBSYMBOL*)0ull ) goto label$62;
 	{
 		if( LABEL$1 != (struct $8FBSYMBOL*)0ull ) goto label$64;
 		{
-			SYMBSETARRAYDIMTB( SYM$1, 1ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$82$1 );
+			SYMBSETARRAYDIMTB( SYM$1, 1ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$86$1 );
 			SYMBMAYBEADDARRAYDESC( SYM$1 );
 		}
 		label$64:;
@@ -1155,10 +1180,10 @@ struct $8FBSYMBOL* ASTDATASTMTADD( struct $8FBSYMBOL* LABEL$1, int64 ELEMENTS$1
 	}
 	label$62:;
 	label$61:;
-	uint8* vr$18 = SYMBUNIQUELABEL(  );
-	struct $8FBSYMBOL* vr$19 = SYMBADDVAR( (uint8*)*(uint8**)&ID$1, (uint8*)vr$18, 20ll, *(struct $8FBSYMBOL**)((uint8*)&AST$ + 232ll), 0ll, 1ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$82$1, 3ll, 9ll );
-	SYM$1 = vr$19;
-	*(struct $8FBSYMBOL**)((uint8*)SYM$1 + 168ll) = (struct $8FBSYMBOL*)0ull;
+	uint8* vr$16 = SYMBUNIQUELABEL(  );
+	struct $8FBSYMBOL* vr$17 = SYMBADDVAR( (uint8*)*(uint8**)&ID$1, (uint8*)vr$16, 20ll, *(struct $8FBSYMBOL**)((uint8*)&AST$ + 232ll), 0ll, 1ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$86$1, 3ll, 9ll );
+	SYM$1 = vr$17;
+	*(struct $8FBSYMBOL**)((uint8*)SYM$1 + 176ll) = (struct $8FBSYMBOL*)0ull;
 	fb$result$1 = SYM$1;
 	label$56:;
 	return fb$result$1;
@@ -1167,7 +1192,7 @@ struct $8FBSYMBOL* ASTDATASTMTADD( struct $8FBSYMBOL* LABEL$1, int64 ELEMENTS$1
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1176,20 +1201,11 @@ static void HCREATEDATADESC( void )
 {
 	label$65:;
 	static struct $10FBARRAYDIM DTB$1[1];
-	struct $8FBARRAY1I10FBARRAYDIME {
-		struct $10FBARRAYDIM* DATA;
-		struct $10FBARRAYDIM* PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10FBARRAYDIME ) == 64 );
-	static struct $8FBARRAY1I10FBARRAYDIME tmp$85$1 = { (struct $10FBARRAYDIM*)DTB$1, (struct $10FBARRAYDIM*)DTB$1, 16ll, 16ll, 1ll, { { 1ll, 0ll, 0ll } } };
+	static struct $8FBARRAY1I10FBARRAYDIME tmp$89$1 = { (struct $10FBARRAYDIM*)DTB$1, (struct $10FBARRAYDIM*)DTB$1, 16ll, 16ll, 1ll, 49ll, { { 1ll, 0ll, 0ll } } };
 	struct $8FBSYMBOL* vr$0 = SYMBSTRUCTBEGIN( (struct $10FBSYMBOLTB*)0ull, (struct $8FBHASHTB*)0ull, (struct $8FBSYMBOL*)0ull, (uint8*)"__FB_DATADESC$", (uint8*)0ull, 0ll, 1ll, 0ll, 0ll, 0ll );
 	*(struct $8FBSYMBOL**)((uint8*)&AST$ + 232ll) = vr$0;
-	SYMBADDFIELD( *(struct $8FBSYMBOL**)((uint8*)&AST$ + 232ll), (uint8*)"type", 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$85$1, 5ll, (struct $8FBSYMBOL*)0ull, 0ll, 0ll, 0ll );
-	SYMBADDFIELD( *(struct $8FBSYMBOL**)((uint8*)&AST$ + 232ll), (uint8*)"node", 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$85$1, 32ll, (struct $8FBSYMBOL*)0ull, 0ll, 0ll, 0ll );
+	SYMBADDFIELD( *(struct $8FBSYMBOL**)((uint8*)&AST$ + 232ll), (uint8*)"type", 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$89$1, 5ll, (struct $8FBSYMBOL*)0ull, 0ll, 0ll, 0ll );
+	SYMBADDFIELD( *(struct $8FBSYMBOL**)((uint8*)&AST$ + 232ll), (uint8*)"node", 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$89$1, 32ll, (struct $8FBSYMBOL*)0ull, 0ll, 0ll, 0ll );
 	SYMBSTRUCTEND( *(struct $8FBSYMBOL**)((uint8*)&AST$ + 232ll), 0ll );
 	label$66:;
 }
