@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +513,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +582,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +612,18 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 typedef int64 $15IRVREGTYPE_ENUM;
 typedef int64 $12IR_REGFAMILY;
 struct $6IRVREG;
@@ -643,9 +669,9 @@ struct $6IRVREG {
 	struct $5IRTAC* TACLAST;
 };
 __FB_STATIC_ASSERT( sizeof( struct $6IRVREG ) == 120 );
-typedef void (*tmp$33)( void );
-typedef void (*tmp$52)( int64, struct $8FBSYMBOL* );
-typedef void (*tmp$37)( struct $8FBSYMBOL* );
+typedef void (*tmp$38)( void );
+typedef void (*tmp$56)( int64, struct $8FBSYMBOL* );
+typedef void (*tmp$42)( struct $8FBSYMBOL* );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -662,7 +688,8 @@ struct $7ASTNODE* ASTNEWASSIGN( struct $7ASTNODE*, struct $7ASTNODE*, $9AST_OPOP
 int64 ASTTRYOVLSTRINGCONV( struct $7ASTNODE** );
 int64 ASTCONSTEQZERO( struct $7ASTNODE* );
 struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL*, int64, int64, struct $8FBSYMBOL* );
-struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
+typedef int64 $15AST_LINK_RETURN;
+struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, $15AST_LINK_RETURN );
 struct $7ASTNODE* ASTNEWNODE( int64, int64, struct $8FBSYMBOL* );
 struct $6IRVREG* ASTLOAD( struct $7ASTNODE* );
 struct $7ASTNODE* ASTTYPEINIUPDATE( struct $7ASTNODE* );
@@ -683,122 +710,120 @@ int64 SYMBHASCTOR( struct $8FBSYMBOL* );
 int64 SYMBHASDEFCTOR( struct $8FBSYMBOL* );
 void TYPEMAX( int64, struct $8FBSYMBOL*, int64, struct $8FBSYMBOL*, int64*, struct $8FBSYMBOL** );
 int64 HCHECKTYPES( int64, struct $8FBSYMBOL*, int64, struct $8FBSYMBOL*, int64*, struct $8FBSYMBOL** );
-typedef int64 (*tmp$34)( void );
+typedef int64 (*tmp$39)( void );
 typedef int64 $14IR_OPTIONVALUE;
-typedef int64 (*tmp$35)( $14IR_OPTIONVALUE );
-typedef int64 (*tmp$36)( int64, int64 );
-typedef void (*tmp$38)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef uint8* (*tmp$39)( void );
-typedef void (*tmp$40)( struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$41)( int64 );
-typedef void (*tmp$42)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$44)( struct $9ASTASMTOK* );
-typedef void (*tmp$45)( uint8* );
-typedef void (*tmp$46)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
-typedef void (*tmp$47)( int64, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$48)( struct $6IRVREG* );
-typedef void (*tmp$49)( int64, struct $6IRVREG* );
-typedef void (*tmp$50)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
-typedef void (*tmp$51)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$53)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
-typedef void (*tmp$54)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
-typedef void (*tmp$55)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$56)( int64, struct $8FBSYMBOL*, int64, uint8* );
-typedef void (*tmp$57)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$58)( struct $8FBSYMBOL*, double );
-typedef void (*tmp$59)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$60)( int64, uint8*, int64 );
-typedef void (*tmp$61)( int64, uint16*, int64 );
-typedef void (*tmp$62)( int64 );
-typedef void (*tmp$63)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$64)( uint8* );
-typedef struct $6IRVREG* (*tmp$65)( int64, struct $8FBSYMBOL* );
-typedef struct $6IRVREG* (*tmp$66)( int64, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$67)( int64, struct $8FBSYMBOL*, double );
-typedef struct $6IRVREG* (*tmp$68)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
-typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
-typedef void (*tmp$71)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
-typedef uint64 (*tmp$72)( struct $6IRVREG* );
+typedef int64 (*tmp$40)( $14IR_OPTIONVALUE );
+typedef int64 (*tmp$41)( int64, int64 );
+typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef uint8* (*tmp$44)( void );
+typedef void (*tmp$45)( struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$46)( int64 );
+typedef void (*tmp$47)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef void (*tmp$48)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64, struct $6IRVREG* );
+typedef void (*tmp$49)( struct $9ASTASMTOK* );
+typedef void (*tmp$50)( uint8* );
+typedef void (*tmp$51)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
+typedef void (*tmp$52)( int64, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$53)( struct $6IRVREG* );
+typedef void (*tmp$54)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
+typedef void (*tmp$55)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
+typedef void (*tmp$57)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
+typedef void (*tmp$58)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
+typedef void (*tmp$59)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$60)( int64, struct $8FBSYMBOL*, int64, uint8* );
+typedef void (*tmp$61)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$62)( struct $8FBSYMBOL*, double );
+typedef void (*tmp$63)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$64)( int64, uint8*, int64 );
+typedef void (*tmp$65)( int64, uint16*, int64 );
+typedef void (*tmp$66)( int64 );
+typedef void (*tmp$67)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$68)( uint8* );
+typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL* );
+typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$71)( int64, struct $8FBSYMBOL*, double );
+typedef struct $6IRVREG* (*tmp$72)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$73)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
+typedef struct $6IRVREG* (*tmp$74)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
+typedef void (*tmp$75)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
+typedef uint64 (*tmp$76)( struct $6IRVREG* );
 struct $7IR_VTBL {
-	tmp$33 INIT;
-	tmp$33 END;
-	tmp$34 EMITBEGIN;
-	tmp$33 EMITEND;
-	tmp$35 GETOPTIONVALUE;
-	tmp$36 SUPPORTSOP;
-	tmp$37 PROCBEGIN;
-	tmp$37 PROCEND;
-	tmp$38 PROCALLOCARG;
-	tmp$38 PROCALLOCLOCAL;
-	tmp$39 PROCGETFRAMEREGNAME;
-	tmp$37 SCOPEBEGIN;
-	tmp$37 SCOPEEND;
-	tmp$37 PROCALLOCSTATICVARS;
-	tmp$40 EMITCONVERT;
-	tmp$37 EMITLABEL;
-	tmp$37 EMITLABELNF;
-	tmp$41 EMITRETURN;
-	tmp$38 EMITPROCBEGIN;
-	tmp$42 EMITPROCEND;
-	tmp$43 EMITPUSHARG;
-	tmp$44 EMITASMLINE;
-	tmp$45 EMITCOMMENT;
-	tmp$46 EMITBOP;
-	tmp$47 EMITUOP;
-	tmp$40 EMITSTORE;
-	tmp$33 EMITSPILLREGS;
-	tmp$48 EMITLOAD;
-	tmp$40 EMITLOADRES;
-	tmp$49 EMITSTACK;
-	tmp$47 EMITADDR;
-	tmp$50 EMITCALL;
-	tmp$51 EMITCALLPTR;
-	tmp$41 EMITSTACKALIGN;
-	tmp$48 EMITJUMPPTR;
-	tmp$52 EMITBRANCH;
-	tmp$53 EMITJMPTB;
-	tmp$54 EMITMEM;
-	tmp$55 EMITMACRO;
-	tmp$37 EMITSCOPEBEGIN;
-	tmp$37 EMITSCOPEEND;
-	tmp$37 EMITDECL;
-	tmp$56 EMITDBG;
-	tmp$37 EMITVARINIBEGIN;
-	tmp$37 EMITVARINIEND;
-	tmp$57 EMITVARINII;
-	tmp$58 EMITVARINIF;
-	tmp$59 EMITVARINIOFS;
-	tmp$60 EMITVARINISTR;
-	tmp$61 EMITVARINIWSTR;
-	tmp$62 EMITVARINIPAD;
-	tmp$63 EMITVARINISCOPEBEGIN;
-	tmp$33 EMITVARINISCOPEEND;
-	tmp$33 EMITFBCTINFBEGIN;
-	tmp$64 EMITFBCTINFSTRING;
-	tmp$33 EMITFBCTINFEND;
-	tmp$65 ALLOCVREG;
-	tmp$66 ALLOCVRIMM;
-	tmp$67 ALLOCVRIMMF;
-	tmp$68 ALLOCVRVAR;
-	tmp$69 ALLOCVRIDX;
-	tmp$70 ALLOCVRPTR;
-	tmp$68 ALLOCVROFS;
-	tmp$71 SETVREGDATATYPE;
-	tmp$72 GETDISTANCE;
-	tmp$47 LOADVR;
-	tmp$40 STOREVR;
-	tmp$41 XCHGTOS;
+	tmp$38 INIT;
+	tmp$38 END;
+	tmp$39 EMITBEGIN;
+	tmp$38 EMITEND;
+	tmp$40 GETOPTIONVALUE;
+	tmp$41 SUPPORTSOP;
+	tmp$42 PROCBEGIN;
+	tmp$42 PROCEND;
+	tmp$43 PROCALLOCARG;
+	tmp$43 PROCALLOCLOCAL;
+	tmp$44 PROCGETFRAMEREGNAME;
+	tmp$42 SCOPEBEGIN;
+	tmp$42 SCOPEEND;
+	tmp$42 PROCALLOCSTATICVARS;
+	tmp$45 EMITCONVERT;
+	tmp$42 EMITLABEL;
+	tmp$42 EMITLABELNF;
+	tmp$46 EMITRETURN;
+	tmp$43 EMITPROCBEGIN;
+	tmp$47 EMITPROCEND;
+	tmp$48 EMITPUSHARG;
+	tmp$49 EMITASMLINE;
+	tmp$50 EMITCOMMENT;
+	tmp$51 EMITBOP;
+	tmp$52 EMITUOP;
+	tmp$45 EMITSTORE;
+	tmp$38 EMITSPILLREGS;
+	tmp$53 EMITLOAD;
+	tmp$45 EMITLOADRES;
+	tmp$52 EMITSTACK;
+	tmp$52 EMITADDR;
+	tmp$54 EMITCALL;
+	tmp$55 EMITCALLPTR;
+	tmp$46 EMITSTACKALIGN;
+	tmp$53 EMITJUMPPTR;
+	tmp$56 EMITBRANCH;
+	tmp$57 EMITJMPTB;
+	tmp$58 EMITMEM;
+	tmp$59 EMITMACRO;
+	tmp$42 EMITSCOPEBEGIN;
+	tmp$42 EMITSCOPEEND;
+	tmp$42 EMITDECL;
+	tmp$60 EMITDBG;
+	tmp$42 EMITVARINIBEGIN;
+	tmp$42 EMITVARINIEND;
+	tmp$61 EMITVARINII;
+	tmp$62 EMITVARINIF;
+	tmp$63 EMITVARINIOFS;
+	tmp$64 EMITVARINISTR;
+	tmp$65 EMITVARINIWSTR;
+	tmp$66 EMITVARINIPAD;
+	tmp$67 EMITVARINISCOPEBEGIN;
+	tmp$38 EMITVARINISCOPEEND;
+	tmp$38 EMITFBCTINFBEGIN;
+	tmp$68 EMITFBCTINFSTRING;
+	tmp$38 EMITFBCTINFEND;
+	tmp$69 ALLOCVREG;
+	tmp$70 ALLOCVRIMM;
+	tmp$71 ALLOCVRIMMF;
+	tmp$72 ALLOCVRVAR;
+	tmp$73 ALLOCVRIDX;
+	tmp$74 ALLOCVRPTR;
+	tmp$72 ALLOCVROFS;
+	tmp$75 SETVREGDATATYPE;
+	tmp$76 GETDISTANCE;
+	tmp$52 LOADVR;
+	tmp$45 STOREVR;
+	tmp$46 XCHGTOS;
 };
 __FB_STATIC_ASSERT( sizeof( struct $7IR_VTBL ) == 544 );
 typedef int64 $6IR_OPT;
 struct $5IRCTX {
-	int64 INITED;
 	struct $7IR_VTBL VTBL;
 	$6IR_OPT OPTIONS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 560 );
+__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 552 );
 extern struct $5IRCTX IR$;
 struct $12AST_PROC_CTX {
 	struct $7ASTNODE* HEAD;
@@ -868,21 +893,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -890,20 +905,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
 int64 HCHECKTYPES( int64 LDTYPE$1, struct $8FBSYMBOL* LSUBTYPE$1, int64 RDTYPE$1, struct $8FBSYMBOL* RSUBTYPE$1, int64* DTYPE$1, struct $8FBSYMBOL** SUBTYPE$1 )
 {
@@ -932,7 +949,7 @@ int64 HCHECKTYPES( int64 LDTYPE$1, struct $8FBSYMBOL* LSUBTYPE$1, int64 RDTYPE$1
 		goto label$14;
 		label$15:;
 		{
-			int64 TMP$80$3;
+			int64 TMP$84$3;
 			if( LMATCH$1 == 0ll ) goto label$19;
 			{
 				*DTYPE$1 = LDTYPE$1;
@@ -948,23 +965,23 @@ int64 HCHECKTYPES( int64 LDTYPE$1, struct $8FBSYMBOL* LSUBTYPE$1, int64 RDTYPE$1
 			}
 			label$18:;
 			if( (OTHERDTYPE$1 & 480ll) == 0ll ) goto label$20;
-			TMP$80$3 = 24ll;
+			TMP$84$3 = 24ll;
 			goto label$49;
 			label$20:;
-			TMP$80$3 = OTHERDTYPE$1 & 31ll;
+			TMP$84$3 = OTHERDTYPE$1 & 31ll;
 			label$49:;
-			if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$80$3 * 56ll)) == 0ll ) goto label$22;
+			if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$84$3 * 56ll)) == 0ll ) goto label$22;
 			{
 				goto label$11;
 			}
 			label$22:;
 			label$21:;
 			{
-				int64 TMP$81$4;
-				TMP$81$4 = OTHERDTYPE$1 & 31ll;
-				if( TMP$81$4 == 4ll ) goto label$25;
+				int64 TMP$85$4;
+				TMP$85$4 = OTHERDTYPE$1 & 31ll;
+				if( TMP$85$4 == 4ll ) goto label$25;
 				label$26:;
-				if( TMP$81$4 != 7ll ) goto label$24;
+				if( TMP$85$4 != 7ll ) goto label$24;
 				label$25:;
 				{
 					goto label$11;
@@ -1130,7 +1147,7 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 	{
 		if( *(int64*)((uint8*)TRUEXPR$1 + 8ll) != 20ll ) goto label$61;
 		{
-			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)TRUEXPR$1 + 16ll) + 200ll) & 524288ll) == 0ll ) goto label$63;
+			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)TRUEXPR$1 + 16ll) + 208ll) & 131072ll) == 0ll ) goto label$63;
 			{
 				if( *(int64*)((uint8*)FALSEXPR$1 + 8ll) != 4ll ) goto label$65;
 				{
@@ -1142,7 +1159,7 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 			}
 			goto label$62;
 			label$63:;
-			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)TRUEXPR$1 + 16ll) + 200ll) & 262144ll) == 0ll ) goto label$66;
+			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)TRUEXPR$1 + 16ll) + 208ll) & 65536ll) == 0ll ) goto label$66;
 			{
 				if( *(int64*)((uint8*)FALSEXPR$1 + 8ll) != 7ll ) goto label$68;
 				{
@@ -1159,7 +1176,7 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 		label$61:;
 		if( *(int64*)((uint8*)FALSEXPR$1 + 8ll) != 20ll ) goto label$69;
 		{
-			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)FALSEXPR$1 + 16ll) + 200ll) & 524288ll) == 0ll ) goto label$71;
+			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)FALSEXPR$1 + 16ll) + 208ll) & 131072ll) == 0ll ) goto label$71;
 			{
 				if( *(int64*)((uint8*)TRUEXPR$1 + 8ll) != 4ll ) goto label$73;
 				{
@@ -1171,7 +1188,7 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 			}
 			goto label$70;
 			label$71:;
-			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)FALSEXPR$1 + 16ll) + 200ll) & 262144ll) == 0ll ) goto label$74;
+			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)FALSEXPR$1 + 16ll) + 208ll) & 65536ll) == 0ll ) goto label$74;
 			{
 				if( *(int64*)((uint8*)TRUEXPR$1 + 8ll) != 7ll ) goto label$76;
 				{
@@ -1208,11 +1225,11 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 	label$80:;
 	label$79:;
 	{
-		int64 TMP$82$2;
-		TMP$82$2 = DTYPE$1 & 511ll;
-		if( TMP$82$2 == 18ll ) goto label$83;
+		int64 TMP$86$2;
+		TMP$86$2 = DTYPE$1 & 511ll;
+		if( TMP$86$2 == 18ll ) goto label$83;
 		label$84:;
-		if( TMP$82$2 != 4ll ) goto label$82;
+		if( TMP$86$2 != 4ll ) goto label$82;
 		label$83:;
 		{
 			DTYPE$1 = 17ll;
@@ -1224,7 +1241,7 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 	{
 		struct $8FBSYMBOL* vr$60 = SYMBADDTEMPVAR( 39ll, (struct $8FBSYMBOL*)0ull );
 		TEMP$1 = vr$60;
-		*($12FB_SYMBSTATS*)((uint8*)TEMP$1 + 16ll) = *(int64*)((uint8*)TEMP$1 + 16ll) | 16777216ll;
+		*($12FB_SYMBSTATS*)((uint8*)TEMP$1 + 24ll) = *(int64*)((uint8*)TEMP$1 + 24ll) | 16777216ll;
 		ASTDTORLISTADD( TEMP$1 );
 		struct $7ASTNODE* vr$64 = ASTBUILDFAKEWSTRINGACCESS( TEMP$1 );
 		VAREXPR$1 = vr$64;
@@ -1296,7 +1313,7 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 			{
 				struct $7ASTNODE* vr$79 = ASTNEWVAR( TEMP$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 				struct $7ASTNODE* vr$80 = ASTBUILDCTORCALL( SUBTYPE$1, vr$79 );
-				struct $7ASTNODE* vr$81 = ASTNEWLINK( vr$80, CONDEXPR$1, -1ll );
+				struct $7ASTNODE* vr$81 = ASTNEWLINK( vr$80, CONDEXPR$1, 0ll );
 				CONDEXPR$1 = vr$81;
 			}
 			label$89:;
@@ -1325,7 +1342,7 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 			{
 				struct $7ASTNODE* vr$88 = ASTNEWVAR( TEMP$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 				struct $7ASTNODE* vr$89 = ASTBUILDCTORCALL( SUBTYPE$1, vr$88 );
-				struct $7ASTNODE* vr$90 = ASTNEWLINK( vr$89, TRUEXPR$1, -1ll );
+				struct $7ASTNODE* vr$90 = ASTNEWLINK( vr$89, TRUEXPR$1, 0ll );
 				TRUEXPR$1 = vr$90;
 			}
 			label$102:;
@@ -1344,7 +1361,7 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 			{
 				struct $7ASTNODE* vr$93 = ASTNEWVAR( TEMP$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 				struct $7ASTNODE* vr$94 = ASTBUILDCTORCALL( SUBTYPE$1, vr$93 );
-				struct $7ASTNODE* vr$95 = ASTNEWLINK( vr$94, FALSEXPR$1, -1ll );
+				struct $7ASTNODE* vr$95 = ASTNEWLINK( vr$94, FALSEXPR$1, 0ll );
 				FALSEXPR$1 = vr$95;
 			}
 			label$106:;
@@ -1366,7 +1383,7 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 	if( TRUECOOKIE$1 == 0ll ) goto label$108;
 	{
 		struct $7ASTNODE* vr$98 = ASTDTORLISTFLUSH( TRUECOOKIE$1 );
-		struct $7ASTNODE* vr$99 = ASTNEWLINK( TRUEXPR$1, vr$98, -1ll );
+		struct $7ASTNODE* vr$99 = ASTNEWLINK( TRUEXPR$1, vr$98, 0ll );
 		TRUEXPR$1 = vr$99;
 	}
 	label$108:;
@@ -1374,7 +1391,7 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 	if( FALSECOOKIE$1 == 0ll ) goto label$110;
 	{
 		struct $7ASTNODE* vr$100 = ASTDTORLISTFLUSH( FALSECOOKIE$1 );
-		struct $7ASTNODE* vr$101 = ASTNEWLINK( FALSEXPR$1, vr$100, -1ll );
+		struct $7ASTNODE* vr$101 = ASTNEWLINK( FALSEXPR$1, vr$100, 0ll );
 		FALSEXPR$1 = vr$101;
 	}
 	label$110:;
@@ -1383,8 +1400,8 @@ struct $7ASTNODE* ASTNEWIIF( struct $7ASTNODE* CONDEXPR$1, struct $7ASTNODE* TRU
 	N$1 = vr$102;
 	*(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll) = TEMP$1;
 	*(struct $7ASTNODE**)((uint8*)N$1 + 112ll) = VAREXPR$1;
-	struct $7ASTNODE* vr$105 = ASTNEWLINK( TRUEXPR$1, FALSEXPR$1, -1ll );
-	struct $7ASTNODE* vr$106 = ASTNEWLINK( CONDEXPR$1, vr$105, -1ll );
+	struct $7ASTNODE* vr$105 = ASTNEWLINK( TRUEXPR$1, FALSEXPR$1, 0ll );
+	struct $7ASTNODE* vr$106 = ASTNEWLINK( CONDEXPR$1, vr$105, 0ll );
 	*(struct $7ASTNODE**)((uint8*)N$1 + 120ll) = vr$106;
 	*(struct $8FBSYMBOL**)((uint8*)N$1 + 40ll) = FALSELABEL$1;
 	fb$result$1 = N$1;
@@ -1406,7 +1423,7 @@ struct $6IRVREG* ASTLOADIIF( struct $7ASTNODE* N$1 )
 	FALSEXPR$1 = *(struct $7ASTNODE**)((uint8*)*(struct $7ASTNODE**)((uint8*)*(struct $7ASTNODE**)((uint8*)N$1 + 120ll) + 120ll) + 120ll);
 	if( *(int64*)((uint8*)&AST$ + 272ll) == 0ll ) goto label$114;
 	{
-		(*(tmp$33*)((uint8*)&IR$ + 216ll))(  );
+		(*(tmp$38*)((uint8*)&IR$ + 208ll))(  );
 	}
 	label$114:;
 	label$113:;
@@ -1418,19 +1435,19 @@ struct $6IRVREG* ASTLOADIIF( struct $7ASTNODE* N$1 )
 	ASTDELNODE( TRUEXPR$1 );
 	if( *(int64*)((uint8*)&AST$ + 272ll) == 0ll ) goto label$116;
 	{
-		(*(tmp$52*)((uint8*)&IR$ + 288ll))( 98ll, EXITLABEL$1 );
+		(*(tmp$56*)((uint8*)&IR$ + 280ll))( 98ll, EXITLABEL$1 );
 	}
 	label$116:;
 	label$115:;
 	if( *(int64*)((uint8*)&AST$ + 272ll) == 0ll ) goto label$118;
 	{
-		(*(tmp$37*)((uint8*)&IR$ + 136ll))( *(struct $8FBSYMBOL**)((uint8*)N$1 + 40ll) );
+		(*(tmp$42*)((uint8*)&IR$ + 128ll))( *(struct $8FBSYMBOL**)((uint8*)N$1 + 40ll) );
 	}
 	label$118:;
 	label$117:;
 	if( *(int64*)((uint8*)&AST$ + 272ll) == 0ll ) goto label$120;
 	{
-		(*(tmp$33*)((uint8*)&IR$ + 216ll))(  );
+		(*(tmp$38*)((uint8*)&IR$ + 208ll))(  );
 	}
 	label$120:;
 	label$119:;
@@ -1438,7 +1455,7 @@ struct $6IRVREG* ASTLOADIIF( struct $7ASTNODE* N$1 )
 	ASTDELNODE( FALSEXPR$1 );
 	if( *(int64*)((uint8*)&AST$ + 272ll) == 0ll ) goto label$122;
 	{
-		(*(tmp$37*)((uint8*)&IR$ + 136ll))( EXITLABEL$1 );
+		(*(tmp$42*)((uint8*)&IR$ + 128ll))( EXITLABEL$1 );
 	}
 	label$122:;
 	label$121:;
@@ -1454,7 +1471,7 @@ struct $6IRVREG* ASTLOADIIF( struct $7ASTNODE* N$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
