@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +317,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +386,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +416,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +566,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -599,7 +614,18 @@ struct $7ASTNODE {
 };
 __FB_STATIC_ASSERT( sizeof( struct $7ASTNODE ) == 144 );
 typedef int64 $14IR_OPTIONVALUE;
-typedef int64 (*tmp$35)( $14IR_OPTIONVALUE );
+typedef int64 (*tmp$40)( $14IR_OPTIONVALUE );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 typedef int64 $15IRVREGTYPE_ENUM;
 typedef int64 $12IR_REGFAMILY;
 struct $6IRVREG;
@@ -645,7 +671,7 @@ struct $6IRVREG {
 	struct $5IRTAC* TACLAST;
 };
 __FB_STATIC_ASSERT( sizeof( struct $6IRVREG ) == 120 );
-typedef void (*tmp$54)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
+typedef void (*tmp$58)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -668,7 +694,8 @@ struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL*, int64, int64, struct $8FBSYMBOL
 struct $7ASTNODE* ASTNEWDEREF( struct $7ASTNODE*, int64, struct $8FBSYMBOL*, int64 );
 struct $7ASTNODE* ASTNEWADDROF( struct $7ASTNODE* );
 struct $7ASTNODE* ASTNEWLOOP( struct $8FBSYMBOL*, struct $7ASTNODE* );
-struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
+typedef int64 $15AST_LINK_RETURN;
+struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, $15AST_LINK_RETURN );
 struct $7ASTNODE* ASTNEWLABEL( struct $8FBSYMBOL*, int64 );
 struct $7ASTNODE* ASTNEWMEM( int64, struct $7ASTNODE*, struct $7ASTNODE*, int64 );
 struct $7ASTNODE* ASTNEWNODE( int64, int64, struct $8FBSYMBOL* );
@@ -697,122 +724,120 @@ struct $7ASTNODE* RTLMEMDELETEOP( int64, struct $7ASTNODE*, int64, struct $8FBSY
 static struct $7ASTNODE* HCALLCTORLIST( struct $8FBSYMBOL*, struct $7ASTNODE*, int64, struct $8FBSYMBOL* );
 static struct $7ASTNODE* HELEMENTS( struct $7ASTNODE*, int64* );
 static struct $7ASTNODE* HCALLDTORLIST( struct $7ASTNODE* );
-typedef void (*tmp$33)( void );
-typedef int64 (*tmp$34)( void );
-typedef int64 (*tmp$36)( int64, int64 );
-typedef void (*tmp$37)( struct $8FBSYMBOL* );
-typedef void (*tmp$38)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef uint8* (*tmp$39)( void );
-typedef void (*tmp$40)( struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$41)( int64 );
-typedef void (*tmp$42)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$44)( struct $9ASTASMTOK* );
-typedef void (*tmp$45)( uint8* );
-typedef void (*tmp$46)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
-typedef void (*tmp$47)( int64, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$48)( struct $6IRVREG* );
-typedef void (*tmp$49)( int64, struct $6IRVREG* );
-typedef void (*tmp$50)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
-typedef void (*tmp$51)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$52)( int64, struct $8FBSYMBOL* );
-typedef void (*tmp$53)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
-typedef void (*tmp$55)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$56)( int64, struct $8FBSYMBOL*, int64, uint8* );
-typedef void (*tmp$57)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$58)( struct $8FBSYMBOL*, double );
-typedef void (*tmp$59)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$60)( int64, uint8*, int64 );
-typedef void (*tmp$61)( int64, uint16*, int64 );
-typedef void (*tmp$62)( int64 );
-typedef void (*tmp$63)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$64)( uint8* );
-typedef struct $6IRVREG* (*tmp$65)( int64, struct $8FBSYMBOL* );
-typedef struct $6IRVREG* (*tmp$66)( int64, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$67)( int64, struct $8FBSYMBOL*, double );
-typedef struct $6IRVREG* (*tmp$68)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
-typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
-typedef void (*tmp$71)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
-typedef uint64 (*tmp$72)( struct $6IRVREG* );
+typedef void (*tmp$38)( void );
+typedef int64 (*tmp$39)( void );
+typedef int64 (*tmp$41)( int64, int64 );
+typedef void (*tmp$42)( struct $8FBSYMBOL* );
+typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef uint8* (*tmp$44)( void );
+typedef void (*tmp$45)( struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$46)( int64 );
+typedef void (*tmp$47)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef void (*tmp$48)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64, struct $6IRVREG* );
+typedef void (*tmp$49)( struct $9ASTASMTOK* );
+typedef void (*tmp$50)( uint8* );
+typedef void (*tmp$51)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
+typedef void (*tmp$52)( int64, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$53)( struct $6IRVREG* );
+typedef void (*tmp$54)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
+typedef void (*tmp$55)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
+typedef void (*tmp$56)( int64, struct $8FBSYMBOL* );
+typedef void (*tmp$57)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
+typedef void (*tmp$59)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$60)( int64, struct $8FBSYMBOL*, int64, uint8* );
+typedef void (*tmp$61)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$62)( struct $8FBSYMBOL*, double );
+typedef void (*tmp$63)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$64)( int64, uint8*, int64 );
+typedef void (*tmp$65)( int64, uint16*, int64 );
+typedef void (*tmp$66)( int64 );
+typedef void (*tmp$67)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$68)( uint8* );
+typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL* );
+typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$71)( int64, struct $8FBSYMBOL*, double );
+typedef struct $6IRVREG* (*tmp$72)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$73)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
+typedef struct $6IRVREG* (*tmp$74)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
+typedef void (*tmp$75)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
+typedef uint64 (*tmp$76)( struct $6IRVREG* );
 struct $7IR_VTBL {
-	tmp$33 INIT;
-	tmp$33 END;
-	tmp$34 EMITBEGIN;
-	tmp$33 EMITEND;
-	tmp$35 GETOPTIONVALUE;
-	tmp$36 SUPPORTSOP;
-	tmp$37 PROCBEGIN;
-	tmp$37 PROCEND;
-	tmp$38 PROCALLOCARG;
-	tmp$38 PROCALLOCLOCAL;
-	tmp$39 PROCGETFRAMEREGNAME;
-	tmp$37 SCOPEBEGIN;
-	tmp$37 SCOPEEND;
-	tmp$37 PROCALLOCSTATICVARS;
-	tmp$40 EMITCONVERT;
-	tmp$37 EMITLABEL;
-	tmp$37 EMITLABELNF;
-	tmp$41 EMITRETURN;
-	tmp$38 EMITPROCBEGIN;
-	tmp$42 EMITPROCEND;
-	tmp$43 EMITPUSHARG;
-	tmp$44 EMITASMLINE;
-	tmp$45 EMITCOMMENT;
-	tmp$46 EMITBOP;
-	tmp$47 EMITUOP;
-	tmp$40 EMITSTORE;
-	tmp$33 EMITSPILLREGS;
-	tmp$48 EMITLOAD;
-	tmp$40 EMITLOADRES;
-	tmp$49 EMITSTACK;
-	tmp$47 EMITADDR;
-	tmp$50 EMITCALL;
-	tmp$51 EMITCALLPTR;
-	tmp$41 EMITSTACKALIGN;
-	tmp$48 EMITJUMPPTR;
-	tmp$52 EMITBRANCH;
-	tmp$53 EMITJMPTB;
-	tmp$54 EMITMEM;
-	tmp$55 EMITMACRO;
-	tmp$37 EMITSCOPEBEGIN;
-	tmp$37 EMITSCOPEEND;
-	tmp$37 EMITDECL;
-	tmp$56 EMITDBG;
-	tmp$37 EMITVARINIBEGIN;
-	tmp$37 EMITVARINIEND;
-	tmp$57 EMITVARINII;
-	tmp$58 EMITVARINIF;
-	tmp$59 EMITVARINIOFS;
-	tmp$60 EMITVARINISTR;
-	tmp$61 EMITVARINIWSTR;
-	tmp$62 EMITVARINIPAD;
-	tmp$63 EMITVARINISCOPEBEGIN;
-	tmp$33 EMITVARINISCOPEEND;
-	tmp$33 EMITFBCTINFBEGIN;
-	tmp$64 EMITFBCTINFSTRING;
-	tmp$33 EMITFBCTINFEND;
-	tmp$65 ALLOCVREG;
-	tmp$66 ALLOCVRIMM;
-	tmp$67 ALLOCVRIMMF;
-	tmp$68 ALLOCVRVAR;
-	tmp$69 ALLOCVRIDX;
-	tmp$70 ALLOCVRPTR;
-	tmp$68 ALLOCVROFS;
-	tmp$71 SETVREGDATATYPE;
-	tmp$72 GETDISTANCE;
-	tmp$47 LOADVR;
-	tmp$40 STOREVR;
-	tmp$41 XCHGTOS;
+	tmp$38 INIT;
+	tmp$38 END;
+	tmp$39 EMITBEGIN;
+	tmp$38 EMITEND;
+	tmp$40 GETOPTIONVALUE;
+	tmp$41 SUPPORTSOP;
+	tmp$42 PROCBEGIN;
+	tmp$42 PROCEND;
+	tmp$43 PROCALLOCARG;
+	tmp$43 PROCALLOCLOCAL;
+	tmp$44 PROCGETFRAMEREGNAME;
+	tmp$42 SCOPEBEGIN;
+	tmp$42 SCOPEEND;
+	tmp$42 PROCALLOCSTATICVARS;
+	tmp$45 EMITCONVERT;
+	tmp$42 EMITLABEL;
+	tmp$42 EMITLABELNF;
+	tmp$46 EMITRETURN;
+	tmp$43 EMITPROCBEGIN;
+	tmp$47 EMITPROCEND;
+	tmp$48 EMITPUSHARG;
+	tmp$49 EMITASMLINE;
+	tmp$50 EMITCOMMENT;
+	tmp$51 EMITBOP;
+	tmp$52 EMITUOP;
+	tmp$45 EMITSTORE;
+	tmp$38 EMITSPILLREGS;
+	tmp$53 EMITLOAD;
+	tmp$45 EMITLOADRES;
+	tmp$52 EMITSTACK;
+	tmp$52 EMITADDR;
+	tmp$54 EMITCALL;
+	tmp$55 EMITCALLPTR;
+	tmp$46 EMITSTACKALIGN;
+	tmp$53 EMITJUMPPTR;
+	tmp$56 EMITBRANCH;
+	tmp$57 EMITJMPTB;
+	tmp$58 EMITMEM;
+	tmp$59 EMITMACRO;
+	tmp$42 EMITSCOPEBEGIN;
+	tmp$42 EMITSCOPEEND;
+	tmp$42 EMITDECL;
+	tmp$60 EMITDBG;
+	tmp$42 EMITVARINIBEGIN;
+	tmp$42 EMITVARINIEND;
+	tmp$61 EMITVARINII;
+	tmp$62 EMITVARINIF;
+	tmp$63 EMITVARINIOFS;
+	tmp$64 EMITVARINISTR;
+	tmp$65 EMITVARINIWSTR;
+	tmp$66 EMITVARINIPAD;
+	tmp$67 EMITVARINISCOPEBEGIN;
+	tmp$38 EMITVARINISCOPEEND;
+	tmp$38 EMITFBCTINFBEGIN;
+	tmp$68 EMITFBCTINFSTRING;
+	tmp$38 EMITFBCTINFEND;
+	tmp$69 ALLOCVREG;
+	tmp$70 ALLOCVRIMM;
+	tmp$71 ALLOCVRIMMF;
+	tmp$72 ALLOCVRVAR;
+	tmp$73 ALLOCVRIDX;
+	tmp$74 ALLOCVRPTR;
+	tmp$72 ALLOCVROFS;
+	tmp$75 SETVREGDATATYPE;
+	tmp$76 GETDISTANCE;
+	tmp$52 LOADVR;
+	tmp$45 STOREVR;
+	tmp$46 XCHGTOS;
 };
 __FB_STATIC_ASSERT( sizeof( struct $7IR_VTBL ) == 544 );
 typedef int64 $6IR_OPT;
 struct $5IRCTX {
-	int64 INITED;
 	struct $7IR_VTBL VTBL;
 	$6IR_OPT OPTIONS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 560 );
+__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 552 );
 extern struct $5IRCTX IR$;
 struct $12AST_PROC_CTX {
 	struct $7ASTNODE* HEAD;
@@ -882,21 +907,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -904,20 +919,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
 struct $7ASTNODE* ASTNEWMEM( int64 OP$1, struct $7ASTNODE* L$1, struct $7ASTNODE* R$1, int64 BYTES$1 )
 {
@@ -926,7 +943,7 @@ struct $7ASTNODE* ASTNEWMEM( int64 OP$1, struct $7ASTNODE* L$1, struct $7ASTNODE
 	label$10:;
 	struct $7ASTNODE* N$1;
 	uint64 BLKMAXLEN$1;
-	int64 vr$1 = (*(tmp$35*)((uint8*)&IR$ + 40ll))( 1ll );
+	int64 vr$1 = (*(tmp$40*)((uint8*)&IR$ + 32ll))( 1ll );
 	BLKMAXLEN$1 = (uint64)vr$1;
 	uint64 LGT$1;
 	LGT$1 = (uint64)BYTES$1;
@@ -1076,7 +1093,7 @@ struct $7ASTNODE* ASTBUILDNEWOP( $6AST_OP OP$1, struct $8FBSYMBOL* TMP$1, struct
 		LENEXPR$1 = vr$16;
 		if( SAVE_ELMTS$1 == 0ll ) goto label$53;
 		{
-			struct $7ASTNODE* vr$17 = ASTNEWCONSTI( *(int64*)((uint8*)SYMB_DTYPETB$ + 512ll), 9ll, (struct $8FBSYMBOL*)0ull );
+			struct $7ASTNODE* vr$17 = ASTNEWCONSTI( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 512ll), 9ll, (struct $8FBSYMBOL*)0ull );
 			struct $7ASTNODE* vr$18 = ASTNEWBOP( 28ll, LENEXPR$1, vr$17, (struct $8FBSYMBOL*)0ull, 1ll );
 			LENEXPR$1 = vr$18;
 		}
@@ -1095,7 +1112,7 @@ struct $7ASTNODE* ASTBUILDNEWOP( $6AST_OP OP$1, struct $8FBSYMBOL* TMP$1, struct
 	label$51:;
 	label$50:;
 	struct $7ASTNODE* vr$20 = _Z17ASTBUILDVARASSIGNP8FBSYMBOLP7ASTNODEu7INTEGER( TMP$1, NEWEXPR$1, 64ll );
-	struct $7ASTNODE* vr$21 = ASTNEWLINK( TREE$1, vr$20, -1ll );
+	struct $7ASTNODE* vr$21 = ASTNEWLINK( TREE$1, vr$20, 0ll );
 	TREE$1 = vr$21;
 	struct $8FBSYMBOL* vr$22 = SYMBADDLABEL( (uint8*)0ull, 4ll );
 	EXITLABEL$1 = vr$22;
@@ -1103,7 +1120,7 @@ struct $7ASTNODE* ASTBUILDNEWOP( $6AST_OP OP$1, struct $8FBSYMBOL* TMP$1, struct
 	struct $7ASTNODE* vr$24 = ASTNEWVAR( TMP$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$25 = ASTNEWBOP( 48ll, vr$24, vr$23, (struct $8FBSYMBOL*)0ull, 1ll );
 	struct $7ASTNODE* vr$26 = ASTBUILDBRANCH( vr$25, EXITLABEL$1, 0ll, -1ll );
-	struct $7ASTNODE* vr$27 = ASTNEWLINK( TREE$1, vr$26, -1ll );
+	struct $7ASTNODE* vr$27 = ASTNEWLINK( TREE$1, vr$26, 0ll );
 	TREE$1 = vr$27;
 	if( SAVE_ELMTS$1 == 0ll ) goto label$57;
 	{
@@ -1111,19 +1128,19 @@ struct $7ASTNODE* ASTBUILDNEWOP( $6AST_OP OP$1, struct $8FBSYMBOL* TMP$1, struct
 		struct $7ASTNODE* vr$30 = ASTNEWVAR( TMP$1, 0ll, 41ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$31 = ASTNEWDEREF( vr$30, 2147483648ll, (struct $8FBSYMBOL*)0ull, 0ll );
 		struct $7ASTNODE* vr$32 = ASTNEWASSIGN( vr$31, vr$29, 64ll );
-		struct $7ASTNODE* vr$33 = ASTNEWLINK( TREE$1, vr$32, -1ll );
+		struct $7ASTNODE* vr$33 = ASTNEWLINK( TREE$1, vr$32, 0ll );
 		TREE$1 = vr$33;
-		struct $7ASTNODE* vr$34 = ASTNEWCONSTI( *(int64*)((uint8*)SYMB_DTYPETB$ + 512ll), 8ll, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$34 = ASTNEWCONSTI( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 512ll), 8ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$35 = ASTNEWVAR( TMP$1, 0ll, 32ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$36 = ASTNEWSELFBOP( 1ll, vr$35, vr$34, (struct $8FBSYMBOL*)0ull, 1ll );
-		struct $7ASTNODE* vr$37 = ASTNEWLINK( TREE$1, vr$36, -1ll );
+		struct $7ASTNODE* vr$37 = ASTNEWLINK( TREE$1, vr$36, 0ll );
 		TREE$1 = vr$37;
 	}
 	label$57:;
 	label$56:;
 	{
-		uint64 TMP$81$2;
-		TMP$81$2 = (uint64)INIT$1;
+		uint64 TMP$85$2;
+		TMP$85$2 = (uint64)INIT$1;
 		goto label$59;
 		label$60:;
 		{
@@ -1177,21 +1194,21 @@ struct $7ASTNODE* ASTBUILDNEWOP( $6AST_OP OP$1, struct $8FBSYMBOL* TMP$1, struct
 		}
 		goto label$58;
 		label$59:;
-		static const void* tmp$82[5ll] = {
+		static const void* tmp$86[5ll] = {
 			&&label$60,
 			&&label$61,
 			&&label$62,
 			&&label$63,
 			&&label$64,
 		};
-		if( TMP$81$2 > 4ull ) goto label$65;
-		goto *tmp$82[TMP$81$2 - 0ull];
+		if( TMP$85$2 > 4ull ) goto label$65;
+		goto *tmp$86[TMP$85$2 - 0ull];
 		label$58:;
 	}
-	struct $7ASTNODE* vr$60 = ASTNEWLINK( TREE$1, INITEXPR$1, -1ll );
+	struct $7ASTNODE* vr$60 = ASTNEWLINK( TREE$1, INITEXPR$1, 0ll );
 	TREE$1 = vr$60;
 	struct $7ASTNODE* vr$61 = ASTNEWLABEL( EXITLABEL$1, 0ll );
-	struct $7ASTNODE* vr$62 = ASTNEWLINK( TREE$1, vr$61, -1ll );
+	struct $7ASTNODE* vr$62 = ASTNEWLINK( TREE$1, vr$61, 0ll );
 	TREE$1 = vr$62;
 	struct $7ASTNODE* vr$63 = ASTNEWLOOP( EXITLABEL$1, TREE$1 );
 	TREE$1 = vr$63;
@@ -1226,7 +1243,7 @@ struct $7ASTNODE* ASTBUILDDELETEOP( $6AST_OP OP$1, struct $7ASTNODE* PTREXPR$1 )
 	struct $7ASTNODE* vr$17 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$18 = ASTCLONETREE( PTREXPR$1 );
 	struct $7ASTNODE* vr$19 = ASTNEWBOP( 45ll, vr$18, vr$17, LABEL$1, 0ll );
-	struct $7ASTNODE* vr$20 = ASTNEWLINK( TREE$1, vr$19, -1ll );
+	struct $7ASTNODE* vr$20 = ASTNEWLINK( TREE$1, vr$19, 0ll );
 	TREE$1 = vr$20;
 	int64 vr$21 = TYPENEEDSDTORCALL( DTYPE$1, SUBTYPE$1 );
 	if( vr$21 == 0ll ) goto label$73;
@@ -1235,9 +1252,9 @@ struct $7ASTNODE* ASTBUILDDELETEOP( $6AST_OP OP$1, struct $7ASTNODE* PTREXPR$1 )
 		{
 			struct $7ASTNODE* vr$22 = ASTCLONETREE( PTREXPR$1 );
 			struct $7ASTNODE* vr$23 = HCALLDTORLIST( vr$22 );
-			struct $7ASTNODE* vr$24 = ASTNEWLINK( TREE$1, vr$23, -1ll );
+			struct $7ASTNODE* vr$24 = ASTNEWLINK( TREE$1, vr$23, 0ll );
 			TREE$1 = vr$24;
-			struct $7ASTNODE* vr$25 = ASTNEWCONSTI( *(int64*)((uint8*)SYMB_DTYPETB$ + 456ll), 8ll, (struct $8FBSYMBOL*)0ull );
+			struct $7ASTNODE* vr$25 = ASTNEWCONSTI( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 456ll), 8ll, (struct $8FBSYMBOL*)0ull );
 			struct $7ASTNODE* vr$26 = ASTNEWBOP( 29ll, PTREXPR$1, vr$25, (struct $8FBSYMBOL*)0ull, 1ll );
 			PTREXPR$1 = vr$26;
 		}
@@ -1247,7 +1264,7 @@ struct $7ASTNODE* ASTBUILDDELETEOP( $6AST_OP OP$1, struct $7ASTNODE* PTREXPR$1 )
 			struct $7ASTNODE* vr$27 = ASTCLONETREE( PTREXPR$1 );
 			struct $7ASTNODE* vr$28 = ASTNEWDEREF( vr$27, 2147483648ll, (struct $8FBSYMBOL*)0ull, 0ll );
 			struct $7ASTNODE* vr$29 = _Z19ASTBUILDVARDTORCALLP7ASTNODE( vr$28 );
-			struct $7ASTNODE* vr$30 = ASTNEWLINK( TREE$1, vr$29, -1ll );
+			struct $7ASTNODE* vr$30 = ASTNEWLINK( TREE$1, vr$29, 0ll );
 			TREE$1 = vr$30;
 		}
 		label$74:;
@@ -1255,10 +1272,10 @@ struct $7ASTNODE* ASTBUILDDELETEOP( $6AST_OP OP$1, struct $7ASTNODE* PTREXPR$1 )
 	label$73:;
 	label$72:;
 	struct $7ASTNODE* vr$31 = RTLMEMDELETEOP( OP$1, PTREXPR$1, DTYPE$1, SUBTYPE$1 );
-	struct $7ASTNODE* vr$32 = ASTNEWLINK( TREE$1, vr$31, -1ll );
+	struct $7ASTNODE* vr$32 = ASTNEWLINK( TREE$1, vr$31, 0ll );
 	TREE$1 = vr$32;
 	struct $7ASTNODE* vr$33 = ASTNEWLABEL( LABEL$1, -1ll );
-	struct $7ASTNODE* vr$34 = ASTNEWLINK( TREE$1, vr$33, -1ll );
+	struct $7ASTNODE* vr$34 = ASTNEWLINK( TREE$1, vr$33, 0ll );
 	TREE$1 = vr$34;
 	fb$result$1 = TREE$1;
 	label$69:;
@@ -1300,7 +1317,7 @@ struct $6IRVREG* ASTLOADMEM( struct $7ASTNODE* N$1 )
 	label$80:;
 	if( *(int64*)((uint8*)&AST$ + 272ll) == 0ll ) goto label$83;
 	{
-		(*(tmp$54*)((uint8*)&IR$ + 304ll))( *(int64*)((uint8*)N$1 + 48ll), V1$1, V2$1, *(int64*)((uint8*)N$1 + 40ll) );
+		(*(tmp$58*)((uint8*)&IR$ + 296ll))( *(int64*)((uint8*)N$1 + 48ll), V1$1, V2$1, *(int64*)((uint8*)N$1 + 40ll) );
 	}
 	label$83:;
 	label$82:;
@@ -1312,7 +1329,7 @@ struct $6IRVREG* ASTLOADMEM( struct $7ASTNODE* N$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1342,10 +1359,10 @@ static struct $7ASTNODE* HCALLCTORLIST( struct $8FBSYMBOL* TMP$1, struct $7ASTNO
 	TREE$1 = vr$16;
 	struct $7ASTNODE* vr$17 = ASTBUILDVARDEREF( ITER$1 );
 	struct $7ASTNODE* vr$18 = ASTBUILDCTORCALL( SUBTYPE$1, vr$17 );
-	struct $7ASTNODE* vr$19 = ASTNEWLINK( TREE$1, vr$18, -1ll );
+	struct $7ASTNODE* vr$19 = ASTNEWLINK( TREE$1, vr$18, 0ll );
 	TREE$1 = vr$19;
 	struct $7ASTNODE* vr$20 = ASTBUILDVARINC( ITER$1, 1ll );
-	struct $7ASTNODE* vr$21 = ASTNEWLINK( TREE$1, vr$20, -1ll );
+	struct $7ASTNODE* vr$21 = ASTNEWLINK( TREE$1, vr$20, 0ll );
 	TREE$1 = vr$21;
 	struct $7ASTNODE* vr$22 = ASTBUILDWHILECOUNTEREND( TREE$1, CNT$1, LABEL$1, EXITLABEL$1, 0ll );
 	TREE$1 = vr$22;
@@ -1401,7 +1418,7 @@ static struct $7ASTNODE* HCALLDTORLIST( struct $7ASTNODE* PTREXPR$1 )
 	ITER$1 = vr$6;
 	struct $8FBSYMBOL* vr$7 = SYMBADDTEMPVAR( 8ll, (struct $8FBSYMBOL*)0ull );
 	ELMTS$1 = vr$7;
-	struct $7ASTNODE* vr$9 = ASTNEWCONSTI( -(*(int64*)((uint8*)SYMB_DTYPETB$ + 512ll)), 8ll, (struct $8FBSYMBOL*)0ull );
+	struct $7ASTNODE* vr$9 = ASTNEWCONSTI( -(*(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 512ll)), 8ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$10 = ASTCLONETREE( PTREXPR$1 );
 	struct $7ASTNODE* vr$11 = ASTNEWBOP( 28ll, vr$10, vr$9, (struct $8FBSYMBOL*)0ull, 1ll );
 	struct $7ASTNODE* vr$12 = ASTNEWCONV( 41ll, (struct $8FBSYMBOL*)0ull, vr$11, 8ll, (int64*)0ull );
@@ -1411,17 +1428,17 @@ static struct $7ASTNODE* HCALLDTORLIST( struct $7ASTNODE* PTREXPR$1 )
 	struct $7ASTNODE* vr$15 = ASTNEWVAR( ELMTS$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$16 = ASTNEWBOP( 28ll, PTREXPR$1, vr$15, (struct $8FBSYMBOL*)0ull, 7ll );
 	struct $7ASTNODE* vr$17 = _Z17ASTBUILDVARASSIGNP8FBSYMBOLP7ASTNODEu7INTEGER( ITER$1, vr$16, 64ll );
-	struct $7ASTNODE* vr$18 = ASTNEWLINK( TREE$1, vr$17, -1ll );
+	struct $7ASTNODE* vr$18 = ASTNEWLINK( TREE$1, vr$17, 0ll );
 	TREE$1 = vr$18;
 	struct $7ASTNODE* vr$19 = ASTNEWVAR( ELMTS$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$20 = ASTBUILDWHILECOUNTERBEGIN( TREE$1, CNT$1, LABEL$1, EXITLABEL$1, vr$19, -1ll );
 	TREE$1 = vr$20;
 	struct $7ASTNODE* vr$21 = ASTBUILDVARINC( ITER$1, -1ll );
-	struct $7ASTNODE* vr$22 = ASTNEWLINK( TREE$1, vr$21, -1ll );
+	struct $7ASTNODE* vr$22 = ASTNEWLINK( TREE$1, vr$21, 0ll );
 	TREE$1 = vr$22;
 	struct $7ASTNODE* vr$23 = ASTBUILDVARDEREF( ITER$1 );
 	struct $7ASTNODE* vr$24 = _Z19ASTBUILDVARDTORCALLP7ASTNODE( vr$23 );
-	struct $7ASTNODE* vr$25 = ASTNEWLINK( TREE$1, vr$24, -1ll );
+	struct $7ASTNODE* vr$25 = ASTNEWLINK( TREE$1, vr$24, 0ll );
 	TREE$1 = vr$25;
 	struct $7ASTNODE* vr$26 = ASTBUILDWHILECOUNTEREND( TREE$1, CNT$1, LABEL$1, EXITLABEL$1, -1ll );
 	TREE$1 = vr$26;
