@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +317,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +386,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +416,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +566,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -599,7 +614,18 @@ struct $7ASTNODE {
 };
 __FB_STATIC_ASSERT( sizeof( struct $7ASTNODE ) == 144 );
 typedef int64 $9FB_ERRMSG;
-typedef int64 (*tmp$36)( int64, int64 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
+typedef int64 (*tmp$41)( int64, int64 );
 typedef int64 $15IRVREGTYPE_ENUM;
 typedef int64 $12IR_REGFAMILY;
 struct $6IRVREG;
@@ -645,8 +671,8 @@ struct $6IRVREG {
 	struct $5IRTAC* TACLAST;
 };
 __FB_STATIC_ASSERT( sizeof( struct $6IRVREG ) == 120 );
-typedef struct $6IRVREG* (*tmp$65)( int64, struct $8FBSYMBOL* );
-typedef void (*tmp$47)( int64, struct $6IRVREG*, struct $6IRVREG* );
+typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL* );
+typedef void (*tmp$52)( int64, struct $6IRVREG*, struct $6IRVREG* );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -679,122 +705,120 @@ int64 TYPETOSIGNED( int64 );
 struct $7ASTNODE* RTLMATHUOP( int64, struct $7ASTNODE* );
 static int64 HSGNLONGINT( int64 );
 static struct $7ASTNODE* HCONSTUOP( int64, int64, struct $8FBSYMBOL*, struct $7ASTNODE* );
-typedef void (*tmp$33)( void );
-typedef int64 (*tmp$34)( void );
+typedef void (*tmp$38)( void );
+typedef int64 (*tmp$39)( void );
 typedef int64 $14IR_OPTIONVALUE;
-typedef int64 (*tmp$35)( $14IR_OPTIONVALUE );
-typedef void (*tmp$37)( struct $8FBSYMBOL* );
-typedef void (*tmp$38)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef uint8* (*tmp$39)( void );
-typedef void (*tmp$40)( struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$41)( int64 );
-typedef void (*tmp$42)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$44)( struct $9ASTASMTOK* );
-typedef void (*tmp$45)( uint8* );
-typedef void (*tmp$46)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
-typedef void (*tmp$48)( struct $6IRVREG* );
-typedef void (*tmp$49)( int64, struct $6IRVREG* );
-typedef void (*tmp$50)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
-typedef void (*tmp$51)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$52)( int64, struct $8FBSYMBOL* );
-typedef void (*tmp$53)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
-typedef void (*tmp$54)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
-typedef void (*tmp$55)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$56)( int64, struct $8FBSYMBOL*, int64, uint8* );
-typedef void (*tmp$57)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$58)( struct $8FBSYMBOL*, double );
-typedef void (*tmp$59)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$60)( int64, uint8*, int64 );
-typedef void (*tmp$61)( int64, uint16*, int64 );
-typedef void (*tmp$62)( int64 );
-typedef void (*tmp$63)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$64)( uint8* );
-typedef struct $6IRVREG* (*tmp$66)( int64, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$67)( int64, struct $8FBSYMBOL*, double );
-typedef struct $6IRVREG* (*tmp$68)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
-typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
-typedef void (*tmp$71)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
-typedef uint64 (*tmp$72)( struct $6IRVREG* );
+typedef int64 (*tmp$40)( $14IR_OPTIONVALUE );
+typedef void (*tmp$42)( struct $8FBSYMBOL* );
+typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef uint8* (*tmp$44)( void );
+typedef void (*tmp$45)( struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$46)( int64 );
+typedef void (*tmp$47)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef void (*tmp$48)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64, struct $6IRVREG* );
+typedef void (*tmp$49)( struct $9ASTASMTOK* );
+typedef void (*tmp$50)( uint8* );
+typedef void (*tmp$51)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
+typedef void (*tmp$53)( struct $6IRVREG* );
+typedef void (*tmp$54)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
+typedef void (*tmp$55)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
+typedef void (*tmp$56)( int64, struct $8FBSYMBOL* );
+typedef void (*tmp$57)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
+typedef void (*tmp$58)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
+typedef void (*tmp$59)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$60)( int64, struct $8FBSYMBOL*, int64, uint8* );
+typedef void (*tmp$61)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$62)( struct $8FBSYMBOL*, double );
+typedef void (*tmp$63)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$64)( int64, uint8*, int64 );
+typedef void (*tmp$65)( int64, uint16*, int64 );
+typedef void (*tmp$66)( int64 );
+typedef void (*tmp$67)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$68)( uint8* );
+typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$71)( int64, struct $8FBSYMBOL*, double );
+typedef struct $6IRVREG* (*tmp$72)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$73)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
+typedef struct $6IRVREG* (*tmp$74)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
+typedef void (*tmp$75)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
+typedef uint64 (*tmp$76)( struct $6IRVREG* );
 struct $7IR_VTBL {
-	tmp$33 INIT;
-	tmp$33 END;
-	tmp$34 EMITBEGIN;
-	tmp$33 EMITEND;
-	tmp$35 GETOPTIONVALUE;
-	tmp$36 SUPPORTSOP;
-	tmp$37 PROCBEGIN;
-	tmp$37 PROCEND;
-	tmp$38 PROCALLOCARG;
-	tmp$38 PROCALLOCLOCAL;
-	tmp$39 PROCGETFRAMEREGNAME;
-	tmp$37 SCOPEBEGIN;
-	tmp$37 SCOPEEND;
-	tmp$37 PROCALLOCSTATICVARS;
-	tmp$40 EMITCONVERT;
-	tmp$37 EMITLABEL;
-	tmp$37 EMITLABELNF;
-	tmp$41 EMITRETURN;
-	tmp$38 EMITPROCBEGIN;
-	tmp$42 EMITPROCEND;
-	tmp$43 EMITPUSHARG;
-	tmp$44 EMITASMLINE;
-	tmp$45 EMITCOMMENT;
-	tmp$46 EMITBOP;
-	tmp$47 EMITUOP;
-	tmp$40 EMITSTORE;
-	tmp$33 EMITSPILLREGS;
-	tmp$48 EMITLOAD;
-	tmp$40 EMITLOADRES;
-	tmp$49 EMITSTACK;
-	tmp$47 EMITADDR;
-	tmp$50 EMITCALL;
-	tmp$51 EMITCALLPTR;
-	tmp$41 EMITSTACKALIGN;
-	tmp$48 EMITJUMPPTR;
-	tmp$52 EMITBRANCH;
-	tmp$53 EMITJMPTB;
-	tmp$54 EMITMEM;
-	tmp$55 EMITMACRO;
-	tmp$37 EMITSCOPEBEGIN;
-	tmp$37 EMITSCOPEEND;
-	tmp$37 EMITDECL;
-	tmp$56 EMITDBG;
-	tmp$37 EMITVARINIBEGIN;
-	tmp$37 EMITVARINIEND;
-	tmp$57 EMITVARINII;
-	tmp$58 EMITVARINIF;
-	tmp$59 EMITVARINIOFS;
-	tmp$60 EMITVARINISTR;
-	tmp$61 EMITVARINIWSTR;
-	tmp$62 EMITVARINIPAD;
-	tmp$63 EMITVARINISCOPEBEGIN;
-	tmp$33 EMITVARINISCOPEEND;
-	tmp$33 EMITFBCTINFBEGIN;
-	tmp$64 EMITFBCTINFSTRING;
-	tmp$33 EMITFBCTINFEND;
-	tmp$65 ALLOCVREG;
-	tmp$66 ALLOCVRIMM;
-	tmp$67 ALLOCVRIMMF;
-	tmp$68 ALLOCVRVAR;
-	tmp$69 ALLOCVRIDX;
-	tmp$70 ALLOCVRPTR;
-	tmp$68 ALLOCVROFS;
-	tmp$71 SETVREGDATATYPE;
-	tmp$72 GETDISTANCE;
-	tmp$47 LOADVR;
-	tmp$40 STOREVR;
-	tmp$41 XCHGTOS;
+	tmp$38 INIT;
+	tmp$38 END;
+	tmp$39 EMITBEGIN;
+	tmp$38 EMITEND;
+	tmp$40 GETOPTIONVALUE;
+	tmp$41 SUPPORTSOP;
+	tmp$42 PROCBEGIN;
+	tmp$42 PROCEND;
+	tmp$43 PROCALLOCARG;
+	tmp$43 PROCALLOCLOCAL;
+	tmp$44 PROCGETFRAMEREGNAME;
+	tmp$42 SCOPEBEGIN;
+	tmp$42 SCOPEEND;
+	tmp$42 PROCALLOCSTATICVARS;
+	tmp$45 EMITCONVERT;
+	tmp$42 EMITLABEL;
+	tmp$42 EMITLABELNF;
+	tmp$46 EMITRETURN;
+	tmp$43 EMITPROCBEGIN;
+	tmp$47 EMITPROCEND;
+	tmp$48 EMITPUSHARG;
+	tmp$49 EMITASMLINE;
+	tmp$50 EMITCOMMENT;
+	tmp$51 EMITBOP;
+	tmp$52 EMITUOP;
+	tmp$45 EMITSTORE;
+	tmp$38 EMITSPILLREGS;
+	tmp$53 EMITLOAD;
+	tmp$45 EMITLOADRES;
+	tmp$52 EMITSTACK;
+	tmp$52 EMITADDR;
+	tmp$54 EMITCALL;
+	tmp$55 EMITCALLPTR;
+	tmp$46 EMITSTACKALIGN;
+	tmp$53 EMITJUMPPTR;
+	tmp$56 EMITBRANCH;
+	tmp$57 EMITJMPTB;
+	tmp$58 EMITMEM;
+	tmp$59 EMITMACRO;
+	tmp$42 EMITSCOPEBEGIN;
+	tmp$42 EMITSCOPEEND;
+	tmp$42 EMITDECL;
+	tmp$60 EMITDBG;
+	tmp$42 EMITVARINIBEGIN;
+	tmp$42 EMITVARINIEND;
+	tmp$61 EMITVARINII;
+	tmp$62 EMITVARINIF;
+	tmp$63 EMITVARINIOFS;
+	tmp$64 EMITVARINISTR;
+	tmp$65 EMITVARINIWSTR;
+	tmp$66 EMITVARINIPAD;
+	tmp$67 EMITVARINISCOPEBEGIN;
+	tmp$38 EMITVARINISCOPEEND;
+	tmp$38 EMITFBCTINFBEGIN;
+	tmp$68 EMITFBCTINFSTRING;
+	tmp$38 EMITFBCTINFEND;
+	tmp$69 ALLOCVREG;
+	tmp$70 ALLOCVRIMM;
+	tmp$71 ALLOCVRIMMF;
+	tmp$72 ALLOCVRVAR;
+	tmp$73 ALLOCVRIDX;
+	tmp$74 ALLOCVRPTR;
+	tmp$72 ALLOCVROFS;
+	tmp$75 SETVREGDATATYPE;
+	tmp$76 GETDISTANCE;
+	tmp$52 LOADVR;
+	tmp$45 STOREVR;
+	tmp$46 XCHGTOS;
 };
 __FB_STATIC_ASSERT( sizeof( struct $7IR_VTBL ) == 544 );
 typedef int64 $6IR_OPT;
 struct $5IRCTX {
-	int64 INITED;
 	struct $7IR_VTBL VTBL;
 	$6IR_OPT OPTIONS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 560 );
+__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 552 );
 extern struct $5IRCTX IR$;
 struct $12AST_PROC_CTX {
 	struct $7ASTNODE* HEAD;
@@ -864,10 +888,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -901,6 +926,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -909,11 +938,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -966,19 +996,8 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -986,20 +1005,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -1040,8 +1061,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -1049,8 +1073,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -1097,6 +1122,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -1118,22 +1144,27 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 
 struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 {
-	int64 TMP$85$1;
-	int64 TMP$88$1;
+	int64 TMP$89$1;
+	int64 TMP$92$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$55:;
@@ -1151,7 +1182,7 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 	}
 	label$58:;
 	label$57:;
-	if( *(struct $8FBSYMBOL**)((uint8*)((uint8*)&SYMB$ + (OP$1 << (3ll & 63ll))) + 198168ll) == (struct $8FBSYMBOL*)0ull ) goto label$60;
+	if( *(struct $8FBSYMBOL**)((uint8*)((uint8*)&SYMB$ + (OP$1 << (3ll & 63ll))) + 198208ll) == (struct $8FBSYMBOL*)0ull ) goto label$60;
 	{
 		struct $8FBSYMBOL* PROC$2;
 		$9FB_ERRMSG ERR_NUM$2;
@@ -1202,27 +1233,27 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 		label$65:;
 	}
 	if( (*(int64*)((uint8*)O$1 + 8ll) & 480ll) == 0ll ) goto label$70;
-	TMP$85$1 = 24ll;
+	TMP$89$1 = 24ll;
 	goto label$144;
 	label$70:;
-	TMP$85$1 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
+	TMP$89$1 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
 	label$144:;
-	if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$85$1 * 56ll)) != 2ll ) goto label$72;
+	if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$89$1 * 56ll)) != 2ll ) goto label$72;
 	{
 		goto label$56;
 	}
 	label$72:;
 	label$71:;
 	{
-		int64 TMP$86$2;
-		uint64 TMP$87$2;
+		int64 TMP$90$2;
+		uint64 TMP$91$2;
 		if( (*(int64*)((uint8*)O$1 + 8ll) & 480ll) == 0ll ) goto label$73;
-		TMP$86$2 = 24ll;
+		TMP$90$2 = 24ll;
 		goto label$145;
 		label$73:;
-		TMP$86$2 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
+		TMP$90$2 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
 		label$145:;
-		TMP$87$2 = (uint64)TMP$86$2;
+		TMP$91$2 = (uint64)TMP$90$2;
 		goto label$75;
 		label$76:;
 		{
@@ -1263,7 +1294,7 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 		}
 		goto label$74;
 		label$75:;
-		static const void* tmp$100[21ll] = {
+		static const void* tmp$104[21ll] = {
 			&&label$76,
 			&&label$74,
 			&&label$74,
@@ -1286,17 +1317,17 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 			&&label$74,
 			&&label$83,
 		};
-		if( (TMP$87$2 - 4ull) > 20ull ) goto label$74;
-		goto *tmp$100[TMP$87$2 - 4ull];
+		if( (TMP$91$2 - 4ull) > 20ull ) goto label$74;
+		goto *tmp$104[TMP$91$2 - 4ull];
 		label$74:;
 	}
 	if( (*(int64*)((uint8*)O$1 + 8ll) & 480ll) == 0ll ) goto label$86;
-	TMP$88$1 = 24ll;
+	TMP$92$1 = 24ll;
 	goto label$146;
 	label$86:;
-	TMP$88$1 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
+	TMP$92$1 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
 	label$146:;
-	DO_PROMOTE$1 = (int64)-(*(int64*)((uint8*)&ENV$ + 272ll) != 3ll) & (int64)-(*(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$88$1 * 56ll)) == 0ll);
+	DO_PROMOTE$1 = (int64)-(*(int64*)((uint8*)&ENV$ + 272ll) != 3ll) & (int64)-(*(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$92$1 * 56ll)) == 0ll);
 	if( (*(int64*)((uint8*)O$1 + 8ll) & 511ll) != 1ll ) goto label$88;
 	{
 		if( OP$1 != 52ll ) goto label$90;
@@ -1314,30 +1345,30 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 	label$87:;
 	if( DO_PROMOTE$1 == 0ll ) goto label$92;
 	{
-		int64 TMP$89$2;
-		int64 TMP$90$2;
-		int64 TMP$91$2;
+		int64 TMP$93$2;
+		int64 TMP$94$2;
+		int64 TMP$95$2;
 		if( (*(int64*)((uint8*)O$1 + 8ll) & 480ll) == 0ll ) goto label$93;
-		TMP$89$2 = 24ll;
+		TMP$93$2 = 24ll;
 		goto label$147;
 		label$93:;
-		TMP$89$2 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
+		TMP$93$2 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
 		label$147:;
-		if( (*(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$89$2 * 56ll)) + 32ll) & 480ll) == 0ll ) goto label$95;
-		TMP$91$2 = 24ll;
+		if( (*(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$93$2 * 56ll)) + 32ll) & 480ll) == 0ll ) goto label$95;
+		TMP$95$2 = 24ll;
 		goto label$148;
 		label$95:;
 		if( (*(int64*)((uint8*)O$1 + 8ll) & 480ll) == 0ll ) goto label$94;
-		TMP$90$2 = 24ll;
+		TMP$94$2 = 24ll;
 		goto label$149;
 		label$94:;
-		TMP$90$2 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
+		TMP$94$2 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
 		label$149:;
-		TMP$91$2 = *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$90$2 * 56ll)) + 32ll) & 31ll;
+		TMP$95$2 = *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$94$2 * 56ll)) + 32ll) & 31ll;
 		label$148:;
-		RANK$1 = *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$91$2 * 56ll)) + 24ll);
-		INTRANK$1 = *(int64*)((uint8*)SYMB_DTYPETB$ + 472ll);
-		UINTRANK$1 = *(int64*)((uint8*)SYMB_DTYPETB$ + 528ll);
+		RANK$1 = *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$95$2 * 56ll)) + 24ll);
+		INTRANK$1 = *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 472ll);
+		UINTRANK$1 = *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 528ll);
 		if( RANK$1 >= INTRANK$1 ) goto label$97;
 		{
 			struct $7ASTNODE* vr$57 = ASTNEWCONV( (*(int64*)((uint8*)O$1 + 8ll) & -512ll) | 8ll, (struct $8FBSYMBOL*)0ull, O$1, 0ll, (int64*)0ull );
@@ -1361,19 +1392,19 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 	DTYPE$1 = *(int64*)((uint8*)O$1 + 8ll);
 	SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)O$1 + 16ll);
 	{
-		uint64 TMP$92$2;
-		TMP$92$2 = (uint64)OP$1;
+		uint64 TMP$96$2;
+		TMP$96$2 = (uint64)OP$1;
 		goto label$101;
 		label$102:;
 		{
-			int64 TMP$93$3;
+			int64 TMP$97$3;
 			if( (*(int64*)((uint8*)O$1 + 8ll) & 480ll) == 0ll ) goto label$103;
-			TMP$93$3 = 24ll;
+			TMP$97$3 = 24ll;
 			goto label$150;
 			label$103:;
-			TMP$93$3 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
+			TMP$97$3 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
 			label$150:;
-			if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$93$3 * 56ll)) == 0ll ) goto label$105;
+			if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$97$3 * 56ll)) == 0ll ) goto label$105;
 			{
 				struct $7ASTNODE* vr$75 = ASTNEWCONV( (*(int64*)((uint8*)O$1 + 8ll) & -512ll) | 8ll, (struct $8FBSYMBOL*)0ull, O$1, 0ll, (int64*)0ull );
 				O$1 = vr$75;
@@ -1386,14 +1417,14 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 		goto label$100;
 		label$106:;
 		{
-			int64 TMP$94$3;
+			int64 TMP$98$3;
 			if( (*(int64*)((uint8*)O$1 + 8ll) & 480ll) == 0ll ) goto label$107;
-			TMP$94$3 = 24ll;
+			TMP$98$3 = 24ll;
 			goto label$151;
 			label$107:;
-			TMP$94$3 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
+			TMP$98$3 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
 			label$151:;
-			if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$94$3 * 56ll)) != 0ll ) goto label$109;
+			if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$98$3 * 56ll)) != 0ll ) goto label$109;
 			{
 				int64 vr$83 = TYPETOSIGNED( DTYPE$1 );
 				DTYPE$1 = vr$83;
@@ -1404,27 +1435,27 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 		goto label$100;
 		label$110:;
 		{
-			int64 TMP$95$3;
+			int64 TMP$99$3;
 			if( (DTYPE$1 & 480ll) == 0ll ) goto label$111;
-			TMP$95$3 = 24ll;
+			TMP$99$3 = 24ll;
 			goto label$152;
 			label$111:;
-			TMP$95$3 = DTYPE$1 & 31ll;
+			TMP$99$3 = DTYPE$1 & 31ll;
 			label$152:;
-			if( ~(*(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$95$3 * 56ll)) + 16ll)) == 0ll ) goto label$113;
+			if( ~(*(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$99$3 * 56ll)) + 16ll)) == 0ll ) goto label$113;
 			{
 				if( *(int64*)O$1 != 16ll ) goto label$115;
 				{
 					if( *(int64*)((uint8*)&AST$ + 464ll) != 0ll ) goto label$117;
 					{
-						int64 TMP$96$6;
+						int64 TMP$100$6;
 						if( (DTYPE$1 & 480ll) == 0ll ) goto label$118;
-						TMP$96$6 = 24ll;
+						TMP$100$6 = 24ll;
 						goto label$153;
 						label$118:;
-						TMP$96$6 = DTYPE$1 & 31ll;
+						TMP$100$6 = DTYPE$1 & 31ll;
 						label$153:;
-						if( *(uint64*)((uint8*)O$1 + 40ll) <= (1ull << (((*(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$96$6 * 56ll)) + 8ll) << (3ll & 63ll)) + -1ll) & 63ll)) ) goto label$120;
+						if( *(uint64*)((uint8*)O$1 + 40ll) <= (1ull << (((*(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$100$6 * 56ll)) + 8ll) << (3ll & 63ll)) + -1ll) & 63ll)) ) goto label$120;
 						{
 							ERRREPORTWARN( 5ll, (uint8*)0ull, 1ll, (uint8*)0ull );
 						}
@@ -1445,14 +1476,14 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 		goto label$100;
 		label$121:;
 		{
-			int64 TMP$97$3;
+			int64 TMP$101$3;
 			if( (*(int64*)((uint8*)O$1 + 8ll) & 480ll) == 0ll ) goto label$122;
-			TMP$97$3 = 24ll;
+			TMP$101$3 = 24ll;
 			goto label$154;
 			label$122:;
-			TMP$97$3 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
+			TMP$101$3 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
 			label$154:;
-			if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$97$3 * 56ll)) == 1ll ) goto label$124;
+			if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$101$3 * 56ll)) == 1ll ) goto label$124;
 			{
 				struct $7ASTNODE* vr$105 = ASTNEWCONV( (*(int64*)((uint8*)O$1 + 8ll) & -512ll) | 16ll, (struct $8FBSYMBOL*)0ull, O$1, 0ll, (int64*)0ull );
 				O$1 = vr$105;
@@ -1465,14 +1496,14 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 		goto label$100;
 		label$125:;
 		{
-			int64 TMP$98$3;
+			int64 TMP$102$3;
 			if( (*(int64*)((uint8*)O$1 + 8ll) & 480ll) == 0ll ) goto label$126;
-			TMP$98$3 = 24ll;
+			TMP$102$3 = 24ll;
 			goto label$155;
 			label$126:;
-			TMP$98$3 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
+			TMP$102$3 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
 			label$155:;
-			if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$98$3 * 56ll)) != 0ll ) goto label$128;
+			if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$102$3 * 56ll)) != 0ll ) goto label$128;
 			{
 				struct $7ASTNODE* vr$113 = ASTNEWCONSTI( 0ll, DTYPE$1, (struct $8FBSYMBOL*)0ull );
 				struct $7ASTNODE* vr$114 = ASTNEWBOP( 28ll, O$1, vr$113, (struct $8FBSYMBOL*)0ull, 1ll );
@@ -1485,14 +1516,14 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 		goto label$100;
 		label$129:;
 		{
-			int64 TMP$99$3;
+			int64 TMP$103$3;
 			if( (*(int64*)((uint8*)O$1 + 8ll) & 480ll) == 0ll ) goto label$130;
-			TMP$99$3 = 24ll;
+			TMP$103$3 = 24ll;
 			goto label$156;
 			label$130:;
-			TMP$99$3 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
+			TMP$103$3 = *(int64*)((uint8*)O$1 + 8ll) & 31ll;
 			label$156:;
-			if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$99$3 * 56ll)) != 0ll ) goto label$132;
+			if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$103$3 * 56ll)) != 0ll ) goto label$132;
 			{
 				struct $7ASTNODE* vr$120 = ASTNEWCONSTI( 0ll, DTYPE$1, (struct $8FBSYMBOL*)0ull );
 				struct $7ASTNODE* vr$121 = ASTNEWBOP( 34ll, O$1, vr$120, (struct $8FBSYMBOL*)0ull, 1ll );
@@ -1510,7 +1541,7 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 		}
 		goto label$100;
 		label$101:;
-		static const void* tmp$101[21ll] = {
+		static const void* tmp$105[21ll] = {
 			&&label$102,
 			&&label$133,
 			&&label$110,
@@ -1533,8 +1564,8 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 			&&label$125,
 			&&label$129,
 		};
-		if( (TMP$92$2 - 52ull) > 20ull ) goto label$100;
-		goto *tmp$101[TMP$92$2 - 52ull];
+		if( (TMP$96$2 - 52ull) > 20ull ) goto label$100;
+		goto *tmp$105[TMP$96$2 - 52ull];
 		label$100:;
 	}
 	if( *(int64*)O$1 != 16ll ) goto label$135;
@@ -1562,9 +1593,9 @@ struct $7ASTNODE* ASTNEWUOP( int64 OP$1, struct $7ASTNODE* O$1 )
 	}
 	label$137:;
 	label$136:;
-	if( (*(int64*)((uint8*)&IR$ + 552ll) & 131072ll) == 0ll ) goto label$141;
+	if( (*(int64*)((uint8*)&IR$ + 544ll) & 131072ll) == 0ll ) goto label$141;
 	{
-		int64 vr$130 = (*(tmp$36*)((uint8*)&IR$ + 48ll))( OP$1, DTYPE$1 );
+		int64 vr$130 = (*(tmp$41*)((uint8*)&IR$ + 40ll))( OP$1, DTYPE$1 );
 		if( vr$130 != 0ll ) goto label$143;
 		{
 			struct $7ASTNODE* vr$131 = RTLMATHUOP( OP$1, O$1 );
@@ -1618,7 +1649,7 @@ struct $6IRVREG* ASTLOADUOP( struct $7ASTNODE* N$1 )
 	{
 		if( (*(int64*)((uint8*)N$1 + 48ll) & 1ll) == 0ll ) goto label$166;
 		{
-			struct $6IRVREG* vr$10 = (*(tmp$65*)((uint8*)&IR$ + 456ll))( *(int64*)((uint8*)O$1 + 8ll), *(struct $8FBSYMBOL**)((uint8*)O$1 + 16ll) );
+			struct $6IRVREG* vr$10 = (*(tmp$69*)((uint8*)&IR$ + 448ll))( *(int64*)((uint8*)O$1 + 8ll), *(struct $8FBSYMBOL**)((uint8*)O$1 + 16ll) );
 			VR$1 = vr$10;
 			*(int64*)((uint8*)V1$1 + 40ll) = *(int64*)((uint8*)N$1 + 32ll);
 			*(int64*)((uint8*)VR$1 + 40ll) = *(int64*)((uint8*)N$1 + 32ll);
@@ -1630,7 +1661,7 @@ struct $6IRVREG* ASTLOADUOP( struct $7ASTNODE* N$1 )
 			*(int64*)((uint8*)V1$1 + 40ll) = *(int64*)((uint8*)N$1 + 32ll);
 		}
 		label$165:;
-		(*(tmp$47*)((uint8*)&IR$ + 200ll))( OP$1, V1$1, VR$1 );
+		(*(tmp$52*)((uint8*)&IR$ + 192ll))( OP$1, V1$1, VR$1 );
 		if( VR$1 != (struct $6IRVREG*)0ull ) goto label$168;
 		{
 			VR$1 = V1$1;
@@ -1649,7 +1680,7 @@ struct $6IRVREG* ASTLOADUOP( struct $7ASTNODE* N$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1681,24 +1712,24 @@ static int64 HSGNLONGINT( int64 X$1 )
 
 static struct $7ASTNODE* HCONSTUOP( int64 OP$1, int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, struct $7ASTNODE* L$1 )
 {
-	int64 TMP$80$1;
+	int64 TMP$84$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$15:;
 	double D$1;
 	int64 I$1;
 	if( (*(int64*)((uint8*)L$1 + 8ll) & 480ll) == 0ll ) goto label$17;
-	TMP$80$1 = 24ll;
+	TMP$84$1 = 24ll;
 	goto label$169;
 	label$17:;
-	TMP$80$1 = *(int64*)((uint8*)L$1 + 8ll) & 31ll;
+	TMP$84$1 = *(int64*)((uint8*)L$1 + 8ll) & 31ll;
 	label$169:;
-	if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$80$1 * 56ll)) != 1ll ) goto label$19;
+	if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$84$1 * 56ll)) != 1ll ) goto label$19;
 	{
 		D$1 = *(double*)((uint8*)L$1 + 40ll);
 		{
-			uint64 TMP$81$3;
-			TMP$81$3 = (uint64)OP$1;
+			uint64 TMP$85$3;
+			TMP$85$3 = (uint64)OP$1;
 			goto label$21;
 			label$22:;
 			{
@@ -1783,7 +1814,7 @@ static struct $7ASTNODE* HCONSTUOP( int64 OP$1, int64 DTYPE$1, struct $8FBSYMBOL
 			}
 			goto label$20;
 			label$21:;
-			static const void* tmp$102[19ll] = {
+			static const void* tmp$106[19ll] = {
 				&&label$22,
 				&&label$37,
 				&&label$23,
@@ -1804,8 +1835,8 @@ static struct $7ASTNODE* HCONSTUOP( int64 OP$1, int64 DTYPE$1, struct $8FBSYMBOL
 				&&label$35,
 				&&label$36,
 			};
-			if( (TMP$81$3 - 54ull) > 18ull ) goto label$37;
-			goto *tmp$102[TMP$81$3 - 54ull];
+			if( (TMP$85$3 - 54ull) > 18ull ) goto label$37;
+			goto *tmp$106[TMP$85$3 - 54ull];
 			label$20:;
 		}
 		*(double*)((uint8*)L$1 + 40ll) = D$1;
@@ -1813,19 +1844,19 @@ static struct $7ASTNODE* HCONSTUOP( int64 OP$1, int64 DTYPE$1, struct $8FBSYMBOL
 	goto label$18;
 	label$19:;
 	{
-		int64 TMP$82$2;
+		int64 TMP$86$2;
 		I$1 = *(int64*)((uint8*)L$1 + 40ll);
 		if( (*(int64*)((uint8*)L$1 + 8ll) & 480ll) == 0ll ) goto label$38;
-		TMP$82$2 = 24ll;
+		TMP$86$2 = 24ll;
 		goto label$170;
 		label$38:;
-		TMP$82$2 = *(int64*)((uint8*)L$1 + 8ll) & 31ll;
+		TMP$86$2 = *(int64*)((uint8*)L$1 + 8ll) & 31ll;
 		label$170:;
-		if( *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$82$2 * 56ll)) + 8ll) != 8ll ) goto label$40;
+		if( *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$86$2 * 56ll)) + 8ll) != 8ll ) goto label$40;
 		{
 			{
-				uint64 TMP$83$4;
-				TMP$83$4 = (uint64)OP$1;
+				uint64 TMP$87$4;
+				TMP$87$4 = (uint64)OP$1;
 				goto label$42;
 				label$43:;
 				{
@@ -1853,7 +1884,7 @@ static struct $7ASTNODE* HCONSTUOP( int64 OP$1, int64 DTYPE$1, struct $8FBSYMBOL
 				}
 				goto label$41;
 				label$42:;
-				static const void* tmp$103[6ll] = {
+				static const void* tmp$107[6ll] = {
 					&&label$43,
 					&&label$47,
 					&&label$44,
@@ -1861,8 +1892,8 @@ static struct $7ASTNODE* HCONSTUOP( int64 OP$1, int64 DTYPE$1, struct $8FBSYMBOL
 					&&label$45,
 					&&label$46,
 				};
-				if( (TMP$83$4 - 52ull) > 5ull ) goto label$47;
-				goto *tmp$103[TMP$83$4 - 52ull];
+				if( (TMP$87$4 - 52ull) > 5ull ) goto label$47;
+				goto *tmp$107[TMP$87$4 - 52ull];
 				label$41:;
 			}
 		}
@@ -1870,8 +1901,8 @@ static struct $7ASTNODE* HCONSTUOP( int64 OP$1, int64 DTYPE$1, struct $8FBSYMBOL
 		label$40:;
 		{
 			{
-				uint64 TMP$84$4;
-				TMP$84$4 = (uint64)OP$1;
+				uint64 TMP$88$4;
+				TMP$88$4 = (uint64)OP$1;
 				goto label$49;
 				label$50:;
 				{
@@ -1899,7 +1930,7 @@ static struct $7ASTNODE* HCONSTUOP( int64 OP$1, int64 DTYPE$1, struct $8FBSYMBOL
 				}
 				goto label$48;
 				label$49:;
-				static const void* tmp$104[6ll] = {
+				static const void* tmp$108[6ll] = {
 					&&label$50,
 					&&label$54,
 					&&label$51,
@@ -1907,8 +1938,8 @@ static struct $7ASTNODE* HCONSTUOP( int64 OP$1, int64 DTYPE$1, struct $8FBSYMBOL
 					&&label$52,
 					&&label$53,
 				};
-				if( (TMP$84$4 - 52ull) > 5ull ) goto label$54;
-				goto *tmp$104[TMP$84$4 - 52ull];
+				if( (TMP$88$4 - 52ull) > 5ull ) goto label$54;
+				goto *tmp$108[TMP$88$4 - 52ull];
 				label$48:;
 			}
 		}
