@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +317,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +386,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +416,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +566,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -643,7 +658,7 @@ struct $6IRVREG {
 	struct $5IRTAC* TACLAST;
 };
 __FB_STATIC_ASSERT( sizeof( struct $6IRVREG ) == 120 );
-typedef struct $6IRVREG* (*tmp$68)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$72)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -658,124 +673,122 @@ struct $7ASTNODE* ASTNEWCONV( int64, struct $8FBSYMBOL*, struct $7ASTNODE*, $11A
 struct $7ASTNODE* ASTNEWNODE( int64, int64, struct $8FBSYMBOL* );
 void ASTDTORLISTADDREF( struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBADDPROCPTRFROMFUNCTION( struct $8FBSYMBOL* );
-typedef void (*tmp$33)( void );
-typedef int64 (*tmp$34)( void );
+typedef void (*tmp$38)( void );
+typedef int64 (*tmp$39)( void );
 typedef int64 $14IR_OPTIONVALUE;
-typedef int64 (*tmp$35)( $14IR_OPTIONVALUE );
-typedef int64 (*tmp$36)( int64, int64 );
-typedef void (*tmp$37)( struct $8FBSYMBOL* );
-typedef void (*tmp$38)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef uint8* (*tmp$39)( void );
-typedef void (*tmp$40)( struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$41)( int64 );
-typedef void (*tmp$42)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$44)( struct $9ASTASMTOK* );
-typedef void (*tmp$45)( uint8* );
-typedef void (*tmp$46)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
-typedef void (*tmp$47)( int64, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$48)( struct $6IRVREG* );
-typedef void (*tmp$49)( int64, struct $6IRVREG* );
-typedef void (*tmp$50)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
-typedef void (*tmp$51)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$52)( int64, struct $8FBSYMBOL* );
-typedef void (*tmp$53)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
-typedef void (*tmp$54)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
-typedef void (*tmp$55)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$56)( int64, struct $8FBSYMBOL*, int64, uint8* );
-typedef void (*tmp$57)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$58)( struct $8FBSYMBOL*, double );
-typedef void (*tmp$59)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$60)( int64, uint8*, int64 );
-typedef void (*tmp$61)( int64, uint16*, int64 );
-typedef void (*tmp$62)( int64 );
-typedef void (*tmp$63)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$64)( uint8* );
-typedef struct $6IRVREG* (*tmp$65)( int64, struct $8FBSYMBOL* );
-typedef struct $6IRVREG* (*tmp$66)( int64, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$67)( int64, struct $8FBSYMBOL*, double );
-typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
-typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
-typedef void (*tmp$71)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
-typedef uint64 (*tmp$72)( struct $6IRVREG* );
+typedef int64 (*tmp$40)( $14IR_OPTIONVALUE );
+typedef int64 (*tmp$41)( int64, int64 );
+typedef void (*tmp$42)( struct $8FBSYMBOL* );
+typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef uint8* (*tmp$44)( void );
+typedef void (*tmp$45)( struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$46)( int64 );
+typedef void (*tmp$47)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef void (*tmp$48)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64, struct $6IRVREG* );
+typedef void (*tmp$49)( struct $9ASTASMTOK* );
+typedef void (*tmp$50)( uint8* );
+typedef void (*tmp$51)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
+typedef void (*tmp$52)( int64, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$53)( struct $6IRVREG* );
+typedef void (*tmp$54)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
+typedef void (*tmp$55)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
+typedef void (*tmp$56)( int64, struct $8FBSYMBOL* );
+typedef void (*tmp$57)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
+typedef void (*tmp$58)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
+typedef void (*tmp$59)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$60)( int64, struct $8FBSYMBOL*, int64, uint8* );
+typedef void (*tmp$61)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$62)( struct $8FBSYMBOL*, double );
+typedef void (*tmp$63)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$64)( int64, uint8*, int64 );
+typedef void (*tmp$65)( int64, uint16*, int64 );
+typedef void (*tmp$66)( int64 );
+typedef void (*tmp$67)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$68)( uint8* );
+typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL* );
+typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$71)( int64, struct $8FBSYMBOL*, double );
+typedef struct $6IRVREG* (*tmp$73)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
+typedef struct $6IRVREG* (*tmp$74)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
+typedef void (*tmp$75)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
+typedef uint64 (*tmp$76)( struct $6IRVREG* );
 struct $7IR_VTBL {
-	tmp$33 INIT;
-	tmp$33 END;
-	tmp$34 EMITBEGIN;
-	tmp$33 EMITEND;
-	tmp$35 GETOPTIONVALUE;
-	tmp$36 SUPPORTSOP;
-	tmp$37 PROCBEGIN;
-	tmp$37 PROCEND;
-	tmp$38 PROCALLOCARG;
-	tmp$38 PROCALLOCLOCAL;
-	tmp$39 PROCGETFRAMEREGNAME;
-	tmp$37 SCOPEBEGIN;
-	tmp$37 SCOPEEND;
-	tmp$37 PROCALLOCSTATICVARS;
-	tmp$40 EMITCONVERT;
-	tmp$37 EMITLABEL;
-	tmp$37 EMITLABELNF;
-	tmp$41 EMITRETURN;
-	tmp$38 EMITPROCBEGIN;
-	tmp$42 EMITPROCEND;
-	tmp$43 EMITPUSHARG;
-	tmp$44 EMITASMLINE;
-	tmp$45 EMITCOMMENT;
-	tmp$46 EMITBOP;
-	tmp$47 EMITUOP;
-	tmp$40 EMITSTORE;
-	tmp$33 EMITSPILLREGS;
-	tmp$48 EMITLOAD;
-	tmp$40 EMITLOADRES;
-	tmp$49 EMITSTACK;
-	tmp$47 EMITADDR;
-	tmp$50 EMITCALL;
-	tmp$51 EMITCALLPTR;
-	tmp$41 EMITSTACKALIGN;
-	tmp$48 EMITJUMPPTR;
-	tmp$52 EMITBRANCH;
-	tmp$53 EMITJMPTB;
-	tmp$54 EMITMEM;
-	tmp$55 EMITMACRO;
-	tmp$37 EMITSCOPEBEGIN;
-	tmp$37 EMITSCOPEEND;
-	tmp$37 EMITDECL;
-	tmp$56 EMITDBG;
-	tmp$37 EMITVARINIBEGIN;
-	tmp$37 EMITVARINIEND;
-	tmp$57 EMITVARINII;
-	tmp$58 EMITVARINIF;
-	tmp$59 EMITVARINIOFS;
-	tmp$60 EMITVARINISTR;
-	tmp$61 EMITVARINIWSTR;
-	tmp$62 EMITVARINIPAD;
-	tmp$63 EMITVARINISCOPEBEGIN;
-	tmp$33 EMITVARINISCOPEEND;
-	tmp$33 EMITFBCTINFBEGIN;
-	tmp$64 EMITFBCTINFSTRING;
-	tmp$33 EMITFBCTINFEND;
-	tmp$65 ALLOCVREG;
-	tmp$66 ALLOCVRIMM;
-	tmp$67 ALLOCVRIMMF;
-	tmp$68 ALLOCVRVAR;
-	tmp$69 ALLOCVRIDX;
-	tmp$70 ALLOCVRPTR;
-	tmp$68 ALLOCVROFS;
-	tmp$71 SETVREGDATATYPE;
-	tmp$72 GETDISTANCE;
-	tmp$47 LOADVR;
-	tmp$40 STOREVR;
-	tmp$41 XCHGTOS;
+	tmp$38 INIT;
+	tmp$38 END;
+	tmp$39 EMITBEGIN;
+	tmp$38 EMITEND;
+	tmp$40 GETOPTIONVALUE;
+	tmp$41 SUPPORTSOP;
+	tmp$42 PROCBEGIN;
+	tmp$42 PROCEND;
+	tmp$43 PROCALLOCARG;
+	tmp$43 PROCALLOCLOCAL;
+	tmp$44 PROCGETFRAMEREGNAME;
+	tmp$42 SCOPEBEGIN;
+	tmp$42 SCOPEEND;
+	tmp$42 PROCALLOCSTATICVARS;
+	tmp$45 EMITCONVERT;
+	tmp$42 EMITLABEL;
+	tmp$42 EMITLABELNF;
+	tmp$46 EMITRETURN;
+	tmp$43 EMITPROCBEGIN;
+	tmp$47 EMITPROCEND;
+	tmp$48 EMITPUSHARG;
+	tmp$49 EMITASMLINE;
+	tmp$50 EMITCOMMENT;
+	tmp$51 EMITBOP;
+	tmp$52 EMITUOP;
+	tmp$45 EMITSTORE;
+	tmp$38 EMITSPILLREGS;
+	tmp$53 EMITLOAD;
+	tmp$45 EMITLOADRES;
+	tmp$52 EMITSTACK;
+	tmp$52 EMITADDR;
+	tmp$54 EMITCALL;
+	tmp$55 EMITCALLPTR;
+	tmp$46 EMITSTACKALIGN;
+	tmp$53 EMITJUMPPTR;
+	tmp$56 EMITBRANCH;
+	tmp$57 EMITJMPTB;
+	tmp$58 EMITMEM;
+	tmp$59 EMITMACRO;
+	tmp$42 EMITSCOPEBEGIN;
+	tmp$42 EMITSCOPEEND;
+	tmp$42 EMITDECL;
+	tmp$60 EMITDBG;
+	tmp$42 EMITVARINIBEGIN;
+	tmp$42 EMITVARINIEND;
+	tmp$61 EMITVARINII;
+	tmp$62 EMITVARINIF;
+	tmp$63 EMITVARINIOFS;
+	tmp$64 EMITVARINISTR;
+	tmp$65 EMITVARINIWSTR;
+	tmp$66 EMITVARINIPAD;
+	tmp$67 EMITVARINISCOPEBEGIN;
+	tmp$38 EMITVARINISCOPEEND;
+	tmp$38 EMITFBCTINFBEGIN;
+	tmp$68 EMITFBCTINFSTRING;
+	tmp$38 EMITFBCTINFEND;
+	tmp$69 ALLOCVREG;
+	tmp$70 ALLOCVRIMM;
+	tmp$71 ALLOCVRIMMF;
+	tmp$72 ALLOCVRVAR;
+	tmp$73 ALLOCVRIDX;
+	tmp$74 ALLOCVRPTR;
+	tmp$72 ALLOCVROFS;
+	tmp$75 SETVREGDATATYPE;
+	tmp$76 GETDISTANCE;
+	tmp$52 LOADVR;
+	tmp$45 STOREVR;
+	tmp$46 XCHGTOS;
 };
 __FB_STATIC_ASSERT( sizeof( struct $7IR_VTBL ) == 544 );
 typedef int64 $6IR_OPT;
 struct $5IRCTX {
-	int64 INITED;
 	struct $7IR_VTBL VTBL;
 	$6IR_OPT OPTIONS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 560 );
+__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 552 );
 extern struct $5IRCTX IR$;
 struct $12AST_PROC_CTX {
 	struct $7ASTNODE* HEAD;
@@ -845,10 +858,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -866,20 +880,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
 struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL* SYM$1, int64 OFS$1, int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1 )
 {
@@ -890,9 +906,9 @@ struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL* SYM$1, int64 OFS$1, int64 DTYPE$
 	if( DTYPE$1 != 2147483648ll ) goto label$13;
 	{
 		{
-			$12FB_SYMBCLASS TMP$79$3;
-			TMP$79$3 = *($12FB_SYMBCLASS*)SYM$1;
-			if( TMP$79$3 != 7ll ) goto label$15;
+			$12FB_SYMBCLASS TMP$83$3;
+			TMP$83$3 = *($12FB_SYMBCLASS*)SYM$1;
+			if( TMP$83$3 != 7ll ) goto label$15;
 			label$16:;
 			{
 				DTYPE$1 = 0ll;
@@ -900,11 +916,11 @@ struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL* SYM$1, int64 OFS$1, int64 DTYPE$
 			}
 			goto label$14;
 			label$15:;
-			if( TMP$79$3 != 3ll ) goto label$17;
+			if( TMP$83$3 != 3ll ) goto label$17;
 			label$18:;
 			{
 				DTYPE$1 = 22ll;
-				if( (*(int64*)((uint8*)SYM$1 + 16ll) & 16384ll) == 0ll ) goto label$20;
+				if( (*(int64*)((uint8*)SYM$1 + 24ll) & 16384ll) == 0ll ) goto label$20;
 				{
 					SUBTYPE$1 = SYM$1;
 				}
@@ -919,9 +935,9 @@ struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL* SYM$1, int64 OFS$1, int64 DTYPE$
 			goto label$14;
 			label$17:;
 			{
-				DTYPE$1 = *(int64*)((uint8*)SYM$1 + 48ll);
-				SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 56ll);
-				if( (((int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 262144ll) != 0ll) | (int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 512ll) != 0ll)) | (int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 33554432ll) != 0ll)) == 0ll ) goto label$23;
+				DTYPE$1 = *(int64*)((uint8*)SYM$1 + 56ll);
+				SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 64ll);
+				if( (((int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 65536ll) != 0ll) | (int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 512ll) != 0ll)) | (int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 262144ll) != 0ll)) == 0ll ) goto label$23;
 				{
 					DTYPE$1 = (((DTYPE$1 & 31ll) | ((DTYPE$1 & 480ll) + 32ll)) | ((DTYPE$1 & 261632ll) << (1ll & 63ll))) | (DTYPE$1 & 32505856ll);
 				}
@@ -938,7 +954,7 @@ struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL* SYM$1, int64 OFS$1, int64 DTYPE$
 	N$1 = vr$27;
 	if( SYM$1 == (struct $8FBSYMBOL*)0ull ) goto label$25;
 	{
-		if( ((int64)-(*(int64*)SYM$1 == 1ll) & (int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 4194304ll) != 0ll)) == 0ll ) goto label$27;
+		if( ((int64)-(*(int64*)SYM$1 == 1ll) & (int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 4096ll) != 0ll)) == 0ll ) goto label$27;
 		{
 			ASTDTORLISTADDREF( SYM$1 );
 		}
@@ -974,14 +990,14 @@ struct $6IRVREG* ASTLOADVAR( struct $7ASTNODE* N$1 )
 	OFS$1 = *(int64*)((uint8*)N$1 + 40ll);
 	if( S$1 == (struct $8FBSYMBOL*)0ull ) goto label$33;
 	{
-		*($12FB_SYMBSTATS*)((uint8*)S$1 + 16ll) = *(int64*)((uint8*)S$1 + 16ll) | 2ll;
-		OFS$1 = OFS$1 + *(int64*)((uint8*)S$1 + 80ll);
+		*($12FB_SYMBSTATS*)((uint8*)S$1 + 24ll) = *(int64*)((uint8*)S$1 + 24ll) | 2ll;
+		OFS$1 = OFS$1 + *(int64*)((uint8*)S$1 + 88ll);
 	}
 	label$33:;
 	label$32:;
 	if( *(int64*)((uint8*)&AST$ + 272ll) == 0ll ) goto label$35;
 	{
-		struct $6IRVREG* vr$10 = (*(tmp$68*)((uint8*)&IR$ + 480ll))( *(int64*)((uint8*)N$1 + 8ll), *(struct $8FBSYMBOL**)((uint8*)N$1 + 16ll), S$1, OFS$1 );
+		struct $6IRVREG* vr$10 = (*(tmp$72*)((uint8*)&IR$ + 472ll))( *(int64*)((uint8*)N$1 + 8ll), *(struct $8FBSYMBOL**)((uint8*)N$1 + 16ll), S$1, OFS$1 );
 		VR$1 = vr$10;
 		*(int64*)((uint8*)VR$1 + 40ll) = *(int64*)((uint8*)N$1 + 32ll);
 	}
@@ -995,7 +1011,7 @@ struct $6IRVREG* ASTLOADVAR( struct $7ASTNODE* N$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
