@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +317,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +386,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +416,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +566,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -603,6 +618,17 @@ struct $11TSTRSETITEM {
 	int64 USERDATA;
 };
 __FB_STATIC_ASSERT( sizeof( struct $11TSTRSETITEM ) == 32 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
 static void fb_ctor__astzvectorize( void ) __attribute__(( constructor ));
@@ -648,21 +674,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -670,20 +686,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -724,8 +742,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -733,8 +754,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -781,6 +803,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -802,16 +825,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 static int64 VECTORWIDTH$;
 static int64 MAXVECTORWIDTH$;
@@ -972,7 +1000,7 @@ __attribute__(( constructor )) static void fb_ctor__astzvectorize( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1003,7 +1031,7 @@ static int64 HNODESMATCH( struct $7ASTNODE* VN$1, struct $7ASTNODE* N$1 )
 	label$14:;
 	if( *(int64*)VN$1 != 16ll ) goto label$19;
 	{
-		int64 TMP$79$2;
+		int64 TMP$83$2;
 		if( (*(int64*)((uint8*)VN$1 + 8ll) & 511ll) == (*(int64*)((uint8*)N$1 + 8ll) & 511ll) ) goto label$21;
 		{
 			fb$result$1 = 0ll;
@@ -1012,12 +1040,12 @@ static int64 HNODESMATCH( struct $7ASTNODE* VN$1, struct $7ASTNODE* N$1 )
 		label$21:;
 		label$20:;
 		if( (*(int64*)((uint8*)VN$1 + 8ll) & 480ll) == 0ll ) goto label$22;
-		TMP$79$2 = 24ll;
+		TMP$83$2 = 24ll;
 		goto label$315;
 		label$22:;
-		TMP$79$2 = *(int64*)((uint8*)VN$1 + 8ll) & 31ll;
+		TMP$83$2 = *(int64*)((uint8*)VN$1 + 8ll) & 31ll;
 		label$315:;
-		if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$79$2 * 56ll)) != 1ll ) goto label$24;
+		if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$83$2 * 56ll)) != 1ll ) goto label$24;
 		{
 			if( *(double*)((uint8*)VN$1 + 40ll) == *(double*)((uint8*)N$1 + 40ll) ) goto label$26;
 			{
@@ -1061,8 +1089,8 @@ static int64 HALLOWEDINVECTORIZE( struct $7ASTNODE* N$1, int64 DEREF$1 )
 		label$32:;
 	}
 	{
-		uint64 TMP$80$2;
-		TMP$80$2 = *(uint64*)N$1;
+		uint64 TMP$84$2;
+		TMP$84$2 = *(uint64*)N$1;
 		goto label$34;
 		label$35:;
 		{
@@ -1135,7 +1163,7 @@ static int64 HALLOWEDINVECTORIZE( struct $7ASTNODE* N$1, int64 DEREF$1 )
 		goto label$33;
 		label$55:;
 		{
-			DTYPE$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll) + 48ll) & 31ll;
+			DTYPE$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll) + 56ll) & 31ll;
 			if( ((int64)-(DTYPE$1 == 15ll) | (int64)-(DTYPE$1 == 20ll)) == 0ll ) goto label$57;
 			{
 				fb$result$1 = -1ll;
@@ -1157,7 +1185,7 @@ static int64 HALLOWEDINVECTORIZE( struct $7ASTNODE* N$1, int64 DEREF$1 )
 		goto label$33;
 		label$59:;
 		{
-			DTYPE$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll) + 48ll) & 31ll;
+			DTYPE$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll) + 56ll) & 31ll;
 			if( DTYPE$1 != 15ll ) goto label$61;
 			{
 				fb$result$1 = -1ll;
@@ -1187,7 +1215,7 @@ static int64 HALLOWEDINVECTORIZE( struct $7ASTNODE* N$1, int64 DEREF$1 )
 		}
 		goto label$33;
 		label$34:;
-		static const void* tmp$90[20ll] = {
+		static const void* tmp$94[20ll] = {
 			&&label$49,
 			&&label$49,
 			&&label$35,
@@ -1209,8 +1237,8 @@ static int64 HALLOWEDINVECTORIZE( struct $7ASTNODE* N$1, int64 DEREF$1 )
 			&&label$59,
 			&&label$64,
 		};
-		if( (TMP$80$2 - 1ull) > 19ull ) goto label$65;
-		goto *tmp$90[TMP$80$2 - 1ull];
+		if( (TMP$84$2 - 1ull) > 19ull ) goto label$65;
+		goto *tmp$94[TMP$84$2 - 1ull];
 		label$33:;
 	}
 	fb$result$1 = 0ll;
@@ -1265,14 +1293,14 @@ static struct $7ASTNODE* HSKIPNEWNODES( struct $7ASTNODE* N$1, int64 DOMERGE$1 )
 			{
 				if( DOMERGE$1 == 0ll ) goto label$86;
 				{
-					int64 TMP$81$5;
+					int64 TMP$85$5;
 					if( *(int64*)((uint8*)N$1 + 32ll) != 0ll ) goto label$87;
-					TMP$81$5 = 2ll;
+					TMP$85$5 = 2ll;
 					goto label$316;
 					label$87:;
-					TMP$81$5 = *(int64*)((uint8*)N$1 + 32ll) + 1ll;
+					TMP$85$5 = *(int64*)((uint8*)N$1 + 32ll) + 1ll;
 					label$316:;
-					*(int64*)((uint8*)N$1 + 32ll) = TMP$81$5;
+					*(int64*)((uint8*)N$1 + 32ll) = TMP$85$5;
 				}
 				label$86:;
 				label$85:;
@@ -1393,14 +1421,14 @@ static struct $7ASTNODE* HVECTORIZENODE( struct $7ASTNODE* N$1, int64 DIST$1 )
 	}
 	if( ((int64)-(*(int64*)N$1 == 4ll) | (int64)-(*(int64*)N$1 == 3ll)) == 0ll ) goto label$113;
 	{
-		int64 TMP$82$2;
+		int64 TMP$86$2;
 		if( *(int64*)((uint8*)N$1 + 32ll) != 0ll ) goto label$114;
-		TMP$82$2 = 2ll;
+		TMP$86$2 = 2ll;
 		goto label$317;
 		label$114:;
-		TMP$82$2 = *(int64*)((uint8*)N$1 + 32ll) + 1ll;
+		TMP$86$2 = *(int64*)((uint8*)N$1 + 32ll) + 1ll;
 		label$317:;
-		*(int64*)((uint8*)N$1 + 32ll) = TMP$82$2;
+		*(int64*)((uint8*)N$1 + 32ll) = TMP$86$2;
 	}
 	goto label$112;
 	label$113:;
@@ -1412,14 +1440,14 @@ static struct $7ASTNODE* HVECTORIZENODE( struct $7ASTNODE* N$1, int64 DIST$1 )
 		goto label$115;
 		label$116:;
 		{
-			int64 TMP$83$3;
+			int64 TMP$87$3;
 			if( *(int64*)((uint8*)N$1 + 32ll) != 0ll ) goto label$117;
-			TMP$83$3 = 2ll;
+			TMP$87$3 = 2ll;
 			goto label$318;
 			label$117:;
-			TMP$83$3 = *(int64*)((uint8*)N$1 + 32ll) + 1ll;
+			TMP$87$3 = *(int64*)((uint8*)N$1 + 32ll) + 1ll;
 			label$318:;
-			*(int64*)((uint8*)N$1 + 32ll) = TMP$83$3;
+			*(int64*)((uint8*)N$1 + 32ll) = TMP$87$3;
 		}
 		label$115:;
 	}
@@ -1447,9 +1475,9 @@ static int64 HCHECKDEREFVAR( struct $7ASTNODE* N$1, int64* DTYPE$1 )
 	if( N$1 == (struct $7ASTNODE*)0ull ) goto label$123;
 	{
 		{
-			$13AST_NODECLASS TMP$84$3;
-			TMP$84$3 = *($13AST_NODECLASS*)N$1;
-			if( TMP$84$3 != 5ll ) goto label$125;
+			$13AST_NODECLASS TMP$88$3;
+			TMP$88$3 = *($13AST_NODECLASS*)N$1;
+			if( TMP$88$3 != 5ll ) goto label$125;
 			label$126:;
 			{
 				*DTYPE$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
@@ -1463,12 +1491,12 @@ static int64 HCHECKDEREFVAR( struct $7ASTNODE* N$1, int64* DTYPE$1 )
 			}
 			goto label$124;
 			label$125:;
-			if( TMP$84$3 == 17ll ) goto label$130;
+			if( TMP$88$3 == 17ll ) goto label$130;
 			label$131:;
-			if( TMP$84$3 != 19ll ) goto label$129;
+			if( TMP$88$3 != 19ll ) goto label$129;
 			label$130:;
 			{
-				*DTYPE$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll) + 48ll) & 31ll;
+				*DTYPE$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll) + 56ll) & 31ll;
 				if( ((int64)-(*DTYPE$1 == 15ll) | (int64)-(*DTYPE$1 == 16ll)) == 0ll ) goto label$133;
 				{
 					RESULT$1 = -1ll;
@@ -1507,7 +1535,7 @@ static int64 HCHECKARRAYVAR( struct $7ASTNODE* N$1, int64* DTYPE$1 )
 	}
 	if( *(int64*)N$1 != 17ll ) goto label$140;
 	{
-		*DTYPE$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll) + 48ll) & 31ll;
+		*DTYPE$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll) + 56ll) & 31ll;
 		if( ((int64)-(*DTYPE$1 == 15ll) | (int64)-(*DTYPE$1 == 16ll)) == 0ll ) goto label$142;
 		{
 			fb$result$1 = -1ll;
@@ -1530,31 +1558,31 @@ static int64 HCHECKMEMOFFSET( struct $7ASTNODE* VECTORNODE$1, int64 OFFSET$1, $1
 	NEEDOFFSET$1 = 0ll;
 	if( *(int64*)((uint8*)VECTORNODE$1 + 32ll) == 0ll ) goto label$146;
 	{
-		int64 TMP$85$2;
+		int64 TMP$89$2;
 		if( *(int64*)((uint8*)VECTORNODE$1 + 32ll) <= VECTORWIDTH$ ) goto label$148;
 		{
 			VECTORWIDTH$ = *(int64*)((uint8*)VECTORNODE$1 + 32ll);
 			label$148:;
 		}
 		if( (DTYPE$1 & 480ll) == 0ll ) goto label$149;
-		TMP$85$2 = 24ll;
+		TMP$89$2 = 24ll;
 		goto label$319;
 		label$149:;
-		TMP$85$2 = DTYPE$1 & 31ll;
+		TMP$89$2 = DTYPE$1 & 31ll;
 		label$319:;
-		NEEDOFFSET$1 = VECTORWIDTH$ * *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$85$2 * 56ll)) + 8ll);
+		NEEDOFFSET$1 = VECTORWIDTH$ * *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$89$2 * 56ll)) + 8ll);
 	}
 	goto label$145;
 	label$146:;
 	{
-		int64 TMP$86$2;
+		int64 TMP$90$2;
 		if( (DTYPE$1 & 480ll) == 0ll ) goto label$150;
-		TMP$86$2 = 24ll;
+		TMP$90$2 = 24ll;
 		goto label$320;
 		label$150:;
-		TMP$86$2 = DTYPE$1 & 31ll;
+		TMP$90$2 = DTYPE$1 & 31ll;
 		label$320:;
-		NEEDOFFSET$1 = *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$86$2 * 56ll)) + 8ll);
+		NEEDOFFSET$1 = *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$90$2 * 56ll)) + 8ll);
 	}
 	label$145:;
 	fb$result$1 = -1ll;
@@ -1592,9 +1620,9 @@ static $11FB_DATATYPE HGETASSIGNDATATYPE( struct $7ASTNODE* N$1 )
 		label$160:;
 	}
 	{
-		$13AST_NODECLASS TMP$87$2;
-		TMP$87$2 = *($13AST_NODECLASS*)N$1;
-		if( TMP$87$2 != 5ll ) goto label$162;
+		$13AST_NODECLASS TMP$91$2;
+		TMP$91$2 = *($13AST_NODECLASS*)N$1;
+		if( TMP$91$2 != 5ll ) goto label$162;
 		label$163:;
 		{
 			fb$result$1 = *(int64*)((uint8*)N$1 + 8ll) & 31ll;
@@ -1602,12 +1630,12 @@ static $11FB_DATATYPE HGETASSIGNDATATYPE( struct $7ASTNODE* N$1 )
 		}
 		goto label$161;
 		label$162:;
-		if( TMP$87$2 == 17ll ) goto label$165;
+		if( TMP$91$2 == 17ll ) goto label$165;
 		label$166:;
-		if( TMP$87$2 != 19ll ) goto label$164;
+		if( TMP$91$2 != 19ll ) goto label$164;
 		label$165:;
 		{
-			fb$result$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll) + 48ll) & 31ll;
+			fb$result$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)N$1 + 24ll) + 56ll) & 31ll;
 			goto label$158;
 		}
 		goto label$161;
@@ -1681,31 +1709,31 @@ static int64 HMERGENODE( struct $7ASTNODE* VECTORNODE$1, struct $7ASTNODE* N$1,
 		OFFSET$1 = N_OFS$1 - VN_OFS$1;
 		if( *(int64*)((uint8*)VECTORNODE$1 + 32ll) == 0ll ) goto label$183;
 		{
-			int64 TMP$88$3;
+			int64 TMP$92$3;
 			if( *(int64*)((uint8*)VECTORNODE$1 + 32ll) <= VECTORWIDTH$ ) goto label$185;
 			{
 				VECTORWIDTH$ = *(int64*)((uint8*)VECTORNODE$1 + 32ll);
 				label$185:;
 			}
 			if( (DTYPE$1 & 480ll) == 0ll ) goto label$186;
-			TMP$88$3 = 24ll;
+			TMP$92$3 = 24ll;
 			goto label$321;
 			label$186:;
-			TMP$88$3 = DTYPE$1 & 31ll;
+			TMP$92$3 = DTYPE$1 & 31ll;
 			label$321:;
-			NEEDOFFSET$1 = VECTORWIDTH$ * *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$88$3 * 56ll)) + 8ll);
+			NEEDOFFSET$1 = VECTORWIDTH$ * *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$92$3 * 56ll)) + 8ll);
 		}
 		goto label$182;
 		label$183:;
 		{
-			int64 TMP$89$3;
+			int64 TMP$93$3;
 			if( (DTYPE$1 & 480ll) == 0ll ) goto label$187;
-			TMP$89$3 = 24ll;
+			TMP$93$3 = 24ll;
 			goto label$322;
 			label$187:;
-			TMP$89$3 = DTYPE$1 & 31ll;
+			TMP$93$3 = DTYPE$1 & 31ll;
 			label$322:;
-			NEEDOFFSET$1 = *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$89$3 * 56ll)) + 8ll);
+			NEEDOFFSET$1 = *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$93$3 * 56ll)) + 8ll);
 		}
 		label$182:;
 		if( OFFSET$1 == NEEDOFFSET$1 ) goto label$189;
@@ -1744,7 +1772,7 @@ static int64 HMERGENODE( struct $7ASTNODE* VECTORNODE$1, struct $7ASTNODE* N$1,
 		VN_OFS$1 = 0ll;
 		HGETVARDISTANCE( VECTORNODE$1, &VN_OFS$1, N$1, &N_OFS$1 );
 		OFFSET$1 = N_OFS$1 - VN_OFS$1;
-		DTYPE$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)VECTORNODE$1 + 24ll) + 48ll) & 31ll;
+		DTYPE$1 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)VECTORNODE$1 + 24ll) + 56ll) & 31ll;
 		int64 vr$28 = HCHECKMEMOFFSET( VECTORNODE$1, OFFSET$1, DTYPE$1 );
 		if( vr$28 != 0ll ) goto label$199;
 		{
@@ -1977,8 +2005,8 @@ static int64 ASTINTRATREEVECTORIZE( struct $7ASTNODE* N$1 )
 					if( *(int64*)((uint8*)L$1 + 40ll) != 55ll ) goto label$263;
 					{
 						__builtin_memcpy( N$1, L$1, 144 );
+						*(int64*)((uint8*)N$1 + 32ll) = *(int64*)((uint8*)*(struct $7ASTNODE**)((uint8*)N$1 + 112ll) + 32ll);
 						ASTDELNODE( L$1 );
-						*(int64*)((uint8*)N$1 + 32ll) = 0ll;
 						fb$result$1 = -1ll;
 						goto label$251;
 					}
@@ -1991,7 +2019,7 @@ static int64 ASTINTRATREEVECTORIZE( struct $7ASTNODE* N$1 )
 				*(struct $7ASTNODE**)((uint8*)N$1 + 120ll) = (struct $7ASTNODE*)0ull;
 				*($13AST_NODECLASS*)N$1 = 4ll;
 				*(int64*)((uint8*)N$1 + 40ll) = 55ll;
-				*(int64*)((uint8*)N$1 + 32ll) = 0ll;
+				*(int64*)((uint8*)N$1 + 32ll) = *(int64*)((uint8*)*(struct $7ASTNODE**)((uint8*)N$1 + 112ll) + 32ll);
 				fb$result$1 = -1ll;
 				goto label$251;
 			}
@@ -2003,15 +2031,15 @@ static int64 ASTINTRATREEVECTORIZE( struct $7ASTNODE* N$1 )
 	}
 	label$255:;
 	label$254:;
-	int64 vr$18 = ASTINTRATREEVECTORIZE( *(struct $7ASTNODE**)((uint8*)N$1 + 112ll) );
-	if( vr$18 != -1ll ) goto label$265;
+	int64 vr$22 = ASTINTRATREEVECTORIZE( *(struct $7ASTNODE**)((uint8*)N$1 + 112ll) );
+	if( vr$22 != -1ll ) goto label$265;
 	{
 		CHANGED$1 = -1ll;
 	}
 	label$265:;
 	label$264:;
-	int64 vr$20 = ASTINTRATREEVECTORIZE( *(struct $7ASTNODE**)((uint8*)N$1 + 120ll) );
-	if( vr$20 != -1ll ) goto label$267;
+	int64 vr$24 = ASTINTRATREEVECTORIZE( *(struct $7ASTNODE**)((uint8*)N$1 + 120ll) );
+	if( vr$24 != -1ll ) goto label$267;
 	{
 		CHANGED$1 = -1ll;
 	}
