@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +513,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +582,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +612,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -624,10 +639,10 @@ void ASTSETTYPE( struct $7ASTNODE*, int64, struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBGETPROCRESULT( struct $8FBSYMBOL* );
 typedef int64 $10FB_SYMBOPT;
 struct $8FBSYMBOL* SYMBADDLABEL( uint8*, $10FB_SYMBOPT );
-struct $8FBSYMBOL* SYMBADDPROCPARAM( struct $8FBSYMBOL*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, $13FB_SYMBATTRIB );
-struct $8FBSYMBOL* SYMBADDPROC( struct $8FBSYMBOL*, uint8*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, $10FB_SYMBOPT );
+struct $8FBSYMBOL* SYMBADDPROCPARAM( struct $8FBSYMBOL*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, $13FB_SYMBATTRIB, $13FB_PROCATTRIB );
+struct $8FBSYMBOL* SYMBADDPROC( struct $8FBSYMBOL*, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB, $13FB_PROCATTRIB, int64, $10FB_SYMBOPT );
 struct $8FBSYMBOL* SYMBPREADDPROC( uint8* );
-uint8* SYMBUNIQUEID( void );
+uint8* SYMBUNIQUEID( boolean );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -709,10 +724,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -730,20 +746,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -784,8 +802,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -793,8 +814,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -841,6 +863,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -862,22 +885,27 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 
 void FBMAINBEGIN( void )
 {
 	label$24:;
-	if( *(int64*)((uint8*)&ENV$ + 1128ll) == 0ll ) goto label$27;
+	if( *(int64*)((uint8*)&ENV$ + 1160ll) == 0ll ) goto label$27;
 	{
 		HMAINBEGIN(  );
 	}
@@ -887,7 +915,7 @@ void FBMAINBEGIN( void )
 		HMODLEVELBEGIN(  );
 	}
 	label$26:;
-	if( (*(int64*)((uint8*)&ENV$ + 1128ll) & (int64)-(*(int64*)((uint8*)&ENV$ + 192ll) == 2ll)) == 0ll ) goto label$29;
+	if( (*(int64*)((uint8*)&ENV$ + 1160ll) & (int64)-(*(int64*)((uint8*)&ENV$ + 192ll) == 2ll)) == 0ll ) goto label$29;
 	{
 		if( *(int64*)((uint8*)&ENV$ + 216ll) != 0ll ) goto label$31;
 		{
@@ -910,11 +938,11 @@ void FBMAINEND( void )
 	label$32:;
 	int64 CALLRTEXIT$1;
 	CALLRTEXIT$1 = 0ll;
-	if( *(int64*)((uint8*)&ENV$ + 1128ll) == 0ll ) goto label$35;
+	if( *(int64*)((uint8*)&ENV$ + 1160ll) == 0ll ) goto label$35;
 	{
 		if( *(struct $8FBSYMBOL**)((uint8*)&AST$ + 248ll) == (struct $8FBSYMBOL*)0ull ) goto label$37;
 		{
-			RTLDATARESTORE( (struct $8FBSYMBOL*)0ull, *(struct $7ASTNODE**)((uint8*)&ENV$ + 1240ll) );
+			RTLDATARESTORE( (struct $8FBSYMBOL*)0ull, *(struct $7ASTNODE**)((uint8*)&ENV$ + 1400ll) );
 		}
 		label$37:;
 		label$36:;
@@ -929,7 +957,7 @@ void FBMAINEND( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -938,7 +966,7 @@ static void HCALLMAIN( void )
 {
 	label$10:;
 	struct $7ASTNODE* MAIN$1;
-	struct $7ASTNODE* vr$0 = ASTNEWCALL( *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll), (struct $7ASTNODE*)0ull );
+	struct $7ASTNODE* vr$0 = ASTNEWCALL( *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll), (struct $7ASTNODE*)0ull );
 	MAIN$1 = vr$0;
 	struct $7ASTNODE* vr$1 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
 	ASTNEWARG( MAIN$1, vr$1, 2147483648ll, -1ll );
@@ -957,19 +985,19 @@ static void HBUILDDLLMAINWIN32( void )
 	struct $8FBSYMBOL* PARAM$1;
 	struct $8FBSYMBOL* vr$0 = SYMBPREADDPROC( (uint8*)0ull );
 	PROC$1 = vr$0;
-	SYMBADDPROCPARAM( PROC$1, (uint8*)"__FB_DLLINSTANCE__", 32ll, (struct $8FBSYMBOL*)0ull, 0ll, 1ll, 0ll );
-	struct $8FBSYMBOL* vr$1 = SYMBADDPROCPARAM( PROC$1, (uint8*)"__FB_DLLREASON__", 9ll, (struct $8FBSYMBOL*)0ull, 0ll, 1ll, 0ll );
+	SYMBADDPROCPARAM( PROC$1, (uint8*)"__FB_DLLINSTANCE__", 32ll, (struct $8FBSYMBOL*)0ull, 0ll, 1ll, 0ll, 0ll );
+	struct $8FBSYMBOL* vr$1 = SYMBADDPROCPARAM( PROC$1, (uint8*)"__FB_DLLREASON__", 9ll, (struct $8FBSYMBOL*)0ull, 0ll, 1ll, 0ll, 0ll );
 	PARAM$1 = vr$1;
-	SYMBADDPROCPARAM( PROC$1, (uint8*)"__FB_DLLRESERVED__", 32ll, (struct $8FBSYMBOL*)0ull, 0ll, 1ll, 0ll );
-	struct $8FBSYMBOL* vr$2 = SYMBADDPROC( PROC$1, (uint8*)0ull, (uint8*)"DllMain", 8ll, (struct $8FBSYMBOL*)0ull, 32ll, *(int64*)((uint8*)&ENV$ + 512ll), 4ll );
+	SYMBADDPROCPARAM( PROC$1, (uint8*)"__FB_DLLRESERVED__", 32ll, (struct $8FBSYMBOL*)0ull, 0ll, 1ll, 0ll, 0ll );
+	struct $8FBSYMBOL* vr$2 = SYMBADDPROC( PROC$1, (uint8*)0ull, (uint8*)"DllMain", 8ll, (struct $8FBSYMBOL*)0ull, 32ll, 0ll, *(int64*)((uint8*)&ENV$ + 544ll), 4ll );
 	PROC$1 = vr$2;
 	ASTPROCBEGIN( PROC$1, 0ll );
-	struct $7ASTNODE* vr$5 = ASTNEWCONSTI( 1ll, *(int64*)((uint8*)PROC$1 + 48ll) & 511ll, (struct $8FBSYMBOL*)0ull );
+	struct $7ASTNODE* vr$5 = ASTNEWCONSTI( 1ll, *(int64*)((uint8*)PROC$1 + 56ll) & 511ll, (struct $8FBSYMBOL*)0ull );
 	struct $8FBSYMBOL* vr$6 = SYMBGETPROCRESULT( PROC$1 );
 	struct $7ASTNODE* vr$7 = ASTNEWVAR( vr$6, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$8 = ASTNEWASSIGN( vr$7, vr$5, 0ll );
 	ASTADD( vr$8 );
-	PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 96ll);
+	PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 104ll);
 	struct $8FBSYMBOL* vr$10 = SYMBADDLABEL( (uint8*)0ull, 4ll );
 	LABEL$1 = vr$10;
 	struct $7ASTNODE* vr$11 = ASTNEWCONSTI( 1ll, 9ll, (struct $8FBSYMBOL*)0ull );
@@ -988,7 +1016,7 @@ static void HBUILDDLLMAINCTOR( void )
 	label$14:;
 	struct $8FBSYMBOL* PROC$1;
 	struct $8FBSYMBOL* vr$0 = SYMBPREADDPROC( (uint8*)0ull );
-	struct $8FBSYMBOL* vr$1 = SYMBADDPROC( vr$0, (uint8*)0ull, (uint8*)"__fb_DllMain_ctor", 0ll, (struct $8FBSYMBOL*)0ull, 64ll, 3ll, 4ll );
+	struct $8FBSYMBOL* vr$1 = SYMBADDPROC( vr$0, (uint8*)0ull, (uint8*)"__fb_DllMain_ctor", 0ll, (struct $8FBSYMBOL*)0ull, 64ll, 0ll, 3ll, 4ll );
 	PROC$1 = vr$1;
 	SYMBADDGLOBALCTOR( PROC$1 );
 	ASTPROCBEGIN( PROC$1, 0ll );
@@ -1004,21 +1032,21 @@ static void HMAINBEGIN( void )
 	struct $8FBSYMBOL* ARGV$1;
 	struct $8FBSYMBOL* vr$0 = SYMBPREADDPROC( (uint8*)0ull );
 	PROC$1 = vr$0;
-	SYMBADDPROCPARAM( PROC$1, (uint8*)"__FB_ARGC__", 11ll, (struct $8FBSYMBOL*)0ull, 0ll, 1ll, 0ll );
-	struct $8FBSYMBOL* vr$1 = SYMBADDPROCPARAM( PROC$1, (uint8*)"__FB_ARGV__", 68ll, (struct $8FBSYMBOL*)0ull, 0ll, 1ll, 0ll );
+	SYMBADDPROCPARAM( PROC$1, (uint8*)"__FB_ARGC__", 11ll, (struct $8FBSYMBOL*)0ull, 0ll, 1ll, 0ll, 0ll );
+	struct $8FBSYMBOL* vr$1 = SYMBADDPROCPARAM( PROC$1, (uint8*)"__FB_ARGV__", 68ll, (struct $8FBSYMBOL*)0ull, 0ll, 1ll, 0ll, 0ll );
 	ARGV$1 = vr$1;
 	$13FB_SYMBATTRIB ATTRIB$1;
 	ATTRIB$1 = 32ll;
 	FBSTRING ID$1;
 	FBSTRING* vr$2 = FBGETENTRYPOINT(  );
-	FBSTRING* vr$4 = fb_StrInit( (void*)&ID$1, -1ll, (void*)vr$2, -1ll, 0 );
+	fb_StrInit( (void*)&ID$1, -1ll, (void*)vr$2, -1ll, 0 );
 	if( *(int64*)((uint8*)&ENV$ + 192ll) != 2ll ) goto label$19;
 	{
 		ATTRIB$1 = 64ll;
 		if( *(int64*)((uint8*)&ENV$ + 208ll) != 1ll ) goto label$21;
 		{
-			uint8* vr$5 = SYMBUNIQUEID(  );
-			fb_StrAssign( (void*)&ID$1, -1ll, (void*)vr$5, 0ll, 0 );
+			uint8* vr$4 = SYMBUNIQUEID( (boolean)0ll );
+			fb_StrAssign( (void*)&ID$1, -1ll, (void*)vr$4, 0ll, 0 );
 		}
 		label$21:;
 		label$20:;
@@ -1026,31 +1054,31 @@ static void HMAINBEGIN( void )
 	goto label$18;
 	label$19:;
 	{
-		*($12FB_SYMBSTATS*)((uint8*)ARGV$1 + 16ll) = *(int64*)((uint8*)ARGV$1 + 16ll) | 524288ll;
+		*($12FB_SYMBSTATS*)((uint8*)ARGV$1 + 24ll) = *(int64*)((uint8*)ARGV$1 + 24ll) | 524288ll;
 	}
 	label$18:;
-	struct $8FBSYMBOL* vr$10 = SYMBADDPROC( PROC$1, (uint8*)0ull, (uint8*)*(uint8**)&ID$1, 11ll, (struct $8FBSYMBOL*)0ull, ATTRIB$1, 3ll, 4ll );
-	*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) = vr$10;
-	*($12FB_SYMBSTATS*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) + 16ll) = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) + 16ll) | 4096ll;
-	ASTPROCBEGIN( *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll), -1ll );
+	struct $8FBSYMBOL* vr$9 = SYMBADDPROC( PROC$1, (uint8*)0ull, (uint8*)*(uint8**)&ID$1, 11ll, (struct $8FBSYMBOL*)0ull, ATTRIB$1, 0ll, 3ll, 4ll );
+	*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) = vr$9;
+	*($12FB_SYMBSTATS*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) + 24ll) = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) + 24ll) | 4096ll;
+	ASTPROCBEGIN( *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll), -1ll );
 	fb_StrDelete( (FBSTRING*)&ID$1 );
 	label$17:;
 }
 
 static void HMODLEVELBEGIN( void )
 {
-	FBSTRING TMP$88$1;
+	FBSTRING TMP$92$1;
 	label$22:;
-	__builtin_memset( &TMP$88$1, 0, 24ll );
+	__builtin_memset( &TMP$92$1, 0, 24ll );
 	FBSTRING* vr$1 = FBGETMODULEENTRY(  );
-	FBSTRING* vr$3 = fb_StrAssign( (void*)&TMP$88$1, -1ll, (void*)vr$1, -1ll, 0 );
-	struct $8FBSYMBOL* vr$4 = SYMBPREADDPROC( (uint8*)0ull );
-	struct $8FBSYMBOL* vr$5 = SYMBADDPROC( vr$4, (uint8*)"{modlevel}", (uint8*)*(uint8**)&TMP$88$1, 0ll, (struct $8FBSYMBOL*)0ull, 64ll, 3ll, 4ll );
-	*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) = vr$5;
-	fb_StrDelete( (FBSTRING*)&TMP$88$1 );
-	SYMBADDGLOBALCTOR( *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) );
-	*($12FB_SYMBSTATS*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) + 16ll) = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) + 16ll) | 2ll;
-	*($12FB_SYMBSTATS*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) + 16ll) = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) + 16ll) | 8192ll;
-	ASTPROCBEGIN( *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll), -1ll );
+	fb_StrAssign( (void*)&TMP$92$1, -1ll, (void*)vr$1, -1ll, 0 );
+	struct $8FBSYMBOL* vr$3 = SYMBPREADDPROC( (uint8*)0ull );
+	struct $8FBSYMBOL* vr$4 = SYMBADDPROC( vr$3, (uint8*)"{modlevel}", (uint8*)*(uint8**)&TMP$92$1, 0ll, (struct $8FBSYMBOL*)0ull, 64ll, 0ll, 3ll, 4ll );
+	*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) = vr$4;
+	fb_StrDelete( (FBSTRING*)&TMP$92$1 );
+	SYMBADDGLOBALCTOR( *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) );
+	*($12FB_SYMBSTATS*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) + 24ll) = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) + 24ll) | 2ll;
+	*($12FB_SYMBSTATS*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) + 24ll) = *(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) + 24ll) | 8192ll;
+	ASTPROCBEGIN( *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll), -1ll );
 	label$23:;
 }
