@@ -9,13 +9,14 @@ typedef unsigned long long uint64;
 typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $10FB_BACKEND;
-typedef void (*tmp$33)( void );
-typedef int64 (*tmp$34)( void );
+typedef void (*tmp$38)( void );
+typedef int64 (*tmp$39)( void );
 typedef int64 $14IR_OPTIONVALUE;
-typedef int64 (*tmp$35)( $14IR_OPTIONVALUE );
-typedef int64 (*tmp$36)( int64, int64 );
+typedef int64 (*tmp$40)( $14IR_OPTIONVALUE );
+typedef int64 (*tmp$41)( int64, int64 );
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -183,7 +184,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -329,6 +330,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -338,7 +340,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -347,7 +350,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -358,10 +361,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -370,9 +374,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -471,14 +475,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -500,7 +506,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -511,9 +519,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -574,6 +588,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -603,10 +618,10 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
-typedef void (*tmp$37)( struct $8FBSYMBOL* );
-typedef void (*tmp$38)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef uint8* (*tmp$39)( void );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
+typedef void (*tmp$42)( struct $8FBSYMBOL* );
+typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef uint8* (*tmp$44)( void );
 typedef int64 $15IRVREGTYPE_ENUM;
 typedef int64 $12IR_REGFAMILY;
 struct $6IRVREG;
@@ -652,110 +667,110 @@ struct $6IRVREG {
 	struct $5IRTAC* TACLAST;
 };
 __FB_STATIC_ASSERT( sizeof( struct $6IRVREG ) == 120 );
-typedef void (*tmp$40)( struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$41)( int64 );
-typedef void (*tmp$42)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$44)( struct $9ASTASMTOK* );
-typedef void (*tmp$45)( uint8* );
-typedef void (*tmp$46)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
-typedef void (*tmp$47)( int64, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$48)( struct $6IRVREG* );
-typedef void (*tmp$49)( int64, struct $6IRVREG* );
-typedef void (*tmp$50)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
-typedef void (*tmp$51)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$52)( int64, struct $8FBSYMBOL* );
-typedef void (*tmp$53)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
-typedef void (*tmp$54)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
-typedef void (*tmp$55)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$56)( int64, struct $8FBSYMBOL*, int64, uint8* );
-typedef void (*tmp$57)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$58)( struct $8FBSYMBOL*, double );
-typedef void (*tmp$59)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$60)( int64, uint8*, int64 );
-typedef void (*tmp$61)( int64, uint16*, int64 );
-typedef void (*tmp$62)( int64 );
-typedef void (*tmp$63)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$64)( uint8* );
-typedef struct $6IRVREG* (*tmp$65)( int64, struct $8FBSYMBOL* );
-typedef struct $6IRVREG* (*tmp$66)( int64, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$67)( int64, struct $8FBSYMBOL*, double );
-typedef struct $6IRVREG* (*tmp$68)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
-typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
-typedef void (*tmp$71)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
-typedef uint64 (*tmp$72)( struct $6IRVREG* );
+typedef void (*tmp$45)( struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$46)( int64 );
+typedef void (*tmp$47)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef void (*tmp$48)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64, struct $6IRVREG* );
+typedef void (*tmp$49)( struct $9ASTASMTOK* );
+typedef void (*tmp$50)( uint8* );
+typedef void (*tmp$51)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
+typedef void (*tmp$52)( int64, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$53)( struct $6IRVREG* );
+typedef void (*tmp$54)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
+typedef void (*tmp$55)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
+typedef void (*tmp$56)( int64, struct $8FBSYMBOL* );
+typedef void (*tmp$57)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
+typedef void (*tmp$58)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
+typedef void (*tmp$59)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$60)( int64, struct $8FBSYMBOL*, int64, uint8* );
+typedef void (*tmp$61)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$62)( struct $8FBSYMBOL*, double );
+typedef void (*tmp$63)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$64)( int64, uint8*, int64 );
+typedef void (*tmp$65)( int64, uint16*, int64 );
+typedef void (*tmp$66)( int64 );
+typedef void (*tmp$67)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$68)( uint8* );
+typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL* );
+typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$71)( int64, struct $8FBSYMBOL*, double );
+typedef struct $6IRVREG* (*tmp$72)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$73)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
+typedef struct $6IRVREG* (*tmp$74)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
+typedef void (*tmp$75)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
+typedef uint64 (*tmp$76)( struct $6IRVREG* );
 struct $7IR_VTBL {
-	tmp$33 INIT;
-	tmp$33 END;
-	tmp$34 EMITBEGIN;
-	tmp$33 EMITEND;
-	tmp$35 GETOPTIONVALUE;
-	tmp$36 SUPPORTSOP;
-	tmp$37 PROCBEGIN;
-	tmp$37 PROCEND;
-	tmp$38 PROCALLOCARG;
-	tmp$38 PROCALLOCLOCAL;
-	tmp$39 PROCGETFRAMEREGNAME;
-	tmp$37 SCOPEBEGIN;
-	tmp$37 SCOPEEND;
-	tmp$37 PROCALLOCSTATICVARS;
-	tmp$40 EMITCONVERT;
-	tmp$37 EMITLABEL;
-	tmp$37 EMITLABELNF;
-	tmp$41 EMITRETURN;
-	tmp$38 EMITPROCBEGIN;
-	tmp$42 EMITPROCEND;
-	tmp$43 EMITPUSHARG;
-	tmp$44 EMITASMLINE;
-	tmp$45 EMITCOMMENT;
-	tmp$46 EMITBOP;
-	tmp$47 EMITUOP;
-	tmp$40 EMITSTORE;
-	tmp$33 EMITSPILLREGS;
-	tmp$48 EMITLOAD;
-	tmp$40 EMITLOADRES;
-	tmp$49 EMITSTACK;
-	tmp$47 EMITADDR;
-	tmp$50 EMITCALL;
-	tmp$51 EMITCALLPTR;
-	tmp$41 EMITSTACKALIGN;
-	tmp$48 EMITJUMPPTR;
-	tmp$52 EMITBRANCH;
-	tmp$53 EMITJMPTB;
-	tmp$54 EMITMEM;
-	tmp$55 EMITMACRO;
-	tmp$37 EMITSCOPEBEGIN;
-	tmp$37 EMITSCOPEEND;
-	tmp$37 EMITDECL;
-	tmp$56 EMITDBG;
-	tmp$37 EMITVARINIBEGIN;
-	tmp$37 EMITVARINIEND;
-	tmp$57 EMITVARINII;
-	tmp$58 EMITVARINIF;
-	tmp$59 EMITVARINIOFS;
-	tmp$60 EMITVARINISTR;
-	tmp$61 EMITVARINIWSTR;
-	tmp$62 EMITVARINIPAD;
-	tmp$63 EMITVARINISCOPEBEGIN;
-	tmp$33 EMITVARINISCOPEEND;
-	tmp$33 EMITFBCTINFBEGIN;
-	tmp$64 EMITFBCTINFSTRING;
-	tmp$33 EMITFBCTINFEND;
-	tmp$65 ALLOCVREG;
-	tmp$66 ALLOCVRIMM;
-	tmp$67 ALLOCVRIMMF;
-	tmp$68 ALLOCVRVAR;
-	tmp$69 ALLOCVRIDX;
-	tmp$70 ALLOCVRPTR;
-	tmp$68 ALLOCVROFS;
-	tmp$71 SETVREGDATATYPE;
-	tmp$72 GETDISTANCE;
-	tmp$47 LOADVR;
-	tmp$40 STOREVR;
-	tmp$41 XCHGTOS;
+	tmp$38 INIT;
+	tmp$38 END;
+	tmp$39 EMITBEGIN;
+	tmp$38 EMITEND;
+	tmp$40 GETOPTIONVALUE;
+	tmp$41 SUPPORTSOP;
+	tmp$42 PROCBEGIN;
+	tmp$42 PROCEND;
+	tmp$43 PROCALLOCARG;
+	tmp$43 PROCALLOCLOCAL;
+	tmp$44 PROCGETFRAMEREGNAME;
+	tmp$42 SCOPEBEGIN;
+	tmp$42 SCOPEEND;
+	tmp$42 PROCALLOCSTATICVARS;
+	tmp$45 EMITCONVERT;
+	tmp$42 EMITLABEL;
+	tmp$42 EMITLABELNF;
+	tmp$46 EMITRETURN;
+	tmp$43 EMITPROCBEGIN;
+	tmp$47 EMITPROCEND;
+	tmp$48 EMITPUSHARG;
+	tmp$49 EMITASMLINE;
+	tmp$50 EMITCOMMENT;
+	tmp$51 EMITBOP;
+	tmp$52 EMITUOP;
+	tmp$45 EMITSTORE;
+	tmp$38 EMITSPILLREGS;
+	tmp$53 EMITLOAD;
+	tmp$45 EMITLOADRES;
+	tmp$52 EMITSTACK;
+	tmp$52 EMITADDR;
+	tmp$54 EMITCALL;
+	tmp$55 EMITCALLPTR;
+	tmp$46 EMITSTACKALIGN;
+	tmp$53 EMITJUMPPTR;
+	tmp$56 EMITBRANCH;
+	tmp$57 EMITJMPTB;
+	tmp$58 EMITMEM;
+	tmp$59 EMITMACRO;
+	tmp$42 EMITSCOPEBEGIN;
+	tmp$42 EMITSCOPEEND;
+	tmp$42 EMITDECL;
+	tmp$60 EMITDBG;
+	tmp$42 EMITVARINIBEGIN;
+	tmp$42 EMITVARINIEND;
+	tmp$61 EMITVARINII;
+	tmp$62 EMITVARINIF;
+	tmp$63 EMITVARINIOFS;
+	tmp$64 EMITVARINISTR;
+	tmp$65 EMITVARINIWSTR;
+	tmp$66 EMITVARINIPAD;
+	tmp$67 EMITVARINISCOPEBEGIN;
+	tmp$38 EMITVARINISCOPEEND;
+	tmp$38 EMITFBCTINFBEGIN;
+	tmp$68 EMITFBCTINFSTRING;
+	tmp$38 EMITFBCTINFEND;
+	tmp$69 ALLOCVREG;
+	tmp$70 ALLOCVRIMM;
+	tmp$71 ALLOCVRIMMF;
+	tmp$72 ALLOCVRVAR;
+	tmp$73 ALLOCVRIDX;
+	tmp$74 ALLOCVRPTR;
+	tmp$72 ALLOCVROFS;
+	tmp$75 SETVREGDATATYPE;
+	tmp$76 GETDISTANCE;
+	tmp$52 LOADVR;
+	tmp$45 STOREVR;
+	tmp$46 XCHGTOS;
 };
 __FB_STATIC_ASSERT( sizeof( struct $7IR_VTBL ) == 544 );
+typedef int64 $6IR_OPT;
 struct $10TFLISTITEM;
 struct $10TFLISTITEM {
 	struct $10TFLISTITEM* NEXT;
@@ -798,13 +813,12 @@ struct $6IRVREG* IRHLNEWVREG( int64, struct $8FBSYMBOL*, int64 );
 extern struct $7IR_VTBL IRTAC_VTBL$;
 extern struct $7IR_VTBL IRHLC_VTBL$;
 extern struct $7IR_VTBL IRLLVM_VTBL$;
-typedef int64 $6IR_OPT;
+extern struct $7IR_VTBL IRGAS64_VTBL$;
 struct $5IRCTX {
-	int64 INITED;
 	struct $7IR_VTBL VTBL;
 	$6IR_OPT OPTIONS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 560 );
+__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 552 );
 extern struct $5IRCTX IR$;
 struct $12AST_PROC_CTX {
 	struct $7ASTNODE* HEAD;
@@ -874,10 +888,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -895,20 +910,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $13FB_COMPTARGET;
 typedef int64 $10FB_CPUTYPE;
@@ -948,8 +965,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -957,8 +977,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -1005,6 +1026,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -1026,16 +1048,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $8FBARRAY1IPvE {
 	void** DATA;
@@ -1043,10 +1070,11 @@ struct $8FBARRAY1IPvE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IPvE ) == 64 );
-static struct $8FBARRAY1IPvE tmp$99$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IPvE ) == 72 );
+static struct $8FBARRAY1IPvE tmp$104$;
 struct $11IRHLCONTEXT {
 	int64 REGCOUNT;
 	struct $6TFLIST VREGS;
@@ -1061,103 +1089,112 @@ void IRINIT( void )
 {
 	label$10:;
 	{
-		$10FB_BACKEND TMP$100$2;
-		TMP$100$2 = *($10FB_BACKEND*)((uint8*)&ENV$ + 208ll);
-		if( TMP$100$2 != 1ll ) goto label$13;
+		$10FB_BACKEND TMP$105$2;
+		TMP$105$2 = *($10FB_BACKEND*)((uint8*)&ENV$ + 208ll);
+		if( TMP$105$2 != 1ll ) goto label$13;
 		label$14:;
 		{
-			__builtin_memcpy( (struct $7IR_VTBL*)((uint8*)&IR$ + 8ll), &IRHLC_VTBL$, 544 );
+			__builtin_memcpy( (struct $7IR_VTBL*)&IR$, &IRHLC_VTBL$, 544 );
 		}
 		goto label$12;
 		label$13:;
-		if( TMP$100$2 != 2ll ) goto label$15;
+		if( TMP$105$2 != 2ll ) goto label$15;
 		label$16:;
 		{
-			__builtin_memcpy( (struct $7IR_VTBL*)((uint8*)&IR$ + 8ll), &IRLLVM_VTBL$, 544 );
+			__builtin_memcpy( (struct $7IR_VTBL*)&IR$, &IRLLVM_VTBL$, 544 );
 		}
 		goto label$12;
 		label$15:;
+		if( TMP$105$2 != 3ll ) goto label$17;
+		label$18:;
 		{
-			__builtin_memcpy( (struct $7IR_VTBL*)((uint8*)&IR$ + 8ll), &IRTAC_VTBL$, 544 );
+			__builtin_memcpy( (struct $7IR_VTBL*)&IR$, &IRGAS64_VTBL$, 544 );
 		}
+		goto label$12;
 		label$17:;
+		{
+			__builtin_memcpy( (struct $7IR_VTBL*)&IR$, &IRTAC_VTBL$, 544 );
+		}
+		label$19:;
 		label$12:;
 	}
-	(*(tmp$33*)((uint8*)&IR$ + 8ll))(  );
+	*($6IR_OPT*)((uint8*)&IR$ + 544ll) = 0ll;
+	(*(tmp$38*)&IR$)(  );
 	label$11:;
 }
 
 void IREND( void )
 {
-	label$18:;
-	(*(tmp$33*)((uint8*)&IR$ + 16ll))(  );
-	label$19:;
+	label$20:;
+	(*(tmp$38*)((uint8*)&IR$ + 8ll))(  );
+	*($6IR_OPT*)((uint8*)&IR$ + 544ll) = 0ll;
+	label$21:;
 }
 
 void IRHLINIT( void )
 {
-	label$20:;
+	label$22:;
 	FLISTINIT( (struct $6TFLIST*)((uint8*)&IRHL$ + 8ll), 6144ll, 120ll );
 	LISTINIT( (struct $5TLIST*)((uint8*)&IRHL$ + 120ll), 32ll, 24ll, 6ll );
-	label$21:;
+	label$23:;
 }
 
 void IRHLEND( void )
 {
-	label$22:;
+	label$24:;
 	LISTEND( (struct $5TLIST*)((uint8*)&IRHL$ + 120ll) );
 	FLISTEND( (struct $6TFLIST*)((uint8*)&IRHL$ + 8ll) );
-	label$23:;
+	label$25:;
 }
 
 void IRHLEMITPROCBEGIN( void )
 {
-	label$24:;
+	label$26:;
 	*(int64*)&IRHL$ = 0ll;
-	label$25:;
+	label$27:;
 }
 
 void IRHLEMITPROCEND( void )
 {
-	label$26:;
+	label$28:;
 	FLISTRESET( (struct $6TFLIST*)((uint8*)&IRHL$ + 8ll) );
-	label$27:;
+	label$29:;
 }
 
-void IRHLEMITPUSHARG( struct $8FBSYMBOL* PARAM$1, struct $6IRVREG* VR$1, int64 UDTLEN$1, int64 LEVEL$1 )
+void IRHLEMITPUSHARG( struct $8FBSYMBOL* PARAM$1, struct $6IRVREG* VR$1, int64 UDTLEN$1, int64 LEVEL$1, struct $6IRVREG* LREG$1 )
 {
-	label$28:;
+	label$30:;
 	struct $9IRCALLARG* ARG$1;
 	void* vr$1 = LISTNEWNODE( (struct $5TLIST*)((uint8*)&IRHL$ + 120ll) );
 	ARG$1 = (struct $9IRCALLARG*)vr$1;
 	*(struct $8FBSYMBOL**)ARG$1 = PARAM$1;
 	*(struct $6IRVREG**)((uint8*)ARG$1 + 8ll) = VR$1;
 	*(int64*)((uint8*)ARG$1 + 16ll) = LEVEL$1;
-	label$29:;
+	label$31:;
 }
 
 struct $6IRVREG* IRHLNEWVREG( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, int64 VTYPE$1 )
 {
 	struct $6IRVREG* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$30:;
+	label$32:;
 	struct $6IRVREG* V$1;
 	void* vr$2 = FLISTNEWITEM( (struct $6TFLIST*)((uint8*)&IRHL$ + 8ll) );
 	V$1 = (struct $6IRVREG*)vr$2;
 	*($15IRVREGTYPE_ENUM*)V$1 = VTYPE$1;
 	*($11FB_DATATYPE*)((uint8*)V$1 + 8ll) = DTYPE$1;
 	*(struct $8FBSYMBOL**)((uint8*)V$1 + 16ll) = SUBTYPE$1;
-	if( VTYPE$1 != 4ll ) goto label$33;
+	if( VTYPE$1 != 4ll ) goto label$35;
 	{
 		*(int64*)((uint8*)V$1 + 24ll) = *(int64*)&IRHL$;
 		*(int64*)&IRHL$ = *(int64*)&IRHL$ + 1ll;
 	}
-	goto label$32;
-	label$33:;
+	goto label$34;
+	label$35:;
 	{
 		*(int64*)((uint8*)V$1 + 24ll) = -1ll;
 	}
-	label$32:;
+	label$34:;
 	*($12IR_REGFAMILY*)((uint8*)V$1 + 32ll) = 0ll;
 	*(int64*)((uint8*)V$1 + 40ll) = 0ll;
 	*(struct $8FBSYMBOL**)((uint8*)V$1 + 56ll) = (struct $8FBSYMBOL*)0ull;
@@ -1166,7 +1203,7 @@ struct $6IRVREG* IRHLNEWVREG( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, int64
 	*(struct $6IRVREG**)((uint8*)V$1 + 80ll) = (struct $6IRVREG*)0ull;
 	*(struct $6IRVREG**)((uint8*)V$1 + 88ll) = (struct $6IRVREG*)0ull;
 	fb$result$1 = V$1;
-	label$31:;
+	label$33:;
 	return fb$result$1;
 }
 
@@ -1174,10 +1211,10 @@ struct $6IRVREG* IRHLALLOCVREG( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1 )
 {
 	struct $6IRVREG* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$34:;
+	label$36:;
 	struct $6IRVREG* vr$1 = IRHLNEWVREG( DTYPE$1, SUBTYPE$1, 4ll );
 	fb$result$1 = vr$1;
-	label$35:;
+	label$37:;
 	return fb$result$1;
 }
 
@@ -1185,13 +1222,13 @@ struct $6IRVREG* IRHLALLOCVRIMM( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, in
 {
 	struct $6IRVREG* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$36:;
+	label$38:;
 	struct $6IRVREG* VR$1;
 	struct $6IRVREG* vr$1 = IRHLNEWVREG( DTYPE$1, SUBTYPE$1, 0ll );
 	VR$1 = vr$1;
 	*(int64*)((uint8*)VR$1 + 48ll) = VALUE$1;
 	fb$result$1 = VR$1;
-	label$37:;
+	label$39:;
 	return fb$result$1;
 }
 
@@ -1199,13 +1236,13 @@ struct $6IRVREG* IRHLALLOCVRIMMF( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, d
 {
 	struct $6IRVREG* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$38:;
+	label$40:;
 	struct $6IRVREG* VR$1;
 	struct $6IRVREG* vr$1 = IRHLNEWVREG( DTYPE$1, SUBTYPE$1, 0ll );
 	VR$1 = vr$1;
 	*(double*)((uint8*)VR$1 + 48ll) = VALUE$1;
 	fb$result$1 = VR$1;
-	label$39:;
+	label$41:;
 	return fb$result$1;
 }
 
@@ -1213,14 +1250,14 @@ struct $6IRVREG* IRHLALLOCVRVAR( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, st
 {
 	struct $6IRVREG* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$40:;
+	label$42:;
 	struct $6IRVREG* VR$1;
 	struct $6IRVREG* vr$1 = IRHLNEWVREG( DTYPE$1, SUBTYPE$1, 1ll );
 	VR$1 = vr$1;
 	*(struct $8FBSYMBOL**)((uint8*)VR$1 + 56ll) = SYMBOL$1;
 	*(int64*)((uint8*)VR$1 + 64ll) = OFS$1;
 	fb$result$1 = VR$1;
-	label$41:;
+	label$43:;
 	return fb$result$1;
 }
 
@@ -1228,7 +1265,7 @@ struct $6IRVREG* IRHLALLOCVRIDX( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, st
 {
 	struct $6IRVREG* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$42:;
+	label$44:;
 	struct $6IRVREG* VR$1;
 	struct $6IRVREG* vr$1 = IRHLNEWVREG( DTYPE$1, SUBTYPE$1, 2ll );
 	VR$1 = vr$1;
@@ -1236,7 +1273,7 @@ struct $6IRVREG* IRHLALLOCVRIDX( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, st
 	*(int64*)((uint8*)VR$1 + 64ll) = OFS$1;
 	*(struct $6IRVREG**)((uint8*)VR$1 + 80ll) = VIDX$1;
 	fb$result$1 = VR$1;
-	label$43:;
+	label$45:;
 	return fb$result$1;
 }
 
@@ -1244,14 +1281,14 @@ struct $6IRVREG* IRHLALLOCVRPTR( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, in
 {
 	struct $6IRVREG* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$44:;
+	label$46:;
 	struct $6IRVREG* VR$1;
 	struct $6IRVREG* vr$1 = IRHLNEWVREG( DTYPE$1, SUBTYPE$1, 3ll );
 	VR$1 = vr$1;
 	*(int64*)((uint8*)VR$1 + 64ll) = OFS$1;
 	*(struct $6IRVREG**)((uint8*)VR$1 + 80ll) = VIDX$1;
 	fb$result$1 = VR$1;
-	label$45:;
+	label$47:;
 	return fb$result$1;
 }
 
@@ -1259,39 +1296,39 @@ struct $6IRVREG* IRHLALLOCVROFS( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, st
 {
 	struct $6IRVREG* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$46:;
+	label$48:;
 	struct $6IRVREG* VR$1;
 	struct $6IRVREG* vr$1 = IRHLNEWVREG( DTYPE$1, SUBTYPE$1, 5ll );
 	VR$1 = vr$1;
 	*(struct $8FBSYMBOL**)((uint8*)VR$1 + 56ll) = SYMBOL$1;
 	*(int64*)((uint8*)VR$1 + 64ll) = OFS$1;
 	fb$result$1 = VR$1;
-	label$47:;
+	label$49:;
 	return fb$result$1;
 }
 
-void IRFOREACHDATASTMT( tmp$37 CALLBACK$1 )
+void IRFOREACHDATASTMT( tmp$42 CALLBACK$1 )
 {
-	label$48:;
+	label$50:;
 	struct $8FBSYMBOL* SYM$1;
 	SYM$1 = *(struct $8FBSYMBOL**)((uint8*)&AST$ + 240ll);
-	label$50:;
-	if( SYM$1 == (struct $8FBSYMBOL*)0ull ) goto label$51;
+	label$52:;
+	if( SYM$1 == (struct $8FBSYMBOL*)0ull ) goto label$53;
 	{
 		(CALLBACK$1)( SYM$1 );
-		SYM$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 168ll);
+		SYM$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 176ll);
 	}
-	goto label$50;
+	goto label$52;
+	label$53:;
 	label$51:;
-	label$49:;
 }
 
 void IRHLFLUSHSTATICINITIALIZER( struct $8FBSYMBOL* SYM$1 )
 {
-	label$52:;
-	ASTLOADSTATICINITIALIZER( *(struct $7ASTNODE**)((uint8*)SYM$1 + 88ll), SYM$1 );
-	*(struct $7ASTNODE**)((uint8*)SYM$1 + 88ll) = (struct $7ASTNODE*)0ull;
-	label$53:;
+	label$54:;
+	ASTLOADSTATICINITIALIZER( *(struct $7ASTNODE**)((uint8*)SYM$1 + 96ll), SYM$1 );
+	*(struct $7ASTNODE**)((uint8*)SYM$1 + 96ll) = (struct $7ASTNODE*)0ull;
+	label$55:;
 }
 
 __attribute__(( constructor )) static void fb_ctor__ir( void )
@@ -1303,7 +1340,7 @@ __attribute__(( constructor )) static void fb_ctor__ir( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
