@@ -36,8 +36,17 @@ struct $5TLIST {
 __FB_STATIC_ASSERT( sizeof( struct $5TLIST ) == 64 );
 typedef int64 $6AST_OP;
 typedef int64 $13AST_NODECLASS;
+typedef int64 $11AST_OPFLAGS;
+struct $10AST_OPINFO {
+	$13AST_NODECLASS CLASS;
+	$11AST_OPFLAGS FLAGS;
+	uint8* ID;
+	$6AST_OP SELFOP;
+};
+__FB_STATIC_ASSERT( sizeof( struct $10AST_OPINFO ) == 32 );
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -153,6 +162,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -162,7 +172,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -171,7 +182,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -182,10 +193,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -194,9 +206,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +281,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +312,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +349,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +418,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +448,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +598,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -638,18 +685,19 @@ struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL*, int64, int64, struct $8FBSYMBOL
 struct $7ASTNODE* ASTNEWFIELD( struct $7ASTNODE*, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWDEREF( struct $7ASTNODE*, int64, struct $8FBSYMBOL*, int64 );
 struct $7ASTNODE* ASTNEWADDROF( struct $7ASTNODE* );
-struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
+typedef int64 $15AST_LINK_RETURN;
+struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, $15AST_LINK_RETURN );
 struct $7ASTNODE* _Z17ASTBUILDVARASSIGNP8FBSYMBOLP7ASTNODEu7INTEGER( struct $8FBSYMBOL*, struct $7ASTNODE*, int64 );
 struct $7ASTNODE* ASTBUILDCALLRESULTUDT( struct $7ASTNODE* );
 struct $8FBSYMBOL* SYMBADDTEMPVAR( int64, struct $8FBSYMBOL* );
 int64 SYMBCHECKACCESS( struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBUDTGETFIRSTFIELD( struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBUDTGETNEXTFIELD( struct $8FBSYMBOL* );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
 int64 LEXGETLOOKAHEAD( int64, $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $15FB_CMPSTMT_MASK;
 int64 CCOMPSTMTISALLOWED( $15FB_CMPSTMT_MASK );
 int64 CASSIGNMENTORPTRCALLEX( struct $7ASTNODE* );
@@ -665,14 +713,6 @@ void HSKIPUNTIL( int64, int64, $8LEXCHECK, int64 );
 static uint8* HCARD2ORD( int64 );
 static void HREPORTLETERROR( int64, int64 );
 static struct $7ASTNODE* HASSIGNFROMFIELD( struct $8FBSYMBOL*, struct $7ASTNODE*, struct $8FBSYMBOL*, int64 );
-typedef int64 $11AST_OPFLAGS;
-struct $10AST_OPINFO {
-	$13AST_NODECLASS CLASS;
-	$11AST_OPFLAGS FLAGS;
-	uint8* ID;
-	$6AST_OP SELFOP;
-};
-__FB_STATIC_ASSERT( sizeof( struct $10AST_OPINFO ) == 32 );
 extern struct $10AST_OPINFO AST_OPTB$[121];
 struct $16__FB_ARRAYDIMTB$ {
 	int64 ELEMENTS;
@@ -686,10 +726,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -707,20 +748,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -761,8 +804,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -770,8 +816,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -817,6 +864,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -838,16 +886,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -998,6 +1051,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1009,7 +1063,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 void PARSERLETINIT( void )
@@ -1070,8 +1124,8 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 	int64 vr$1 = LEXGETTOKEN( 0ll );
 	TK$1 = vr$1;
 	{
-		uint64 TMP$88$2;
-		TMP$88$2 = (uint64)TK$1;
+		uint64 TMP$93$2;
+		TMP$93$2 = (uint64)TK$1;
 		goto label$23;
 		label$24:;
 		{
@@ -1166,10 +1220,10 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 			}
 			label$43:;
 			label$42:;
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 			{
-				uint64 TMP$89$4;
-				TMP$89$4 = (uint64)TK$1;
+				uint64 TMP$94$4;
+				TMP$94$4 = (uint64)TK$1;
 				goto label$45;
 				label$46:;
 				{
@@ -1303,7 +1357,7 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 				goto label$44;
 				label$72:;
 				{
-					int64 vr$2 = HMATCH( 93ll );
+					int64 vr$2 = HMATCH( 93ll, 0ll );
 					if( vr$2 != 0ll ) goto label$74;
 					{
 						ERRREPORT( 66ll, 0ll, (uint8*)0ull );
@@ -1316,12 +1370,12 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 				label$75:;
 				{
 					int64 IS_NEW$5;
-					IS_NEW$5 = (int64)-(TK$1 == 387ll);
-					int64 vr$4 = HMATCH( 91ll );
+					IS_NEW$5 = (int64)-(TK$1 == 388ll);
+					int64 vr$4 = HMATCH( 91ll, 0ll );
 					if( vr$4 == 0ll ) goto label$77;
 					{
-						$6AST_OP TMP$90$6;
-						int64 vr$5 = HMATCH( 93ll );
+						$6AST_OP TMP$95$6;
+						int64 vr$5 = HMATCH( 93ll, 0ll );
 						if( vr$5 != 0ll ) goto label$79;
 						{
 							ERRREPORT( 66ll, 0ll, (uint8*)0ull );
@@ -1329,24 +1383,24 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 						label$79:;
 						label$78:;
 						if( IS_NEW$5 == 0ll ) goto label$80;
-						TMP$90$6 = 19ll;
+						TMP$95$6 = 19ll;
 						goto label$91;
 						label$80:;
-						TMP$90$6 = 21ll;
+						TMP$95$6 = 21ll;
 						label$91:;
-						OP$1 = TMP$90$6;
+						OP$1 = TMP$95$6;
 					}
 					goto label$76;
 					label$77:;
 					{
-						$6AST_OP TMP$91$6;
+						$6AST_OP TMP$96$6;
 						if( IS_NEW$5 == 0ll ) goto label$81;
-						TMP$91$6 = 18ll;
+						TMP$96$6 = 18ll;
 						goto label$92;
 						label$81:;
-						TMP$91$6 = 20ll;
+						TMP$96$6 = 20ll;
 						label$92:;
-						OP$1 = TMP$91$6;
+						OP$1 = TMP$96$6;
 					}
 					label$76:;
 				}
@@ -1371,7 +1425,7 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 				}
 				goto label$44;
 				label$45:;
-				static const void* tmp$92[400ll] = {
+				static const void* tmp$97[401ll] = {
 					&&label$70,
 					&&label$85,
 					&&label$85,
@@ -1695,6 +1749,7 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 					&&label$85,
 					&&label$85,
 					&&label$85,
+					&&label$85,
 					&&label$75,
 					&&label$75,
 					&&label$52,
@@ -1773,8 +1828,8 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 					&&label$85,
 					&&label$69,
 				};
-				if( (TMP$89$4 - 64ull) > 399ull ) goto label$85;
-				goto *tmp$92[TMP$89$4 - 64ull];
+				if( (TMP$94$4 - 64ull) > 400ull ) goto label$85;
+				goto *tmp$97[TMP$94$4 - 64ull];
 				label$44:;
 			}
 			fb$result$1 = OP$1;
@@ -1787,7 +1842,7 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 		}
 		goto label$22;
 		label$23:;
-		static const void* tmp$93[426ll] = {
+		static const void* tmp$98[427ll] = {
 			&&label$40,
 			&&label$86,
 			&&label$86,
@@ -2137,6 +2192,7 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 			&&label$86,
 			&&label$86,
 			&&label$86,
+			&&label$86,
 			&&label$41,
 			&&label$41,
 			&&label$41,
@@ -2215,11 +2271,11 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 			&&label$86,
 			&&label$41,
 		};
-		if( (TMP$88$2 - 38ull) > 425ull ) goto label$86;
-		goto *tmp$93[TMP$88$2 - 38ull];
+		if( (TMP$93$2 - 38ull) > 426ull ) goto label$86;
+		goto *tmp$98[TMP$93$2 - 38ull];
 		label$22:;
 	}
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	if( IS_OVERLOAD$1 != 0ll ) goto label$88;
 	{
 		fb$result$1 = OP$1;
@@ -2230,7 +2286,7 @@ int64 COPERATOR( int64 IS_OVERLOAD$1 )
 	int64 vr$6 = CASSIGNTOKEN(  );
 	if( vr$6 == 0ll ) goto label$90;
 	{
-		OP$1 = *(int64*)(((uint8*)AST_OPTB$ + (OP$1 << (5ll & 63ll))) + 24ll);
+		OP$1 = *(int64*)(((int64)(struct $10AST_OPINFO*)AST_OPTB$ + (OP$1 << (5ll & 63ll))) + 24ll);
 	}
 	label$90:;
 	label$89:;
@@ -2267,13 +2323,13 @@ void CASSIGNMENT( struct $7ASTNODE* L$1 )
 		}
 		label$100:;
 		label$99:;
-		OP$1 = *(int64*)(((uint8*)AST_OPTB$ + (OP$1 << (5ll & 63ll))) + 24ll);
+		OP$1 = *(int64*)(((int64)(struct $10AST_OPINFO*)AST_OPTB$ + (OP$1 << (5ll & 63ll))) + 24ll);
 	}
 	label$98:;
 	label$97:;
 	LEXSKIPTOKEN( 0ll );
-	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll) = *(struct $8FBSYMBOL**)((uint8*)L$1 + 16ll);
-	*(int64*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)L$1 + 8ll) & 511ll;
+	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll) = *(struct $8FBSYMBOL**)((uint8*)L$1 + 16ll);
+	*(int64*)((uint8*)&PARSER$ + 304ll) = *(int64*)((uint8*)L$1 + 8ll) & 511ll;
 	struct $7ASTNODE* R$1;
 	struct $7ASTNODE* vr$10 = CEXPRESSION(  );
 	R$1 = vr$10;
@@ -2285,8 +2341,8 @@ void CASSIGNMENT( struct $7ASTNODE* L$1 )
 	}
 	label$102:;
 	label$101:;
-	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll) = (struct $8FBSYMBOL*)0ull;
-	*(int64*)((uint8*)&PARSER$ + 296ll) = 2147483648ll;
+	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll) = (struct $8FBSYMBOL*)0ull;
+	*(int64*)((uint8*)&PARSER$ + 304ll) = 2147483648ll;
 	if( OP$1 == -1ll ) goto label$104;
 	{
 		struct $7ASTNODE* vr$11 = ASTNEWSELFBOP( OP$1, L$1, R$1, (struct $8FBSYMBOL*)0ull, 2ll );
@@ -2364,7 +2420,7 @@ int64 CASSIGNMENTORPTRCALL( void )
 	struct $8FBSYMBOL* FLD$1;
 	fb$result$1 = 0ll;
 	int64 vr$1 = LEXGETTOKEN( 0ll );
-	if( vr$1 == 389ll ) goto label$142;
+	if( vr$1 == 390ll ) goto label$142;
 	{
 		struct $7ASTNODE* vr$2 = CVARORDEREF( 2ll );
 		EXPR$1 = vr$2;
@@ -2397,7 +2453,7 @@ int64 CASSIGNMENTORPTRCALL( void )
 	}
 	label$142:;
 	label$141:;
-	if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 262144ll) != 0ll ) goto label$150;
+	if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 262144ll) != 0ll ) goto label$150;
 	{
 		int64 vr$8 = LEXGETLOOKAHEAD( 1ll, 0ll );
 		if( vr$8 == 40ll ) goto label$152;
@@ -2408,7 +2464,7 @@ int64 CASSIGNMENTORPTRCALL( void )
 		label$152:;
 		{
 			ISMULT$1 = -1ll;
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 		}
 		label$151:;
 	}
@@ -2422,7 +2478,7 @@ int64 CASSIGNMENTORPTRCALL( void )
 	}
 	label$154:;
 	label$153:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	if( ISMULT$1 != 0ll ) goto label$156;
 	{
 		struct $7ASTNODE* vr$10 = CVARORDEREF( 0ll );
@@ -2519,12 +2575,12 @@ int64 CASSIGNMENTORPTRCALL( void )
 	if( EXPR$1 == (struct $7ASTNODE*)0ull ) goto label$177;
 	{
 		{
-			int64 TMP$103$3;
-			TMP$103$3 = *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll;
-			if( TMP$103$3 != 20ll ) goto label$179;
+			int64 TMP$108$3;
+			TMP$108$3 = *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll;
+			if( TMP$108$3 != 20ll ) goto label$179;
 			label$180:;
 			{
-				if( ((int64)-(((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)EXPR$1 + 16ll) + 200ll) & 1ll) != 0ll) | (int64)-(((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)EXPR$1 + 16ll) + 200ll) & 8192ll) != 0ll)) == 0ll ) goto label$182;
+				if( ((int64)-(((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)EXPR$1 + 16ll) + 208ll) & 1ll) != 0ll) | (int64)-(((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)EXPR$1 + 16ll) + 208ll) & 8192ll) != 0ll)) == 0ll ) goto label$182;
 				{
 					ERRREPORT( 268ll, 0ll, (uint8*)0ull );
 					ASTDELTREE( EXPR$1 );
@@ -2621,7 +2677,7 @@ int64 CASSIGNMENTORPTRCALL( void )
 				}
 				label$205:;
 				label$204:;
-				struct $7ASTNODE* vr$66 = ASTNEWLINK( TREE$1, EXPR$1, -1ll );
+				struct $7ASTNODE* vr$66 = ASTNEWLINK( TREE$1, EXPR$1, 0ll );
 				TREE$1 = vr$66;
 			}
 			label$203:;
@@ -2644,7 +2700,7 @@ int64 CASSIGNMENTORPTRCALL( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -2682,8 +2738,8 @@ static uint8* HCARD2ORD( int64 NUM$1 )
 		{
 			static FBSTRING TMP$3;
 			FBSTRING* vr$1 = fb_LongintToStr( NUM$1 );
-			FBSTRING* vr$2 = fb_StrAssign( (void*)&TMP$3, -1ll, (void*)vr$1, -1ll, 0 );
-			FBSTRING* vr$3 = fb_StrConcatAssign( (void*)&TMP$3, -1ll, (void*)"th", 3ll, 0 );
+			fb_StrAssign( (void*)&TMP$3, -1ll, (void*)vr$1, -1ll, 0 );
+			fb_StrConcatAssign( (void*)&TMP$3, -1ll, (void*)"th", 3ll, 0 );
 			fb$result$1 = (uint8*)*(uint8**)&TMP$3;
 			goto label$118;
 		}
@@ -2696,19 +2752,19 @@ static uint8* HCARD2ORD( int64 NUM$1 )
 
 static void HREPORTLETERROR( int64 ERRNUM$1, int64 ELMNUM$1 )
 {
-	FBSTRING TMP$100$1;
-	FBSTRING TMP$101$1;
-	FBSTRING TMP$102$1;
+	FBSTRING TMP$105$1;
+	FBSTRING TMP$106$1;
+	FBSTRING TMP$107$1;
 	label$127:;
-	__builtin_memset( &TMP$102$1, 0, 24ll );
+	__builtin_memset( &TMP$107$1, 0, 24ll );
 	uint8* vr$1 = HCARD2ORD( ELMNUM$1 );
-	__builtin_memset( &TMP$100$1, 0, 24ll );
-	FBSTRING* vr$4 = fb_StrConcat( &TMP$100$1, (void*)"at the ", 8ll, (void*)vr$1, 0ll );
-	__builtin_memset( &TMP$101$1, 0, 24ll );
-	FBSTRING* vr$7 = fb_StrConcat( &TMP$101$1, (void*)vr$4, -1ll, (void*)" element of LET()", 18ll );
-	FBSTRING* vr$9 = fb_StrAssign( (void*)&TMP$102$1, -1ll, (void*)vr$7, -1ll, 0 );
-	ERRREPORTEX( ERRNUM$1, (uint8*)*(uint8**)&TMP$102$1, 0ll, 1ll, (uint8*)0ull );
-	fb_StrDelete( (FBSTRING*)&TMP$102$1 );
+	__builtin_memset( &TMP$105$1, 0, 24ll );
+	FBSTRING* vr$4 = fb_StrConcat( &TMP$105$1, (void*)"at the ", 8ll, (void*)vr$1, 0ll );
+	__builtin_memset( &TMP$106$1, 0, 24ll );
+	FBSTRING* vr$7 = fb_StrConcat( &TMP$106$1, (void*)vr$4, -1ll, (void*)" element of LET()", 18ll );
+	fb_StrAssign( (void*)&TMP$107$1, -1ll, (void*)vr$7, -1ll, 0 );
+	ERRREPORTEX( ERRNUM$1, (uint8*)*(uint8**)&TMP$107$1, 0ll, 1ll, (uint8*)0ull );
+	fb_StrDelete( (FBSTRING*)&TMP$107$1 );
 	label$128:;
 }
 
@@ -2738,7 +2794,7 @@ static struct $7ASTNODE* HASSIGNFROMFIELD( struct $8FBSYMBOL* FLD$1, struct $7AS
 	}
 	label$134:;
 	label$133:;
-	if( *(int64*)((uint8*)FLD$1 + 96ll) == 0ll ) goto label$136;
+	if( *(int64*)((uint8*)FLD$1 + 104ll) == 0ll ) goto label$136;
 	{
 		HREPORTLETERROR( 269ll, NUM$1 );
 		ASTDELTREE( LHS$1 );
@@ -2751,10 +2807,10 @@ static struct $7ASTNODE* HASSIGNFROMFIELD( struct $8FBSYMBOL* FLD$1, struct $7AS
 	struct $7ASTNODE* EXPR$1;
 	struct $7ASTNODE* vr$7 = ASTNEWVAR( RHS$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	EXPR$1 = vr$7;
-	struct $7ASTNODE* vr$9 = ASTNEWCONSTI( *(int64*)((uint8*)FLD$1 + 80ll), 8ll, (struct $8FBSYMBOL*)0ull );
+	struct $7ASTNODE* vr$9 = ASTNEWCONSTI( *(int64*)((uint8*)FLD$1 + 88ll), 8ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$10 = ASTNEWBOP( 28ll, EXPR$1, vr$9, (struct $8FBSYMBOL*)0ull, 1ll );
 	EXPR$1 = vr$10;
-	struct $7ASTNODE* vr$13 = ASTNEWDEREF( EXPR$1, *(int64*)((uint8*)FLD$1 + 48ll), *(struct $8FBSYMBOL**)((uint8*)FLD$1 + 56ll), 0ll );
+	struct $7ASTNODE* vr$13 = ASTNEWDEREF( EXPR$1, *(int64*)((uint8*)FLD$1 + 56ll), *(struct $8FBSYMBOL**)((uint8*)FLD$1 + 64ll), 0ll );
 	EXPR$1 = vr$13;
 	struct $7ASTNODE* vr$14 = ASTNEWFIELD( EXPR$1, FLD$1 );
 	EXPR$1 = vr$14;
