@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $8LEXCHECK;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -178,7 +179,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -315,6 +316,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -324,7 +326,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -333,7 +336,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -344,10 +347,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -356,9 +360,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -457,14 +461,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -486,7 +492,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -497,9 +529,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -560,6 +598,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -589,7 +628,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $10FBSYMCHAIN {
 	struct $8FBSYMBOL* SYM;
 	struct $10FBSYMCHAIN* NEXT;
@@ -614,29 +653,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -669,7 +698,7 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -688,8 +717,6 @@ void FBCHANGEOPTION( int64, int64 );
 void FBINCLUDEFILE( uint8*, int64 );
 FBSTRING* FBGETLANGNAME( $7FB_LANG );
 $7FB_LANG FBGETLANGID( uint8* );
-int64 HMATCHIDORKW( uint8* );
-int64 HMATCH( int64 );
 int64 LEXGETTOKEN( $8LEXCHECK );
 int64 LEXGETCLASS( $8LEXCHECK );
 void LEXEATTOKEN( uint8*, $8LEXCHECK );
@@ -697,6 +724,8 @@ void LEXPPONLYEMITTEXT( FBSTRING* );
 void LEXSKIPTOKEN( $8LEXCHECK );
 void LEXREADLINE( uint64, uint8*, int64 );
 void LEXSKIPLINE( void );
+int64 HMATCHIDORKW( uint8*, $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 static void CDIRECTIVE( void );
 typedef int64 $11AST_OPFLAGS;
 struct $10AST_OPINFO {
@@ -718,10 +747,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -739,20 +769,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -792,8 +824,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -801,8 +836,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -848,6 +884,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -869,23 +906,28 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 
 int64 CCOMMENT( $8LEXCHECK LEXFLAGS$1 )
@@ -894,29 +936,47 @@ int64 CCOMMENT( $8LEXCHECK LEXFLAGS$1 )
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
 	{
-		int64 TMP$88$2;
+		int64 TMP$93$2;
 		int64 vr$1 = LEXGETTOKEN( LEXFLAGS$1 );
-		TMP$88$2 = vr$1;
-		if( TMP$88$2 == 259ll ) goto label$14;
+		TMP$93$2 = vr$1;
+		if( TMP$93$2 == 259ll ) goto label$14;
 		label$15:;
-		if( TMP$88$2 != 260ll ) goto label$13;
+		if( TMP$93$2 != 260ll ) goto label$13;
 		label$14:;
 		{
-			*(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8536ll) = *(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8536ll) + 1ll;
-			LEXSKIPTOKEN( 2571ll );
-			int64 vr$5 = LEXGETTOKEN( 523ll );
-			if( vr$5 != 36ll ) goto label$17;
+			int64 vr$2 = LEXGETTOKEN( LEXFLAGS$1 );
+			if( vr$2 != 260ll ) goto label$17;
 			{
-				LEXSKIPTOKEN( 2571ll );
+				if( *(int64*)((uint8*)&ENV$ + 272ll) != 3ll ) goto label$19;
+				{
+					if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2104ll) == 0ll ) goto label$21;
+					{
+						fb$result$1 = 0ll;
+						goto label$11;
+					}
+					label$21:;
+					label$20:;
+				}
+				label$19:;
+				label$18:;
+			}
+			label$17:;
+			label$16:;
+			*(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8576ll) = *(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8576ll) + 1ll;
+			LEXSKIPTOKEN( 523ll );
+			int64 vr$8 = LEXGETTOKEN( 523ll );
+			if( vr$8 != 36ll ) goto label$23;
+			{
+				LEXSKIPTOKEN( 523ll );
 				CDIRECTIVE(  );
 			}
-			goto label$16;
-			label$17:;
+			goto label$22;
+			label$23:;
 			{
 				LEXSKIPLINE(  );
 			}
-			label$16:;
-			*(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8536ll) = *(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8536ll) + -1ll;
+			label$22:;
+			*(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8576ll) = *(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8576ll) + -1ll;
 			fb$result$1 = -1ll;
 		}
 		goto label$12;
@@ -924,7 +984,7 @@ int64 CCOMMENT( $8LEXCHECK LEXFLAGS$1 )
 		{
 			fb$result$1 = 0ll;
 		}
-		label$18:;
+		label$24:;
 		label$12:;
 	}
 	label$11:;
@@ -934,247 +994,247 @@ int64 CCOMMENT( $8LEXCHECK LEXFLAGS$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
 
 static void CDIRECTIVE( void )
 {
-	label$19:;
+	label$25:;
 	static uint8 INCFILE$1[261];
 	static int64 ISONCE$1;
 	{
-		uint64 TMP$89$2;
+		uint64 TMP$94$2;
 		int64 vr$0 = LEXGETTOKEN( 0ll );
-		TMP$89$2 = (uint64)vr$0;
-		goto label$22;
-		label$23:;
+		TMP$94$2 = (uint64)vr$0;
+		goto label$28;
+		label$29:;
 		{
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 16777216ll) != 0ll ) goto label$25;
+			if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 16777216ll) != 0ll ) goto label$31;
 			{
 				ERRREPORTNOTALLOWED( 16777216ll, 146ll, (uint8*)0ull );
 			}
-			goto label$24;
-			label$25:;
+			goto label$30;
+			label$31:;
 			{
 				LEXSKIPTOKEN( 0ll );
-				*(int64*)((uint8*)&ENV$ + 1360ll) = -1ll;
-				if( *(int64*)((uint8*)&ENV$ + 1144ll) <= 0ll ) goto label$27;
+				*(int64*)((uint8*)&ENV$ + 1520ll) = -1ll;
+				if( *(int64*)((uint8*)&ENV$ + 1176ll) <= 0ll ) goto label$33;
 				{
-					FBSTRING TMP$91$5;
-					__builtin_memset( &TMP$91$5, 0, 24ll );
-					FBSTRING* vr$4 = fb_StrAssign( (void*)&TMP$91$5, -1ll, (void*)"'$dynamic", 10ll, 0 );
-					LEXPPONLYEMITTEXT( &TMP$91$5 );
-					fb_StrDelete( (FBSTRING*)&TMP$91$5 );
-				}
-				label$27:;
-				label$26:;
-			}
-			label$24:;
-		}
-		goto label$21;
-		label$28:;
-		{
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 16777216ll) != 0ll ) goto label$30;
-			{
-				ERRREPORTNOTALLOWED( 16777216ll, 146ll, (uint8*)0ull );
-			}
-			goto label$29;
-			label$30:;
-			{
-				LEXSKIPTOKEN( 0ll );
-				*(int64*)((uint8*)&ENV$ + 1360ll) = 0ll;
-				if( *(int64*)((uint8*)&ENV$ + 1144ll) <= 0ll ) goto label$32;
-				{
-					FBSTRING TMP$93$5;
-					__builtin_memset( &TMP$93$5, 0, 24ll );
-					FBSTRING* vr$10 = fb_StrAssign( (void*)&TMP$93$5, -1ll, (void*)"'$static", 9ll, 0 );
-					LEXPPONLYEMITTEXT( &TMP$93$5 );
-					fb_StrDelete( (FBSTRING*)&TMP$93$5 );
+					FBSTRING TMP$96$5;
+					__builtin_memset( &TMP$96$5, 0, 24ll );
+					fb_StrAssign( (void*)&TMP$96$5, -1ll, (void*)"'$dynamic", 10ll, 0 );
+					LEXPPONLYEMITTEXT( &TMP$96$5 );
+					fb_StrDelete( (FBSTRING*)&TMP$96$5 );
 				}
+				label$33:;
 				label$32:;
-				label$31:;
 			}
-			label$29:;
+			label$30:;
 		}
-		goto label$21;
-		label$33:;
+		goto label$27;
+		label$34:;
 		{
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 16777216ll) != 0ll ) goto label$35;
+			if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 16777216ll) != 0ll ) goto label$36;
 			{
 				ERRREPORTNOTALLOWED( 16777216ll, 146ll, (uint8*)0ull );
 			}
-			goto label$34;
-			label$35:;
+			goto label$35;
+			label$36:;
 			{
 				LEXSKIPTOKEN( 0ll );
-				int64 vr$14 = HMATCHIDORKW( (uint8*)"ONCE" );
-				ISONCE$1 = vr$14;
-				int64 vr$15 = HMATCH( 258ll );
-				if( vr$15 != 0ll ) goto label$37;
+				*(int64*)((uint8*)&ENV$ + 1520ll) = 0ll;
+				if( *(int64*)((uint8*)&ENV$ + 1176ll) <= 0ll ) goto label$38;
+				{
+					FBSTRING TMP$98$5;
+					__builtin_memset( &TMP$98$5, 0, 24ll );
+					fb_StrAssign( (void*)&TMP$98$5, -1ll, (void*)"'$static", 9ll, 0 );
+					LEXPPONLYEMITTEXT( &TMP$98$5 );
+					fb_StrDelete( (FBSTRING*)&TMP$98$5 );
+				}
+				label$38:;
+				label$37:;
+			}
+			label$35:;
+		}
+		goto label$27;
+		label$39:;
+		{
+			if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 16777216ll) != 0ll ) goto label$41;
+			{
+				ERRREPORTNOTALLOWED( 16777216ll, 146ll, (uint8*)0ull );
+			}
+			goto label$40;
+			label$41:;
+			{
+				LEXSKIPTOKEN( 0ll );
+				int64 vr$12 = HMATCHIDORKW( (uint8*)"ONCE", 2048ll );
+				ISONCE$1 = vr$12;
+				int64 vr$13 = HMATCH( 258ll, 0ll );
+				if( vr$13 != 0ll ) goto label$43;
 				{
 					ERRREPORT( 17ll, 0ll, (uint8*)0ull );
-					goto label$21;
+					goto label$27;
 				}
-				label$37:;
-				label$36:;
-				int64 vr$16 = LEXGETCLASS( 0ll );
-				if( vr$16 != 4ll ) goto label$39;
+				label$43:;
+				label$42:;
+				int64 vr$14 = LEXGETCLASS( 0ll );
+				if( vr$14 != 4ll ) goto label$45;
 				{
 					LEXEATTOKEN( (uint8*)INCFILE$1, 0ll );
 				}
-				goto label$38;
-				label$39:;
+				goto label$44;
+				label$45:;
 				{
-					int64 vr$17 = LEXGETTOKEN( 527ll );
-					if( vr$17 == 259ll ) goto label$41;
+					int64 vr$15 = LEXGETTOKEN( 527ll );
+					if( vr$15 == 259ll ) goto label$47;
 					{
 						ERRREPORT( 17ll, 0ll, (uint8*)0ull );
-						goto label$21;
+						goto label$27;
 					}
-					goto label$40;
-					label$41:;
+					goto label$46;
+					label$47:;
 					{
 						LEXSKIPTOKEN( 527ll );
 					}
-					label$40:;
+					label$46:;
 					LEXREADLINE( 39ull, (uint8*)INCFILE$1, 0ll );
-					int64 vr$18 = HMATCH( 39ll );
-					if( vr$18 != 0ll ) goto label$43;
+					int64 vr$16 = HMATCH( 39ll, 0ll );
+					if( vr$16 != 0ll ) goto label$49;
 					{
 						ERRREPORT( 17ll, 0ll, (uint8*)0ull );
-						goto label$21;
+						goto label$27;
 					}
-					label$43:;
-					label$42:;
+					label$49:;
+					label$48:;
 				}
-				label$38:;
+				label$44:;
 				FBINCLUDEFILE( (uint8*)INCFILE$1, ISONCE$1 );
 			}
-			label$34:;
+			label$40:;
 		}
-		goto label$21;
-		label$44:;
+		goto label$27;
+		label$50:;
 		{
 			{
-				int64 TMP$95$4;
-				int64 vr$19 = LEXGETCLASS( 0ll );
-				TMP$95$4 = vr$19;
-				if( TMP$95$4 == 1ll ) goto label$47;
-				label$48:;
-				if( TMP$95$4 != 2ll ) goto label$46;
-				label$47:;
+				int64 TMP$100$4;
+				int64 vr$17 = LEXGETCLASS( 0ll );
+				TMP$100$4 = vr$17;
+				if( TMP$100$4 == 1ll ) goto label$53;
+				label$54:;
+				if( TMP$100$4 != 2ll ) goto label$52;
+				label$53:;
 				{
-					if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 16777216ll) == 0ll ) goto label$50;
+					if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 16777216ll) == 0ll ) goto label$56;
 					{
 						ERRREPORT( 17ll, 0ll, (uint8*)0ull );
 					}
-					label$50:;
-					label$49:;
+					label$56:;
+					label$55:;
 				}
-				goto label$45;
-				label$46:;
+				goto label$51;
+				label$52:;
 				{
-					int64 vr$21 = HMATCHIDORKW( (uint8*)"LANG" );
-					if( vr$21 == 0ll ) goto label$53;
+					int64 vr$19 = HMATCHIDORKW( (uint8*)"LANG", 0ll );
+					if( vr$19 == 0ll ) goto label$59;
 					{
-						int64 vr$22 = HMATCH( 258ll );
-						if( vr$22 != 0ll ) goto label$55;
+						int64 vr$20 = HMATCH( 258ll, 0ll );
+						if( vr$20 != 0ll ) goto label$61;
 						{
 							ERRREPORT( 203ll, -1ll, (uint8*)0ull );
-							goto label$45;
+							goto label$51;
 						}
-						label$55:;
-						label$54:;
-						int64 vr$23 = LEXGETCLASS( 0ll );
-						if( vr$23 != 4ll ) goto label$57;
+						label$61:;
+						label$60:;
+						int64 vr$21 = LEXGETCLASS( 0ll );
+						if( vr$21 != 4ll ) goto label$63;
 						{
 							static $7FB_LANG ID$7;
 							LEXEATTOKEN( (uint8*)INCFILE$1, 0ll );
-							$7FB_LANG vr$24 = FBGETLANGID( (uint8*)INCFILE$1 );
-							ID$7 = vr$24;
-							if( ID$7 != -1ll ) goto label$59;
+							$7FB_LANG vr$22 = FBGETLANGID( (uint8*)INCFILE$1 );
+							ID$7 = vr$22;
+							if( ID$7 != -1ll ) goto label$65;
 							{
 								ERRREPORT( 279ll, 0ll, (uint8*)0ull );
 							}
-							goto label$58;
-							label$59:;
+							goto label$64;
+							label$65:;
 							{
 								FBCHANGEOPTION( 10ll, ID$7 );
-								if( *(int64*)((uint8*)&ENV$ + 1144ll) <= 0ll ) goto label$61;
+								if( *(int64*)((uint8*)&ENV$ + 1176ll) <= 0ll ) goto label$67;
 								{
-									FBSTRING TMP$99$9;
-									FBSTRING TMP$100$9;
-									FBSTRING TMP$101$9;
-									__builtin_memset( &TMP$101$9, 0, 24ll );
-									FBSTRING* vr$26 = FBGETLANGNAME( ID$7 );
-									__builtin_memset( &TMP$99$9, 0, 24ll );
-									FBSTRING* vr$29 = fb_StrConcat( &TMP$99$9, (void*)"'$lang: \x22", 10ll, (void*)vr$26, -1ll );
-									__builtin_memset( &TMP$100$9, 0, 24ll );
-									FBSTRING* vr$32 = fb_StrConcat( &TMP$100$9, (void*)vr$29, -1ll, (void*)"\x22", 2ll );
-									FBSTRING* vr$34 = fb_StrAssign( (void*)&TMP$101$9, -1ll, (void*)vr$32, -1ll, 0 );
-									LEXPPONLYEMITTEXT( &TMP$101$9 );
-									fb_StrDelete( (FBSTRING*)&TMP$101$9 );
+									FBSTRING TMP$104$9;
+									FBSTRING TMP$105$9;
+									FBSTRING TMP$106$9;
+									__builtin_memset( &TMP$106$9, 0, 24ll );
+									FBSTRING* vr$24 = FBGETLANGNAME( ID$7 );
+									__builtin_memset( &TMP$104$9, 0, 24ll );
+									FBSTRING* vr$27 = fb_StrConcat( &TMP$104$9, (void*)"'$lang: \x22", 10ll, (void*)vr$24, -1ll );
+									__builtin_memset( &TMP$105$9, 0, 24ll );
+									FBSTRING* vr$30 = fb_StrConcat( &TMP$105$9, (void*)vr$27, -1ll, (void*)"\x22", 2ll );
+									fb_StrAssign( (void*)&TMP$106$9, -1ll, (void*)vr$30, -1ll, 0 );
+									LEXPPONLYEMITTEXT( &TMP$106$9 );
+									fb_StrDelete( (FBSTRING*)&TMP$106$9 );
 								}
-								label$61:;
-								label$60:;
+								label$67:;
+								label$66:;
 							}
-							label$58:;
+							label$64:;
 						}
-						goto label$56;
-						label$57:;
+						goto label$62;
+						label$63:;
 						{
 							ERRREPORT( 17ll, 0ll, (uint8*)0ull );
 						}
-						label$56:;
+						label$62:;
 					}
-					label$53:;
-					label$52:;
+					label$59:;
+					label$58:;
 				}
+				label$57:;
 				label$51:;
-				label$45:;
 			}
 		}
-		goto label$21;
-		label$22:;
-		static const void* tmp$103[11ll] = {
-			&&label$28,
-			&&label$44,
-			&&label$44,
-			&&label$44,
-			&&label$44,
-			&&label$44,
-			&&label$44,
-			&&label$44,
-			&&label$44,
-			&&label$33,
-			&&label$23,
+		goto label$27;
+		label$28:;
+		static const void* tmp$108[11ll] = {
+			&&label$34,
+			&&label$50,
+			&&label$50,
+			&&label$50,
+			&&label$50,
+			&&label$50,
+			&&label$50,
+			&&label$50,
+			&&label$50,
+			&&label$39,
+			&&label$29,
 		};
-		if( (TMP$89$2 - 307ull) > 10ull ) goto label$44;
-		goto *tmp$103[TMP$89$2 - 307ull];
-		label$21:;
+		if( (TMP$94$2 - 307ull) > 10ull ) goto label$50;
+		goto *tmp$108[TMP$94$2 - 307ull];
+		label$27:;
 	}
-	label$62:;
+	label$68:;
 	{
 		{
-			int64 TMP$102$3;
-			int64 vr$37 = LEXGETTOKEN( 0ll );
-			TMP$102$3 = vr$37;
-			if( TMP$102$3 == 257ll ) goto label$67;
-			label$68:;
-			if( TMP$102$3 != 256ll ) goto label$66;
-			label$67:;
+			int64 TMP$107$3;
+			int64 vr$34 = LEXGETTOKEN( 0ll );
+			TMP$107$3 = vr$34;
+			if( TMP$107$3 == 257ll ) goto label$73;
+			label$74:;
+			if( TMP$107$3 != 256ll ) goto label$72;
+			label$73:;
 			{
-				goto label$63;
+				goto label$69;
 			}
-			label$66:;
-			label$65:;
+			label$72:;
+			label$71:;
 		}
-		LEXSKIPTOKEN( 2571ll );
+		LEXSKIPTOKEN( 523ll );
 	}
-	label$64:;
-	goto label$62;
-	label$63:;
-	label$20:;
+	label$70:;
+	goto label$68;
+	label$69:;
+	label$26:;
 }
