@@ -12,6 +12,7 @@ typedef int64 $15FB_CMPSTMT_MASK;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -128,6 +129,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -137,7 +139,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -146,7 +149,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -157,10 +160,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -169,9 +173,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -270,14 +274,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -299,7 +305,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -310,9 +342,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -373,6 +411,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -402,7 +441,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -552,7 +591,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -752,10 +791,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -773,20 +813,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -827,8 +869,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -836,8 +881,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -883,6 +929,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -904,16 +951,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -958,6 +1010,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -969,7 +1022,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 void CEXTERNSTMTBEGIN( void )
@@ -978,7 +1031,7 @@ void CEXTERNSTMTBEGIN( void )
 	struct $13FB_CMPSTMTSTK* STK$1;
 	int64 MANGLING$1;
 	uint8* LITSTR$1;
-	if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 8ll) != 0ll ) goto label$13;
+	if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 8ll) != 0ll ) goto label$13;
 	{
 		ERRREPORTNOTALLOWED( 8ll, 146ll, (uint8*)0ull );
 		HSKIPCOMPOUND( 306ll, -1ll, 0ll );
@@ -994,7 +1047,7 @@ void CEXTERNSTMTBEGIN( void )
 	}
 	label$15:;
 	label$14:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	int64 vr$2 = LEXGETCLASS( 0ll );
 	if( vr$2 == 4ll ) goto label$17;
 	{
@@ -1009,12 +1062,12 @@ void CEXTERNSTMTBEGIN( void )
 	}
 	label$16:;
 	{
-		FBSTRING TMP$89$2;
+		FBSTRING TMP$94$2;
 		FBSTRING* vr$4 = fb_StrAllocTempDescZ( LITSTR$1 );
 		FBSTRING* vr$5 = fb_StrLcase2( (FBSTRING*)vr$4, 0 );
-		FBSTRING* vr$7 = fb_StrInit( (void*)&TMP$89$2, -1ll, (void*)vr$5, -1ll, 0 );
-		int32 vr$9 = fb_StrCompare( (void*)&TMP$89$2, -1ll, (void*)"c", 2ll );
-		if( (int64)vr$9 != 0ll ) goto label$19;
+		fb_StrInit( (void*)&TMP$94$2, -1ll, (void*)vr$5, -1ll, 0 );
+		int32 vr$8 = fb_StrCompare( (void*)&TMP$94$2, -1ll, (void*)"c", 2ll );
+		if( (int64)vr$8 != 0ll ) goto label$19;
 		label$20:;
 		{
 			MANGLING$1 = 1ll;
@@ -1022,8 +1075,8 @@ void CEXTERNSTMTBEGIN( void )
 		}
 		goto label$18;
 		label$19:;
-		int32 vr$12 = fb_StrCompare( (void*)&TMP$89$2, -1ll, (void*)"windows", 8ll );
-		if( (int64)vr$12 != 0ll ) goto label$21;
+		int32 vr$11 = fb_StrCompare( (void*)&TMP$94$2, -1ll, (void*)"windows", 8ll );
+		if( (int64)vr$11 != 0ll ) goto label$21;
 		label$22:;
 		{
 			MANGLING$1 = 2ll;
@@ -1031,8 +1084,8 @@ void CEXTERNSTMTBEGIN( void )
 		}
 		goto label$18;
 		label$21:;
-		int32 vr$15 = fb_StrCompare( (void*)&TMP$89$2, -1ll, (void*)"windows-ms", 11ll );
-		if( (int64)vr$15 != 0ll ) goto label$23;
+		int32 vr$14 = fb_StrCompare( (void*)&TMP$94$2, -1ll, (void*)"windows-ms", 11ll );
+		if( (int64)vr$14 != 0ll ) goto label$23;
 		label$24:;
 		{
 			MANGLING$1 = 3ll;
@@ -1040,8 +1093,8 @@ void CEXTERNSTMTBEGIN( void )
 		}
 		goto label$18;
 		label$23:;
-		int32 vr$18 = fb_StrCompare( (void*)&TMP$89$2, -1ll, (void*)"c++", 4ll );
-		if( (int64)vr$18 != 0ll ) goto label$25;
+		int32 vr$17 = fb_StrCompare( (void*)&TMP$94$2, -1ll, (void*)"c++", 4ll );
+		if( (int64)vr$17 != 0ll ) goto label$25;
 		label$26:;
 		{
 			MANGLING$1 = 4ll;
@@ -1049,8 +1102,8 @@ void CEXTERNSTMTBEGIN( void )
 		}
 		goto label$18;
 		label$25:;
-		int32 vr$21 = fb_StrCompare( (void*)&TMP$89$2, -1ll, (void*)"rtlib", 6ll );
-		if( (int64)vr$21 != 0ll ) goto label$27;
+		int32 vr$20 = fb_StrCompare( (void*)&TMP$94$2, -1ll, (void*)"rtlib", 6ll );
+		if( (int64)vr$20 != 0ll ) goto label$27;
 		label$28:;
 		{
 			MANGLING$1 = 6ll;
@@ -1065,13 +1118,13 @@ void CEXTERNSTMTBEGIN( void )
 		}
 		label$29:;
 		label$18:;
-		fb_StrDelete( (FBSTRING*)&TMP$89$2 );
+		fb_StrDelete( (FBSTRING*)&TMP$94$2 );
 	}
 	CLIBATTRIBUTE(  );
-	struct $13FB_CMPSTMTSTK* vr$24 = CCOMPSTMTPUSH( 306ll, 4294967262ll );
-	STK$1 = vr$24;
-	*($11FB_MANGLING*)((uint8*)STK$1 + 24ll) = *($11FB_MANGLING*)((uint8*)&PARSER$ + 192ll);
-	*($11FB_MANGLING*)((uint8*)&PARSER$ + 192ll) = MANGLING$1;
+	struct $13FB_CMPSTMTSTK* vr$23 = CCOMPSTMTPUSH( 306ll, 4294967262ll );
+	STK$1 = vr$23;
+	*($11FB_MANGLING*)((uint8*)STK$1 + 24ll) = *($11FB_MANGLING*)((uint8*)&PARSER$ + 200ll);
+	*($11FB_MANGLING*)((uint8*)&PARSER$ + 200ll) = MANGLING$1;
 	label$11:;
 }
 
@@ -1088,9 +1141,9 @@ void CEXTERNSTMTEND( void )
 	}
 	label$33:;
 	label$32:;
-	LEXSKIPTOKEN( 0ll );
-	LEXSKIPTOKEN( 0ll );
-	*($11FB_MANGLING*)((uint8*)&PARSER$ + 192ll) = *($11FB_MANGLING*)((uint8*)STK$1 + 24ll);
+	LEXSKIPTOKEN( 2048ll );
+	LEXSKIPTOKEN( 2048ll );
+	*($11FB_MANGLING*)((uint8*)&PARSER$ + 200ll) = *($11FB_MANGLING*)((uint8*)STK$1 + 24ll);
 	CCOMPSTMTPOP( STK$1 );
 	label$31:;
 }
@@ -1098,7 +1151,7 @@ void CEXTERNSTMTEND( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
