@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -727,13 +766,13 @@ struct $7ASTNODE* ASTNEWLABEL( struct $8FBSYMBOL*, int64 );
 struct $8FBSYMBOL* SYMBLOOKUPBYNAMEANDCLASS( struct $8FBSYMBOL*, uint8*, int64, int64, int64 );
 typedef int64 $10FB_SYMBOPT;
 struct $8FBSYMBOL* SYMBADDLABEL( uint8*, $10FB_SYMBOPT );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 int64 LEXGETCLASS( $8LEXCHECK );
 uint8* LEXGETTEXT( void );
 void LEXSKIPTOKEN( $8LEXCHECK );
 int64 LEXGETLOOKAHEAD( int64, $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 void CSTATEMENT( void );
 struct $13FB_CMPSTMTSTK* CCOMPSTMTPUSH( $8FB_TOKEN, $15FB_CMPSTMT_MASK );
 struct $13FB_CMPSTMTSTK* CCOMPSTMTGETTOS( $8FB_TOKEN, int64 );
@@ -761,10 +800,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -798,6 +838,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -806,11 +850,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -863,7 +908,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -882,20 +927,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -936,8 +983,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -945,8 +995,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -993,6 +1044,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -1014,16 +1066,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 
 void CIFSTMTBEGIN( void )
@@ -1034,7 +1091,7 @@ void CIFSTMTBEGIN( void )
 	struct $8FBSYMBOL* EL$1;
 	struct $13FB_CMPSTMTSTK* STK$1;
 	int64 ISMULTILINE$1;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	struct $7ASTNODE* vr$0 = CEXPRESSION(  );
 	EXPR$1 = vr$0;
 	if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$36;
@@ -1067,7 +1124,7 @@ void CIFSTMTBEGIN( void )
 	*(struct $8FBSYMBOL**)((uint8*)STK$1 + 40ll) = EL$1;
 	*(int64*)((uint8*)STK$1 + 48ll) = 0ll;
 	int64 vr$9 = LEXGETTOKEN( 0ll );
-	if( vr$9 != 391ll ) goto label$40;
+	if( vr$9 != 392ll ) goto label$40;
 	{
 		HIFSINGLELINE( STK$1 );
 		goto label$34;
@@ -1082,13 +1139,13 @@ void CIFSTMTBEGIN( void )
 	goto label$41;
 	label$42:;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 	}
 	label$41:;
 	{
-		uint64 TMP$89$2;
+		uint64 TMP$94$2;
 		int64 vr$11 = LEXGETTOKEN( 0ll );
-		TMP$89$2 = (uint64)vr$11;
+		TMP$94$2 = (uint64)vr$11;
 		goto label$44;
 		label$45:;
 		{
@@ -1115,15 +1172,15 @@ void CIFSTMTBEGIN( void )
 		}
 		goto label$43;
 		label$44:;
-		static const void* tmp$90[5ll] = {
+		static const void* tmp$95[5ll] = {
 			&&label$45,
 			&&label$45,
 			&&label$46,
 			&&label$45,
 			&&label$46,
 		};
-		if( (TMP$89$2 - 256ull) > 4ull ) goto label$49;
-		goto *tmp$90[TMP$89$2 - 256ull];
+		if( (TMP$94$2 - 256ull) > 4ull ) goto label$49;
+		goto *tmp$95[TMP$94$2 - 256ull];
 		label$43:;
 	}
 	struct $7ASTNODE* vr$12 = ASTSCOPEBEGIN(  );
@@ -1189,7 +1246,7 @@ void CIFSTMTNEXT( void )
 	int64 vr$7 = LEXGETTOKEN( 0ll );
 	if( vr$7 != 269ll ) goto label$65;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		struct $7ASTNODE* vr$9 = ASTNEWBRANCH( 98ll, *(struct $8FBSYMBOL**)((uint8*)STK$1 + 40ll), (struct $7ASTNODE*)0ull );
 		ASTADD( vr$9 );
 		if( *(struct $8FBSYMBOL**)((uint8*)STK$1 + 32ll) == (struct $8FBSYMBOL*)0ull ) goto label$67;
@@ -1211,7 +1268,7 @@ void CIFSTMTNEXT( void )
 		}
 		label$69:;
 		label$68:;
-		int64 vr$17 = HMATCH( 267ll );
+		int64 vr$17 = HMATCH( 267ll, 2048ll );
 		if( vr$17 != 0ll ) goto label$71;
 		{
 			ERRREPORT( 31ll, 0ll, (uint8*)0ull );
@@ -1235,7 +1292,7 @@ void CIFSTMTNEXT( void )
 	label$65:;
 	{
 		*(int64*)((uint8*)STK$1 + 48ll) = *(int64*)((uint8*)STK$1 + 48ll) + 1ll;
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		int64 vr$23 = LEXGETTOKEN( 0ll );
 		if( vr$23 != 266ll ) goto label$75;
 		{
@@ -1283,11 +1340,11 @@ void CIFSTMTEND( void )
 	int64 vr$2 = LEXGETTOKEN( 0ll );
 	if( vr$2 != 340ll ) goto label$85;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 	}
 	label$85:;
 	label$84:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	if( *(struct $7ASTNODE**)((uint8*)STK$1 + 16ll) == (struct $7ASTNODE*)0ull ) goto label$87;
 	{
 		ASTSCOPEEND( *(struct $7ASTNODE**)((uint8*)STK$1 + 16ll) );
@@ -1310,7 +1367,7 @@ void CIFSTMTEND( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1323,7 +1380,7 @@ static void HIFSINGLELINE( struct $13FB_CMPSTMTSTK* STK$1 )
 	{
 		struct $8FBSYMBOL* L$2;
 		uint8* vr$1 = LEXGETTEXT(  );
-		struct $8FBSYMBOL* vr$2 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll), (uint8*)vr$1, 7ll, 0ll, 0ll );
+		struct $8FBSYMBOL* vr$2 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll), (uint8*)vr$1, 7ll, 0ll, 0ll );
 		L$2 = vr$2;
 		if( L$2 != (struct $8FBSYMBOL*)0ull ) goto label$15;
 		{
@@ -1346,7 +1403,7 @@ static void HIFSINGLELINE( struct $13FB_CMPSTMTSTK* STK$1 )
 	int64 vr$6 = LEXGETTOKEN( 0ll );
 	if( vr$6 != 268ll ) goto label$17;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		if( *(struct $7ASTNODE**)((uint8*)STK$1 + 16ll) == (struct $7ASTNODE*)0ull ) goto label$19;
 		{
 			ASTSCOPEEND( *(struct $7ASTNODE**)((uint8*)STK$1 + 16ll) );
@@ -1363,7 +1420,7 @@ static void HIFSINGLELINE( struct $13FB_CMPSTMTSTK* STK$1 )
 		{
 			struct $8FBSYMBOL* L$3;
 			uint8* vr$15 = LEXGETTEXT(  );
-			struct $8FBSYMBOL* vr$16 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll), (uint8*)vr$15, 7ll, 0ll, 0ll );
+			struct $8FBSYMBOL* vr$16 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll), (uint8*)vr$15, 7ll, 0ll, 0ll );
 			L$3 = vr$16;
 			if( L$3 != (struct $8FBSYMBOL*)0ull ) goto label$23;
 			{
@@ -1396,27 +1453,27 @@ static void HIFSINGLELINE( struct $13FB_CMPSTMTSTK* STK$1 )
 	}
 	label$16:;
 	{
-		int64 TMP$88$2;
+		int64 TMP$93$2;
 		int64 vr$26 = LEXGETTOKEN( 0ll );
-		TMP$88$2 = vr$26;
-		if( TMP$88$2 != 340ll ) goto label$25;
+		TMP$93$2 = vr$26;
+		if( TMP$93$2 != 340ll ) goto label$25;
 		label$26:;
 		{
 			int64 vr$27 = LEXGETLOOKAHEAD( 1ll, 0ll );
 			if( vr$27 != 266ll ) goto label$28;
 			{
-				LEXSKIPTOKEN( 0ll );
-				LEXSKIPTOKEN( 0ll );
+				LEXSKIPTOKEN( 2048ll );
+				LEXSKIPTOKEN( 2048ll );
 			}
 			label$28:;
 			label$27:;
 		}
 		goto label$24;
 		label$25:;
-		if( TMP$88$2 != 314ll ) goto label$29;
+		if( TMP$93$2 != 314ll ) goto label$29;
 		label$30:;
 		{
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 		}
 		label$29:;
 		label$24:;
