@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 typedef int64 $15FB_CMPSTMT_MASK;
 struct $17FB_CMPSTMT_FORELM {
 	struct $8FBSYMBOL* SYM;
@@ -720,29 +759,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -775,7 +804,7 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -796,12 +825,12 @@ void SYMBNAMESPACEREIMPORT( struct $8FBSYMBOL* );
 void SYMBNESTBEGIN( struct $8FBSYMBOL*, int64 );
 void SYMBNESTEND( int64 );
 uint8* SYMBUNIQUELABEL( void );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 int64 LEXGETCLASS( $8LEXCHECK );
 uint8* LEXGETTEXT( void );
 void LEXSKIPTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $8FB_IDOPT;
 struct $8FBSYMBOL* CPARENTID( $8FB_IDOPT );
 struct $13FB_CMPSTMTSTK* CCOMPSTMTPUSH( $8FB_TOKEN, $15FB_CMPSTMT_MASK );
@@ -832,10 +861,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -869,6 +899,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -877,11 +911,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -934,7 +969,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -953,20 +988,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -1007,8 +1044,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -1016,8 +1056,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -1063,6 +1104,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -1084,23 +1126,28 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 struct $17FBPARSER_STMT_LET {
 	struct $5TLIST LIST;
@@ -1123,6 +1170,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1134,7 +1182,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 void CNAMESPACESTMTBEGIN( void )
@@ -1146,7 +1194,7 @@ void CNAMESPACESTMTBEGIN( void )
 	struct $10FBSYMCHAIN* CHAIN_$1;
 	struct $13FB_CMPSTMTSTK* STK$1;
 	int64 LEVELS$1;
-	if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 4ll) != 0ll ) goto label$17;
+	if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 4ll) != 0ll ) goto label$17;
 	{
 		ERRREPORTNOTALLOWED( 4ll, 146ll, (uint8*)0ull );
 		HSKIPCOMPOUND( 286ll, -1ll, 0ll );
@@ -1162,12 +1210,12 @@ void CNAMESPACESTMTBEGIN( void )
 	}
 	label$19:;
 	label$18:;
-	LEXSKIPTOKEN( 64ll );
+	LEXSKIPTOKEN( 2112ll );
 	PALIAS$1 = (uint8*)0ull;
 	{
-		uint64 TMP$88$2;
+		uint64 TMP$93$2;
 		int64 vr$2 = LEXGETTOKEN( 0ll );
-		TMP$88$2 = (uint64)vr$2;
+		TMP$93$2 = (uint64)vr$2;
 		goto label$21;
 		label$22:;
 		{
@@ -1178,15 +1226,15 @@ void CNAMESPACESTMTBEGIN( void )
 		}
 		goto label$20;
 		label$21:;
-		static const void* tmp$90[5ll] = {
+		static const void* tmp$95[5ll] = {
 			&&label$22,
 			&&label$22,
 			&&label$22,
 			&&label$22,
 			&&label$22,
 		};
-		if( (TMP$88$2 - 256ull) > 4ull ) goto label$20;
-		goto *tmp$90[TMP$88$2 - 256ull];
+		if( (TMP$93$2 - 256ull) > 4ull ) goto label$20;
+		goto *tmp$95[TMP$93$2 - 256ull];
 		label$20:;
 	}
 	LEVELS$1 = 0ll;
@@ -1201,22 +1249,22 @@ void CNAMESPACESTMTBEGIN( void )
 		label$26:;
 		LEVELS$1 = LEVELS$1 + 1ll;
 		{
-			int64 TMP$89$3;
+			int64 TMP$94$3;
 			int64 vr$6 = LEXGETCLASS( 0ll );
-			TMP$89$3 = vr$6;
-			if( TMP$89$3 != 0ll ) goto label$29;
+			TMP$94$3 = vr$6;
+			if( TMP$94$3 != 0ll ) goto label$29;
 			label$30:;
 			{
 				uint8* vr$7 = LEXGETTEXT(  );
 				fb_StrAssign( (void*)ID$1, 129ll, (void*)vr$7, 0ll, 0 );
-				CHAIN_$1 = *(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 2088ll);
+				CHAIN_$1 = *(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2088ll);
 			}
 			goto label$28;
 			label$29:;
-			if( TMP$89$3 != 2ll ) goto label$31;
+			if( TMP$94$3 != 2ll ) goto label$31;
 			label$32:;
 			{
-				if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll) != (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$34;
+				if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll) != (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$34;
 				{
 					ERRREPORT( 4ll, 0ll, (uint8*)0ull );
 					*(uint8*)ID$1 = (uint8)0u;
@@ -1227,7 +1275,7 @@ void CNAMESPACESTMTBEGIN( void )
 				{
 					uint8* vr$11 = LEXGETTEXT(  );
 					fb_StrAssign( (void*)ID$1, 129ll, (void*)vr$11, 0ll, 0 );
-					CHAIN_$1 = *(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 2088ll);
+					CHAIN_$1 = *(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2088ll);
 				}
 				label$33:;
 			}
@@ -1254,7 +1302,7 @@ void CNAMESPACESTMTBEGIN( void )
 			goto label$38;
 			label$39:;
 			{
-				if( *(struct $8FBHASHTB**)((uint8*)SYM$1 + 232ll) == *(struct $8FBHASHTB**)((uint8*)&SYMB$ + 197016ll) ) goto label$41;
+				if( *(struct $8FBHASHTB**)((uint8*)SYM$1 + 248ll) == *(struct $8FBHASHTB**)((uint8*)&SYMB$ + 197032ll) ) goto label$41;
 				{
 					SYM$1 = (struct $8FBSYMBOL*)0ull;
 				}
@@ -1271,7 +1319,7 @@ void CNAMESPACESTMTBEGIN( void )
 		label$36:;
 		if( (int64)*(uint8*)ID$1 == 0ll ) goto label$43;
 		{
-			LEXSKIPTOKEN( 64ll );
+			LEXSKIPTOKEN( 2112ll );
 		}
 		label$43:;
 		label$42:;
@@ -1335,8 +1383,8 @@ void CNAMESPACESTMTEND( void )
 	}
 	label$57:;
 	label$56:;
-	LEXSKIPTOKEN( 0ll );
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
+	LEXSKIPTOKEN( 2048ll );
 	LEVELS$1 = *(int64*)((uint8*)STK$1 + 32ll);
 	*(int64*)((uint8*)&PARSER$ + 176ll) = *(int64*)((uint8*)&PARSER$ + 176ll) - LEVELS$1;
 	label$58:;
@@ -1345,14 +1393,14 @@ void CNAMESPACESTMTEND( void )
 		SYMBNESTEND( 0ll );
 		struct $8FBSYMBOL* NS$2;
 		NS$2 = *(struct $8FBSYMBOL**)((uint8*)STK$1 + 24ll);
-		*(int64*)((uint8*)NS$2 + 168ll) = *(int64*)((uint8*)NS$2 + 168ll) + 1ll;
-		if( *(int64*)((uint8*)NS$2 + 168ll) <= 1ll ) goto label$61;
+		*(int64*)((uint8*)NS$2 + 176ll) = *(int64*)((uint8*)NS$2 + 176ll) + 1ll;
+		if( *(int64*)((uint8*)NS$2 + 176ll) <= 1ll ) goto label$61;
 		{
 			SYMBNAMESPACEREIMPORT( NS$2 );
 		}
 		label$61:;
 		label$60:;
-		*(struct $8FBSYMBOL**)((uint8*)NS$2 + 176ll) = *(struct $8FBSYMBOL**)((uint8*)NS$2 + 104ll);
+		*(struct $8FBSYMBOL**)((uint8*)NS$2 + 184ll) = *(struct $8FBSYMBOL**)((uint8*)NS$2 + 112ll);
 		CCOMPSTMTPOP( STK$1 );
 		struct $13FB_CMPSTMTSTK* vr$10 = CCOMPSTMTGETTOS( 286ll, 0ll );
 		STK$1 = vr$10;
@@ -1373,7 +1421,7 @@ void CUSINGSTMT( void )
 {
 	label$64:;
 	struct $8FBSYMBOL* SYM$1;
-	if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 4ll) != 0ll ) goto label$67;
+	if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 4ll) != 0ll ) goto label$67;
 	{
 		ERRREPORTNOTALLOWED( 4ll, 146ll, (uint8*)0ull );
 		HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
@@ -1381,7 +1429,7 @@ void CUSINGSTMT( void )
 	}
 	label$67:;
 	label$66:;
-	LEXSKIPTOKEN( 64ll );
+	LEXSKIPTOKEN( 2112ll );
 	label$68:;
 	{
 		struct $8FBSYMBOL* vr$1 = CPARENTID( 1ll );
@@ -1418,7 +1466,7 @@ void CUSINGSTMT( void )
 		label$71:;
 	}
 	label$70:;
-	int64 vr$4 = HMATCH( 44ll );
+	int64 vr$4 = HMATCH( 44ll, 0ll );
 	if( vr$4 != 0ll ) goto label$68;
 	label$69:;
 	label$65:;
@@ -1427,7 +1475,7 @@ void CUSINGSTMT( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
