@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -705,6 +744,17 @@ struct $13FB_CMPSTMTSTK {
 	};
 };
 __FB_STATIC_ASSERT( sizeof( struct $13FB_CMPSTMTSTK ) == 176 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -727,16 +777,17 @@ struct $7ASTNODE* ASTNEWCONSTI( int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL*, int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWBRANCH( int64, struct $8FBSYMBOL*, struct $7ASTNODE* );
 struct $7ASTNODE* ASTBUILDJMPTB( struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
-struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
+typedef int64 $15AST_LINK_RETURN;
+struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, $15AST_LINK_RETURN );
 struct $7ASTNODE* ASTNEWLABEL( struct $8FBSYMBOL*, int64 );
 struct $7ASTNODE* ASTNEWDECL( struct $8FBSYMBOL*, int64 );
 typedef int64 $10FB_SYMBOPT;
 struct $8FBSYMBOL* SYMBADDLABEL( uint8*, $10FB_SYMBOPT );
 struct $8FBSYMBOL* SYMBADDIMPLICITVAR( int64, struct $8FBSYMBOL*, int64 );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 struct $13FB_CMPSTMTSTK* CCOMPSTMTPUSH( $8FB_TOKEN, $15FB_CMPSTMT_MASK );
 void CCOMPSTMTPOP( struct $13FB_CMPSTMTSTK* );
 struct $7ASTNODE* CEXPRESSION( void );
@@ -762,21 +813,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -784,20 +825,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -838,8 +881,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -847,8 +893,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -895,6 +942,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -916,16 +964,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $9SELECTCTX {
 	int64 BASE;
@@ -950,7 +1003,7 @@ void PARSERSELCONSTSTMTEND( void )
 
 void CSELCONSTSTMTBEGIN( void )
 {
-	int64 TMP$89$1;
+	int64 TMP$94$1;
 	label$14:;
 	struct $7ASTNODE* EXPR$1;
 	__builtin_memset( &EXPR$1, 0, 8ll );
@@ -984,12 +1037,12 @@ void CSELCONSTSTMTBEGIN( void )
 	label$19:;
 	label$18:;
 	if( ((*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 480ll) == 0ll ) goto label$20;
-	TMP$89$1 = 24ll;
+	TMP$94$1 = 24ll;
 	goto label$45;
 	label$20:;
-	TMP$89$1 = (*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 31ll;
+	TMP$94$1 = (*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 31ll;
 	label$45:;
-	if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$89$1 * 56ll)) == 0ll ) goto label$22;
+	if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$94$1 * 56ll)) == 0ll ) goto label$22;
 	{
 		ASTDELTREE( EXPR$1 );
 		EXPR$1 = (struct $7ASTNODE*)0ull;
@@ -998,11 +1051,11 @@ void CSELCONSTSTMTBEGIN( void )
 	label$22:;
 	{
 		{
-			int64 TMP$90$3;
-			TMP$90$3 = *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll;
-			if( TMP$90$3 == 4ll ) goto label$25;
+			int64 TMP$95$3;
+			TMP$95$3 = *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll;
+			if( TMP$95$3 == 4ll ) goto label$25;
 			label$26:;
-			if( TMP$90$3 != 7ll ) goto label$24;
+			if( TMP$95$3 != 7ll ) goto label$24;
 			label$25:;
 			{
 				if( *(int64*)EXPR$1 == 20ll ) goto label$28;
@@ -1029,14 +1082,14 @@ void CSELCONSTSTMTBEGIN( void )
 	DTYPE$1 = *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll;
 	if( DTYPE$1 == 9ll ) goto label$32;
 	{
-		int64 TMP$91$2;
+		int64 TMP$96$2;
 		if( (DTYPE$1 & 480ll) == 0ll ) goto label$33;
-		TMP$91$2 = 24ll;
+		TMP$96$2 = 24ll;
 		goto label$46;
 		label$33:;
-		TMP$91$2 = DTYPE$1 & 31ll;
+		TMP$96$2 = DTYPE$1 & 31ll;
 		label$46:;
-		if( *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$91$2 * 56ll)) + 8ll) > *(int64*)((uint8*)SYMB_DTYPETB$ + 512ll) ) goto label$35;
+		if( *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$96$2 * 56ll)) + 8ll) > *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 512ll) ) goto label$35;
 		{
 			struct $7ASTNODE* vr$24 = ASTNEWCONV( 9ll, (struct $8FBSYMBOL*)0ull, EXPR$1, 0ll, (int64*)0ull );
 			EXPR$1 = vr$24;
@@ -1057,14 +1110,14 @@ void CSELCONSTSTMTBEGIN( void )
 		if( DTYPE$1 != 7ll ) goto label$37;
 		label$38:;
 		{
-			int64 TMP$92$3;
+			int64 TMP$97$3;
 			if( (DTYPE$1 & 480ll) == 0ll ) goto label$40;
-			TMP$92$3 = 24ll;
+			TMP$97$3 = 24ll;
 			goto label$47;
 			label$40:;
-			TMP$92$3 = DTYPE$1 & 31ll;
+			TMP$97$3 = DTYPE$1 & 31ll;
 			label$47:;
-			DTYPE$1 = *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$92$3 * 56ll)) + 32ll);
+			DTYPE$1 = *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$97$3 * 56ll)) + 32ll);
 		}
 		label$37:;
 		label$36:;
@@ -1074,7 +1127,7 @@ void CSELCONSTSTMTBEGIN( void )
 	struct $8FBSYMBOL* vr$30 = SYMBADDLABEL( (uint8*)0ull, 0ll );
 	CL$1 = vr$30;
 	OPTIONS$1 = 0ll;
-	if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 2ll) != 0ll ) goto label$42;
+	if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 2ll) != 0ll ) goto label$42;
 	{
 		OPTIONS$1 = OPTIONS$1 | 2ll;
 	}
@@ -1082,7 +1135,7 @@ void CSELCONSTSTMTBEGIN( void )
 	label$41:;
 	struct $8FBSYMBOL* vr$35 = SYMBADDIMPLICITVAR( *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll, (struct $8FBSYMBOL*)0ull, OPTIONS$1 );
 	SYM$1 = vr$35;
-	*($12FB_SYMBSTATS*)((uint8*)SYM$1 + 16ll) = *(int64*)((uint8*)SYM$1 + 16ll) | 2048ll;
+	*($12FB_SYMBSTATS*)((uint8*)SYM$1 + 24ll) = *(int64*)((uint8*)SYM$1 + 24ll) | 2048ll;
 	if( (OPTIONS$1 & 2ll) == 0ll ) goto label$44;
 	{
 		struct $7ASTNODE* vr$40 = ASTNEWDECL( SYM$1, -1ll );
@@ -1097,7 +1150,7 @@ void CSELCONSTSTMTBEGIN( void )
 		struct $7ASTNODE* vr$43 = ASTNEWVAR( SYM$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$44 = ASTNEWASSIGN( vr$43, EXPR$1, 64ll );
 		struct $7ASTNODE* vr$45 = ASTNEWDECL( SYM$1, 0ll );
-		struct $7ASTNODE* vr$46 = ASTNEWLINK( vr$45, vr$44, -1ll );
+		struct $7ASTNODE* vr$46 = ASTNEWLINK( vr$45, vr$44, 0ll );
 		ASTADD( vr$46 );
 	}
 	label$43:;
@@ -1121,7 +1174,7 @@ void CSELCONSTSTMTBEGIN( void )
 void CSELCONSTSTMTNEXT( struct $13FB_CMPSTMTSTK* STK$1 )
 {
 	label$61:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	if( *(struct $7ASTNODE**)((uint8*)STK$1 + 16ll) == (struct $7ASTNODE*)0ull ) goto label$64;
 	{
 		ASTSCOPEEND( *(struct $7ASTNODE**)((uint8*)STK$1 + 16ll) );
@@ -1138,7 +1191,7 @@ void CSELCONSTSTMTNEXT( struct $13FB_CMPSTMTSTK* STK$1 )
 	int64 vr$5 = LEXGETTOKEN( 0ll );
 	if( vr$5 != 268ll ) goto label$68;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		struct $8FBSYMBOL* vr$6 = SYMBADDLABEL( (uint8*)0ull, 4ll );
 		*(struct $8FBSYMBOL**)((uint8*)STK$1 + 56ll) = vr$6;
 		struct $7ASTNODE* vr$9 = ASTNEWLABEL( *(struct $8FBSYMBOL**)((uint8*)STK$1 + 56ll), -1ll );
@@ -1173,7 +1226,7 @@ void CSELCONSTSTMTNEXT( struct $13FB_CMPSTMTSTK* STK$1 )
 		int64 vr$23 = LEXGETTOKEN( 0ll );
 		if( vr$23 != 284ll ) goto label$75;
 		{
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 			struct $7ASTNODE* vr$25 = CEXPRESSION(  );
 			int64 vr$26 = CCONSTINTEXPRRANGED( vr$25, *(int64*)((uint8*)STK$1 + 64ll) );
 			TOVALUE$2 = (uint64)vr$26;
@@ -1238,7 +1291,7 @@ void CSELCONSTSTMTNEXT( struct $13FB_CMPSTMTSTK* STK$1 )
 		label$83:;
 	}
 	label$71:;
-	int64 vr$38 = HMATCH( 44ll );
+	int64 vr$38 = HMATCH( 44ll, 0ll );
 	if( vr$38 != 0ll ) goto label$69;
 	label$70:;
 	struct $7ASTNODE* vr$39 = ASTNEWLABEL( LABEL$1, -1ll );
@@ -1253,8 +1306,8 @@ void CSELCONSTSTMTEND( struct $13FB_CMPSTMTSTK* STK$1 )
 {
 	label$91:;
 	struct $8FBSYMBOL* DEFLABEL$1;
-	LEXSKIPTOKEN( 0ll );
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
+	LEXSKIPTOKEN( 2048ll );
 	DEFLABEL$1 = *(struct $8FBSYMBOL**)((uint8*)STK$1 + 56ll);
 	if( DEFLABEL$1 != (struct $8FBSYMBOL*)0ull ) goto label$94;
 	{
@@ -1281,8 +1334,8 @@ void CSELCONSTSTMTEND( struct $13FB_CMPSTMTSTK* STK$1 )
 		{
 			int64 I$3;
 			I$3 = *(int64*)((uint8*)STK$1 + 48ll);
-			int64 TMP$94$3;
-			TMP$94$3 = *(int64*)&CTX$ + -1ll;
+			int64 TMP$99$3;
+			TMP$99$3 = *(int64*)&CTX$ + -1ll;
 			goto label$99;
 			label$102:;
 			{
@@ -1297,7 +1350,7 @@ void CSELCONSTSTMTEND( struct $13FB_CMPSTMTSTK* STK$1 )
 			label$100:;
 			I$3 = I$3 + 1ll;
 			label$99:;
-			if( I$3 <= TMP$94$3 ) goto label$102;
+			if( I$3 <= TMP$99$3 ) goto label$102;
 			label$101:;
 		}
 		*(uint64*)((uint8*)STK$1 + 72ll) = *(uint64*)((uint8*)STK$1 + 72ll) + ADJUST_BIAS$2;
@@ -1334,7 +1387,7 @@ __attribute__(( constructor )) static void fb_ctor__parserzcompoundzselectzconst
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1385,8 +1438,8 @@ static int64 HSELCONSTADDCASE( int64 SWTBASE$1, uint64 VALUE$1, struct $8FBSYMBO
 	{
 		int64 I$2;
 		I$2 = *(int64*)&CTX$;
-		int64 TMP$93$2;
-		TMP$93$2 = (SWTBASE$1 + HIGH$1) + 1ll;
+		int64 TMP$98$2;
+		TMP$98$2 = (SWTBASE$1 + HIGH$1) + 1ll;
 		goto label$57;
 		label$60:;
 		{
@@ -1396,7 +1449,7 @@ static int64 HSELCONSTADDCASE( int64 SWTBASE$1, uint64 VALUE$1, struct $8FBSYMBO
 		label$58:;
 		I$2 = I$2 + -1ll;
 		label$57:;
-		if( I$2 >= TMP$93$2 ) goto label$60;
+		if( I$2 >= TMP$98$2 ) goto label$60;
 		label$59:;
 	}
 	*(uint64*)((uint8*)((uint8*)&CTX$ + ((SWTBASE$1 + HIGH$1) << (3ll & 63ll))) + 8ll) = VALUE$1;
