@@ -8,8 +8,9 @@ typedef   signed long long  int64;
 typedef unsigned long long uint64;
 typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
-typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $12FB_SYMBCLASS;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -618,29 +657,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -673,7 +702,7 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
 static void fb_ctor__parserzdeclzconst( void ) __attribute__(( constructor ));
@@ -681,8 +710,6 @@ static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM*, struct $11TSTRSETIT
 typedef int64 $12FB_ERRMSGOPT;
 void ERRREPORTEX( int64, uint8*, int64, $12FB_ERRMSGOPT, uint8* );
 void ERRREPORT( int64, int64, uint8* );
-typedef int64 $11FB_LANG_OPT;
-void ERRREPORTNOTALLOWED( $11FB_LANG_OPT, int64, uint8* );
 void ASTDELNODE( struct $7ASTNODE* );
 void ASTDELTREE( struct $7ASTNODE* );
 typedef int64 $11AST_CONVOPT;
@@ -692,15 +719,18 @@ struct $7ASTNODE* ASTNEWCONSTI( int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWCONSTZ( int64, struct $8FBSYMBOL* );
 int64 ASTCHECKASSIGNTOTYPE( int64, struct $8FBSYMBOL*, struct $7ASTNODE* );
 struct $8FBSYMBOL* ASTGETSTRLITSYMBOL( struct $7ASTNODE* );
-struct $8FBSYMBOL* SYMBREUSEORADDCONST( uint8*, int64, struct $8FBSYMBOL*, union $7FBVALUE*, int64 );
+struct $8FBSYMBOL* SYMBREUSEORADDCONST( uint8*, int64, struct $8FBSYMBOL*, union $7FBVALUE*, $13FB_SYMBATTRIB );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 int64 LEXGETCLASS( $8LEXCHECK );
 uint8* LEXGETTEXT( void );
 void LEXSKIPTOKEN( $8LEXCHECK );
+void LEXCHECKTOKEN( $8LEXCHECK );
 typedef int64 $14FB_SYMBTYPEOPT;
 int64 CSYMBOLTYPE( int64*, struct $8FBSYMBOL**, int64*, int64*, $14FB_SYMBTYPEOPT );
 void CCURRENTPARENTID( void );
+typedef int64 $15FB_CMPSTMT_MASK;
+int64 CCOMPSTMTISALLOWED( $15FB_CMPSTMT_MASK );
 int64 CASSIGNTOKEN( void );
 struct $7ASTNODE* CEXPRESSION( void );
 void HSKIPUNTIL( int64, int64, $8LEXCHECK, int64 );
@@ -726,10 +756,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -763,6 +794,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -771,11 +806,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -828,7 +864,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -847,20 +883,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -901,8 +939,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -910,8 +951,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -935,6 +977,7 @@ struct $6FBMAIN {
 	struct $7ASTNODE* INITNODE;
 };
 __FB_STATIC_ASSERT( sizeof( struct $6FBMAIN ) == 16 );
+typedef int64 $11FB_LANG_OPT;
 struct $11FB_LANG_CTX {
 	$11FB_LANG_OPT OPT;
 	$11FB_DATATYPE INTEGERKEYWORDDTYPE;
@@ -957,6 +1000,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -978,26 +1022,30 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 typedef int64 $8FB_TOKEN;
-typedef int64 $15FB_CMPSTMT_MASK;
 struct $17FB_CMPSTMT_FORELM {
 	struct $8FBSYMBOL* SYM;
 	union $7FBVALUE VALUE;
@@ -1124,6 +1172,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1135,38 +1184,46 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
-void CCONSTDECL( int64 ATTRIB$1 )
+void CCONSTDECL( $13FB_SYMBATTRIB ATTRIB$1 )
 {
-	label$86:;
+	label$82:;
 	int64 DTYPE$1;
 	struct $8FBSYMBOL* SUBTYPE$1;
-	LEXSKIPTOKEN( 0ll );
+	int64 vr$0 = CCOMPSTMTISALLOWED( 9ll );
+	if( vr$0 != 0ll ) goto label$85;
+	{
+		HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
+		goto label$83;
+	}
+	label$85:;
+	label$84:;
+	LEXSKIPTOKEN( 2048ll );
 	HGETTYPE( &DTYPE$1, &SUBTYPE$1 );
-	label$88:;
+	label$86:;
 	{
 		CCONSTASSIGN( DTYPE$1, SUBTYPE$1, ATTRIB$1 );
-		int64 vr$2 = LEXGETTOKEN( 0ll );
-		if( vr$2 == 44ll ) goto label$92;
+		int64 vr$3 = LEXGETTOKEN( 0ll );
+		if( vr$3 == 44ll ) goto label$90;
 		{
-			goto label$89;
+			goto label$87;
 		}
-		label$92:;
-		label$91:;
+		label$90:;
+		label$89:;
 		LEXSKIPTOKEN( 0ll );
 	}
-	label$90:;
-	goto label$88;
-	label$89:;
+	label$88:;
+	goto label$86;
 	label$87:;
+	label$83:;
 }
 
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1177,12 +1234,12 @@ static void HGETTYPE( int64* DTYPE$1, struct $8FBSYMBOL** SUBTYPE$1 )
 	int64 vr$0 = LEXGETTOKEN( 0ll );
 	if( vr$0 != 376ll ) goto label$13;
 	{
-		int64 TMP$88$2;
-		int64 TMP$89$2;
-		LEXSKIPTOKEN( 0ll );
-		TMP$89$2 = 0ll;
-		TMP$88$2 = 0ll;
-		int64 vr$3 = CSYMBOLTYPE( DTYPE$1, SUBTYPE$1, &TMP$88$2, &TMP$89$2, 1ll );
+		int64 TMP$93$2;
+		int64 TMP$94$2;
+		LEXSKIPTOKEN( 2048ll );
+		TMP$94$2 = 0ll;
+		TMP$93$2 = 0ll;
+		int64 vr$3 = CSYMBOLTYPE( DTYPE$1, SUBTYPE$1, &TMP$93$2, &TMP$94$2, 1ll );
 		if( vr$3 != 0ll ) goto label$15;
 		{
 			ERRREPORT( 14ll, 0ll, (uint8*)0ull );
@@ -1192,19 +1249,19 @@ static void HGETTYPE( int64* DTYPE$1, struct $8FBSYMBOL** SUBTYPE$1 )
 		label$15:;
 		label$14:;
 		{
-			int64 TMP$90$3;
-			TMP$90$3 = *DTYPE$1 & 511ll;
-			if( TMP$90$3 == 0ll ) goto label$18;
+			int64 TMP$95$3;
+			TMP$95$3 = *DTYPE$1 & 511ll;
+			if( TMP$95$3 == 0ll ) goto label$18;
 			label$19:;
-			if( TMP$90$3 == 18ll ) goto label$18;
+			if( TMP$95$3 == 18ll ) goto label$18;
 			label$20:;
-			if( TMP$90$3 == 4ll ) goto label$18;
+			if( TMP$95$3 == 4ll ) goto label$18;
 			label$21:;
-			if( TMP$90$3 == 7ll ) goto label$18;
+			if( TMP$95$3 == 7ll ) goto label$18;
 			label$22:;
-			if( TMP$90$3 == 20ll ) goto label$18;
+			if( TMP$95$3 == 20ll ) goto label$18;
 			label$23:;
-			if( TMP$90$3 != 23ll ) goto label$17;
+			if( TMP$95$3 != 23ll ) goto label$17;
 			label$18:;
 			{
 				ERRREPORT( 24ll, -1ll, (uint8*)0ull );
@@ -1236,17 +1293,17 @@ static void CCONSTASSIGN( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, $13FB_SYM
 	union $7FBVALUE VALUE$1;
 	CCURRENTPARENTID(  );
 	{
-		uint64 TMP$91$2;
+		uint64 TMP$96$2;
 		int64 vr$0 = LEXGETCLASS( 0ll );
-		TMP$91$2 = (uint64)vr$0;
+		TMP$96$2 = (uint64)vr$0;
 		goto label$27;
 		label$28:;
 		{
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 524288ll) == 0ll ) goto label$30;
+			if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 524288ll) == 0ll ) goto label$30;
 			{
-				if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$32;
+				if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$32;
 				{
-					if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 2096ll) <= 0ll ) goto label$34;
+					if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2096ll) <= 0ll ) goto label$34;
 					{
 						ERRREPORT( 90ll, 0ll, (uint8*)0ull );
 					}
@@ -1264,7 +1321,7 @@ static void CCONSTASSIGN( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, $13FB_SYM
 		{
 			if( *(int64*)((uint8*)&ENV$ + 272ll) == 3ll ) goto label$37;
 			{
-				if( ((int64)-(*(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll)) | (int64)-(*(uint64*)((uint8*)&PARSER$ + 184ll) > 0ull)) == 0ll ) goto label$39;
+				if( ((int64)-(*(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll)) | (int64)-(*(uint64*)((uint8*)&PARSER$ + 192ll) > 0ull)) == 0ll ) goto label$39;
 				{
 					ERRREPORT( 4ll, 0ll, (uint8*)0ull );
 					HSKIPUNTIL( 44ll, 0ll, 0ll, 0ll );
@@ -1297,7 +1354,7 @@ static void CCONSTASSIGN( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, $13FB_SYM
 		}
 		goto label$26;
 		label$27:;
-		static const void* tmp$92[6ll] = {
+		static const void* tmp$97[6ll] = {
 			&&label$28,
 			&&label$40,
 			&&label$35,
@@ -1305,175 +1362,165 @@ static void CCONSTASSIGN( int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, $13FB_SYM
 			&&label$43,
 			&&label$40,
 		};
-		if( TMP$91$2 > 5ull ) goto label$43;
-		goto *tmp$92[TMP$91$2 - 0ull];
+		if( TMP$96$2 > 5ull ) goto label$43;
+		goto *tmp$97[TMP$96$2 - 0ull];
 		label$26:;
 	}
-	SUFFIX$1 = *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 16ll);
-	uint8* vr$11 = LEXGETTEXT(  );
-	fb_StrAssign( (void*)ID$1, 129ll, (void*)vr$11, 0ll, 0 );
-	if( SUFFIX$1 == 2147483648ll ) goto label$45;
-	{
-		if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 8388608ll) != 0ll ) goto label$47;
-		{
-			ERRREPORTNOTALLOWED( 8388608ll, 148ll, (uint8*)0ull );
-		}
-		label$47:;
-		label$46:;
-	}
-	label$45:;
-	label$44:;
+	uint8* vr$9 = LEXGETTEXT(  );
+	fb_StrAssign( (void*)ID$1, 129ll, (void*)vr$9, 0ll, 0 );
+	LEXCHECKTOKEN( 4096ll );
+	SUFFIX$1 = *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 16ll);
 	LEXSKIPTOKEN( 0ll );
-	if( DTYPE$1 != 2147483648ll ) goto label$49;
+	if( DTYPE$1 != 2147483648ll ) goto label$45;
 	{
 		HGETTYPE( &DTYPE$1, &SUBTYPE$1 );
 	}
-	label$49:;
-	label$48:;
-	if( SUFFIX$1 == 2147483648ll ) goto label$51;
+	label$45:;
+	label$44:;
+	if( SUFFIX$1 == 2147483648ll ) goto label$47;
 	{
-		if( DTYPE$1 == 2147483648ll ) goto label$53;
+		if( DTYPE$1 == 2147483648ll ) goto label$49;
 		{
 			ERRREPORTEX( 17ll, (uint8*)ID$1, 0ll, 1ll, (uint8*)0ull );
 		}
-		label$53:;
-		label$52:;
+		label$49:;
+		label$48:;
 		DTYPE$1 = SUFFIX$1;
 		SUBTYPE$1 = (struct $8FBSYMBOL*)0ull;
-		ATTRIB$1 = ATTRIB$1 | 268435456ll;
+		ATTRIB$1 = ATTRIB$1 | 1048576ll;
 	}
-	label$51:;
-	label$50:;
+	label$47:;
+	label$46:;
 	DOSKIP$1 = 0ll;
-	int64 vr$16 = CASSIGNTOKEN(  );
-	if( vr$16 != 0ll ) goto label$55;
+	int64 vr$15 = CASSIGNTOKEN(  );
+	if( vr$15 != 0ll ) goto label$51;
 	{
 		ERRREPORT( 10ll, 0ll, (uint8*)0ull );
 		DOSKIP$1 = -1ll;
 	}
-	label$55:;
-	label$54:;
-	struct $7ASTNODE* vr$17 = CEXPRESSION(  );
-	EXPR$1 = vr$17;
-	if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$57;
+	label$51:;
+	label$50:;
+	struct $7ASTNODE* vr$16 = CEXPRESSION(  );
+	EXPR$1 = vr$16;
+	if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$53;
 	{
 		ERRREPORTEX( 11ll, (uint8*)ID$1, 0ll, 1ll, (uint8*)0ull );
 		DOSKIP$1 = -1ll;
-		if( DTYPE$1 != 2147483648ll ) goto label$59;
+		if( DTYPE$1 != 2147483648ll ) goto label$55;
 		{
 			DTYPE$1 = 8ll;
 		}
-		label$59:;
-		label$58:;
-		struct $7ASTNODE* vr$18 = ASTNEWCONSTZ( DTYPE$1, SUBTYPE$1 );
-		EXPR$1 = vr$18;
+		label$55:;
+		label$54:;
+		struct $7ASTNODE* vr$17 = ASTNEWCONSTZ( DTYPE$1, SUBTYPE$1 );
+		EXPR$1 = vr$17;
 	}
-	label$57:;
-	label$56:;
+	label$53:;
+	label$52:;
 	int64 EXPRDTYPE$1;
 	EXPRDTYPE$1 = *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll;
 	LITSYM$1 = (struct $8FBSYMBOL*)0ull;
 	{
-		if( EXPRDTYPE$1 == 4ll ) goto label$62;
-		label$63:;
-		if( EXPRDTYPE$1 != 7ll ) goto label$61;
-		label$62:;
+		if( EXPRDTYPE$1 == 4ll ) goto label$58;
+		label$59:;
+		if( EXPRDTYPE$1 != 7ll ) goto label$57;
+		label$58:;
 		{
-			struct $8FBSYMBOL* vr$21 = ASTGETSTRLITSYMBOL( EXPR$1 );
-			LITSYM$1 = vr$21;
+			struct $8FBSYMBOL* vr$20 = ASTGETSTRLITSYMBOL( EXPR$1 );
+			LITSYM$1 = vr$20;
 		}
-		label$61:;
-		label$60:;
+		label$57:;
+		label$56:;
 	}
-	if( LITSYM$1 == (struct $8FBSYMBOL*)0ull ) goto label$65;
+	if( LITSYM$1 == (struct $8FBSYMBOL*)0ull ) goto label$61;
 	{
-		if( DTYPE$1 == 2147483648ll ) goto label$67;
+		if( DTYPE$1 == 2147483648ll ) goto label$63;
 		{
-			if( (DTYPE$1 & 511ll) == 17ll ) goto label$69;
+			if( (DTYPE$1 & 511ll) == 17ll ) goto label$65;
 			{
 				ERRREPORTEX( 24ll, (uint8*)ID$1, 0ll, 1ll, (uint8*)0ull );
 			}
-			label$69:;
-			label$68:;
+			label$65:;
+			label$64:;
 		}
-		label$67:;
-		label$66:;
+		label$63:;
+		label$62:;
 		*(struct $8FBSYMBOL**)&VALUE$1 = LITSYM$1;
-		struct $8FBSYMBOL* vr$24 = SYMBREUSEORADDCONST( (uint8*)ID$1, EXPRDTYPE$1, (struct $8FBSYMBOL*)0ull, &VALUE$1, ATTRIB$1 );
-		if( vr$24 != (struct $8FBSYMBOL*)0ull ) goto label$71;
+		struct $8FBSYMBOL* vr$23 = SYMBREUSEORADDCONST( (uint8*)ID$1, EXPRDTYPE$1, (struct $8FBSYMBOL*)0ull, &VALUE$1, ATTRIB$1 );
+		if( vr$23 != (struct $8FBSYMBOL*)0ull ) goto label$67;
 		{
 			ERRREPORTEX( 4ll, (uint8*)ID$1, 0ll, 1ll, (uint8*)0ull );
 		}
-		label$71:;
-		label$70:;
+		label$67:;
+		label$66:;
 	}
-	goto label$64;
-	label$65:;
+	goto label$60;
+	label$61:;
 	{
-		if( *(int64*)EXPR$1 == 16ll ) goto label$73;
+		if( *(int64*)EXPR$1 == 16ll ) goto label$69;
 		{
 			ERRREPORTEX( 11ll, (uint8*)ID$1, 0ll, 1ll, (uint8*)0ull );
 			ASTDELTREE( EXPR$1 );
-			struct $7ASTNODE* vr$26 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
-			EXPR$1 = vr$26;
+			struct $7ASTNODE* vr$25 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
+			EXPR$1 = vr$25;
 			EXPRDTYPE$1 = 8ll;
 		}
-		label$73:;
-		label$72:;
-		if( DTYPE$1 == 2147483648ll ) goto label$75;
+		label$69:;
+		label$68:;
+		if( DTYPE$1 == 2147483648ll ) goto label$71;
 		{
-			int64 vr$27 = ASTCHECKASSIGNTOTYPE( DTYPE$1, SUBTYPE$1, EXPR$1 );
-			if( vr$27 != 0ll ) goto label$77;
+			int64 vr$26 = ASTCHECKASSIGNTOTYPE( DTYPE$1, SUBTYPE$1, EXPR$1 );
+			if( vr$26 != 0ll ) goto label$73;
 			{
 				ERRREPORTEX( 20ll, (uint8*)ID$1, 0ll, 1ll, (uint8*)0ull );
 				ASTDELTREE( EXPR$1 );
 				EXPRDTYPE$1 = DTYPE$1;
 				SUBTYPE$1 = (struct $8FBSYMBOL*)0ull;
-				struct $7ASTNODE* vr$28 = ASTNEWCONSTSTR( (uint8*)0ull );
-				EXPR$1 = vr$28;
+				struct $7ASTNODE* vr$27 = ASTNEWCONSTSTR( (uint8*)0ull );
+				EXPR$1 = vr$27;
 			}
-			label$77:;
-			label$76:;
-			if( ((int64)-(DTYPE$1 != EXPRDTYPE$1) | (int64)-(SUBTYPE$1 != *(struct $8FBSYMBOL**)((uint8*)EXPR$1 + 16ll))) == 0ll ) goto label$79;
+			label$73:;
+			label$72:;
+			if( ((int64)-(DTYPE$1 != EXPRDTYPE$1) | (int64)-(SUBTYPE$1 != *(struct $8FBSYMBOL**)((uint8*)EXPR$1 + 16ll))) == 0ll ) goto label$75;
 			{
-				struct $7ASTNODE* vr$33 = ASTNEWCONV( DTYPE$1, SUBTYPE$1, EXPR$1, 0ll, (int64*)0ull );
-				EXPR$1 = vr$33;
-				if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$81;
+				struct $7ASTNODE* vr$32 = ASTNEWCONV( DTYPE$1, SUBTYPE$1, EXPR$1, 0ll, (int64*)0ull );
+				EXPR$1 = vr$32;
+				if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$77;
 				{
 					ERRREPORTEX( 24ll, (uint8*)ID$1, 0ll, 1ll, (uint8*)0ull );
-					struct $7ASTNODE* vr$34 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
-					EXPR$1 = vr$34;
+					struct $7ASTNODE* vr$33 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
+					EXPR$1 = vr$33;
 					DTYPE$1 = 8ll;
 					SUBTYPE$1 = (struct $8FBSYMBOL*)0ull;
 				}
-				label$81:;
-				label$80:;
+				label$77:;
+				label$76:;
 			}
-			label$79:;
-			label$78:;
+			label$75:;
+			label$74:;
 		}
-		goto label$74;
-		label$75:;
+		goto label$70;
+		label$71:;
 		{
 			DTYPE$1 = EXPRDTYPE$1;
 			SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)EXPR$1 + 16ll);
 		}
-		label$74:;
-		struct $8FBSYMBOL* vr$38 = SYMBREUSEORADDCONST( (uint8*)ID$1, DTYPE$1, SUBTYPE$1, (union $7FBVALUE*)((uint8*)EXPR$1 + 40ll), ATTRIB$1 );
-		if( vr$38 != (struct $8FBSYMBOL*)0ull ) goto label$83;
+		label$70:;
+		struct $8FBSYMBOL* vr$37 = SYMBREUSEORADDCONST( (uint8*)ID$1, DTYPE$1, SUBTYPE$1, (union $7FBVALUE*)((uint8*)EXPR$1 + 40ll), ATTRIB$1 );
+		if( vr$37 != (struct $8FBSYMBOL*)0ull ) goto label$79;
 		{
 			ERRREPORTEX( 4ll, (uint8*)ID$1, 0ll, 1ll, (uint8*)0ull );
 		}
-		label$83:;
-		label$82:;
+		label$79:;
+		label$78:;
 	}
-	label$64:;
+	label$60:;
 	ASTDELNODE( EXPR$1 );
-	if( DOSKIP$1 == 0ll ) goto label$85;
+	if( DOSKIP$1 == 0ll ) goto label$81;
 	{
 		HSKIPUNTIL( 44ll, 0ll, 0ll, 0ll );
 	}
-	label$85:;
-	label$84:;
+	label$81:;
+	label$80:;
 	label$25:;
 }
