@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $7FBTOKEN;
 struct $7FBTOKEN {
 	int64 ID;
@@ -613,29 +652,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -668,12 +697,23 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
 };
 __FB_STATIC_ASSERT( sizeof( struct $11TSTRSETITEM ) == 32 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
 static void fb_ctor__parserzdeclzenum( void ) __attribute__(( constructor ));
@@ -686,12 +726,12 @@ void ASTDELTREE( struct $7ASTNODE* );
 struct $7ASTNODE* ASTADD( struct $7ASTNODE* );
 int64 ASTCONSTFLUSHTOINT( struct $7ASTNODE*, int64 );
 struct $7ASTNODE* ASTNEWLIT( uint8* );
-struct $8FBSYMBOL* SYMBADDENUM( uint8*, uint8*, int64, int64 );
-struct $8FBSYMBOL* SYMBADDENUMELEMENT( struct $8FBSYMBOL*, uint8*, int64, int64 );
+struct $8FBSYMBOL* SYMBADDENUM( uint8*, uint8*, $13FB_SYMBATTRIB, int64 );
+struct $8FBSYMBOL* SYMBADDENUMELEMENT( struct $8FBSYMBOL*, uint8*, int64, $13FB_SYMBATTRIB );
 int64 SYMBNAMESPACEIMPORT( struct $8FBSYMBOL* );
 void SYMBNESTBEGIN( struct $8FBSYMBOL*, int64 );
 void SYMBNESTEND( int64 );
-uint8* SYMBUNIQUEID( void );
+uint8* SYMBUNIQUEID( boolean );
 uint8* SYMBUNIQUELABEL( void );
 void DZSTRRESET( struct $8DZSTRING* );
 typedef int64 $8LEXCHECK;
@@ -701,13 +741,15 @@ uint8* LEXGETTEXT( void );
 void LEXSKIPTOKEN( $8LEXCHECK );
 int64 CCOMMENT( $8LEXCHECK );
 int64 CSTMTSEPARATOR( $8LEXCHECK );
-void CCURRENTPARENTID( void );
+typedef int64 $15FB_CMPSTMT_MASK;
+int64 CCOMPSTMTISALLOWED( $15FB_CMPSTMT_MASK );
 int64 CASSIGNTOKEN( void );
 struct $7ASTNODE* CEXPRESSION( void );
 uint8* CALIASATTRIBUTE( void );
 void HSKIPUNTIL( int64, int64, $8LEXCHECK, int64 );
+void HSKIPCOMPOUND( int64, int64, $8LEXCHECK );
 static void HENUMCONSTDECL( uint8*, int64* );
-void CENUMBODY( struct $8FBSYMBOL*, int64 );
+void CENUMBODY( struct $8FBSYMBOL*, $13FB_SYMBATTRIB );
 typedef int64 $11AST_OPFLAGS;
 struct $10AST_OPINFO {
 	$13AST_NODECLASS CLASS;
@@ -728,10 +770,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -765,6 +808,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -773,11 +820,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -830,19 +878,8 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -850,20 +887,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -904,8 +943,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -913,8 +955,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -961,6 +1004,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -982,26 +1026,30 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 typedef int64 $8FB_TOKEN;
-typedef int64 $15FB_CMPSTMT_MASK;
 struct $17FB_CMPSTMT_FORELM {
 	struct $8FBSYMBOL* SYM;
 	union $7FBVALUE VALUE;
@@ -1128,6 +1176,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1139,10 +1188,10 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
-void CENUMBODY( struct $8FBSYMBOL* S$1, int64 ATTRIB$1 )
+void CENUMBODY( struct $8FBSYMBOL* S$1, $13FB_SYMBATTRIB ATTRIB$1 )
 {
 	label$21:;
 	static uint8 ID$1[129];
@@ -1160,17 +1209,17 @@ void CENUMBODY( struct $8FBSYMBOL* S$1, int64 ATTRIB$1 )
 		goto label$26;
 		label$27:;
 		{
-			int64 TMP$89$3;
+			int64 TMP$94$3;
 			int64 vr$6 = LEXGETTOKEN( 0ll );
-			TMP$89$3 = vr$6;
-			if( TMP$89$3 != 256ll ) goto label$29;
+			TMP$94$3 = vr$6;
+			if( TMP$94$3 != 256ll ) goto label$29;
 			label$30:;
 			{
 				goto label$24;
 			}
 			goto label$28;
 			label$29:;
-			if( TMP$89$3 != 340ll ) goto label$31;
+			if( TMP$94$3 != 340ll ) goto label$31;
 			label$32:;
 			{
 				goto label$24;
@@ -1181,17 +1230,17 @@ void CENUMBODY( struct $8FBSYMBOL* S$1, int64 ATTRIB$1 )
 				label$34:;
 				{
 					{
-						int64 TMP$90$6;
+						int64 TMP$95$6;
 						int64 vr$7 = LEXGETCLASS( 0ll );
-						TMP$90$6 = vr$7;
-						if( TMP$90$6 != 0ll ) goto label$38;
+						TMP$95$6 = vr$7;
+						if( TMP$95$6 != 0ll ) goto label$38;
 						label$39:;
 						{
-							if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 524288ll) == 0ll ) goto label$41;
+							if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 524288ll) == 0ll ) goto label$41;
 							{
-								if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$43;
+								if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$43;
 								{
-									if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 2096ll) <= 0ll ) goto label$45;
+									if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2096ll) <= 0ll ) goto label$45;
 									{
 										ERRREPORT( 90ll, 0ll, (uint8*)0ull );
 									}
@@ -1208,10 +1257,10 @@ void CENUMBODY( struct $8FBSYMBOL* S$1, int64 ATTRIB$1 )
 						}
 						goto label$37;
 						label$38:;
-						if( TMP$90$6 != 2ll ) goto label$46;
+						if( TMP$95$6 != 2ll ) goto label$46;
 						label$47:;
 						{
-							if( ((int64)-(*(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll)) | (int64)-(*(uint64*)((uint8*)&PARSER$ + 184ll) > 0ull)) == 0ll ) goto label$49;
+							if( ((int64)-(*(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll)) | (int64)-(*(uint64*)((uint8*)&PARSER$ + 192ll) > 0ull)) == 0ll ) goto label$49;
 							{
 								ERRREPORT( 4ll, 0ll, (uint8*)0ull );
 								uint8* vr$17 = SYMBUNIQUELABEL(  );
@@ -1233,7 +1282,7 @@ void CENUMBODY( struct $8FBSYMBOL* S$1, int64 ATTRIB$1 )
 						label$50:;
 						label$37:;
 					}
-					LEXSKIPTOKEN( 0ll );
+					LEXSKIPTOKEN( 2048ll );
 					HENUMCONSTDECL( (uint8*)ID$1, &VALUE$1 );
 					struct $8FBSYMBOL* vr$20 = SYMBADDENUMELEMENT( S$1, (uint8*)ID$1, VALUE$1, ATTRIB$1 );
 					if( vr$20 != (struct $8FBSYMBOL*)0ull ) goto label$52;
@@ -1258,11 +1307,11 @@ void CENUMBODY( struct $8FBSYMBOL* S$1, int64 ATTRIB$1 )
 				CCOMMENT( 0ll );
 				if( *(int64*)((uint8*)&ENV$ + 296ll) == 0ll ) goto label$56;
 				{
-					if( *(int64*)((uint8*)&ENV$ + 1224ll) != 0ll ) goto label$58;
+					if( *(int64*)((uint8*)&ENV$ + 1256ll) != 0ll ) goto label$58;
 					{
-						struct $7ASTNODE* vr$24 = ASTNEWLIT( *(uint8**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 25024ll) );
+						struct $7ASTNODE* vr$24 = ASTNEWLIT( *(uint8**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 25064ll) );
 						ASTADD( vr$24 );
-						DZSTRRESET( (struct $8DZSTRING*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 25024ll) );
+						DZSTRRESET( (struct $8DZSTRING*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 25064ll) );
 					}
 					label$58:;
 					label$57:;
@@ -1285,7 +1334,7 @@ void CENUMBODY( struct $8FBSYMBOL* S$1, int64 ATTRIB$1 )
 	label$25:;
 	goto label$23;
 	label$24:;
-	if( *(int64*)((uint8*)S$1 + 168ll) != 0ll ) goto label$62;
+	if( *(int64*)((uint8*)S$1 + 176ll) != 0ll ) goto label$62;
 	{
 		ERRREPORT( 256ll, 0ll, (uint8*)0ull );
 	}
@@ -1294,155 +1343,163 @@ void CENUMBODY( struct $8FBSYMBOL* S$1, int64 ATTRIB$1 )
 	label$22:;
 }
 
-void CENUMDECL( int64 ATTRIB$1 )
+void CENUMDECL( $13FB_SYMBATTRIB ATTRIB$1 )
 {
 	label$63:;
 	static uint8 ID$1[129];
 	struct $8FBSYMBOL* E$1;
-	LEXSKIPTOKEN( 0ll );
-	CCURRENTPARENTID(  );
+	int64 vr$0 = CCOMPSTMTISALLOWED( 9ll );
+	if( vr$0 != 0ll ) goto label$66;
 	{
-		int64 TMP$91$2;
-		int64 vr$0 = LEXGETCLASS( 0ll );
-		TMP$91$2 = vr$0;
-		if( TMP$91$2 == 0ll ) goto label$67;
-		label$68:;
-		if( TMP$91$2 != 2ll ) goto label$66;
-		label$67:;
+		HSKIPCOMPOUND( 338ll, -1ll, 0ll );
+		goto label$64;
+	}
+	label$66:;
+	label$65:;
+	LEXSKIPTOKEN( 2048ll );
+	{
+		int64 TMP$96$2;
+		int64 vr$1 = LEXGETCLASS( 0ll );
+		TMP$96$2 = vr$1;
+		if( TMP$96$2 == 0ll ) goto label$69;
+		label$70:;
+		if( TMP$96$2 != 2ll ) goto label$68;
+		label$69:;
 		{
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 524288ll) == 0ll ) goto label$70;
+			if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 524288ll) == 0ll ) goto label$72;
 			{
-				if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$72;
+				if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$74;
 				{
-					if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 2096ll) <= 0ll ) goto label$74;
+					if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2096ll) <= 0ll ) goto label$76;
 					{
 						ERRREPORT( 90ll, 0ll, (uint8*)0ull );
 					}
-					label$74:;
-					label$73:;
+					label$76:;
+					label$75:;
 				}
-				label$72:;
-				label$71:;
+				label$74:;
+				label$73:;
 			}
-			label$70:;
-			label$69:;
-			uint8* vr$5 = LEXGETTEXT(  );
-			fb_StrAssign( (void*)ID$1, 129ll, (void*)vr$5, 0ll, 0 );
-			LEXSKIPTOKEN( 0ll );
-		}
-		goto label$65;
-		label$66:;
-		{
-			uint8* vr$6 = SYMBUNIQUEID(  );
+			label$72:;
+			label$71:;
+			uint8* vr$6 = LEXGETTEXT(  );
 			fb_StrAssign( (void*)ID$1, 129ll, (void*)vr$6, 0ll, 0 );
+			LEXSKIPTOKEN( 4096ll );
 		}
-		label$75:;
-		label$65:;
+		goto label$67;
+		label$68:;
+		{
+			uint8* vr$7 = SYMBUNIQUEID( (boolean)0ll );
+			fb_StrAssign( (void*)ID$1, 129ll, (void*)vr$7, 0ll, 0 );
+			ATTRIB$1 = ATTRIB$1 | 16777216ll;
+		}
+		label$77:;
+		label$67:;
 	}
 	uint8* PALIAS$1;
-	uint8* vr$7 = CALIASATTRIBUTE(  );
-	PALIAS$1 = vr$7;
+	uint8* vr$9 = CALIASATTRIBUTE(  );
+	PALIAS$1 = vr$9;
 	int64 ISEXPLICIT$1;
 	ISEXPLICIT$1 = 0ll;
-	int64 vr$8 = LEXGETTOKEN( 0ll );
-	if( vr$8 != 318ll ) goto label$77;
+	int64 vr$10 = LEXGETTOKEN( 0ll );
+	if( vr$10 != 318ll ) goto label$79;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		ISEXPLICIT$1 = -1ll;
 	}
-	label$77:;
-	label$76:;
-	int64 USE_HASHTB$1;
-	USE_HASHTB$1 = (int64)-(*(int64*)((uint8*)&PARSER$ + 192ll) == 0ll);
-	USE_HASHTB$1 = USE_HASHTB$1 | ISEXPLICIT$1;
-	struct $8FBSYMBOL* vr$11 = SYMBADDENUM( (uint8*)ID$1, PALIAS$1, ATTRIB$1, USE_HASHTB$1 );
-	E$1 = vr$11;
-	if( E$1 != (struct $8FBSYMBOL*)0ull ) goto label$79;
-	{
-		ERRREPORTEX( 4ll, (uint8*)ID$1, 0ll, 1ll, (uint8*)0ull );
-		uint8* vr$12 = SYMBUNIQUELABEL(  );
-		struct $8FBSYMBOL* vr$13 = SYMBADDENUM( vr$12, (uint8*)0ull, 0ll, USE_HASHTB$1 );
-		E$1 = vr$13;
-	}
 	label$79:;
 	label$78:;
-	CCOMMENT( 0ll );
-	if( *(int64*)((uint8*)&ENV$ + 296ll) == 0ll ) goto label$81;
+	int64 USE_HASHTB$1;
+	USE_HASHTB$1 = (int64)-(*(int64*)((uint8*)&PARSER$ + 200ll) == 0ll);
+	USE_HASHTB$1 = USE_HASHTB$1 | ISEXPLICIT$1;
+	struct $8FBSYMBOL* vr$13 = SYMBADDENUM( (uint8*)ID$1, PALIAS$1, ATTRIB$1, USE_HASHTB$1 );
+	E$1 = vr$13;
+	if( E$1 != (struct $8FBSYMBOL*)0ull ) goto label$81;
 	{
-		if( *(int64*)((uint8*)&ENV$ + 1224ll) != 0ll ) goto label$83;
-		{
-			struct $7ASTNODE* vr$15 = ASTNEWLIT( *(uint8**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 25024ll) );
-			ASTADD( vr$15 );
-			DZSTRRESET( (struct $8DZSTRING*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 25024ll) );
-		}
-		label$83:;
-		label$82:;
+		ERRREPORTEX( 4ll, (uint8*)ID$1, 0ll, 1ll, (uint8*)0ull );
+		uint8* vr$14 = SYMBUNIQUELABEL(  );
+		struct $8FBSYMBOL* vr$15 = SYMBADDENUM( vr$14, (uint8*)0ull, 0ll, USE_HASHTB$1 );
+		E$1 = vr$15;
 	}
 	label$81:;
 	label$80:;
-	int64 vr$18 = CSTMTSEPARATOR( 0ll );
-	if( vr$18 != 0ll ) goto label$85;
+	CCOMMENT( 0ll );
+	if( *(int64*)((uint8*)&ENV$ + 296ll) == 0ll ) goto label$83;
+	{
+		if( *(int64*)((uint8*)&ENV$ + 1256ll) != 0ll ) goto label$85;
+		{
+			struct $7ASTNODE* vr$17 = ASTNEWLIT( *(uint8**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 25064ll) );
+			ASTADD( vr$17 );
+			DZSTRRESET( (struct $8DZSTRING*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 25064ll) );
+		}
+		label$85:;
+		label$84:;
+	}
+	label$83:;
+	label$82:;
+	int64 vr$20 = CSTMTSEPARATOR( 0ll );
+	if( vr$20 != 0ll ) goto label$87;
 	{
 		ERRREPORT( 17ll, 0ll, (uint8*)0ull );
 		HSKIPUNTIL( -1ll, -1ll, 0ll, 0ll );
 	}
-	label$85:;
-	label$84:;
-	if( USE_HASHTB$1 == 0ll ) goto label$87;
+	label$87:;
+	label$86:;
+	if( USE_HASHTB$1 == 0ll ) goto label$89;
 	{
 		SYMBNESTBEGIN( E$1, 0ll );
 	}
-	label$87:;
-	label$86:;
-	CENUMBODY( E$1, ATTRIB$1 );
-	if( USE_HASHTB$1 == 0ll ) goto label$89;
+	label$89:;
+	label$88:;
+	CENUMBODY( E$1, ATTRIB$1 & -16777217ll );
+	if( USE_HASHTB$1 == 0ll ) goto label$91;
 	{
 		SYMBNESTEND( 0ll );
 	}
-	label$89:;
-	label$88:;
-	int64 vr$19 = LEXGETTOKEN( 0ll );
-	if( vr$19 == 340ll ) goto label$91;
+	label$91:;
+	label$90:;
+	int64 vr$22 = LEXGETTOKEN( 0ll );
+	if( vr$22 == 340ll ) goto label$93;
 	{
 		ERRREPORT( 74ll, 0ll, (uint8*)0ull );
 		HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
 	}
-	goto label$90;
-	label$91:;
+	goto label$92;
+	label$93:;
 	{
-		LEXSKIPTOKEN( 0ll );
-		int64 vr$20 = LEXGETTOKEN( 0ll );
-		if( vr$20 == 338ll ) goto label$93;
+		LEXSKIPTOKEN( 2048ll );
+		int64 vr$23 = LEXGETTOKEN( 0ll );
+		if( vr$23 == 338ll ) goto label$95;
 		{
 			ERRREPORT( 74ll, 0ll, (uint8*)0ull );
 			HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
 		}
-		goto label$92;
-		label$93:;
+		goto label$94;
+		label$95:;
 		{
-			LEXSKIPTOKEN( 0ll );
-			if( ISEXPLICIT$1 != 0ll ) goto label$95;
+			LEXSKIPTOKEN( 2048ll );
+			if( ISEXPLICIT$1 != 0ll ) goto label$97;
 			{
-				if( USE_HASHTB$1 == 0ll ) goto label$97;
+				if( USE_HASHTB$1 == 0ll ) goto label$99;
 				{
 					SYMBNAMESPACEIMPORT( E$1 );
 				}
-				label$97:;
-				label$96:;
+				label$99:;
+				label$98:;
 			}
-			label$95:;
-			label$94:;
+			label$97:;
+			label$96:;
 		}
-		label$92:;
+		label$94:;
 	}
-	label$90:;
+	label$92:;
 	label$64:;
 }
 
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1454,7 +1511,7 @@ static void HENUMCONSTDECL( uint8* ID$1, int64* VALUE$1 )
 	int64 vr$0 = CASSIGNTOKEN(  );
 	if( vr$0 == 0ll ) goto label$13;
 	{
-		int64 TMP$88$2;
+		int64 TMP$93$2;
 		struct $7ASTNODE* vr$1 = CEXPRESSION(  );
 		EXPR$1 = vr$1;
 		if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$15;
@@ -1474,12 +1531,12 @@ static void HENUMCONSTDECL( uint8* ID$1, int64* VALUE$1 )
 		label$17:;
 		label$16:;
 		if( ((*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 480ll) == 0ll ) goto label$18;
-		TMP$88$2 = 24ll;
-		goto label$98;
+		TMP$93$2 = 24ll;
+		goto label$100;
 		label$18:;
-		TMP$88$2 = (*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 31ll;
-		label$98:;
-		if( *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$88$2 * 56ll)) == 0ll ) goto label$20;
+		TMP$93$2 = (*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 31ll;
+		label$100:;
+		if( *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$93$2 * 56ll)) == 0ll ) goto label$20;
 		{
 			ERRREPORTWARN( 5ll, (uint8*)ID$1, 1ll, (uint8*)0ull );
 		}
