@@ -16,6 +16,7 @@ struct $11TSTRSETITEM {
 __FB_STATIC_ASSERT( sizeof( struct $11TSTRSETITEM ) == 32 );
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -182,7 +183,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -328,6 +329,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -337,7 +339,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -346,7 +349,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -357,10 +360,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -369,9 +373,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -470,14 +474,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -499,7 +505,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -510,9 +542,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -573,6 +611,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -602,7 +641,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $7FBTOKEN;
 struct $7FBTOKEN {
 	int64 ID;
@@ -618,29 +657,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -673,7 +702,7 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 FBSTRING* fb_StrInit( void*, int64, void*, int64, int32 );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
@@ -717,10 +746,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -754,6 +784,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -762,11 +796,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -819,7 +854,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -838,20 +873,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -892,8 +929,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -901,8 +941,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -948,6 +989,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -969,29 +1011,34 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 
 void COPTDECL( void )
 {
 	label$10:;
-	if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 33554432ll) != 0ll ) goto label$13;
+	if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 33554432ll) != 0ll ) goto label$13;
 	{
 		ERRREPORTNOTALLOWED( 33554432ll, 146ll, (uint8*)0ull );
 		HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
@@ -1007,87 +1054,87 @@ void COPTDECL( void )
 	}
 	label$15:;
 	label$14:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	{
-		uint64 TMP$88$2;
+		uint64 TMP$93$2;
 		int64 vr$2 = LEXGETTOKEN( 0ll );
-		TMP$88$2 = (uint64)vr$2;
+		TMP$93$2 = (uint64)vr$2;
 		goto label$17;
 		label$18:;
 		{
-			LEXSKIPTOKEN( 0ll );
-			*(int64*)((uint8*)&ENV$ + 1328ll) = 1ll;
+			LEXSKIPTOKEN( 2048ll );
+			*(int64*)((uint8*)&ENV$ + 1488ll) = 1ll;
 		}
 		goto label$16;
 		label$19:;
 		{
-			LEXSKIPTOKEN( 0ll );
-			*(int64*)((uint8*)&ENV$ + 1360ll) = -1ll;
+			LEXSKIPTOKEN( 2048ll );
+			*(int64*)((uint8*)&ENV$ + 1520ll) = -1ll;
 		}
 		goto label$16;
 		label$20:;
 		{
-			LEXSKIPTOKEN( 0ll );
-			*(int64*)((uint8*)&ENV$ + 1360ll) = 0ll;
+			LEXSKIPTOKEN( 2048ll );
+			*(int64*)((uint8*)&ENV$ + 1520ll) = 0ll;
 		}
 		goto label$16;
 		label$21:;
 		{
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 65536ll) != 0ll ) goto label$23;
+			if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 65536ll) != 0ll ) goto label$23;
 			{
 				ERRREPORTNOTALLOWED( 65536ll, 146ll, (uint8*)0ull );
 			}
 			goto label$22;
 			label$23:;
 			{
-				*(int64*)((uint8*)&ENV$ + 1368ll) = -1ll;
+				*(int64*)((uint8*)&ENV$ + 1528ll) = -1ll;
 			}
 			label$22:;
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 		}
 		goto label$16;
 		label$24:;
 		{
 			{
-				FBSTRING TMP$89$4;
+				FBSTRING TMP$94$4;
 				uint8* vr$4 = LEXGETTEXT(  );
 				FBSTRING* vr$5 = fb_StrAllocTempDescZ( (uint8*)vr$4 );
 				FBSTRING* vr$6 = fb_StrUcase2( (FBSTRING*)vr$5, 0 );
-				FBSTRING* vr$8 = fb_StrInit( (void*)&TMP$89$4, -1ll, (void*)vr$6, -1ll, 0 );
-				int32 vr$10 = fb_StrCompare( (void*)&TMP$89$4, -1ll, (void*)"EXPLICIT", 9ll );
-				if( (int64)vr$10 != 0ll ) goto label$26;
+				fb_StrInit( (void*)&TMP$94$4, -1ll, (void*)vr$6, -1ll, 0 );
+				int32 vr$9 = fb_StrCompare( (void*)&TMP$94$4, -1ll, (void*)"EXPLICIT", 9ll );
+				if( (int64)vr$9 != 0ll ) goto label$26;
 				label$27:;
 				{
-					*(int64*)((uint8*)&ENV$ + 1336ll) = -1ll;
-					LEXSKIPTOKEN( 0ll );
+					*(int64*)((uint8*)&ENV$ + 1496ll) = -1ll;
+					LEXSKIPTOKEN( 2048ll );
 				}
 				goto label$25;
 				label$26:;
-				int32 vr$13 = fb_StrCompare( (void*)&TMP$89$4, -1ll, (void*)"PRIVATE", 8ll );
-				if( (int64)vr$13 != 0ll ) goto label$28;
+				int32 vr$12 = fb_StrCompare( (void*)&TMP$94$4, -1ll, (void*)"PRIVATE", 8ll );
+				if( (int64)vr$12 != 0ll ) goto label$28;
 				label$29:;
 				{
-					LEXSKIPTOKEN( 0ll );
-					*(int64*)((uint8*)&ENV$ + 1344ll) = 0ll;
+					LEXSKIPTOKEN( 2048ll );
+					*(int64*)((uint8*)&ENV$ + 1504ll) = 0ll;
 				}
 				goto label$25;
 				label$28:;
-				int32 vr$16 = fb_StrCompare( (void*)&TMP$89$4, -1ll, (void*)"ESCAPE", 7ll );
-				if( (int64)vr$16 != 0ll ) goto label$30;
+				int32 vr$15 = fb_StrCompare( (void*)&TMP$94$4, -1ll, (void*)"ESCAPE", 7ll );
+				if( (int64)vr$15 != 0ll ) goto label$30;
 				label$31:;
 				{
-					LEXSKIPTOKEN( 0ll );
-					*(int64*)((uint8*)&ENV$ + 1352ll) = -1ll;
+					LEXSKIPTOKEN( 2048ll );
+					*(int64*)((uint8*)&ENV$ + 1512ll) = -1ll;
 				}
 				goto label$25;
 				label$30:;
-				int32 vr$19 = fb_StrCompare( (void*)&TMP$89$4, -1ll, (void*)"BASE", 5ll );
-				if( (int64)vr$19 != 0ll ) goto label$32;
+				int32 vr$18 = fb_StrCompare( (void*)&TMP$94$4, -1ll, (void*)"BASE", 5ll );
+				if( (int64)vr$18 != 0ll ) goto label$32;
 				label$33:;
 				{
-					LEXSKIPTOKEN( 0ll );
-					int64 vr$21 = LEXGETCLASS( 0ll );
-					if( vr$21 == 3ll ) goto label$35;
+					LEXSKIPTOKEN( 2048ll );
+					int64 vr$20 = LEXGETCLASS( 0ll );
+					if( vr$20 == 3ll ) goto label$35;
 					{
 						ERRREPORT( 17ll, 0ll, (uint8*)0ull );
 						HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
@@ -1095,26 +1142,26 @@ void COPTDECL( void )
 					goto label$34;
 					label$35:;
 					{
-						uint8* vr$22 = LEXGETTEXT(  );
-						FBSTRING* vr$23 = fb_StrAllocTempDescZ( (uint8*)vr$22 );
-						int32 vr$24 = fb_VALINT( (FBSTRING*)vr$23 );
-						*(int64*)((uint8*)&ENV$ + 1320ll) = (int64)vr$24;
+						uint8* vr$21 = LEXGETTEXT(  );
+						FBSTRING* vr$22 = fb_StrAllocTempDescZ( (uint8*)vr$21 );
+						int32 vr$23 = fb_VALINT( (FBSTRING*)vr$22 );
+						*(int64*)((uint8*)&ENV$ + 1480ll) = (int64)vr$23;
 						LEXSKIPTOKEN( 0ll );
 					}
 					label$34:;
 				}
 				goto label$25;
 				label$32:;
-				int32 vr$27 = fb_StrCompare( (void*)&TMP$89$4, -1ll, (void*)"NOKEYWORD", 10ll );
-				if( (int64)vr$27 != 0ll ) goto label$36;
+				int32 vr$26 = fb_StrCompare( (void*)&TMP$94$4, -1ll, (void*)"NOKEYWORD", 10ll );
+				if( (int64)vr$26 != 0ll ) goto label$36;
 				label$37:;
 				{
-					LEXSKIPTOKEN( 2ll );
+					LEXSKIPTOKEN( 2050ll );
 					label$38:;
 					{
 						HUNDEFSYMBOL(  );
-						int64 vr$29 = LEXGETTOKEN( 0ll );
-						if( vr$29 == 44ll ) goto label$42;
+						int64 vr$28 = LEXGETTOKEN( 0ll );
+						if( vr$28 == 44ll ) goto label$42;
 						{
 							goto label$39;
 						}
@@ -1128,21 +1175,21 @@ void COPTDECL( void )
 				}
 				goto label$25;
 				label$36:;
-				int32 vr$31 = fb_StrCompare( (void*)&TMP$89$4, -1ll, (void*)"NOGOSUB", 8ll );
-				if( (int64)vr$31 != 0ll ) goto label$43;
+				int32 vr$30 = fb_StrCompare( (void*)&TMP$94$4, -1ll, (void*)"NOGOSUB", 8ll );
+				if( (int64)vr$30 != 0ll ) goto label$43;
 				label$44:;
 				{
-					if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 65536ll) != 0ll ) goto label$46;
+					if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 65536ll) != 0ll ) goto label$46;
 					{
 						ERRREPORTNOTALLOWED( 65536ll, 146ll, (uint8*)0ull );
 					}
 					goto label$45;
 					label$46:;
 					{
-						*(int64*)((uint8*)&ENV$ + 1368ll) = 0ll;
+						*(int64*)((uint8*)&ENV$ + 1528ll) = 0ll;
 					}
 					label$45:;
-					LEXSKIPTOKEN( 0ll );
+					LEXSKIPTOKEN( 2048ll );
 				}
 				goto label$25;
 				label$43:;
@@ -1151,12 +1198,12 @@ void COPTDECL( void )
 				}
 				label$47:;
 				label$25:;
-				fb_StrDelete( (FBSTRING*)&TMP$89$4 );
+				fb_StrDelete( (FBSTRING*)&TMP$94$4 );
 			}
 		}
 		goto label$16;
 		label$17:;
-		static const void* tmp$96[86ll] = {
+		static const void* tmp$101[87ll] = {
 			&&label$20,
 			&&label$24,
 			&&label$24,
@@ -1242,10 +1289,11 @@ void COPTDECL( void )
 			&&label$24,
 			&&label$24,
 			&&label$24,
+			&&label$24,
 			&&label$21,
 		};
-		if( (TMP$88$2 - 307ull) > 85ull ) goto label$24;
-		goto *tmp$96[TMP$88$2 - 307ull];
+		if( (TMP$93$2 - 307ull) > 86ull ) goto label$24;
+		goto *tmp$101[TMP$93$2 - 307ull];
 		label$16:;
 	}
 	label$11:;
@@ -1254,7 +1302,7 @@ void COPTDECL( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1265,13 +1313,13 @@ static void HUNDEFSYMBOL( void )
 	struct $8FBSYMBOL* S$1;
 	__builtin_memset( &S$1, 0, 8ll );
 	{
-		uint64 TMP$97$2;
+		uint64 TMP$102$2;
 		int64 vr$1 = LEXGETCLASS( 2ll );
-		TMP$97$2 = (uint64)vr$1;
+		TMP$102$2 = (uint64)vr$1;
 		goto label$51;
 		label$52:;
 		{
-			S$1 = *(struct $8FBSYMBOL**)*(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 2088ll);
+			S$1 = *(struct $8FBSYMBOL**)*(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2088ll);
 			if( S$1 == (struct $8FBSYMBOL*)0ull ) goto label$54;
 			{
 				SYMBDELFROMHASH( S$1 );
@@ -1287,25 +1335,25 @@ static void HUNDEFSYMBOL( void )
 		goto label$50;
 		label$55:;
 		{
-			struct $8FBSYMBOL* vr$7 = SYMBFINDBYCLASS( *(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 2088ll), 3ll );
+			struct $8FBSYMBOL* vr$7 = SYMBFINDBYCLASS( *(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2088ll), 3ll );
 			S$1 = vr$7;
 			if( S$1 == (struct $8FBSYMBOL*)0ull ) goto label$57;
 			{
-				if( (*(int64*)((uint8*)S$1 + 16ll) & 32ll) != 0ll ) goto label$59;
+				if( (*(int64*)((uint8*)S$1 + 24ll) & 32ll) != 0ll ) goto label$59;
 				{
 					ERRREPORT( 14ll, 0ll, (uint8*)0ull );
 				}
 				goto label$58;
 				label$59:;
 				{
-					if( *(struct $8FBSYMBOL**)*(struct $8FBHASHTB**)((uint8*)S$1 + 232ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$61;
+					if( *(struct $8FBSYMBOL**)*(struct $8FBHASHTB**)((uint8*)S$1 + 248ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$61;
 					{
 						ERRREPORT( 123ll, 0ll, (uint8*)0ull );
 					}
 					goto label$60;
 					label$61:;
 					{
-						if( (*(int64*)((uint8*)S$1 + 16ll) & 8388608ll) == 0ll ) goto label$63;
+						if( (*(int64*)((uint8*)S$1 + 24ll) & 8388608ll) == 0ll ) goto label$63;
 						{
 							ERRREPORT( 177ll, 0ll, (uint8*)0ull );
 						}
@@ -1323,7 +1371,7 @@ static void HUNDEFSYMBOL( void )
 			goto label$56;
 			label$57:;
 			{
-				struct $8FBSYMBOL* vr$17 = SYMBFINDBYCLASS( *(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 2088ll), 5ll );
+				struct $8FBSYMBOL* vr$17 = SYMBFINDBYCLASS( *(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2088ll), 5ll );
 				S$1 = vr$17;
 				if( S$1 != (struct $8FBSYMBOL*)0ull ) goto label$65;
 				{
@@ -1332,14 +1380,14 @@ static void HUNDEFSYMBOL( void )
 				goto label$64;
 				label$65:;
 				{
-					if( *(struct $8FBSYMBOL**)*(struct $8FBHASHTB**)((uint8*)S$1 + 232ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$67;
+					if( *(struct $8FBSYMBOL**)*(struct $8FBHASHTB**)((uint8*)S$1 + 248ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$67;
 					{
 						ERRREPORT( 123ll, 0ll, (uint8*)0ull );
 					}
 					goto label$66;
 					label$67:;
 					{
-						if( (*(int64*)((uint8*)S$1 + 16ll) & 8388608ll) == 0ll ) goto label$69;
+						if( (*(int64*)((uint8*)S$1 + 24ll) & 8388608ll) == 0ll ) goto label$69;
 						{
 							ERRREPORT( 177ll, 0ll, (uint8*)0ull );
 						}
@@ -1365,13 +1413,13 @@ static void HUNDEFSYMBOL( void )
 		}
 		goto label$50;
 		label$51:;
-		static const void* tmp$98[3ll] = {
+		static const void* tmp$103[3ll] = {
 			&&label$55,
 			&&label$52,
 			&&label$52,
 		};
-		if( TMP$97$2 > 2ull ) goto label$70;
-		goto *tmp$98[TMP$97$2 - 0ull];
+		if( TMP$102$2 > 2ull ) goto label$70;
+		goto *tmp$103[TMP$102$2 - 0ull];
 		label$50:;
 	}
 	label$49:;
