@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -610,6 +649,26 @@ struct $16__FB_ARRAYDIMTB$ {
 	int64 UBOUND;
 };
 __FB_STATIC_ASSERT( sizeof( struct $16__FB_ARRAYDIMTB$ ) == 24 );
+struct $8FBARRAY1IcE {
+	uint8* DATA;
+	uint8* PTR;
+	int64 SIZE;
+	int64 ELEMENT_LEN;
+	int64 DIMENSIONS;
+	int64 FLAGS;
+	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
+};
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IcE ) == 72 );
+struct $8FBARRAY2IP7ASTNODEE {
+	struct $7ASTNODE** DATA;
+	struct $7ASTNODE** PTR;
+	int64 SIZE;
+	int64 ELEMENT_LEN;
+	int64 DIMENSIONS;
+	int64 FLAGS;
+	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
+};
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2IP7ASTNODEE ) == 96 );
 struct $7FBTOKEN;
 struct $7FBTOKEN {
 	int64 ID;
@@ -625,29 +684,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -680,16 +729,17 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 struct $7FBARRAYIP7ASTNODEE {
 	struct $7ASTNODE** DATA;
 	struct $7ASTNODE** PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[8];
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYIP7ASTNODEE ) == 232 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYIP7ASTNODEE ) == 240 );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
 static void fb_ctor__parserzdeclzproczparams( void ) __attribute__(( constructor ));
@@ -705,18 +755,19 @@ void ASTDELTREE( struct $7ASTNODE* );
 struct $7ASTNODE* ASTNEWCONSTI( int64, int64, struct $8FBSYMBOL* );
 void ASTFORGETBITFIELDS( struct $7ASTNODE* );
 int64 ASTTYPEINIUSESLOCALS( struct $7ASTNODE*, int64 );
-struct $8FBSYMBOL* SYMBADDPROCPARAM( struct $8FBSYMBOL*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, $13FB_SYMBATTRIB );
+struct $8FBSYMBOL* SYMBADDPROCPARAM( struct $8FBSYMBOL*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, $13FB_SYMBATTRIB, $13FB_PROCATTRIB );
 void SYMBMAKEPARAMOPTIONAL( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $7ASTNODE* );
 void SYMBADDPROCINSTANCEPARAM( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
 int64 SYMBGETDEFTYPE( uint8* );
 int64 SYMBGETDEFAULTPARAMMODE( int64, struct $8FBSYMBOL* );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 int64 LEXGETCLASS( $8LEXCHECK );
 uint8* LEXGETTEXT( void );
 void LEXSKIPTOKEN( $8LEXCHECK );
 int64 LEXGETLOOKAHEAD( int64, $8LEXCHECK );
+void LEXCHECKTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 void CARRAYDECL( int64*, int64*, struct $7FBARRAYIP7ASTNODEE* );
 typedef int64 $9FB_INIOPT;
 struct $7ASTNODE* CINITIALIZER( struct $8FBSYMBOL*, $9FB_INIOPT, int64, struct $8FBSYMBOL* );
@@ -744,10 +795,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -765,20 +817,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -819,8 +873,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -828,8 +885,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -875,6 +933,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -896,23 +955,28 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 
 void CPARAMETERS( struct $8FBSYMBOL* PARENT$1, struct $8FBSYMBOL* PROC$1, int64 PROCMODE$1, int64 ISPROTO$1 )
@@ -920,10 +984,10 @@ void CPARAMETERS( struct $8FBSYMBOL* PARENT$1, struct $8FBSYMBOL* PROC$1, int64
 	label$10:;
 	int64 LENGTH$1;
 	LENGTH$1 = 0ll;
-	if( (*(int64*)((uint8*)PROC$1 + 8ll) & 2048ll) == 0ll ) goto label$13;
+	if( (*(int64*)((uint8*)PROC$1 + 16ll) & 2ll) == 0ll ) goto label$13;
 	{
 		SYMBADDPROCINSTANCEPARAM( PARENT$1, PROC$1 );
-		LENGTH$1 = LENGTH$1 + *(int64*)((uint8*)&ENV$ + 544ll);
+		LENGTH$1 = LENGTH$1 + *(int64*)((uint8*)&ENV$ + 576ll);
 	}
 	label$13:;
 	label$12:;
@@ -954,8 +1018,8 @@ void CPARAMETERS( struct $8FBSYMBOL* PARENT$1, struct $8FBSYMBOL* PROC$1, int64
 		}
 		label$22:;
 		label$21:;
-		LENGTH$1 = LENGTH$1 + *(int64*)((uint8*)PARAM$2 + 72ll);
-		if( *(int64*)((uint8*)PARAM$2 + 88ll) != 4ll ) goto label$24;
+		LENGTH$1 = LENGTH$1 + *(int64*)((uint8*)PARAM$2 + 80ll);
+		if( *(int64*)((uint8*)PARAM$2 + 96ll) != 4ll ) goto label$24;
 		{
 			goto label$19;
 		}
@@ -985,9 +1049,9 @@ void CPARAMETERS( struct $8FBSYMBOL* PARENT$1, struct $8FBSYMBOL* PROC$1, int64
 		LEXSKIPTOKEN( 0ll );
 	}
 	label$27:;
-	if( LENGTH$1 <= (*(int64*)((uint8*)&ENV$ + 544ll) << (6ll & 63ll)) ) goto label$30;
+	if( LENGTH$1 <= (*(int64*)((uint8*)&ENV$ + 576ll) << (6ll & 63ll)) ) goto label$30;
 	{
-		ERRREPORTWARN( 18ll, (uint8*)*(uint8**)((uint8*)PROC$1 + 24ll), 1ll, (uint8*)0ull );
+		ERRREPORTWARN( 18ll, (uint8*)*(uint8**)((uint8*)PROC$1 + 32ll), 1ll, (uint8*)0ull );
 	}
 	label$30:;
 	label$29:;
@@ -997,7 +1061,7 @@ void CPARAMETERS( struct $8FBSYMBOL* PARENT$1, struct $8FBSYMBOL* PROC$1, int64
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1005,14 +1069,14 @@ static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TS
 static void HPARAMERROR( struct $8FBSYMBOL* PROC$1, uint8* PID$1, $9FB_ERRMSG MSGNUM$1, int64 DELTA$1 )
 {
 	label$31:;
-	ERRREPORTPARAM( PROC$1, (int64)*(int16*)((uint8*)PROC$1 + 112ll) + DELTA$1, PID$1, MSGNUM$1 );
+	ERRREPORTPARAM( PROC$1, (int64)*(int16*)((uint8*)PROC$1 + 120ll) + DELTA$1, PID$1, MSGNUM$1 );
 	label$32:;
 }
 
 static void HPARAMWARNING( struct $8FBSYMBOL* PROC$1, uint8* PID$1, $9FB_ERRMSG MSGNUM$1, int64 DELTA$1 )
 {
 	label$33:;
-	ERRREPORTPARAMWARN( PROC$1, (int64)*(int16*)((uint8*)PROC$1 + 112ll) + DELTA$1, PID$1, MSGNUM$1 );
+	ERRREPORTPARAMWARN( PROC$1, (int64)*(int16*)((uint8*)PROC$1 + 120ll) + DELTA$1, PID$1, MSGNUM$1 );
 	label$34:;
 }
 
@@ -1024,9 +1088,9 @@ static struct $7ASTNODE* HOPTIONALEXPR( struct $8FBSYMBOL* PROC$1, uint8* PID$1,
 	struct $7ASTNODE* EXPR$1;
 	int64 INIOPTIONS$1;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	if( *(int64*)((uint8*)PARAM$1 + 88ll) == 1ll ) goto label$38;
+	if( *(int64*)((uint8*)PARAM$1 + 96ll) == 1ll ) goto label$38;
 	{
-		if( *(int64*)((uint8*)PARAM$1 + 88ll) == 2ll ) goto label$40;
+		if( *(int64*)((uint8*)PARAM$1 + 96ll) == 2ll ) goto label$40;
 		{
 			goto label$36;
 		}
@@ -1036,11 +1100,11 @@ static struct $7ASTNODE* HOPTIONALEXPR( struct $8FBSYMBOL* PROC$1, uint8* PID$1,
 	label$38:;
 	label$37:;
 	{
-		int64 TMP$88$2;
-		TMP$88$2 = *(int64*)((uint8*)PARAM$1 + 48ll) & 511ll;
-		if( TMP$88$2 == 0ll ) goto label$43;
+		int64 TMP$93$2;
+		TMP$93$2 = *(int64*)((uint8*)PARAM$1 + 56ll) & 511ll;
+		if( TMP$93$2 == 0ll ) goto label$43;
 		label$44:;
-		if( TMP$88$2 != 23ll ) goto label$42;
+		if( TMP$93$2 != 23ll ) goto label$42;
 		label$43:;
 		{
 			ERRREPORT( 71ll, 0ll, (uint8*)0ull );
@@ -1061,7 +1125,7 @@ static struct $7ASTNODE* HOPTIONALEXPR( struct $8FBSYMBOL* PROC$1, uint8* PID$1,
 	label$46:;
 	label$45:;
 	ASTFORGETBITFIELDS( EXPR$1 );
-	int64 vr$7 = ASTTYPEINIUSESLOCALS( EXPR$1, 12582912ll );
+	int64 vr$7 = ASTTYPEINIUSESLOCALS( EXPR$1, 12288ll );
 	if( vr$7 == 0ll ) goto label$48;
 	{
 		HPARAMERROR( PROC$1, PID$1, 272ll, 0ll );
@@ -1077,14 +1141,14 @@ static struct $7ASTNODE* HOPTIONALEXPR( struct $8FBSYMBOL* PROC$1, uint8* PID$1,
 
 static struct $8FBSYMBOL* HMOCKPARAM( struct $8FBSYMBOL* PROC$1, int64 PMODE$1 )
 {
-	int64 TMP$89$1;
+	int64 TMP$94$1;
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$49:;
 	int64 DTYPE$1;
 	if( PMODE$1 != -1ll ) goto label$52;
 	{
-		PMODE$1 = *(int64*)((uint8*)&ENV$ + 1328ll);
+		PMODE$1 = *(int64*)((uint8*)&ENV$ + 1488ll);
 	}
 	label$52:;
 	label$51:;
@@ -1099,12 +1163,12 @@ static struct $8FBSYMBOL* HMOCKPARAM( struct $8FBSYMBOL* PROC$1, int64 PMODE$1 )
 	}
 	label$53:;
 	if( PMODE$1 != 3ll ) goto label$55;
-	TMP$89$1 = -1ll;
-	goto label$165;
+	TMP$94$1 = -1ll;
+	goto label$161;
 	label$55:;
-	TMP$89$1 = 0ll;
-	label$165:;
-	struct $8FBSYMBOL* vr$1 = SYMBADDPROCPARAM( PROC$1, (uint8*)0ull, DTYPE$1, (struct $8FBSYMBOL*)0ull, TMP$89$1, PMODE$1, 0ll );
+	TMP$94$1 = 0ll;
+	label$161:;
+	struct $8FBSYMBOL* vr$1 = SYMBADDPROCPARAM( PROC$1, (uint8*)0ull, DTYPE$1, (struct $8FBSYMBOL*)0ull, TMP$94$1, PMODE$1, 0ll, 0ll );
 	fb$result$1 = vr$1;
 	label$50:;
 	return fb$result$1;
@@ -1112,21 +1176,12 @@ static struct $8FBSYMBOL* HMOCKPARAM( struct $8FBSYMBOL* PROC$1, int64 PMODE$1 )
 
 static struct $8FBSYMBOL* HPARAMDECL( struct $8FBSYMBOL* PROC$1, int64 PROC_MODE$1, int64 ISPROTO$1 )
 {
-	uint8* TMP$100$1;
+	uint8* TMP$105$1;
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$56:;
 	static uint8 IDTB$1[8][129];
-	struct $8FBARRAY1IcE {
-		uint8* DATA;
-		uint8* PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IcE ) == 64 );
-	static struct $8FBARRAY1IcE tmp$90$1 = { (uint8*)IDTB$1, (uint8*)IDTB$1, 1032ll, 129ll, 1ll, { { 8ll, 0ll, 7ll } } };
+	static struct $8FBARRAY1IcE tmp$95$1 = { (uint8*)IDTB$1, (uint8*)IDTB$1, 1032ll, 129ll, 1ll, 49ll, { { 8ll, 0ll, 7ll } } };
 	static int64 RECLEVEL$1 = 0ll;
 	uint8* ID$1;
 	int64 DTYPE$1;
@@ -1141,16 +1196,7 @@ static struct $8FBSYMBOL* HPARAMDECL( struct $8FBSYMBOL* PROC$1, int64 PROC_MODE
 	struct $8FBSYMBOL* SUBTYPE$1;
 	struct $8FBSYMBOL* PARAM$1;
 	static struct $7ASTNODE* EXPRTB$1[8][2];
-	struct $8FBARRAY2IP7ASTNODEE {
-		struct $7ASTNODE** DATA;
-		struct $7ASTNODE** PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[2];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2IP7ASTNODEE ) == 88 );
-	static struct $8FBARRAY2IP7ASTNODEE tmp$91$1 = { (struct $7ASTNODE**)EXPRTB$1, (struct $7ASTNODE**)EXPRTB$1, 128ll, 8ll, 2ll, { { 8ll, 0ll, 7ll }, { 2ll, 0ll, 1ll } } };
+	static struct $8FBARRAY2IP7ASTNODEE tmp$96$1 = { (struct $7ASTNODE**)EXPRTB$1, (struct $7ASTNODE**)EXPRTB$1, 128ll, 8ll, 2ll, 50ll, { { 8ll, 0ll, 7ll }, { 2ll, 0ll, 1ll } } };
 	fb$result$1 = (struct $8FBSYMBOL*)0ull;
 	ATTRIB$1 = 0ll;
 	int64 vr$1 = LEXGETTOKEN( 0ll );
@@ -1174,7 +1220,7 @@ static struct $8FBSYMBOL* HPARAMDECL( struct $8FBSYMBOL* PROC$1, int64 PROC_MODE
 				LEXSKIPTOKEN( 0ll );
 			}
 			label$62:;
-			if( (int64)*(int16*)((uint8*)PROC$1 + 112ll) != 0ll ) goto label$65;
+			if( (int64)*(int16*)((uint8*)PROC$1 + 120ll) != 0ll ) goto label$65;
 			{
 				HPARAMERROR( PROC$1, (uint8*)"...", 313ll, 1ll );
 				struct $8FBSYMBOL* vr$6 = HMOCKPARAM( PROC$1, 4ll );
@@ -1192,7 +1238,7 @@ static struct $8FBSYMBOL* HPARAMDECL( struct $8FBSYMBOL* PROC$1, int64 PROC_MODE
 			}
 			label$67:;
 			label$66:;
-			struct $8FBSYMBOL* vr$8 = SYMBADDPROCPARAM( PROC$1, (uint8*)0ull, 2147483648ll, (struct $8FBSYMBOL*)0ull, 0ll, 4ll, 0ll );
+			struct $8FBSYMBOL* vr$8 = SYMBADDPROCPARAM( PROC$1, (uint8*)0ull, 2147483648ll, (struct $8FBSYMBOL*)0ull, 0ll, 4ll, 0ll, 0ll );
 			fb$result$1 = vr$8;
 			goto label$57;
 		}
@@ -1210,22 +1256,22 @@ static struct $8FBSYMBOL* HPARAMDECL( struct $8FBSYMBOL* PROC$1, int64 PROC_MODE
 	label$59:;
 	label$58:;
 	{
-		int64 TMP$93$2;
+		int64 TMP$98$2;
 		int64 vr$10 = LEXGETTOKEN( 0ll );
-		TMP$93$2 = vr$10;
-		if( TMP$93$2 != 319ll ) goto label$69;
+		TMP$98$2 = vr$10;
+		if( TMP$98$2 != 319ll ) goto label$69;
 		label$70:;
 		{
 			MODE$1 = 1ll;
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 		}
 		goto label$68;
 		label$69:;
-		if( TMP$93$2 != 320ll ) goto label$71;
+		if( TMP$98$2 != 320ll ) goto label$71;
 		label$72:;
 		{
 			MODE$1 = 2ll;
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 		}
 		goto label$68;
 		label$71:;
@@ -1236,19 +1282,19 @@ static struct $8FBSYMBOL* HPARAMDECL( struct $8FBSYMBOL* PROC$1, int64 PROC_MODE
 		label$68:;
 	}
 	{
-		int64 TMP$94$2;
+		int64 TMP$99$2;
 		int64 vr$11 = LEXGETCLASS( 0ll );
-		TMP$94$2 = vr$11;
-		if( TMP$94$2 != 0ll ) goto label$75;
+		TMP$99$2 = vr$11;
+		if( TMP$99$2 != 0ll ) goto label$75;
 		label$76:;
 		{
 			READID$1 = -1ll;
 		}
 		goto label$74;
 		label$75:;
-		if( TMP$94$2 == 1ll ) goto label$78;
+		if( TMP$99$2 == 1ll ) goto label$78;
 		label$79:;
-		if( TMP$94$2 != 2ll ) goto label$77;
+		if( TMP$99$2 != 2ll ) goto label$77;
 		label$78:;
 		{
 			if( ISPROTO$1 != 0ll ) goto label$81;
@@ -1295,25 +1341,15 @@ static struct $8FBSYMBOL* HPARAMDECL( struct $8FBSYMBOL* PROC$1, int64 PROC_MODE
 	}
 	label$86:;
 	label$85:;
-	ID$1 = (uint8*)((uint8*)IDTB$1 + (RECLEVEL$1 * 129ll));
+	ID$1 = (uint8*)((int64)(uint8*)IDTB$1 + (RECLEVEL$1 * 129ll));
 	fb_StrAssign( (void*)ID$1, 0ll, (void*)"", 1ll, 0 );
 	if( READID$1 == 0ll ) goto label$88;
 	{
 		uint8* vr$25 = LEXGETTEXT(  );
 		fb_StrAssign( (void*)ID$1, 0ll, (void*)vr$25, 0ll, 0 );
-		DOTPOS$1 = *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 2096ll);
-		DTYPE$1 = *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 16ll);
-		if( DTYPE$1 == 2147483648ll ) goto label$90;
-		{
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 8388608ll) != 0ll ) goto label$92;
-			{
-				ERRREPORTNOTALLOWED( 8388608ll, 148ll, (uint8*)0ull );
-			}
-			label$92:;
-			label$91:;
-		}
-		label$90:;
-		label$89:;
+		DOTPOS$1 = *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2096ll);
+		LEXCHECKTOKEN( 4096ll );
+		DTYPE$1 = *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 16ll);
 		LEXSKIPTOKEN( 0ll );
 	}
 	goto label$87;
@@ -1324,321 +1360,321 @@ static struct $8FBSYMBOL* HPARAMDECL( struct $8FBSYMBOL* PROC$1, int64 PROC_MODE
 	label$87:;
 	DIMENSIONS$1 = 0ll;
 	HAVE_BOUNDS$1 = 0ll;
-	int64 vr$31 = LEXGETTOKEN( 0ll );
-	if( vr$31 != 40ll ) goto label$94;
+	int64 vr$30 = LEXGETTOKEN( 0ll );
+	if( vr$30 != 40ll ) goto label$90;
 	{
 		LEXSKIPTOKEN( 0ll );
-		if( MODE$1 == -1ll ) goto label$96;
+		if( MODE$1 == -1ll ) goto label$92;
 		{
 			HPARAMERROR( PROC$1, ID$1, 59ll, 1ll );
 		}
-		label$96:;
-		label$95:;
+		label$92:;
+		label$91:;
 		MODE$1 = 3ll;
-		int64 vr$32 = LEXGETTOKEN( 0ll );
-		if( vr$32 != 41ll ) goto label$98;
+		int64 vr$31 = LEXGETTOKEN( 0ll );
+		if( vr$31 != 41ll ) goto label$94;
 		{
 			DIMENSIONS$1 = -1ll;
 		}
-		goto label$97;
-		label$98:;
+		goto label$93;
+		label$94:;
 		{
-			CARRAYDECL( &DIMENSIONS$1, &HAVE_BOUNDS$1, (struct $7FBARRAYIP7ASTNODEE*)&tmp$91$1 );
-			if( HAVE_BOUNDS$1 == 0ll ) goto label$100;
+			CARRAYDECL( &DIMENSIONS$1, &HAVE_BOUNDS$1, (struct $7FBARRAYIP7ASTNODEE*)&tmp$96$1 );
+			if( HAVE_BOUNDS$1 == 0ll ) goto label$96;
 			{
 				HPARAMERROR( PROC$1, ID$1, 59ll, 1ll );
 			}
-			label$100:;
-			label$99:;
+			label$96:;
+			label$95:;
 		}
-		label$97:;
-		int64 vr$35 = HMATCH( 41ll );
-		if( vr$35 != 0ll ) goto label$102;
+		label$93:;
+		int64 vr$34 = HMATCH( 41ll, 0ll );
+		if( vr$34 != 0ll ) goto label$98;
 		{
 			ERRREPORT( 7ll, 0ll, (uint8*)0ull );
 		}
+		label$98:;
+		label$97:;
+	}
+	label$90:;
+	label$89:;
+	USE_DEFAULT$1 = 0ll;
+	if( MODE$1 != -1ll ) goto label$100;
+	{
+		MODE$1 = *(int64*)((uint8*)&ENV$ + 1488ll);
+		USE_DEFAULT$1 = -1ll;
+		if( (*(int64*)((uint8*)&ENV$ + 392ll) & 2ll) == 0ll ) goto label$102;
+		{
+			HPARAMWARNING( PROC$1, ID$1, 15ll, 1ll );
+		}
 		label$102:;
 		label$101:;
 	}
-	label$94:;
-	label$93:;
-	USE_DEFAULT$1 = 0ll;
-	if( MODE$1 != -1ll ) goto label$104;
-	{
-		MODE$1 = *(int64*)((uint8*)&ENV$ + 1328ll);
-		USE_DEFAULT$1 = -1ll;
-		if( (*(int64*)((uint8*)&ENV$ + 392ll) & 2ll) == 0ll ) goto label$106;
-		{
-			HPARAMWARNING( PROC$1, ID$1, 15ll, 1ll );
-		}
-		label$106:;
-		label$105:;
-	}
-	label$104:;
-	label$103:;
+	label$100:;
+	label$99:;
 	DOSKIP$1 = 0ll;
-	int64 vr$37 = LEXGETTOKEN( 0ll );
-	if( vr$37 != 376ll ) goto label$108;
+	int64 vr$36 = LEXGETTOKEN( 0ll );
+	if( vr$36 != 376ll ) goto label$104;
 	{
-		int64 TMP$95$2;
-		int64 TMP$96$2;
-		LEXSKIPTOKEN( 0ll );
-		if( DTYPE$1 == 2147483648ll ) goto label$110;
+		int64 TMP$100$2;
+		int64 TMP$101$2;
+		LEXSKIPTOKEN( 2048ll );
+		if( DTYPE$1 == 2147483648ll ) goto label$106;
 		{
 			HPARAMERROR( PROC$1, ID$1, 59ll, 1ll );
 			goto label$57;
 		}
-		label$110:;
-		label$109:;
+		label$106:;
+		label$105:;
 		RECLEVEL$1 = RECLEVEL$1 + 1ll;
 		int64 OPTIONS$2;
 		OPTIONS$2 = 1ll;
-		if( MODE$1 != 2ll ) goto label$112;
+		if( MODE$1 != 2ll ) goto label$108;
 		{
-			if( ISPROTO$1 == 0ll ) goto label$114;
+			if( ISPROTO$1 == 0ll ) goto label$110;
 			{
 				OPTIONS$2 = OPTIONS$2 | 2ll;
 			}
-			label$114:;
-			label$113:;
+			label$110:;
+			label$109:;
 			OPTIONS$2 = OPTIONS$2 & -2ll;
 			OPTIONS$2 = OPTIONS$2 | 4ll;
 		}
-		label$112:;
-		label$111:;
-		TMP$96$2 = 0ll;
-		TMP$95$2 = 0ll;
-		int64 vr$46 = CSYMBOLTYPE( &DTYPE$1, &SUBTYPE$1, &TMP$95$2, &TMP$96$2, OPTIONS$2 );
-		if( vr$46 != 0ll ) goto label$116;
+		label$108:;
+		label$107:;
+		TMP$101$2 = 0ll;
+		TMP$100$2 = 0ll;
+		int64 vr$45 = CSYMBOLTYPE( &DTYPE$1, &SUBTYPE$1, &TMP$100$2, &TMP$101$2, OPTIONS$2 );
+		if( vr$45 != 0ll ) goto label$112;
 		{
 			HPARAMERROR( PROC$1, ID$1, 59ll, 1ll );
 			DTYPE$1 = 8ll;
 			SUBTYPE$1 = (struct $8FBSYMBOL*)0ull;
 			DOSKIP$1 = -1ll;
 		}
-		label$116:;
-		label$115:;
-		if( MODE$1 != 1ll ) goto label$118;
+		label$112:;
+		label$111:;
+		if( MODE$1 != 1ll ) goto label$114;
 		{
 			HCOMPLAINIFABSTRACTCLASS( DTYPE$1, SUBTYPE$1 );
 		}
-		label$118:;
-		label$117:;
+		label$114:;
+		label$113:;
 		RECLEVEL$1 = RECLEVEL$1 + -1ll;
 	}
-	goto label$107;
-	label$108:;
+	goto label$103;
+	label$104:;
 	{
-		if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 4194304ll) != 0ll ) goto label$120;
+		if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 4194304ll) != 0ll ) goto label$116;
 		{
 			ERRREPORTNOTALLOWED( 4194304ll, 147ll, (uint8*)0ull );
 			DOSKIP$1 = -1ll;
 		}
-		goto label$119;
-		label$120:;
+		goto label$115;
+		label$116:;
 		{
-			if( READID$1 != 0ll ) goto label$122;
+			if( READID$1 != 0ll ) goto label$118;
 			{
 				HPARAMERROR( PROC$1, (uint8*)0ull, 59ll, 1ll );
 				DOSKIP$1 = -1ll;
 			}
-			label$122:;
-			label$121:;
+			label$118:;
+			label$117:;
 		}
-		label$119:;
+		label$115:;
 		SUBTYPE$1 = (struct $8FBSYMBOL*)0ull;
-		ATTRIB$1 = ATTRIB$1 | 268435456ll;
+		ATTRIB$1 = ATTRIB$1 | 1048576ll;
 	}
-	label$107:;
-	if( *(int64*)((uint8*)&ENV$ + 272ll) != 0ll ) goto label$124;
+	label$103:;
+	if( *(int64*)((uint8*)&ENV$ + 272ll) != 0ll ) goto label$120;
 	{
-		if( USE_DEFAULT$1 == 0ll ) goto label$126;
+		if( USE_DEFAULT$1 == 0ll ) goto label$122;
 		{
-			int64 vr$50 = SYMBGETDEFAULTPARAMMODE( DTYPE$1, SUBTYPE$1 );
-			MODE$1 = vr$50;
+			int64 vr$49 = SYMBGETDEFAULTPARAMMODE( DTYPE$1, SUBTYPE$1 );
+			MODE$1 = vr$49;
 		}
-		label$126:;
-		label$125:;
+		label$122:;
+		label$121:;
+	}
+	label$120:;
+	label$119:;
+	if( DTYPE$1 != 2147483648ll ) goto label$124;
+	{
+		int64 vr$50 = SYMBGETDEFTYPE( (uint8*)ID$1 );
+		DTYPE$1 = vr$50;
 	}
 	label$124:;
 	label$123:;
-	if( DTYPE$1 != 2147483648ll ) goto label$128;
-	{
-		int64 vr$51 = SYMBGETDEFTYPE( (uint8*)ID$1 );
-		DTYPE$1 = vr$51;
-	}
-	label$128:;
-	label$127:;
-	if( DOSKIP$1 == 0ll ) goto label$130;
+	if( DOSKIP$1 == 0ll ) goto label$126;
 	{
 		HSKIPUNTIL( 44ll, 0ll, 0ll, 0ll );
 	}
-	label$130:;
-	label$129:;
+	label$126:;
+	label$125:;
 	{
-		int64 TMP$97$2;
-		uint64 TMP$98$2;
-		if( (DTYPE$1 & 480ll) == 0ll ) goto label$131;
-		TMP$97$2 = 24ll;
-		goto label$166;
-		label$131:;
-		TMP$97$2 = DTYPE$1 & 31ll;
-		label$166:;
-		TMP$98$2 = (uint64)TMP$97$2;
-		goto label$133;
+		int64 TMP$102$2;
+		uint64 TMP$103$2;
+		if( (DTYPE$1 & 480ll) == 0ll ) goto label$127;
+		TMP$102$2 = 24ll;
+		goto label$162;
+		label$127:;
+		TMP$102$2 = DTYPE$1 & 31ll;
+		label$162:;
+		TMP$103$2 = (uint64)TMP$102$2;
+		goto label$129;
+		label$130:;
+		{
+			int64 TMP$104$3;
+			if( (DTYPE$1 & 480ll) == 0ll ) goto label$131;
+			TMP$104$3 = 24ll;
+			goto label$163;
+			label$131:;
+			TMP$104$3 = DTYPE$1 & 31ll;
+			label$163:;
+			if( ((int64)-(MODE$1 == 1ll) | (int64)-(TMP$104$3 == 18ll)) == 0ll ) goto label$133;
+			{
+				HPARAMERROR( PROC$1, ID$1, 59ll, 1ll );
+				DTYPE$1 = (((DTYPE$1 & 31ll) | ((DTYPE$1 & 480ll) + 32ll)) | ((DTYPE$1 & 261632ll) << (1ll & 63ll))) | (DTYPE$1 & 32505856ll);
+			}
+			label$133:;
+			label$132:;
+		}
+		goto label$128;
 		label$134:;
 		{
-			int64 TMP$99$3;
-			if( (DTYPE$1 & 480ll) == 0ll ) goto label$135;
-			TMP$99$3 = 24ll;
-			goto label$167;
-			label$135:;
-			TMP$99$3 = DTYPE$1 & 31ll;
-			label$167:;
-			if( ((int64)-(MODE$1 == 1ll) | (int64)-(TMP$99$3 == 18ll)) == 0ll ) goto label$137;
+			if( ISPROTO$1 != 0ll ) goto label$136;
 			{
 				HPARAMERROR( PROC$1, ID$1, 59ll, 1ll );
 				DTYPE$1 = (((DTYPE$1 & 31ll) | ((DTYPE$1 & 480ll) + 32ll)) | ((DTYPE$1 & 261632ll) << (1ll & 63ll))) | (DTYPE$1 & 32505856ll);
 			}
-			label$137:;
+			goto label$135;
 			label$136:;
-		}
-		goto label$132;
-		label$138:;
-		{
-			if( ISPROTO$1 != 0ll ) goto label$140;
 			{
-				HPARAMERROR( PROC$1, ID$1, 59ll, 1ll );
-				DTYPE$1 = (((DTYPE$1 & 31ll) | ((DTYPE$1 & 480ll) + 32ll)) | ((DTYPE$1 & 261632ll) << (1ll & 63ll))) | (DTYPE$1 & 32505856ll);
-			}
-			goto label$139;
-			label$140:;
-			{
-				if( MODE$1 != 1ll ) goto label$142;
+				if( MODE$1 != 1ll ) goto label$138;
 				{
 					HPARAMERROR( PROC$1, ID$1, 59ll, 1ll );
 					DTYPE$1 = (((DTYPE$1 & 31ll) | ((DTYPE$1 & 480ll) + 32ll)) | ((DTYPE$1 & 261632ll) << (1ll & 63ll))) | (DTYPE$1 & 32505856ll);
 				}
-				label$142:;
-				label$141:;
+				label$138:;
+				label$137:;
 			}
-			label$139:;
+			label$135:;
 		}
-		goto label$132;
-		label$143:;
+		goto label$128;
+		label$139:;
 		{
-			if( ISPROTO$1 != 0ll ) goto label$145;
+			if( ISPROTO$1 != 0ll ) goto label$141;
 			{
-				if( DOTPOS$1 <= 0ll ) goto label$147;
+				if( DOTPOS$1 <= 0ll ) goto label$143;
 				{
 					HPARAMERROR( PROC$1, ID$1, 59ll, 1ll );
 				}
-				label$147:;
-				label$146:;
+				label$143:;
+				label$142:;
 			}
-			label$145:;
-			label$144:;
+			label$141:;
+			label$140:;
 		}
-		goto label$132;
-		label$133:;
-		static const void* tmp$101[21ll] = {
-			&&label$138,
-			&&label$132,
-			&&label$132,
-			&&label$132,
+		goto label$128;
+		label$129:;
+		static const void* tmp$106[21ll] = {
 			&&label$134,
-			&&label$132,
-			&&label$132,
-			&&label$134,
-			&&label$132,
-			&&label$132,
-			&&label$132,
-			&&label$132,
-			&&label$132,
-			&&label$132,
-			&&label$132,
-			&&label$132,
-			&&label$132,
-			&&label$132,
-			&&label$134,
-			&&label$132,
-			&&label$143,
+			&&label$128,
+			&&label$128,
+			&&label$128,
+			&&label$130,
+			&&label$128,
+			&&label$128,
+			&&label$130,
+			&&label$128,
+			&&label$128,
+			&&label$128,
+			&&label$128,
+			&&label$128,
+			&&label$128,
+			&&label$128,
+			&&label$128,
+			&&label$128,
+			&&label$128,
+			&&label$130,
+			&&label$128,
+			&&label$139,
 		};
-		if( TMP$98$2 > 20ull ) goto label$132;
-		goto *tmp$101[TMP$98$2 - 0ull];
-		label$132:;
+		if( TMP$103$2 > 20ull ) goto label$128;
+		goto *tmp$106[TMP$103$2 - 0ull];
+		label$128:;
 	}
-	if( ISPROTO$1 == 0ll ) goto label$148;
-	TMP$100$1 = (uint8*)0ull;
-	goto label$168;
-	label$148:;
-	TMP$100$1 = ID$1;
-	label$168:;
-	struct $8FBSYMBOL* vr$86 = SYMBADDPROCPARAM( PROC$1, TMP$100$1, DTYPE$1, SUBTYPE$1, DIMENSIONS$1, MODE$1, ATTRIB$1 );
-	PARAM$1 = vr$86;
-	if( PARAM$1 != (struct $8FBSYMBOL*)0ull ) goto label$150;
+	if( ISPROTO$1 == 0ll ) goto label$144;
+	TMP$105$1 = (uint8*)0ull;
+	goto label$164;
+	label$144:;
+	TMP$105$1 = ID$1;
+	label$164:;
+	struct $8FBSYMBOL* vr$85 = SYMBADDPROCPARAM( PROC$1, TMP$105$1, DTYPE$1, SUBTYPE$1, DIMENSIONS$1, MODE$1, ATTRIB$1, 0ll );
+	PARAM$1 = vr$85;
+	if( PARAM$1 != (struct $8FBSYMBOL*)0ull ) goto label$146;
 	{
 		goto label$57;
 	}
-	label$150:;
-	label$149:;
-	if( ISPROTO$1 != 0ll ) goto label$152;
+	label$146:;
+	label$145:;
+	if( ISPROTO$1 != 0ll ) goto label$148;
 	{
-		if( *(int64*)((uint8*)PARAM$1 + 72ll) <= (*(int64*)((uint8*)&ENV$ + 544ll) << (2ll & 63ll)) ) goto label$154;
+		if( *(int64*)((uint8*)PARAM$1 + 80ll) <= (*(int64*)((uint8*)&ENV$ + 576ll) << (2ll & 63ll)) ) goto label$150;
 		{
-			if( (*(int64*)((uint8*)&ENV$ + 392ll) & 4ll) == 0ll ) goto label$156;
+			if( (*(int64*)((uint8*)&ENV$ + 392ll) & 4ll) == 0ll ) goto label$152;
 			{
 				HPARAMWARNING( PROC$1, ID$1, 17ll, 0ll );
 			}
-			label$156:;
-			label$155:;
+			label$152:;
+			label$151:;
 		}
-		label$154:;
-		label$153:;
+		label$150:;
+		label$149:;
 	}
-	label$152:;
-	label$151:;
-	int64 vr$90 = CASSIGNTOKEN(  );
-	if( vr$90 == 0ll ) goto label$158;
+	label$148:;
+	label$147:;
+	int64 vr$89 = CASSIGNTOKEN(  );
+	if( vr$89 == 0ll ) goto label$154;
 	{
-		if( MODE$1 != 3ll ) goto label$160;
+		if( MODE$1 != 3ll ) goto label$156;
 		{
-			int64 vr$91 = LEXGETTOKEN( 0ll );
-			if( vr$91 != 372ll ) goto label$162;
+			int64 vr$90 = LEXGETTOKEN( 0ll );
+			if( vr$90 != 372ll ) goto label$158;
 			{
-				LEXSKIPTOKEN( 0ll );
-				*($12FB_SYMBSTATS*)((uint8*)PARAM$1 + 16ll) = *(int64*)((uint8*)PARAM$1 + 16ll) | 2048ll;
+				LEXSKIPTOKEN( 2048ll );
+				*($12FB_SYMBSTATS*)((uint8*)PARAM$1 + 24ll) = *(int64*)((uint8*)PARAM$1 + 24ll) | 2048ll;
 			}
-			goto label$161;
-			label$162:;
+			goto label$157;
+			label$158:;
 			{
 				HPARAMERROR( PROC$1, ID$1, 59ll, 0ll );
 				HSKIPUNTIL( 44ll, 0ll, 0ll, 0ll );
 			}
-			label$161:;
+			label$157:;
 		}
-		goto label$159;
-		label$160:;
+		goto label$155;
+		label$156:;
 		{
 			struct $7ASTNODE* OPTEXPR$3;
-			struct $7ASTNODE* vr$95 = HOPTIONALEXPR( PROC$1, ID$1, PARAM$1 );
-			OPTEXPR$3 = vr$95;
-			if( OPTEXPR$3 == (struct $7ASTNODE*)0ull ) goto label$164;
+			struct $7ASTNODE* vr$94 = HOPTIONALEXPR( PROC$1, ID$1, PARAM$1 );
+			OPTEXPR$3 = vr$94;
+			if( OPTEXPR$3 == (struct $7ASTNODE*)0ull ) goto label$160;
 			{
 				SYMBMAKEPARAMOPTIONAL( PROC$1, PARAM$1, OPTEXPR$3 );
 			}
-			goto label$163;
-			label$164:;
+			goto label$159;
+			label$160:;
 			{
 				HPARAMERROR( PROC$1, ID$1, 59ll, 0ll );
 				HSKIPUNTIL( 44ll, 0ll, 0ll, 0ll );
 			}
-			label$163:;
+			label$159:;
 		}
-		label$159:;
+		label$155:;
 	}
-	label$158:;
-	label$157:;
+	label$154:;
+	label$153:;
 	fb$result$1 = PARAM$1;
 	label$57:;
 	return fb$result$1;
