@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -648,11 +687,11 @@ struct $8FBSYMBOL* SYMBGETCOMPDEFCTOR( struct $8FBSYMBOL* );
 int64 SYMBCHECKACCESS( struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBUDTGETFIRSTFIELD( struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBUDTGETNEXTINITABLEFIELD( struct $8FBSYMBOL* );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
 int64 LEXGETLOOKAHEAD( int64, $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 struct $7ASTNODE* CEXPRESSION( void );
 $12FB_PARAMMODE CBYDESCARRAYARGPARENS( struct $7ASTNODE* );
 void HSKIPUNTIL( int64, int64, $8LEXCHECK, int64 );
@@ -681,10 +720,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -702,20 +742,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -756,8 +798,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -765,8 +810,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -813,6 +859,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -834,16 +881,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -995,6 +1047,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1006,12 +1059,12 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 struct $7ASTNODE* CINITIALIZER( struct $8FBSYMBOL* SYM$1, $9FB_INIOPT OPTIONS$1, int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1 )
 {
-	struct $7ASTNODE* TMP$90$1;
+	struct $7ASTNODE* TMP$95$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$139:;
@@ -1019,7 +1072,7 @@ struct $7ASTNODE* CINITIALIZER( struct $8FBSYMBOL* SYM$1, $9FB_INIOPT OPTIONS$1,
 	int64 OK$1;
 	struct $10FB_INITCTX CTX$1;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	if( ((int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 65540ll) != 0ll) | (int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 8ll) != 0ll)) == 0ll ) goto label$142;
+	if( ((int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 16388ll) != 0ll) | (int64)-((*(int64*)((uint8*)SYM$1 + 8ll) & 8ll) != 0ll)) == 0ll ) goto label$142;
 	{
 		ERRREPORT( 75ll, -1ll, (uint8*)0ull );
 		goto label$140;
@@ -1041,7 +1094,7 @@ struct $7ASTNODE* CINITIALIZER( struct $8FBSYMBOL* SYM$1, $9FB_INIOPT OPTIONS$1,
 	*(int64*)((uint8*)&CTX$1 + 24ll) = -1ll;
 	*(struct $7ASTNODE**)((uint8*)&CTX$1 + 48ll) = (struct $7ASTNODE*)0ull;
 	HUPDATECONTEXTDTYPE( &CTX$1, DTYPE$1, SUBTYPE$1 );
-	struct $7ASTNODE* vr$14 = ASTTYPEINIBEGIN( *(int64*)((uint8*)&CTX$1 + 8ll), *(struct $8FBSYMBOL**)((uint8*)&CTX$1 + 16ll), IS_LOCAL$1, *(int64*)((uint8*)SYM$1 + 80ll) );
+	struct $7ASTNODE* vr$14 = ASTTYPEINIBEGIN( *(int64*)((uint8*)&CTX$1 + 8ll), *(struct $8FBSYMBOL**)((uint8*)&CTX$1 + 16ll), IS_LOCAL$1, *(int64*)((uint8*)SYM$1 + 88ll) );
 	*(struct $7ASTNODE**)((uint8*)&CTX$1 + 32ll) = vr$14;
 	int64 vr$15 = TYPEHASCTOR( *(int64*)((uint8*)&CTX$1 + 8ll), *(struct $8FBSYMBOL**)((uint8*)&CTX$1 + 16ll) );
 	if( vr$15 == 0ll ) goto label$146;
@@ -1074,12 +1127,12 @@ struct $7ASTNODE* CINITIALIZER( struct $8FBSYMBOL* SYM$1, $9FB_INIOPT OPTIONS$1,
 	label$147:;
 	ASTTYPEINIEND( *(struct $7ASTNODE**)((uint8*)&CTX$1 + 32ll), (int64)-((OPTIONS$1 & 1ll) != 0ll) );
 	if( OK$1 == 0ll ) goto label$151;
-	TMP$90$1 = *(struct $7ASTNODE**)((uint8*)&CTX$1 + 32ll);
+	TMP$95$1 = *(struct $7ASTNODE**)((uint8*)&CTX$1 + 32ll);
 	goto label$152;
 	label$151:;
-	TMP$90$1 = (struct $7ASTNODE*)0ull;
+	TMP$95$1 = (struct $7ASTNODE*)0ull;
 	label$152:;
-	fb$result$1 = TMP$90$1;
+	fb$result$1 = TMP$95$1;
 	label$140:;
 	return fb$result$1;
 }
@@ -1087,7 +1140,7 @@ struct $7ASTNODE* CINITIALIZER( struct $8FBSYMBOL* SYM$1, $9FB_INIOPT OPTIONS$1,
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1097,8 +1150,8 @@ static void HUPDATECONTEXTDTYPE( struct $10FB_INITCTX* CTX$1, int64 DTYPE$1, str
 	label$10:;
 	if( DTYPE$1 != 2147483648ll ) goto label$13;
 	{
-		*(int64*)((uint8*)CTX$1 + 8ll) = *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 48ll);
-		*(struct $8FBSYMBOL**)((uint8*)CTX$1 + 16ll) = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 56ll);
+		*(int64*)((uint8*)CTX$1 + 8ll) = *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 56ll);
+		*(struct $8FBSYMBOL**)((uint8*)CTX$1 + 16ll) = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 64ll);
 	}
 	goto label$12;
 	label$13:;
@@ -1153,10 +1206,10 @@ static int64 HELMINIT( struct $10FB_INITCTX* CTX$1, int64 NO_FAKE$1 )
 	struct $8FBSYMBOL* OLDSYM$1;
 	int64 OLD_DTYPE$1;
 	fb$result$1 = 0ll;
-	OLDSYM$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll);
-	OLD_DTYPE$1 = *(int64*)((uint8*)&PARSER$ + 296ll);
-	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll) = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 56ll);
-	*(int64*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 48ll) & 511ll;
+	OLDSYM$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll);
+	OLD_DTYPE$1 = *(int64*)((uint8*)&PARSER$ + 304ll);
+	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll) = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 64ll);
+	*(int64*)((uint8*)&PARSER$ + 304ll) = *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 56ll) & 511ll;
 	struct $7ASTNODE* vr$6 = CEXPRESSION(  );
 	EXPR$1 = vr$6;
 	if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$25;
@@ -1169,8 +1222,8 @@ static int64 HELMINIT( struct $10FB_INITCTX* CTX$1, int64 NO_FAKE$1 )
 	label$25:;
 	label$24:;
 	*(struct $7ASTNODE**)((uint8*)CTX$1 + 48ll) = EXPR$1;
-	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll) = OLDSYM$1;
-	*(int64*)((uint8*)&PARSER$ + 296ll) = OLD_DTYPE$1;
+	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll) = OLDSYM$1;
+	*(int64*)((uint8*)&PARSER$ + 304ll) = OLD_DTYPE$1;
 	int64 vr$11 = HDOASSIGN( CTX$1, EXPR$1, NO_FAKE$1 );
 	fb$result$1 = vr$11;
 	label$23:;
@@ -1193,16 +1246,16 @@ static int64 HARRAYINIT( struct $10FB_INITCTX* CTX$1, int64 NO_FAKE$1 )
 		LEXSKIPTOKEN( 0ll );
 		*(int64*)((uint8*)CTX$1 + 24ll) = *(int64*)((uint8*)CTX$1 + 24ll) + 1ll;
 		ISARRAY$1 = -1ll;
-		if( *(int64*)((uint8*)CTX$1 + 24ll) < *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 96ll) ) goto label$31;
+		if( *(int64*)((uint8*)CTX$1 + 24ll) < *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 104ll) ) goto label$31;
 		{
-			$9FB_ERRMSG TMP$88$3;
-			if( *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 96ll) <= 0ll ) goto label$32;
-			TMP$88$3 = 67ll;
+			$9FB_ERRMSG TMP$93$3;
+			if( *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 104ll) <= 0ll ) goto label$32;
+			TMP$93$3 = 67ll;
 			goto label$153;
 			label$32:;
-			TMP$88$3 = 63ll;
+			TMP$93$3 = 63ll;
 			label$153:;
-			ERRREPORT( TMP$88$3, 0ll, (uint8*)0ull );
+			ERRREPORT( TMP$93$3, 0ll, (uint8*)0ull );
 			HSKIPUNTIL( 125ll, -1ll, 0ll, 0ll );
 			*(int64*)((uint8*)CTX$1 + 24ll) = *(int64*)((uint8*)CTX$1 + 24ll) + -1ll;
 			goto label$27;
@@ -1213,7 +1266,7 @@ static int64 HARRAYINIT( struct $10FB_INITCTX* CTX$1, int64 NO_FAKE$1 )
 	goto label$28;
 	label$29:;
 	{
-		if( *(int64*)((uint8*)CTX$1 + 24ll) >= (*(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 96ll) + -1ll) ) goto label$34;
+		if( *(int64*)((uint8*)CTX$1 + 24ll) >= (*(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 104ll) + -1ll) ) goto label$34;
 		{
 			ERRREPORT( 64ll, 0ll, (uint8*)0ull );
 			*(int64*)((uint8*)CTX$1 + 24ll) = *(int64*)((uint8*)CTX$1 + 24ll) + 1ll;
@@ -1231,14 +1284,14 @@ static int64 HARRAYINIT( struct $10FB_INITCTX* CTX$1, int64 NO_FAKE$1 )
 	label$35:;
 	if( *(int64*)((uint8*)CTX$1 + 24ll) < 0ll ) goto label$38;
 	{
-		if( *(int64*)((uint8*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 104ll) + (*(int64*)((uint8*)CTX$1 + 24ll) << (4ll & 63ll))) + 8ll) != -9223372036854775808ull ) goto label$40;
+		if( *(int64*)((uint8*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 112ll) + (*(int64*)((uint8*)CTX$1 + 24ll) << (4ll & 63ll))) + 8ll) != -9223372036854775808ull ) goto label$40;
 		{
 			ELEMENTS$1 = -1ll;
 		}
 		goto label$39;
 		label$40:;
 		{
-			ELEMENTS$1 = (*(int64*)((uint8*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 104ll) + (*(int64*)((uint8*)CTX$1 + 24ll) << (4ll & 63ll))) + 8ll) - *(int64*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 104ll) + (*(int64*)((uint8*)CTX$1 + 24ll) << (4ll & 63ll)))) + 1ll;
+			ELEMENTS$1 = (*(int64*)((uint8*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 112ll) + (*(int64*)((uint8*)CTX$1 + 24ll) << (4ll & 63ll))) + 8ll) - *(int64*)((uint8*)*(struct $10FBARRAYDIM**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 112ll) + (*(int64*)((uint8*)CTX$1 + 24ll) << (4ll & 63ll)))) + 1ll;
 		}
 		label$39:;
 	}
@@ -1251,7 +1304,7 @@ static int64 HARRAYINIT( struct $10FB_INITCTX* CTX$1, int64 NO_FAKE$1 )
 	ELM_CNT$1 = 0ll;
 	label$41:;
 	{
-		if( *(int64*)((uint8*)CTX$1 + 24ll) >= (*(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 96ll) + -1ll) ) goto label$45;
+		if( *(int64*)((uint8*)CTX$1 + 24ll) >= (*(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 104ll) + -1ll) ) goto label$45;
 		{
 			int64 vr$44 = HARRAYINIT( CTX$1, 0ll );
 			if( vr$44 != 0ll ) goto label$47;
@@ -1297,7 +1350,7 @@ static int64 HARRAYINIT( struct $10FB_INITCTX* CTX$1, int64 NO_FAKE$1 )
 		label$54:;
 	}
 	label$43:;
-	int64 vr$53 = HMATCH( 44ll );
+	int64 vr$53 = HMATCH( 44ll, 0ll );
 	if( vr$53 != 0ll ) goto label$41;
 	label$42:;
 	if( ELEMENTS$1 != -1ll ) goto label$57;
@@ -1305,7 +1358,7 @@ static int64 HARRAYINIT( struct $10FB_INITCTX* CTX$1, int64 NO_FAKE$1 )
 		ELEMENTS$1 = ELM_CNT$1;
 		SYMBSETFIXEDSIZEARRAYDIMENSIONELEMENTS( *(struct $8FBSYMBOL**)CTX$1, *(int64*)((uint8*)CTX$1 + 24ll), ELEMENTS$1 );
 		SYMBMAYBEADDARRAYDESC( *(struct $8FBSYMBOL**)CTX$1 );
-		int64 vr$67 = SYMBCHECKARRAYSIZE( *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 96ll), *(struct $10FBARRAYDIM**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 104ll), *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 72ll), (int64)-((*(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 8ll) & 3ll) == 0ll) );
+		int64 vr$67 = SYMBCHECKARRAYSIZE( *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 104ll), *(struct $10FBARRAYDIM**)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 112ll), *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 80ll), (int64)-((*(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 8ll) & 3ll) == 0ll) );
 		if( vr$67 != 0ll ) goto label$59;
 		{
 			ERRREPORT( 50ll, 0ll, (uint8*)0ull );
@@ -1354,20 +1407,20 @@ static int64 HARRAYINIT( struct $10FB_INITCTX* CTX$1, int64 NO_FAKE$1 )
 		label$69:;
 		{
 			int64 PAD_LGT$3;
-			if( (*(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 8ll) & 33554432ll) == 0ll ) goto label$71;
+			if( (*(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 8ll) & 262144ll) == 0ll ) goto label$71;
 			{
-				PAD_LGT$3 = *(int64*)((uint8*)&ENV$ + 544ll);
+				PAD_LGT$3 = *(int64*)((uint8*)&ENV$ + 576ll);
 			}
 			goto label$70;
 			label$71:;
 			{
 				{
-					uint64 TMP$89$5;
-					TMP$89$5 = (uint64)(*(int64*)((uint8*)CTX$1 + 8ll) & 511ll);
+					uint64 TMP$94$5;
+					TMP$94$5 = (uint64)(*(int64*)((uint8*)CTX$1 + 8ll) & 511ll);
 					goto label$73;
 					label$74:;
 					{
-						PAD_LGT$3 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 72ll);
+						PAD_LGT$3 = *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 80ll);
 					}
 					goto label$72;
 					label$75:;
@@ -1377,7 +1430,7 @@ static int64 HARRAYINIT( struct $10FB_INITCTX* CTX$1, int64 NO_FAKE$1 )
 					}
 					goto label$72;
 					label$73:;
-					static const void* tmp$91[15ll] = {
+					static const void* tmp$96[15ll] = {
 						&&label$74,
 						&&label$75,
 						&&label$75,
@@ -1394,8 +1447,8 @@ static int64 HARRAYINIT( struct $10FB_INITCTX* CTX$1, int64 NO_FAKE$1 )
 						&&label$75,
 						&&label$74,
 					};
-					if( (TMP$89$5 - 4ull) > 14ull ) goto label$75;
-					goto *tmp$91[TMP$89$5 - 4ull];
+					if( (TMP$94$5 - 4ull) > 14ull ) goto label$75;
+					goto *tmp$96[TMP$94$5 - 4ull];
 					label$72:;
 				}
 			}
@@ -1437,7 +1490,7 @@ static int64 HUDTINIT( struct $10FB_INITCTX* CTX$1 )
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$80:;
-	static int64 REC_CNT$1;
+	static int64 REC_CNT$1 = 0ll;
 	int64 ELM_CNT$1;
 	int64 LGT$1;
 	int64 BASEOFS$1;
@@ -1452,14 +1505,14 @@ static int64 HUDTINIT( struct $10FB_INITCTX* CTX$1 )
 	if( (*(int64*)((uint8*)CTX$1 + 40ll) & 2ll) == 0ll ) goto label$83;
 	{
 		struct $7ASTNODE* EXPR$2;
-		OLDSUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll);
-		OLDDTYPE$1 = *(int64*)((uint8*)&PARSER$ + 296ll);
-		*(int64*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)CTX$1 + 8ll);
-		*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll) = *(struct $8FBSYMBOL**)((uint8*)CTX$1 + 16ll);
+		OLDSUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll);
+		OLDDTYPE$1 = *(int64*)((uint8*)&PARSER$ + 304ll);
+		*(int64*)((uint8*)&PARSER$ + 304ll) = *(int64*)((uint8*)CTX$1 + 8ll);
+		*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll) = *(struct $8FBSYMBOL**)((uint8*)CTX$1 + 16ll);
 		struct $7ASTNODE* vr$6 = CEXPRESSION(  );
 		EXPR$2 = vr$6;
-		*(int64*)((uint8*)&PARSER$ + 296ll) = OLDDTYPE$1;
-		*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll) = OLDSUBTYPE$1;
+		*(int64*)((uint8*)&PARSER$ + 304ll) = OLDDTYPE$1;
+		*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll) = OLDSUBTYPE$1;
 		if( EXPR$2 != (struct $7ASTNODE*)0ull ) goto label$85;
 		{
 			ERRREPORT( 9ll, 0ll, (uint8*)0ull );
@@ -1470,7 +1523,7 @@ static int64 HUDTINIT( struct $10FB_INITCTX* CTX$1 )
 		label$84:;
 		if( *(int64*)*(struct $8FBSYMBOL**)CTX$1 != 4ll ) goto label$87;
 		{
-			if( *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 88ll) != 2ll ) goto label$89;
+			if( *(int64*)((uint8*)*(struct $8FBSYMBOL**)CTX$1 + 96ll) != 2ll ) goto label$89;
 			{
 				if( ((int64)-((*(int64*)((uint8*)EXPR$2 + 8ll) & 511ll) == (*(int64*)((uint8*)CTX$1 + 8ll) & 511ll)) & (int64)-(*(struct $8FBSYMBOL**)((uint8*)EXPR$2 + 16ll) == *(struct $8FBSYMBOL**)((uint8*)CTX$1 + 16ll))) == 0ll ) goto label$91;
 				{
@@ -1562,7 +1615,7 @@ static int64 HUDTINIT( struct $10FB_INITCTX* CTX$1 )
 		label$103:;
 		if( LGT$1 <= 0ll ) goto label$106;
 		{
-			PAD_LGT$1 = *(int64*)((uint8*)FLD$1 + 80ll) - LGT$1;
+			PAD_LGT$1 = *(int64*)((uint8*)FLD$1 + 88ll) - LGT$1;
 			if( PAD_LGT$1 <= 0ll ) goto label$108;
 			{
 				ASTTYPEINIADDPAD( *(struct $7ASTNODE**)((uint8*)CTX$1 + 32ll), PAD_LGT$1 );
@@ -1573,7 +1626,7 @@ static int64 HUDTINIT( struct $10FB_INITCTX* CTX$1 )
 		}
 		label$106:;
 		label$105:;
-		*(int64*)((uint8*)*(struct $7ASTNODE**)((uint8*)CTX$1 + 32ll) + 40ll) = BASEOFS$1 + *(int64*)((uint8*)FLD$1 + 80ll);
+		*(int64*)((uint8*)*(struct $7ASTNODE**)((uint8*)CTX$1 + 32ll) + 40ll) = BASEOFS$1 + *(int64*)((uint8*)FLD$1 + 88ll);
 		int64 vr$58 = SYMBCHECKACCESS( FLD$1 );
 		if( vr$58 != 0ll ) goto label$110;
 		{
@@ -1668,7 +1721,7 @@ static int64 HUDTINIT( struct $10FB_INITCTX* CTX$1 )
 		}
 		label$126:;
 		label$125:;
-		int64 vr$92 = HMATCH( 44ll );
+		int64 vr$92 = HMATCH( 44ll, 0ll );
 		if( vr$92 != 0ll ) goto label$132;
 		{
 			goto label$101;
