@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -618,29 +657,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -673,7 +702,7 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
 int32 fb_StrCompare( void*, int64, void*, int64 );
@@ -683,15 +712,15 @@ void ERRREPORT( int64, int64, uint8* );
 struct $8FBSYMBOL* SYMBLOOKUPBYNAMEANDCLASS( struct $8FBSYMBOL*, uint8*, int64, int64, int64 );
 struct $8FBSYMBOL* SYMBADDFWDREF( uint8* );
 struct $8FBSYMBOL* SYMBADDTYPEDEF( uint8*, int64, struct $8FBSYMBOL*, int64 );
-uint8* SYMBUNIQUEID( void );
+uint8* SYMBUNIQUEID( boolean );
 uint8* SYMBUNIQUELABEL( void );
-int64 HMATCH( int64 );
 void HUCASE( uint8*, uint8* );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 int64 LEXGETCLASS( $8LEXCHECK );
 uint8* LEXGETTEXT( void );
 void LEXSKIPTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $14FB_SYMBTYPEOPT;
 int64 CSYMBOLTYPE( int64*, struct $8FBSYMBOL**, int64*, int64*, $14FB_SYMBTYPEOPT );
 void CCURRENTPARENTID( void );
@@ -723,10 +752,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -760,6 +790,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -768,11 +802,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -825,7 +860,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -844,20 +879,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -898,8 +935,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -907,8 +947,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -955,6 +996,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -976,23 +1018,28 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 
 void CTYPEDEFMULTDECL( void )
@@ -1006,7 +1053,7 @@ void CTYPEDEFMULTDECL( void )
 	}
 	label$77:;
 	label$76:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	int64 DTYPE$1;
 	__builtin_memset( &DTYPE$1, 0, 8ll );
 	int64 IS_FIXLENSTR$1;
@@ -1026,7 +1073,7 @@ void CTYPEDEFMULTDECL( void )
 		HADDTYPEDEF( PID$2, PFWDNAME$1, DTYPE$1, SUBTYPE$1, LGT$1, IS_FIXLENSTR$1 );
 	}
 	label$80:;
-	int64 vr$11 = HMATCH( 44ll );
+	int64 vr$11 = HMATCH( 44ll, 0ll );
 	if( vr$11 != 0ll ) goto label$78;
 	label$79:;
 	label$75:;
@@ -1045,7 +1092,7 @@ void CTYPEDEFSINGLEDECL( uint8* PID$1 )
 	label$83:;
 	label$85:;
 	{
-		int64 vr$1 = HMATCH( 376ll );
+		int64 vr$1 = HMATCH( 376ll, 2048ll );
 		if( vr$1 != 0ll ) goto label$89;
 		{
 			ERRREPORT( 17ll, 0ll, (uint8*)0ull );
@@ -1064,7 +1111,7 @@ void CTYPEDEFSINGLEDECL( uint8* PID$1 )
 		uint8* vr$10 = HREADTYPE( &DTYPE$2, &SUBTYPE$2, &LGT$2, &IS_FIXLENSTR$2 );
 		PFWDNAME$2 = vr$10;
 		HADDTYPEDEF( PID$1, PFWDNAME$2, DTYPE$2, SUBTYPE$2, LGT$2, IS_FIXLENSTR$2 );
-		int64 vr$11 = HMATCH( 44ll );
+		int64 vr$11 = HMATCH( 44ll, 0ll );
 		if( vr$11 != 0ll ) goto label$91;
 		{
 			goto label$86;
@@ -1083,7 +1130,7 @@ void CTYPEDEFSINGLEDECL( uint8* PID$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1096,20 +1143,20 @@ static void HPTRDECL( int64* DTYPE$1 )
 	label$12:;
 	{
 		{
-			uint64 TMP$88$3;
+			uint64 TMP$93$3;
 			int64 vr$0 = LEXGETTOKEN( 0ll );
-			TMP$88$3 = (uint64)vr$0;
+			TMP$93$3 = (uint64)vr$0;
 			goto label$16;
 			label$17:;
 			{
-				LEXSKIPTOKEN( 0ll );
+				LEXSKIPTOKEN( 2048ll );
 				{
-					int64 TMP$89$5;
+					int64 TMP$94$5;
 					int64 vr$1 = LEXGETTOKEN( 0ll );
-					TMP$89$5 = vr$1;
-					if( TMP$89$5 == 373ll ) goto label$20;
+					TMP$94$5 = vr$1;
+					if( TMP$94$5 == 373ll ) goto label$20;
 					label$21:;
-					if( TMP$89$5 != 374ll ) goto label$19;
+					if( TMP$94$5 != 374ll ) goto label$19;
 					label$20:;
 					{
 						if( PTR_CNT$1 < 8ll ) goto label$23;
@@ -1123,7 +1170,7 @@ static void HPTRDECL( int64* DTYPE$1 )
 							PTR_CNT$1 = PTR_CNT$1 + 1ll;
 						}
 						label$22:;
-						LEXSKIPTOKEN( 0ll );
+						LEXSKIPTOKEN( 2048ll );
 					}
 					goto label$18;
 					label$19:;
@@ -1149,7 +1196,7 @@ static void HPTRDECL( int64* DTYPE$1 )
 					PTR_CNT$1 = PTR_CNT$1 + 1ll;
 				}
 				label$26:;
-				LEXSKIPTOKEN( 0ll );
+				LEXSKIPTOKEN( 2048ll );
 			}
 			goto label$15;
 			label$28:;
@@ -1158,7 +1205,7 @@ static void HPTRDECL( int64* DTYPE$1 )
 			}
 			goto label$15;
 			label$16:;
-			static const void* tmp$92[40ll] = {
+			static const void* tmp$97[40ll] = {
 				&&label$17,
 				&&label$28,
 				&&label$28,
@@ -1200,8 +1247,8 @@ static void HPTRDECL( int64* DTYPE$1 )
 				&&label$25,
 				&&label$25,
 			};
-			if( (TMP$88$3 - 335ull) > 39ull ) goto label$28;
-			goto *tmp$92[TMP$88$3 - 335ull];
+			if( (TMP$93$3 - 335ull) > 39ull ) goto label$28;
+			goto *tmp$97[TMP$93$3 - 335ull];
 			label$15:;
 		}
 	}
@@ -1226,23 +1273,23 @@ static uint8* HREADTYPE( int64* DTYPE$1, struct $8FBSYMBOL** SUBTYPE$1, int64* L
 	label$32:;
 	label$31:;
 	{
-		int64 TMP$90$2;
+		int64 TMP$95$2;
 		int64 vr$2 = LEXGETCLASS( 0ll );
-		TMP$90$2 = vr$2;
-		if( TMP$90$2 == 0ll ) goto label$35;
+		TMP$95$2 = vr$2;
+		if( TMP$95$2 == 0ll ) goto label$35;
 		label$36:;
-		if( TMP$90$2 != 2ll ) goto label$34;
+		if( TMP$95$2 != 2ll ) goto label$34;
 		label$35:;
 		{
 			uint8* vr$3 = LEXGETTEXT(  );
 			fb_StrAssign( (void*)TNAME$1, 129ll, (void*)vr$3, 0ll, 0 );
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 		}
 		goto label$33;
 		label$34:;
 		{
 			ERRREPORT( 14ll, 0ll, (uint8*)0ull );
-			uint8* vr$4 = SYMBUNIQUEID(  );
+			uint8* vr$4 = SYMBUNIQUEID( (boolean)0ll );
 			fb_StrAssign( (void*)TNAME$1, 129ll, (void*)vr$4, 0ll, 0 );
 			HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
 		}
@@ -1281,7 +1328,7 @@ static void HADDFORWARDREF( uint8* PID$1, uint8* PFWDNAME$1, int64* DTYPE$1, str
 		*LGT$1 = -1ll;
 		if( *SUBTYPE$1 != (struct $8FBSYMBOL*)0ull ) goto label$43;
 		{
-			struct $8FBSYMBOL* vr$16 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll), (uint8*)PFWDNAME$1, 14ll, -1ll, 0ll );
+			struct $8FBSYMBOL* vr$16 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll), (uint8*)PFWDNAME$1, 14ll, -1ll, 0ll );
 			*SUBTYPE$1 = vr$16;
 			if( *SUBTYPE$1 != (struct $8FBSYMBOL*)0ull ) goto label$45;
 			{
@@ -1317,7 +1364,7 @@ static void HADDTYPEDEF( uint8* PID$1, uint8* PFWDNAME$1, int64 DTYPE$1, struct
 	{
 		if( IS_FIXLENSTR$1 == 0ll ) goto label$53;
 		{
-			*($12FB_SYMBSTATS*)((uint8*)TYPEDEF$1 + 16ll) = *(int64*)((uint8*)TYPEDEF$1 + 16ll) | 2097152ll;
+			*($12FB_SYMBSTATS*)((uint8*)TYPEDEF$1 + 24ll) = *(int64*)((uint8*)TYPEDEF$1 + 24ll) | 2097152ll;
 		}
 		label$53:;
 		label$52:;
@@ -1328,13 +1375,13 @@ static void HADDTYPEDEF( uint8* PID$1, uint8* PFWDNAME$1, int64 DTYPE$1, struct
 		int64 ISDUP$2;
 		ISDUP$2 = -1ll;
 		struct $8FBSYMBOL* SYM$2;
-		struct $8FBSYMBOL* vr$8 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll), (uint8*)PID$1, 13ll, 0ll, 0ll );
+		struct $8FBSYMBOL* vr$8 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll), (uint8*)PID$1, 13ll, 0ll, 0ll );
 		SYM$2 = vr$8;
 		if( SYM$2 == (struct $8FBSYMBOL*)0ull ) goto label$55;
 		{
-			if( *(int64*)((uint8*)SYM$2 + 48ll) != DTYPE$1 ) goto label$57;
+			if( *(int64*)((uint8*)SYM$2 + 56ll) != DTYPE$1 ) goto label$57;
 			{
-				if( *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 56ll) != SUBTYPE$1 ) goto label$59;
+				if( *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 64ll) != SUBTYPE$1 ) goto label$59;
 				{
 					ISDUP$2 = 0ll;
 				}
@@ -1365,17 +1412,17 @@ static uint8* HREADID( void )
 	static uint8 ID$1[129];
 	CCURRENTPARENTID(  );
 	{
-		uint64 TMP$91$2;
+		uint64 TMP$96$2;
 		int64 vr$1 = LEXGETCLASS( 0ll );
-		TMP$91$2 = (uint64)vr$1;
+		TMP$96$2 = (uint64)vr$1;
 		goto label$65;
 		label$66:;
 		{
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 524288ll) == 0ll ) goto label$68;
+			if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 524288ll) == 0ll ) goto label$68;
 			{
-				if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$70;
+				if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$70;
 				{
-					if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 2096ll) <= 0ll ) goto label$72;
+					if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2096ll) <= 0ll ) goto label$72;
 					{
 						ERRREPORT( 90ll, 0ll, (uint8*)0ull );
 					}
@@ -1389,7 +1436,7 @@ static uint8* HREADID( void )
 			label$67:;
 			uint8* vr$6 = LEXGETTEXT(  );
 			fb_StrAssign( (void*)ID$1, 129ll, (void*)vr$6, 0ll, 0 );
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 		}
 		goto label$64;
 		label$73:;
@@ -1400,13 +1447,13 @@ static uint8* HREADID( void )
 		}
 		goto label$64;
 		label$65:;
-		static const void* tmp$93[3ll] = {
+		static const void* tmp$98[3ll] = {
 			&&label$66,
 			&&label$66,
 			&&label$66,
 		};
-		if( TMP$91$2 > 2ull ) goto label$73;
-		goto *tmp$93[TMP$91$2 - 0ull];
+		if( TMP$96$2 > 2ull ) goto label$73;
+		goto *tmp$98[TMP$96$2 - 0ull];
 		label$64:;
 	}
 	fb$result$1 = (uint8*)ID$1;
