@@ -9,6 +9,7 @@ typedef unsigned long long uint64;
 typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -314,6 +315,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -323,7 +325,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -332,7 +335,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -343,10 +346,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -355,9 +359,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -456,14 +460,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -485,7 +491,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -496,9 +528,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -559,6 +597,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -588,7 +627,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $10FBSYMCHAIN {
 	struct $8FBSYMBOL* SYM;
 	struct $10FBSYMCHAIN* NEXT;
@@ -613,29 +652,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -668,7 +697,7 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -683,15 +712,15 @@ typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
 int64 LEXGETLOOKAHEAD( int64, $8LEXCHECK );
-void CCONSTDECL( int64 );
-void CTYPEDECL( int64 );
-void CENUMDECL( int64 );
+void CCONSTDECL( $13FB_SYMBATTRIB );
+void CTYPEDECL( $13FB_SYMBATTRIB );
+void CENUMDECL( $13FB_SYMBATTRIB );
 int64 HCHECKSCOPE( void );
 int64 CVARIABLEDECL( $13FB_SYMBATTRIB );
 void CPROCDECL( void );
 void CDEFDECL( void );
 void COPTDECL( void );
-void CPROCSTMTBEGIN( int64 );
+void CPROCSTMTBEGIN( $13FB_SYMBATTRIB, $13FB_PROCATTRIB );
 void HSKIPUNTIL( int64, int64, $8LEXCHECK, int64 );
 typedef int64 $11AST_OPFLAGS;
 struct $10AST_OPINFO {
@@ -713,10 +742,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -734,20 +764,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -788,8 +820,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -797,8 +832,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -845,6 +881,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -866,23 +903,28 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -1034,6 +1076,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1045,7 +1088,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 int64 CDECLARATION( void )
@@ -1055,11 +1098,13 @@ int64 CDECLARATION( void )
 	label$10:;
 	$13FB_SYMBATTRIB ATTRIB$1;
 	ATTRIB$1 = 0ll;
+	$13FB_PROCATTRIB PATTRIB$1;
+	PATTRIB$1 = 0ll;
 	int64 TK$1;
 	fb$result$1 = 0ll;
 	if( *(int64*)((uint8*)&ENV$ + 272ll) != 3ll ) goto label$13;
 	{
-		if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 16ll) == 2147483648ll ) goto label$15;
+		if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 16ll) == 2147483648ll ) goto label$15;
 		{
 			fb$result$1 = 0ll;
 			goto label$11;
@@ -1070,9 +1115,9 @@ int64 CDECLARATION( void )
 	label$13:;
 	label$12:;
 	{
-		uint64 TMP$88$2;
+		uint64 TMP$93$2;
 		int64 vr$3 = LEXGETTOKEN( 0ll );
-		TMP$88$2 = (uint64)vr$3;
+		TMP$93$2 = (uint64)vr$3;
 		goto label$17;
 		label$18:;
 		{
@@ -1083,7 +1128,7 @@ int64 CDECLARATION( void )
 			}
 			label$20:;
 			label$19:;
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 		}
 		goto label$16;
 		label$21:;
@@ -1095,7 +1140,7 @@ int64 CDECLARATION( void )
 			}
 			label$23:;
 			label$22:;
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 		}
 		goto label$16;
 		label$24:;
@@ -1120,7 +1165,7 @@ int64 CDECLARATION( void )
 		}
 		goto label$16;
 		label$17:;
-		static const void* tmp$94[59ll] = {
+		static const void* tmp$99[59ll] = {
 			&&label$25,
 			&&label$25,
 			&&label$25,
@@ -1181,26 +1226,26 @@ int64 CDECLARATION( void )
 			&&label$18,
 			&&label$21,
 		};
-		if( (TMP$88$2 - 321ull) > 58ull ) goto label$16;
-		goto *tmp$94[TMP$88$2 - 321ull];
+		if( (TMP$93$2 - 321ull) > 58ull ) goto label$16;
+		goto *tmp$99[TMP$93$2 - 321ull];
 		label$16:;
 	}
 	int64 vr$6 = LEXGETTOKEN( 0ll );
 	TK$1 = vr$6;
 	{
-		uint64 TMP$89$2;
-		TMP$89$2 = (uint64)TK$1;
+		uint64 TMP$94$2;
+		TMP$94$2 = (uint64)TK$1;
 		goto label$28;
 		label$29:;
 		{
 			{
-				uint64 TMP$90$4;
+				uint64 TMP$95$4;
 				int64 vr$7 = LEXGETLOOKAHEAD( 1ll, 0ll );
-				TMP$90$4 = (uint64)vr$7;
+				TMP$95$4 = (uint64)vr$7;
 				goto label$31;
 				label$32:;
 				{
-					CPROCSTMTBEGIN( ATTRIB$1 );
+					CPROCSTMTBEGIN( ATTRIB$1, PATTRIB$1 );
 					fb$result$1 = -1ll;
 				}
 				goto label$30;
@@ -1232,7 +1277,7 @@ int64 CDECLARATION( void )
 				}
 				goto label$30;
 				label$31:;
-				static const void* tmp$95[11ll] = {
+				static const void* tmp$100[11ll] = {
 					&&label$32,
 					&&label$32,
 					&&label$32,
@@ -1245,8 +1290,8 @@ int64 CDECLARATION( void )
 					&&label$32,
 					&&label$32,
 				};
-				if( (TMP$90$4 - 345ull) > 10ull ) goto label$33;
-				goto *tmp$95[TMP$90$4 - 345ull];
+				if( (TMP$95$4 - 345ull) > 10ull ) goto label$33;
+				goto *tmp$100[TMP$95$4 - 345ull];
 				label$30:;
 			}
 		}
@@ -1255,26 +1300,26 @@ int64 CDECLARATION( void )
 		{
 			if( ATTRIB$1 == 0ll ) goto label$42;
 			{
-				CPROCSTMTBEGIN( ATTRIB$1 );
+				CPROCSTMTBEGIN( ATTRIB$1, PATTRIB$1 );
 				fb$result$1 = -1ll;
 			}
 			goto label$41;
 			label$42:;
 			{
 				{
-					int64 TMP$91$5;
+					int64 TMP$96$5;
 					int64 vr$9 = LEXGETLOOKAHEAD( 1ll, 0ll );
-					TMP$91$5 = vr$9;
-					if( TMP$91$5 == 299ll ) goto label$45;
+					TMP$96$5 = vr$9;
+					if( TMP$96$5 == 299ll ) goto label$45;
 					label$46:;
-					if( TMP$91$5 != 305ll ) goto label$44;
+					if( TMP$96$5 != 305ll ) goto label$44;
 					label$45:;
 					{
 					}
 					goto label$43;
 					label$44:;
 					{
-						CPROCSTMTBEGIN( 0ll );
+						CPROCSTMTBEGIN( 0ll, 0ll );
 						fb$result$1 = -1ll;
 					}
 					label$47:;
@@ -1288,15 +1333,15 @@ int64 CDECLARATION( void )
 		{
 			if( ATTRIB$1 == 0ll ) goto label$50;
 			{
-				CPROCSTMTBEGIN( ATTRIB$1 );
+				CPROCSTMTBEGIN( ATTRIB$1, PATTRIB$1 );
 				fb$result$1 = -1ll;
 			}
 			goto label$49;
 			label$50:;
 			{
-				if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) != *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) ) goto label$52;
+				if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) != *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) ) goto label$52;
 				{
-					CPROCSTMTBEGIN( 0ll );
+					CPROCSTMTBEGIN( 0ll, 0ll );
 					fb$result$1 = -1ll;
 				}
 				label$52:;
@@ -1309,34 +1354,34 @@ int64 CDECLARATION( void )
 		{
 			if( ATTRIB$1 == 0ll ) goto label$55;
 			{
-				CPROCSTMTBEGIN( ATTRIB$1 );
+				CPROCSTMTBEGIN( ATTRIB$1, PATTRIB$1 );
 				fb$result$1 = -1ll;
 			}
 			goto label$54;
 			label$55:;
 			{
-				if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) != *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) ) goto label$57;
+				if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) != *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) ) goto label$57;
 				{
-					CPROCSTMTBEGIN( 0ll );
+					CPROCSTMTBEGIN( 0ll, 0ll );
 					fb$result$1 = -1ll;
 				}
 				goto label$56;
 				label$57:;
 				{
 					{
-						int64 TMP$92$6;
+						int64 TMP$97$6;
 						int64 vr$10 = LEXGETLOOKAHEAD( 1ll, 0ll );
-						TMP$92$6 = vr$10;
-						if( TMP$92$6 == 299ll ) goto label$60;
+						TMP$97$6 = vr$10;
+						if( TMP$97$6 == 299ll ) goto label$60;
 						label$61:;
-						if( TMP$92$6 != 305ll ) goto label$59;
+						if( TMP$97$6 != 305ll ) goto label$59;
 						label$60:;
 						{
 						}
 						goto label$58;
 						label$59:;
 						{
-							CPROCSTMTBEGIN( 0ll );
+							CPROCSTMTBEGIN( 0ll, 0ll );
 							fb$result$1 = -1ll;
 						}
 						label$62:;
@@ -1353,12 +1398,12 @@ int64 CDECLARATION( void )
 			if( ATTRIB$1 != 0ll ) goto label$65;
 			{
 				{
-					int64 TMP$93$5;
+					int64 TMP$98$5;
 					int64 vr$11 = LEXGETLOOKAHEAD( 1ll, 0ll );
-					TMP$93$5 = vr$11;
-					if( TMP$93$5 == 301ll ) goto label$68;
+					TMP$98$5 = vr$11;
+					if( TMP$98$5 == 301ll ) goto label$68;
 					label$69:;
-					if( TMP$93$5 != 40ll ) goto label$67;
+					if( TMP$98$5 != 40ll ) goto label$67;
 					label$68:;
 					{
 						fb$result$1 = 0ll;
@@ -1405,7 +1450,7 @@ int64 CDECLARATION( void )
 		}
 		goto label$27;
 		label$28:;
-		static const void* tmp$96[50ll] = {
+		static const void* tmp$101[50ll] = {
 			&&label$72,
 			&&label$29,
 			&&label$72,
@@ -1457,8 +1502,8 @@ int64 CDECLARATION( void )
 			&&label$29,
 			&&label$29,
 		};
-		if( (TMP$89$2 - 306ull) > 49ull ) goto label$73;
-		goto *tmp$96[TMP$89$2 - 306ull];
+		if( (TMP$94$2 - 306ull) > 49ull ) goto label$73;
+		goto *tmp$101[TMP$94$2 - 306ull];
 		label$27:;
 	}
 	label$11:;
@@ -1468,7 +1513,7 @@ int64 CDECLARATION( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
