@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -614,29 +653,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -669,7 +698,7 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 typedef int64 $15FB_CMPSTMT_MASK;
 struct $17FB_CMPSTMT_FORELM {
 	struct $8FBSYMBOL* SYM;
@@ -797,13 +826,13 @@ int64 SYMBHASCTOR( struct $8FBSYMBOL* );
 int64 SYMBGETDEFTYPE( uint8* );
 struct $8FBSYMBOL* SYMBGETCOMPCTORHEAD( struct $8FBSYMBOL* );
 int64 SYMBVARCHECKACCESS( struct $8FBSYMBOL* );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 int64 LEXGETCLASS( $8LEXCHECK );
 uint8* LEXGETTEXT( void );
 void LEXSKIPTOKEN( $8LEXCHECK );
 int64 LEXGETLOOKAHEAD( int64, $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $8FB_IDOPT;
 struct $10FBSYMCHAIN* CIDENTIFIER( struct $8FBSYMBOL**, $8FB_IDOPT );
 struct $7ASTNODE* CEXPRESSION( void );
@@ -844,10 +873,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -865,20 +895,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -919,8 +951,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -928,8 +963,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -975,6 +1011,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -996,23 +1033,28 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -1056,6 +1098,7 @@ __FB_STATIC_ASSERT( sizeof( struct $13FBPARSER_STMT ) == 176 );
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1067,7 +1110,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 struct $7ASTNODE* CEQINPARENSONLYEXPR( void )
@@ -1077,26 +1120,26 @@ struct $7ASTNODE* CEQINPARENSONLYEXPR( void )
 	label$10:;
 	struct $7ASTNODE* EXPR$1;
 	int64 EQINPARENSONLY$1;
-	EQINPARENSONLY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 256ll) != 0ll);
+	EQINPARENSONLY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 256ll) != 0ll);
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 256ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 256ll;
 	}
 	goto label$12;
 	label$13:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -257ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -257ll;
 	}
 	label$12:;
 	struct $7ASTNODE* vr$5 = CEXPRESSION(  );
 	EXPR$1 = vr$5;
 	if( EQINPARENSONLY$1 == 0ll ) goto label$15;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 256ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 256ll;
 	}
 	goto label$14;
 	label$15:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -257ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -257ll;
 	}
 	label$14:;
 	fb$result$1 = EXPR$1;
@@ -1112,26 +1155,26 @@ struct $7ASTNODE* CGTINPARENSONLYEXPR( void )
 	label$16:;
 	struct $7ASTNODE* EXPR$1;
 	int64 GTINPARENSONLY$1;
-	GTINPARENSONLY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 512ll) != 0ll);
+	GTINPARENSONLY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 512ll) != 0ll);
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 512ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 512ll;
 	}
 	goto label$18;
 	label$19:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -513ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -513ll;
 	}
 	label$18:;
 	struct $7ASTNODE* vr$5 = CEXPRESSION(  );
 	EXPR$1 = vr$5;
 	if( GTINPARENSONLY$1 == 0ll ) goto label$21;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 512ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 512ll;
 	}
 	goto label$20;
 	label$21:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -513ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -513ll;
 	}
 	label$20:;
 	fb$result$1 = EXPR$1;
@@ -1158,82 +1201,82 @@ struct $7ASTNODE* CPARENTEXPRESSION( void )
 	label$25:;
 	label$24:;
 	LEXSKIPTOKEN( 0ll );
-	*(int64*)((uint8*)&PARSER$ + 280ll) = *(int64*)((uint8*)&PARSER$ + 280ll) + 1ll;
+	*(int64*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) + 1ll;
 	int64 IS_OPT$1;
-	IS_OPT$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 1ll) != 0ll);
+	IS_OPT$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 1ll) != 0ll);
 	goto label$27;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 1ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 1ll;
 	}
 	goto label$26;
 	label$27:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -2ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -2ll;
 	}
 	label$26:;
-	EQINPARENSONLY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 256ll) != 0ll);
-	GTINPARENSONLY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 512ll) != 0ll);
-	IDXINPARENSONLY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 4096ll) != 0ll);
+	EQINPARENSONLY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 256ll) != 0ll);
+	GTINPARENSONLY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 512ll) != 0ll);
+	IDXINPARENSONLY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 4096ll) != 0ll);
 	goto label$29;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 256ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 256ll;
 	}
 	goto label$28;
 	label$29:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -257ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -257ll;
 	}
 	label$28:;
 	goto label$31;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 512ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 512ll;
 	}
 	goto label$30;
 	label$31:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -513ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -513ll;
 	}
 	label$30:;
 	goto label$33;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 4096ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 4096ll;
 	}
 	goto label$32;
 	label$33:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -4097ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -4097ll;
 	}
 	label$32:;
 	struct $7ASTNODE* vr$19 = CEXPRESSION(  );
 	PAREXPR$1 = vr$19;
 	if( EQINPARENSONLY$1 == 0ll ) goto label$35;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 256ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 256ll;
 	}
 	goto label$34;
 	label$35:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -257ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -257ll;
 	}
 	label$34:;
 	if( GTINPARENSONLY$1 == 0ll ) goto label$37;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 512ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 512ll;
 	}
 	goto label$36;
 	label$37:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -513ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -513ll;
 	}
 	label$36:;
 	if( IDXINPARENSONLY$1 == 0ll ) goto label$39;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 4096ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 4096ll;
 	}
 	goto label$38;
 	label$39:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -4097ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -4097ll;
 	}
 	label$38:;
 	if( PAREXPR$1 != (struct $7ASTNODE*)0ull ) goto label$41;
@@ -1257,12 +1300,12 @@ struct $7ASTNODE* CPARENTEXPRESSION( void )
 	if( vr$27 != 41ll ) goto label$45;
 	{
 		LEXSKIPTOKEN( 0ll );
-		*(int64*)((uint8*)&PARSER$ + 280ll) = *(int64*)((uint8*)&PARSER$ + 280ll) + -1ll;
+		*(int64*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) + -1ll;
 	}
 	goto label$44;
 	label$45:;
 	{
-		if( ((int64)-(IS_OPT$1 == 0ll) | (int64)-(*(int64*)((uint8*)&PARSER$ + 280ll) == 0ll)) == 0ll ) goto label$47;
+		if( ((int64)-(IS_OPT$1 == 0ll) | (int64)-(*(int64*)((uint8*)&PARSER$ + 288ll) == 0ll)) == 0ll ) goto label$47;
 		{
 			ERRREPORT( 7ll, 0ll, (uint8*)0ull );
 			HSKIPUNTIL( 41ll, -1ll, 0ll, 0ll );
@@ -1280,122 +1323,122 @@ struct $7ASTNODE* CATOM( struct $8FBSYMBOL* BASE_PARENT$1, struct $10FBSYMCHAIN*
 {
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$167:;
+	label$168:;
 	int64 TK_CLASS$1;
-	if( CHAIN_$1 != (struct $10FBSYMCHAIN*)0ull ) goto label$170;
+	if( CHAIN_$1 != (struct $10FBSYMCHAIN*)0ull ) goto label$171;
 	{
 		int64 vr$1 = LEXGETCLASS( 0ll );
 		TK_CLASS$1 = vr$1;
 	}
-	goto label$169;
-	label$170:;
+	goto label$170;
+	label$171:;
 	{
 		TK_CLASS$1 = 0ll;
 	}
-	label$169:;
+	label$170:;
 	{
-		uint64 TMP$94$2;
-		TMP$94$2 = (uint64)TK_CLASS$1;
-		goto label$172;
-		label$173:;
+		uint64 TMP$99$2;
+		TMP$99$2 = (uint64)TK_CLASS$1;
+		goto label$173;
+		label$174:;
 		{
-			if( CHAIN_$1 != (struct $10FBSYMCHAIN*)0ull ) goto label$175;
+			if( CHAIN_$1 != (struct $10FBSYMCHAIN*)0ull ) goto label$176;
 			{
 				struct $10FBSYMCHAIN* vr$3 = CIDENTIFIER( &BASE_PARENT$1, 50ll );
 				CHAIN_$1 = vr$3;
 			}
+			label$176:;
 			label$175:;
-			label$174:;
 			struct $7ASTNODE* vr$4 = HCHECKID( BASE_PARENT$1, CHAIN_$1 );
 			fb$result$1 = vr$4;
-			goto label$168;
+			goto label$169;
 		}
-		goto label$171;
-		label$176:;
+		goto label$172;
+		label$177:;
 		{
-			if( *(int64*)((uint8*)&ENV$ + 272ll) != 3ll ) goto label$178;
+			if( *(int64*)((uint8*)&ENV$ + 272ll) != 3ll ) goto label$179;
 			{
-				struct $7ASTNODE* vr$7 = HCHECKID( BASE_PARENT$1, *(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 2088ll) );
+				struct $7ASTNODE* vr$7 = HCHECKID( BASE_PARENT$1, *(struct $10FBSYMCHAIN**)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 2088ll) );
 				fb$result$1 = vr$7;
-				goto label$168;
+				goto label$169;
 			}
+			label$179:;
 			label$178:;
-			label$177:;
 		}
-		goto label$171;
-		label$179:;
+		goto label$172;
+		label$180:;
 		{
 			struct $7ASTNODE* vr$8 = CNUMLITERAL( -1ll );
 			fb$result$1 = vr$8;
-			goto label$168;
+			goto label$169;
 		}
-		goto label$171;
-		label$180:;
+		goto label$172;
+		label$181:;
 		{
 			struct $7ASTNODE* vr$9 = CSTRLITERAL( -1ll );
 			fb$result$1 = vr$9;
-			goto label$168;
+			goto label$169;
 		}
-		goto label$171;
-		label$181:;
+		goto label$172;
+		label$182:;
 		{
 			int64 vr$10 = LEXGETTOKEN( 0ll );
-			if( vr$10 == 46ll ) goto label$183;
+			if( vr$10 == 46ll ) goto label$184;
 			{
 				fb$result$1 = (struct $7ASTNODE*)0ull;
-				goto label$168;
+				goto label$169;
 			}
+			label$184:;
 			label$183:;
-			label$182:;
-			if( *(struct $13FB_CMPSTMTSTK**)((uint8*)&PARSER$ + 104ll) == (struct $13FB_CMPSTMTSTK*)0ull ) goto label$185;
+			if( *(struct $13FB_CMPSTMTSTK**)((uint8*)&PARSER$ + 104ll) == (struct $13FB_CMPSTMTSTK*)0ull ) goto label$186;
 			{
 				int64 vr$11 = LEXGETLOOKAHEAD( 1ll, 64ll );
-				if( vr$11 == 46ll ) goto label$187;
+				if( vr$11 == 46ll ) goto label$188;
 				{
-					struct $7ASTNODE* vr$14 = CWITHVARIABLE( (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 2ll) != 0ll) );
+					struct $7ASTNODE* vr$14 = CWITHVARIABLE( (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 2ll) != 0ll) );
 					fb$result$1 = vr$14;
-					goto label$168;
+					goto label$169;
 				}
+				label$188:;
 				label$187:;
-				label$186:;
 			}
+			label$186:;
 			label$185:;
-			label$184:;
 			struct $10FBSYMCHAIN* vr$16 = CIDENTIFIER( &BASE_PARENT$1, 50ll );
 			CHAIN_$1 = vr$16;
-			if( CHAIN_$1 == (struct $10FBSYMCHAIN*)0ull ) goto label$189;
+			if( CHAIN_$1 == (struct $10FBSYMCHAIN*)0ull ) goto label$190;
 			{
 				struct $7ASTNODE* vr$17 = HFINDID( BASE_PARENT$1, CHAIN_$1, 0ll );
 				fb$result$1 = vr$17;
-				goto label$168;
+				goto label$169;
 			}
+			label$190:;
 			label$189:;
-			label$188:;
 		}
-		goto label$171;
-		label$172:;
-		static const void* tmp$95[7ll] = {
-			&&label$173,
-			&&label$173,
-			&&label$173,
-			&&label$179,
+		goto label$172;
+		label$173:;
+		static const void* tmp$100[7ll] = {
+			&&label$174,
+			&&label$174,
+			&&label$174,
 			&&label$180,
-			&&label$176,
 			&&label$181,
+			&&label$177,
+			&&label$182,
 		};
-		if( TMP$94$2 > 6ull ) goto label$171;
-		goto *tmp$95[TMP$94$2 - 0ull];
-		label$171:;
+		if( TMP$99$2 > 6ull ) goto label$172;
+		goto *tmp$100[TMP$99$2 - 0ull];
+		label$172:;
 	}
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	label$168:;
+	label$169:;
 	return fb$result$1;
 }
 
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1409,7 +1452,7 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 	uint8* vr$1 = LEXGETTEXT(  );
 	ID$1 = vr$1;
 	int64 SUFFIX$1;
-	SUFFIX$1 = *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 16ll);
+	SUFFIX$1 = *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 16ll);
 	int64 DEFDTYPE$1;
 	int64 vr$4 = SYMBGETDEFTYPE( (uint8*)ID$1 );
 	DEFDTYPE$1 = vr$4;
@@ -1425,15 +1468,15 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 			{
 				int64 IS_MATCH$4;
 				IS_MATCH$4 = -1ll;
-				if( (*(int64*)((uint8*)SYM$2 + 8ll) & 268435456ll) == 0ll ) goto label$59;
+				if( (*(int64*)((uint8*)SYM$2 + 8ll) & 1048576ll) == 0ll ) goto label$59;
 				{
 					if( *(int64*)SYM$2 != 1ll ) goto label$61;
 					{
 						if( DEFDTYPE$1 != 17ll ) goto label$63;
 						{
 							{
-								uint64 TMP$88$8;
-								TMP$88$8 = (uint64)(*(int64*)((uint8*)SYM$2 + 48ll) & 511ll);
+								uint64 TMP$93$8;
+								TMP$93$8 = (uint64)(*(int64*)((uint8*)SYM$2 + 56ll) & 511ll);
 								goto label$65;
 								label$66:;
 								{
@@ -1445,7 +1488,7 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 								}
 								goto label$64;
 								label$65:;
-								static const void* tmp$96[15ll] = {
+								static const void* tmp$101[15ll] = {
 									&&label$66,
 									&&label$67,
 									&&label$67,
@@ -1462,15 +1505,15 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 									&&label$66,
 									&&label$66,
 								};
-								if( (TMP$88$8 - 4ull) > 14ull ) goto label$67;
-								goto *tmp$96[TMP$88$8 - 4ull];
+								if( (TMP$93$8 - 4ull) > 14ull ) goto label$67;
+								goto *tmp$101[TMP$93$8 - 4ull];
 								label$64:;
 							}
 						}
 						goto label$62;
 						label$63:;
 						{
-							IS_MATCH$4 = (int64)-((*(int64*)((uint8*)SYM$2 + 48ll) & 511ll) == DEFDTYPE$1);
+							IS_MATCH$4 = (int64)-((*(int64*)((uint8*)SYM$2 + 56ll) & 511ll) == DEFDTYPE$1);
 						}
 						label$62:;
 					}
@@ -1482,8 +1525,8 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 				if( IS_MATCH$4 == 0ll ) goto label$69;
 				{
 					{
-						uint64 TMP$89$6;
-						TMP$89$6 = *(uint64*)SYM$2;
+						uint64 TMP$94$6;
+						TMP$94$6 = *(uint64*)SYM$2;
 						goto label$71;
 						label$72:;
 						{
@@ -1494,9 +1537,9 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 						goto label$70;
 						label$73:;
 						{
-							if( (*(int64*)((uint8*)SYM$2 + 16ll) & 32ll) == 0ll ) goto label$75;
+							if( (*(int64*)((uint8*)SYM$2 + 24ll) & 32ll) == 0ll ) goto label$75;
 							{
-								IS_MATCH$4 = (int64)-((*(int64*)((uint8*)SYM$2 + 8ll) & 268435456ll) == 0ll);
+								IS_MATCH$4 = (int64)-((*(int64*)((uint8*)SYM$2 + 8ll) & 1048576ll) == 0ll);
 							}
 							label$75:;
 							label$74:;
@@ -1528,7 +1571,7 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 						goto label$70;
 						label$83:;
 						{
-							if( (*(int64*)((uint8*)SYM$2 + 8ll) & 268435456ll) != 0ll ) goto label$85;
+							if( (*(int64*)((uint8*)SYM$2 + 8ll) & 1048576ll) != 0ll ) goto label$85;
 							{
 								struct $7ASTNODE* vr$25 = CQUIRKFUNCTION( SYM$2 );
 								fb$result$1 = vr$25;
@@ -1539,7 +1582,7 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 						}
 						goto label$70;
 						label$71:;
-						static const void* tmp$97[6ll] = {
+						static const void* tmp$102[6ll] = {
 							&&label$78,
 							&&label$72,
 							&&label$73,
@@ -1547,14 +1590,14 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 							&&label$70,
 							&&label$83,
 						};
-						if( (TMP$89$6 - 1ull) > 5ull ) goto label$70;
-						goto *tmp$97[TMP$89$6 - 1ull];
+						if( (TMP$94$6 - 1ull) > 5ull ) goto label$70;
+						goto *tmp$102[TMP$94$6 - 1ull];
 						label$70:;
 					}
 				}
 				label$69:;
 				label$68:;
-				SYM$2 = *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 264ll);
+				SYM$2 = *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 280ll);
 			}
 			label$57:;
 			if( SYM$2 != (struct $8FBSYMBOL*)0ull ) goto label$55;
@@ -1569,8 +1612,8 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 				if( SUFFIX$1 != 17ll ) goto label$90;
 				{
 					{
-						uint64 TMP$90$6;
-						TMP$90$6 = (uint64)(*(int64*)((uint8*)SYM$2 + 48ll) & 511ll);
+						uint64 TMP$95$6;
+						TMP$95$6 = (uint64)(*(int64*)((uint8*)SYM$2 + 56ll) & 511ll);
 						goto label$92;
 						label$93:;
 						{
@@ -1583,7 +1626,7 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 						}
 						goto label$91;
 						label$92:;
-						static const void* tmp$98[15ll] = {
+						static const void* tmp$103[15ll] = {
 							&&label$93,
 							&&label$94,
 							&&label$94,
@@ -1600,22 +1643,22 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 							&&label$93,
 							&&label$93,
 						};
-						if( (TMP$90$6 - 4ull) > 14ull ) goto label$94;
-						goto *tmp$98[TMP$90$6 - 4ull];
+						if( (TMP$95$6 - 4ull) > 14ull ) goto label$94;
+						goto *tmp$103[TMP$95$6 - 4ull];
 						label$91:;
 					}
 				}
 				goto label$89;
 				label$90:;
 				{
-					IS_MATCH$4 = (int64)-((*(int64*)((uint8*)SYM$2 + 48ll) & 511ll) == SUFFIX$1);
+					IS_MATCH$4 = (int64)-((*(int64*)((uint8*)SYM$2 + 56ll) & 511ll) == SUFFIX$1);
 				}
 				label$89:;
 				if( IS_MATCH$4 == 0ll ) goto label$96;
 				{
 					{
-						uint64 TMP$91$6;
-						TMP$91$6 = *(uint64*)SYM$2;
+						uint64 TMP$96$6;
+						TMP$96$6 = *(uint64*)SYM$2;
 						goto label$98;
 						label$99:;
 						{
@@ -1655,7 +1698,7 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 						}
 						goto label$97;
 						label$98:;
-						static const void* tmp$99[6ll] = {
+						static const void* tmp$104[6ll] = {
 							&&label$101,
 							&&label$99,
 							&&label$100,
@@ -1663,8 +1706,8 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 							&&label$97,
 							&&label$106,
 						};
-						if( (TMP$91$6 - 1ull) > 5ull ) goto label$97;
-						goto *tmp$99[TMP$91$6 - 1ull];
+						if( (TMP$96$6 - 1ull) > 5ull ) goto label$97;
+						goto *tmp$104[TMP$96$6 - 1ull];
 						label$97:;
 					}
 				}
@@ -1673,7 +1716,7 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 				{
 					if( *(int64*)SYM$2 != 6ll ) goto label$108;
 					{
-						if( *(int64*)((uint8*)SYM$2 + 88ll) != 476ll ) goto label$110;
+						if( *(int64*)((uint8*)SYM$2 + 96ll) != 477ll ) goto label$110;
 						{
 							if( SUFFIX$1 != 17ll ) goto label$112;
 							{
@@ -1691,7 +1734,7 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 					label$107:;
 				}
 				label$95:;
-				SYM$2 = *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 264ll);
+				SYM$2 = *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 280ll);
 			}
 			label$88:;
 			if( SYM$2 != (struct $8FBSYMBOL*)0ull ) goto label$86;
@@ -1700,7 +1743,7 @@ static struct $7ASTNODE* HFINDID_QB( struct $8FBSYMBOL* BASE_PARENT$1, struct $1
 		label$53:;
 		if( VAR_SYM$2 == (struct $8FBSYMBOL*)0ull ) goto label$114;
 		{
-			struct $7ASTNODE* vr$43 = _Z11CVARIABLEEXP8FBSYMBOLu7INTEGER( VAR_SYM$2, (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 2ll) != 0ll) );
+			struct $7ASTNODE* vr$43 = _Z11CVARIABLEEXP8FBSYMBOLu7INTEGER( VAR_SYM$2, (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 2ll) != 0ll) );
 			fb$result$1 = vr$43;
 			goto label$49;
 		}
@@ -1736,8 +1779,8 @@ static struct $7ASTNODE* HFINDID( struct $8FBSYMBOL* BASE_PARENT$1, struct $10FB
 		label$122:;
 		{
 			{
-				uint64 TMP$92$4;
-				TMP$92$4 = *(uint64*)SYM$2;
+				uint64 TMP$97$4;
+				TMP$97$4 = *(uint64*)SYM$2;
 				goto label$126;
 				label$127:;
 				{
@@ -1755,14 +1798,14 @@ static struct $7ASTNODE* HFINDID( struct $8FBSYMBOL* BASE_PARENT$1, struct $10FB
 				goto label$125;
 				label$129:;
 				{
-					struct $7ASTNODE* vr$8 = _Z11CVARIABLEEXP10FBSYMCHAINu7INTEGER( CHAIN_$1, (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 2ll) != 0ll) );
+					struct $7ASTNODE* vr$8 = _Z11CVARIABLEEXP10FBSYMCHAINu7INTEGER( CHAIN_$1, (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 2ll) != 0ll) );
 					fb$result$1 = vr$8;
 					goto label$116;
 				}
 				goto label$125;
 				label$130:;
 				{
-					struct $7ASTNODE* vr$11 = CIMPLICITDATAMEMBER( BASE_PARENT$1, CHAIN_$1, (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 2ll) != 0ll), OPTIONS$1 );
+					struct $7ASTNODE* vr$11 = CIMPLICITDATAMEMBER( BASE_PARENT$1, CHAIN_$1, (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 2ll) != 0ll), OPTIONS$1 );
 					fb$result$1 = vr$11;
 					goto label$116;
 				}
@@ -1792,7 +1835,7 @@ static struct $7ASTNODE* HFINDID( struct $8FBSYMBOL* BASE_PARENT$1, struct $10FB
 					if( vr$15 == (struct $8FBSYMBOL*)0ull ) goto label$136;
 					{
 						HCOMPLAINIFABSTRACTCLASS( 20ll, SYM$2 );
-						LEXSKIPTOKEN( 0ll );
+						LEXSKIPTOKEN( 2048ll );
 						struct $7ASTNODE* vr$16 = CCTORCALL( SYM$2 );
 						struct $7ASTNODE* vr$17 = CSTRIDXORMEMBERDEREF( vr$16 );
 						fb$result$1 = vr$17;
@@ -1807,9 +1850,9 @@ static struct $7ASTNODE* HFINDID( struct $8FBSYMBOL* BASE_PARENT$1, struct $10FB
 					int64 vr$18 = SYMBHASCTOR( SYM$2 );
 					if( vr$18 == 0ll ) goto label$139;
 					{
-						HCOMPLAINIFABSTRACTCLASS( 20ll, *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 56ll) );
-						LEXSKIPTOKEN( 0ll );
-						struct $7ASTNODE* vr$21 = CCTORCALL( *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 56ll) );
+						HCOMPLAINIFABSTRACTCLASS( 20ll, *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 64ll) );
+						LEXSKIPTOKEN( 2048ll );
+						struct $7ASTNODE* vr$21 = CCTORCALL( *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 64ll) );
 						struct $7ASTNODE* vr$22 = CSTRIDXORMEMBERDEREF( vr$21 );
 						fb$result$1 = vr$22;
 						goto label$116;
@@ -1818,8 +1861,13 @@ static struct $7ASTNODE* HFINDID( struct $8FBSYMBOL* BASE_PARENT$1, struct $10FB
 					label$138:;
 				}
 				goto label$125;
+				label$140:;
+				{
+					ERRREPORT( 325ll, 0ll, (uint8*)0ull );
+				}
+				goto label$125;
 				label$126:;
-				static const void* tmp$100[13ll] = {
+				static const void* tmp$105[16ll] = {
 					&&label$129,
 					&&label$127,
 					&&label$128,
@@ -1833,12 +1881,15 @@ static struct $7ASTNODE* HFINDID( struct $8FBSYMBOL* BASE_PARENT$1, struct $10FB
 					&&label$134,
 					&&label$130,
 					&&label$137,
+					&&label$125,
+					&&label$125,
+					&&label$140,
 				};
-				if( (TMP$92$4 - 1ull) > 12ull ) goto label$125;
-				goto *tmp$100[TMP$92$4 - 1ull];
+				if( (TMP$97$4 - 1ull) > 15ull ) goto label$125;
+				goto *tmp$105[TMP$97$4 - 1ull];
 				label$125:;
 			}
-			SYM$2 = *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 264ll);
+			SYM$2 = *(struct $8FBSYMBOL**)((uint8*)SYM$2 + 280ll);
 		}
 		label$124:;
 		if( SYM$2 != (struct $8FBSYMBOL*)0ull ) goto label$122;
@@ -1857,67 +1908,67 @@ static struct $7ASTNODE* HBASEMEMBERACCESS( void )
 {
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$140:;
+	label$141:;
 	struct $8FBSYMBOL* PROC$1;
-	PROC$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll);
-	if( (*(int64*)((uint8*)PROC$1 + 8ll) & 2048ll) != 0ll ) goto label$143;
+	PROC$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll);
+	if( (*(int64*)((uint8*)PROC$1 + 16ll) & 2ll) != 0ll ) goto label$144;
 	{
 		ERRREPORT( 294ll, 0ll, (uint8*)0ull );
 		HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
 		struct $7ASTNODE* vr$3 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
 		fb$result$1 = vr$3;
-		goto label$141;
+		goto label$142;
 	}
-	label$143:;
-	label$142:;
-	struct $8FBSYMBOL* PARENT$1;
-	PARENT$1 = *(struct $8FBSYMBOL**)*(struct $8FBHASHTB**)((uint8*)PROC$1 + 232ll);
-	struct $8FBSYMBOL* BASE_$1;
-	BASE_$1 = *(struct $8FBSYMBOL**)((uint8*)PARENT$1 + 168ll);
 	label$144:;
+	label$143:;
+	struct $8FBSYMBOL* PARENT$1;
+	PARENT$1 = *(struct $8FBSYMBOL**)*(struct $8FBHASHTB**)((uint8*)PROC$1 + 248ll);
+	struct $8FBSYMBOL* BASE_$1;
+	BASE_$1 = *(struct $8FBSYMBOL**)((uint8*)PARENT$1 + 176ll);
+	label$145:;
 	{
-		if( BASE_$1 != (struct $8FBSYMBOL*)0ull ) goto label$148;
+		if( BASE_$1 != (struct $8FBSYMBOL*)0ull ) goto label$149;
 		{
 			ERRREPORT( 295ll, 0ll, (uint8*)0ull );
 			HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
 			struct $7ASTNODE* vr$7 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
 			fb$result$1 = vr$7;
-			goto label$141;
+			goto label$142;
 		}
+		label$149:;
 		label$148:;
-		label$147:;
-		LEXSKIPTOKEN( 64ll );
-		int64 vr$8 = HMATCH( 46ll );
-		if( vr$8 != 0ll ) goto label$150;
+		LEXSKIPTOKEN( 2112ll );
+		int64 vr$8 = HMATCH( 46ll, 0ll );
+		if( vr$8 != 0ll ) goto label$151;
 		{
 			ERRREPORT( 120ll, 0ll, (uint8*)0ull );
 			HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
 			struct $7ASTNODE* vr$9 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
 			fb$result$1 = vr$9;
-			goto label$141;
+			goto label$142;
 		}
-		label$150:;
-		label$149:;
-		int64 vr$10 = LEXGETTOKEN( 0ll );
-		if( vr$10 == 353ll ) goto label$152;
-		{
-			goto label$145;
-		}
-		label$152:;
 		label$151:;
-		BASE_$1 = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)BASE_$1 + 56ll) + 168ll);
+		label$150:;
+		int64 vr$10 = LEXGETTOKEN( 0ll );
+		if( vr$10 == 353ll ) goto label$153;
+		{
+			goto label$146;
+		}
+		label$153:;
+		label$152:;
+		BASE_$1 = *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)BASE_$1 + 64ll) + 176ll);
 	}
+	label$147:;
+	goto label$145;
 	label$146:;
-	goto label$144;
-	label$145:;
 	struct $10FBSYMCHAIN CHAIN_$1;
 	*(struct $8FBSYMBOL**)&CHAIN_$1 = BASE_$1;
 	*(struct $10FBSYMCHAIN**)((uint8*)&CHAIN_$1 + 8ll) = (struct $10FBSYMCHAIN*)0ull;
 	*(int64*)((uint8*)&CHAIN_$1 + 16ll) = 0ll;
 	__builtin_memset( (void*)((uint8*)&CHAIN_$1 + 24ll), 0, 24ll );
-	struct $7ASTNODE* vr$16 = HFINDID( *(struct $8FBSYMBOL**)((uint8*)BASE_$1 + 56ll), &CHAIN_$1, 2048ll );
+	struct $7ASTNODE* vr$16 = HFINDID( *(struct $8FBSYMBOL**)((uint8*)BASE_$1 + 64ll), &CHAIN_$1, 2048ll );
 	fb$result$1 = vr$16;
-	label$141:;
+	label$142:;
 	return fb$result$1;
 }
 
@@ -1925,63 +1976,63 @@ static struct $7ASTNODE* HCHECKID( struct $8FBSYMBOL* BASE_PARENT$1, struct $10F
 {
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$153:;
+	label$154:;
 	struct $7ASTNODE* EXPR$1;
-	if( CHAIN_$1 == (struct $10FBSYMCHAIN*)0ull ) goto label$156;
+	if( CHAIN_$1 == (struct $10FBSYMCHAIN*)0ull ) goto label$157;
 	{
 		struct $7ASTNODE* vr$1 = HFINDID( BASE_PARENT$1, CHAIN_$1, 0ll );
 		EXPR$1 = vr$1;
-		if( EXPR$1 == (struct $7ASTNODE*)0ull ) goto label$158;
+		if( EXPR$1 == (struct $7ASTNODE*)0ull ) goto label$159;
 		{
 			fb$result$1 = EXPR$1;
-			goto label$154;
+			goto label$155;
 		}
+		label$159:;
 		label$158:;
-		label$157:;
 	}
+	label$157:;
 	label$156:;
-	label$155:;
-	if( (*(int64*)((uint8*)&PARSER$ + 288ll) & 1024ll) == 0ll ) goto label$160;
+	if( (*(int64*)((uint8*)&PARSER$ + 296ll) & 1024ll) == 0ll ) goto label$161;
 	{
-		FBSTRING TMP$93$2;
-		__builtin_memset( &TMP$93$2, 0, 24ll );
+		FBSTRING TMP$98$2;
+		__builtin_memset( &TMP$98$2, 0, 24ll );
 		uint8* vr$4 = LEXGETTEXT(  );
 		FBSTRING* vr$5 = fb_StrAllocTempDescZ( (uint8*)vr$4 );
 		FBSTRING* vr$6 = fb_StrUcase2( (FBSTRING*)vr$5, 0 );
-		FBSTRING* vr$8 = fb_StrAssign( (void*)&TMP$93$2, -1ll, (void*)vr$6, -1ll, 0 );
-		struct $7ASTNODE* vr$9 = ASTNEWCONSTSTR( (uint8*)*(uint8**)&TMP$93$2 );
-		EXPR$1 = vr$9;
-		fb_StrDelete( (FBSTRING*)&TMP$93$2 );
+		fb_StrAssign( (void*)&TMP$98$2, -1ll, (void*)vr$6, -1ll, 0 );
+		struct $7ASTNODE* vr$8 = ASTNEWCONSTSTR( (uint8*)*(uint8**)&TMP$98$2 );
+		EXPR$1 = vr$8;
+		fb_StrDelete( (FBSTRING*)&TMP$98$2 );
 		LEXSKIPTOKEN( 0ll );
 		fb$result$1 = EXPR$1;
-		goto label$154;
+		goto label$155;
 	}
+	label$161:;
 	label$160:;
-	label$159:;
-	if( *(int64*)((uint8*)&ENV$ + 272ll) == 3ll ) goto label$162;
+	if( *(int64*)((uint8*)&ENV$ + 272ll) == 3ll ) goto label$163;
 	{
-		int64 vr$11 = LEXGETCLASS( 0ll );
-		if( vr$11 == 0ll ) goto label$164;
+		int64 vr$10 = LEXGETCLASS( 0ll );
+		if( vr$10 == 0ll ) goto label$165;
 		{
 			fb$result$1 = (struct $7ASTNODE*)0ull;
-			goto label$154;
+			goto label$155;
 		}
+		label$165:;
 		label$164:;
-		label$163:;
 	}
+	label$163:;
 	label$162:;
-	label$161:;
-	goto label$166;
+	goto label$167;
 	{
 		ERRREPORTNOTALLOWED( 2097152ll, 149ll, (uint8*)0ull );
 		fb$result$1 = (struct $7ASTNODE*)0ull;
-		goto label$154;
+		goto label$155;
 	}
+	label$167:;
 	label$166:;
-	label$165:;
-	struct $7ASTNODE* vr$14 = _Z11CVARIABLEEXP10FBSYMCHAINu7INTEGER( (struct $10FBSYMCHAIN*)0ull, (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 2ll) != 0ll) );
-	fb$result$1 = vr$14;
-	goto label$154;
-	label$154:;
+	struct $7ASTNODE* vr$13 = _Z11CVARIABLEEXP10FBSYMCHAINu7INTEGER( (struct $10FBSYMCHAIN*)0ull, (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 2ll) != 0ll) );
+	fb$result$1 = vr$13;
+	goto label$155;
+	label$155:;
 	return fb$result$1;
 }
