@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -659,10 +698,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -680,20 +720,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
 struct $10TSTACKNODE {
@@ -843,6 +885,7 @@ __FB_STATIC_ASSERT( sizeof( struct $13FBPARSER_STMT ) == 176 );
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -854,7 +897,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 struct $7ASTNODE* CEXPRESSION( void )
@@ -863,26 +906,26 @@ struct $7ASTNODE* CEXPRESSION( void )
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
 	int64 LAST_ISEXPR$1;
-	LAST_ISEXPR$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 4ll) != 0ll);
+	LAST_ISEXPR$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 4ll) != 0ll);
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 4ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 4ll;
 	}
 	goto label$12;
 	label$13:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -5ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -5ll;
 	}
 	label$12:;
 	struct $7ASTNODE* vr$5 = CBOOLEXPRESSION(  );
 	fb$result$1 = vr$5;
 	if( LAST_ISEXPR$1 == 0ll ) goto label$15;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 4ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 4ll;
 	}
 	goto label$14;
 	label$15:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -5ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -5ll;
 	}
 	label$14:;
 	label$11:;
@@ -895,27 +938,27 @@ struct $7ASTNODE* CEXPRESSIONWITHNIDXARRAY( int64 ALLOW_NIDXARRAY$1 )
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$16:;
 	int64 OLDCHECKARRAY$1;
-	OLDCHECKARRAY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 288ll) & 2ll) != 0ll);
+	OLDCHECKARRAY$1 = (int64)-((*(int64*)((uint8*)&PARSER$ + 296ll) & 2ll) != 0ll);
 	if( ~ALLOW_NIDXARRAY$1 == 0ll ) goto label$19;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 2ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 2ll;
 	}
 	goto label$18;
 	label$19:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -3ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -3ll;
 	}
 	label$18:;
 	struct $7ASTNODE* vr$6 = CEXPRESSION(  );
 	fb$result$1 = vr$6;
 	if( OLDCHECKARRAY$1 == 0ll ) goto label$21;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 2ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 2ll;
 	}
 	goto label$20;
 	label$21:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -3ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -3ll;
 	}
 	label$20:;
 	label$17:;
@@ -943,9 +986,9 @@ struct $7ASTNODE* CBOOLEXPRESSION( void )
 	label$26:;
 	{
 		{
-			uint64 TMP$89$3;
+			uint64 TMP$94$3;
 			int64 vr$2 = LEXGETTOKEN( 0ll );
-			TMP$89$3 = (uint64)vr$2;
+			TMP$94$3 = (uint64)vr$2;
 			goto label$30;
 			label$31:;
 			{
@@ -963,12 +1006,12 @@ struct $7ASTNODE* CBOOLEXPRESSION( void )
 			}
 			goto label$29;
 			label$30:;
-			static const void* tmp$90[2ll] = {
+			static const void* tmp$95[2ll] = {
 				&&label$31,
 				&&label$32,
 			};
-			if( (TMP$89$3 - 290ull) > 1ull ) goto label$33;
-			goto *tmp$90[TMP$89$3 - 290ull];
+			if( (TMP$94$3 - 290ull) > 1ull ) goto label$33;
+			goto *tmp$95[TMP$94$3 - 290ull];
 			label$29:;
 		}
 		int64 vr$3 = LEXGETLOOKAHEAD( 1ll, 0ll );
@@ -979,7 +1022,7 @@ struct $7ASTNODE* CBOOLEXPRESSION( void )
 		}
 		label$35:;
 		label$34:;
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		ASTDTORLISTSCOPEBEGIN( 0ll );
 		struct $7ASTNODE* vr$5 = CLOGEXPRESSION(  );
 		EXPR$1 = vr$5;
@@ -1031,9 +1074,9 @@ struct $7ASTNODE* CLOGEXPRESSION( void )
 	label$44:;
 	{
 		{
-			uint64 TMP$91$3;
+			uint64 TMP$96$3;
 			int64 vr$2 = LEXGETTOKEN( 0ll );
-			TMP$91$3 = (uint64)vr$2;
+			TMP$96$3 = (uint64)vr$2;
 			goto label$48;
 			label$49:;
 			{
@@ -1056,13 +1099,13 @@ struct $7ASTNODE* CLOGEXPRESSION( void )
 			}
 			goto label$47;
 			label$48:;
-			static const void* tmp$92[3ll] = {
+			static const void* tmp$97[3ll] = {
 				&&label$49,
 				&&label$50,
 				&&label$51,
 			};
-			if( (TMP$91$3 - 292ull) > 2ull ) goto label$52;
-			goto *tmp$92[TMP$91$3 - 292ull];
+			if( (TMP$96$3 - 292ull) > 2ull ) goto label$52;
+			goto *tmp$97[TMP$96$3 - 292ull];
 			label$47:;
 		}
 		int64 vr$3 = LEXGETLOOKAHEAD( 1ll, 0ll );
@@ -1073,7 +1116,7 @@ struct $7ASTNODE* CLOGEXPRESSION( void )
 		}
 		label$54:;
 		label$53:;
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		struct $7ASTNODE* vr$5 = CLOGOREXPRESSION(  );
 		EXPR$1 = vr$5;
 		if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$56;
@@ -1135,7 +1178,7 @@ struct $7ASTNODE* CLOGOREXPRESSION( void )
 		}
 		label$69:;
 		label$68:;
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		struct $7ASTNODE* vr$5 = CLOGANDEXPRESSION(  );
 		EXPR$1 = vr$5;
 		if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$71;
@@ -1197,7 +1240,7 @@ struct $7ASTNODE* CLOGANDEXPRESSION( void )
 		}
 		label$84:;
 		label$83:;
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		struct $7ASTNODE* vr$5 = CRELEXPRESSION(  );
 		EXPR$1 = vr$5;
 		if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$86;
@@ -1246,14 +1289,14 @@ struct $7ASTNODE* CRELEXPRESSION( void )
 	label$93:;
 	{
 		{
-			uint64 TMP$93$3;
+			uint64 TMP$98$3;
 			int64 vr$2 = LEXGETTOKEN( 0ll );
-			TMP$93$3 = (uint64)vr$2;
+			TMP$98$3 = (uint64)vr$2;
 			goto label$97;
 			label$98:;
 			{
-				*(int64*)((uint8*)&PARSER$ + 312ll) = (int64)-(*(int64*)((uint8*)&PARSER$ + 280ll) == 0ll);
-				if( (*(int64*)((uint8*)&PARSER$ + 288ll) & 256ll) == 0ll ) goto label$100;
+				*(int64*)((uint8*)&PARSER$ + 320ll) = (int64)-(*(int64*)((uint8*)&PARSER$ + 288ll) == 0ll);
+				if( (*(int64*)((uint8*)&PARSER$ + 296ll) & 256ll) == 0ll ) goto label$100;
 				{
 					goto label$94;
 				}
@@ -1264,7 +1307,7 @@ struct $7ASTNODE* CRELEXPRESSION( void )
 			goto label$96;
 			label$101:;
 			{
-				if( (*(int64*)((uint8*)&PARSER$ + 288ll) & 512ll) == 0ll ) goto label$103;
+				if( (*(int64*)((uint8*)&PARSER$ + 296ll) & 512ll) == 0ll ) goto label$103;
 				{
 					goto label$94;
 				}
@@ -1299,7 +1342,7 @@ struct $7ASTNODE* CRELEXPRESSION( void )
 			}
 			goto label$96;
 			label$97:;
-			static const void* tmp$94[6ll] = {
+			static const void* tmp$99[6ll] = {
 				&&label$98,
 				&&label$101,
 				&&label$104,
@@ -1307,8 +1350,8 @@ struct $7ASTNODE* CRELEXPRESSION( void )
 				&&label$106,
 				&&label$107,
 			};
-			if( (TMP$93$3 - 299ull) > 5ull ) goto label$108;
-			goto *tmp$94[TMP$93$3 - 299ull];
+			if( (TMP$98$3 - 299ull) > 5ull ) goto label$108;
+			goto *tmp$99[TMP$98$3 - 299ull];
 			label$96:;
 		}
 		LEXSKIPTOKEN( 0ll );
@@ -1342,8 +1385,8 @@ struct $7ASTNODE* CRELEXPRESSION( void )
 
 struct $7ASTNODE* CISEXPRESSION( void )
 {
-	int64 TMP$95$1;
-	int64 TMP$96$1;
+	int64 TMP$100$1;
+	int64 TMP$101$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$113:;
@@ -1367,7 +1410,7 @@ struct $7ASTNODE* CISEXPRESSION( void )
 	label$117:;
 	if( (*(int64*)((uint8*)ISEXPR$1 + 8ll) & 511ll) != 20ll ) goto label$120;
 	{
-		if( (*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)ISEXPR$1 + 16ll) + 16ll) & 4194304ll) != 0ll ) goto label$122;
+		if( (*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)ISEXPR$1 + 16ll) + 24ll) & 4194304ll) != 0ll ) goto label$122;
 		{
 			ERRREPORT( 297ll, 0ll, (uint8*)0ull );
 			struct $7ASTNODE* vr$8 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
@@ -1384,12 +1427,12 @@ struct $7ASTNODE* CISEXPRESSION( void )
 		ISEXPR$1 = vr$9;
 	}
 	label$119:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	int64 DTYPE$1;
 	struct $8FBSYMBOL* SUBTYPE$1;
-	TMP$96$1 = 0ll;
-	TMP$95$1 = 0ll;
-	int64 vr$14 = CSYMBOLTYPE( &DTYPE$1, &SUBTYPE$1, &TMP$95$1, &TMP$96$1, 1ll );
+	TMP$101$1 = 0ll;
+	TMP$100$1 = 0ll;
+	int64 vr$14 = CSYMBOLTYPE( &DTYPE$1, &SUBTYPE$1, &TMP$100$1, &TMP$101$1, 1ll );
 	if( vr$14 != 0ll ) goto label$124;
 	{
 		fb$result$1 = (struct $7ASTNODE*)0ull;
@@ -1399,7 +1442,7 @@ struct $7ASTNODE* CISEXPRESSION( void )
 	label$123:;
 	if( (DTYPE$1 & 511ll) != 20ll ) goto label$126;
 	{
-		if( (*(int64*)((uint8*)SUBTYPE$1 + 16ll) & 4194304ll) != 0ll ) goto label$128;
+		if( (*(int64*)((uint8*)SUBTYPE$1 + 24ll) & 4194304ll) != 0ll ) goto label$128;
 		{
 			ERRREPORT( 297ll, 0ll, (uint8*)0ull );
 			struct $7ASTNODE* vr$18 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
@@ -1429,7 +1472,7 @@ struct $7ASTNODE* CISEXPRESSION( void )
 	}
 	label$125:;
 	struct $7ASTNODE* EXPR$1;
-	struct $7ASTNODE* vr$25 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $12FB_STRUCTEXT**)((uint8*)SUBTYPE$1 + 224ll) + 296ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
+	struct $7ASTNODE* vr$25 = ASTNEWVAR( *(struct $8FBSYMBOL**)((uint8*)*(struct $12FB_STRUCTEXT**)((uint8*)SUBTYPE$1 + 240ll) + 304ll), 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	EXPR$1 = vr$25;
 	struct $7ASTNODE* vr$26 = ASTNEWBOP( 51ll, ISEXPR$1, EXPR$1, (struct $8FBSYMBOL*)0ull, 1ll );
 	ISEXPR$1 = vr$26;
@@ -1528,17 +1571,17 @@ struct $7ASTNODE* CADDEXPRESSION( void )
 	label$151:;
 	{
 		{
-			int64 TMP$97$3;
+			int64 TMP$102$3;
 			int64 vr$2 = LEXGETTOKEN( 0ll );
-			TMP$97$3 = vr$2;
-			if( TMP$97$3 != 43ll ) goto label$155;
+			TMP$102$3 = vr$2;
+			if( TMP$102$3 != 43ll ) goto label$155;
 			label$156:;
 			{
 				OP$1 = 28ll;
 			}
 			goto label$154;
 			label$155:;
-			if( TMP$97$3 != 45ll ) goto label$157;
+			if( TMP$102$3 != 45ll ) goto label$157;
 			label$158:;
 			{
 				OP$1 = 29ll;
@@ -1608,17 +1651,17 @@ struct $7ASTNODE* CSHIFTEXPRESSION( void )
 	label$170:;
 	{
 		{
-			int64 TMP$98$3;
+			int64 TMP$103$3;
 			int64 vr$2 = LEXGETTOKEN( 0ll );
-			TMP$98$3 = vr$2;
-			if( TMP$98$3 != 297ll ) goto label$174;
+			TMP$103$3 = vr$2;
+			if( TMP$103$3 != 297ll ) goto label$174;
 			label$175:;
 			{
 				OP$1 = 41ll;
 			}
 			goto label$173;
 			label$174:;
-			if( TMP$98$3 != 298ll ) goto label$176;
+			if( TMP$103$3 != 298ll ) goto label$176;
 			label$177:;
 			{
 				OP$1 = 42ll;
@@ -1639,7 +1682,7 @@ struct $7ASTNODE* CSHIFTEXPRESSION( void )
 		}
 		label$180:;
 		label$179:;
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		struct $7ASTNODE* vr$5 = CMODEXPRESSION(  );
 		EXPR$1 = vr$5;
 		if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$182;
@@ -1701,7 +1744,7 @@ struct $7ASTNODE* CMODEXPRESSION( void )
 		}
 		label$195:;
 		label$194:;
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		struct $7ASTNODE* vr$5 = CINTDIVEXPRESSION(  );
 		EXPR$1 = vr$5;
 		if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$197;
@@ -1812,17 +1855,17 @@ struct $7ASTNODE* CMULTEXPRESSION( void )
 	label$219:;
 	{
 		{
-			int64 TMP$99$3;
+			int64 TMP$104$3;
 			int64 vr$2 = LEXGETTOKEN( 0ll );
-			TMP$99$3 = vr$2;
-			if( TMP$99$3 != 42ll ) goto label$223;
+			TMP$104$3 = vr$2;
+			if( TMP$104$3 != 42ll ) goto label$223;
 			label$224:;
 			{
 				OP$1 = 30ll;
 			}
 			goto label$222;
 			label$223:;
-			if( TMP$99$3 != 47ll ) goto label$225;
+			if( TMP$104$3 != 47ll ) goto label$225;
 			label$226:;
 			{
 				OP$1 = 31ll;
@@ -1937,7 +1980,7 @@ struct $7ASTNODE* CEXPEXPRESSION( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
