@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -612,6 +651,7 @@ struct $16FB_CALL_ARG_LIST {
 	struct $11FB_CALL_ARG* TAIL;
 };
 __FB_STATIC_ASSERT( sizeof( struct $16FB_CALL_ARG_LIST ) == 24 );
+typedef int64 $8LEXCHECK;
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -631,7 +671,6 @@ struct $7ASTNODE* ASTBUILDBYREFRESULTDEREF( struct $7ASTNODE* );
 struct $8FBSYMBOL* SYMBADDTEMPVAR( int64, struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBGETCOMPCTORHEAD( struct $8FBSYMBOL* );
 struct $11FB_CALL_ARG* SYMBALLOCOVLCALLARG( struct $5TLIST*, struct $16FB_CALL_ARG_LIST*, int64 );
-typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
 struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $7ASTNODE*, struct $16FB_CALL_ARG_LIST*, $12FB_PARSEROPT );
@@ -660,10 +699,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -681,20 +721,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
 struct $10TSTACKNODE {
@@ -844,6 +886,7 @@ __FB_STATIC_ASSERT( sizeof( struct $13FBPARSER_STMT ) == 176 );
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -855,7 +898,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 struct $7ASTNODE* CFUNCTIONCALL( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYMBOL* SYM$1, struct $7ASTNODE* PTREXPR$1, struct $7ASTNODE* THISEXPR$1, $12FB_PARSEROPT OPTIONS$1 )
@@ -877,13 +920,13 @@ struct $7ASTNODE* CFUNCTIONCALL( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSY
 	label$12:;
 	OPTIONS$1 = OPTIONS$1 | 16ll;
 	HMETHODCALLADDINSTPTROVLARG( SYM$1, THISEXPR$1, &ARG_LIST$1, &OPTIONS$1 );
-	if( (*(int64*)((uint8*)SYM$1 + 8ll) & 32768ll) == 0ll ) goto label$15;
+	if( (*(int64*)((uint8*)SYM$1 + 16ll) & 32ll) == 0ll ) goto label$15;
 	{
 		OPTIONS$1 = OPTIONS$1 | 128ll;
 		int64 vr$7 = LEXGETTOKEN( 0ll );
 		if( vr$7 != 40ll ) goto label$17;
 		{
-			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)*(struct $10FBSYMBOLTB**)((uint8*)SYM$1 + 272ll) + 200ll) & 512ll) != 0ll ) goto label$19;
+			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)*(struct $10FBSYMBOLTB**)((uint8*)SYM$1 + 288ll) + 208ll) & 512ll) != 0ll ) goto label$19;
 			{
 				ERRREPORT( 196ll, -1ll, (uint8*)0ull );
 			}
@@ -908,7 +951,7 @@ struct $7ASTNODE* CFUNCTIONCALL( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSY
 		goto label$16;
 		label$17:;
 		{
-			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)*(struct $10FBSYMBOLTB**)((uint8*)SYM$1 + 272ll) + 200ll) & 128ll) != 0ll ) goto label$23;
+			if( ((int64)*(int32*)((uint8*)*(struct $8FBSYMBOL**)*(struct $10FBSYMBOLTB**)((uint8*)SYM$1 + 288ll) + 208ll) & 128ll) != 0ll ) goto label$23;
 			{
 				ERRREPORT( 194ll, 0ll, (uint8*)0ull );
 			}
@@ -970,12 +1013,26 @@ struct $7ASTNODE* CFUNCTIONCALL( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSY
 
 struct $7ASTNODE* CFUNCTIONEX( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYMBOL* SYM$1, $12FB_PARSEROPT OPTIONS$1 )
 {
+	$8LEXCHECK TMP$93$1;
+	$8LEXCHECK TMP$94$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$30:;
-	LEXSKIPTOKEN( 0ll );
-	struct $7ASTNODE* vr$1 = CFUNCTIONCALL( BASE_PARENT$1, SYM$1, (struct $7ASTNODE*)0ull, (struct $7ASTNODE*)0ull, OPTIONS$1 );
-	fb$result$1 = vr$1;
+	if( (*(int64*)((uint8*)SYM$1 + 8ll) & 1048576ll) == 0ll ) goto label$33;
+	if( (*(int64*)((uint8*)SYM$1 + 24ll) & 32ll) == 0ll ) goto label$32;
+	TMP$93$1 = 8192ll;
+	goto label$35;
+	label$32:;
+	TMP$93$1 = 4096ll;
+	label$35:;
+	TMP$94$1 = TMP$93$1;
+	goto label$34;
+	label$33:;
+	TMP$94$1 = 2048ll;
+	label$34:;
+	LEXSKIPTOKEN( TMP$94$1 );
+	struct $7ASTNODE* vr$5 = CFUNCTIONCALL( BASE_PARENT$1, SYM$1, (struct $7ASTNODE*)0ull, (struct $7ASTNODE*)0ull, OPTIONS$1 );
+	fb$result$1 = vr$5;
 	label$31:;
 	return fb$result$1;
 }
@@ -984,32 +1041,32 @@ struct $7ASTNODE* CMETHODCALL( struct $8FBSYMBOL* SYM$1, struct $7ASTNODE* THISE
 {
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$32:;
+	label$36:;
 	struct $7ASTNODE* EXPR$1;
-	LEXSKIPTOKEN( 0ll );
-	if( (*(int64*)((uint8*)&PARSER$ + 288ll) & 4ll) == 0ll ) goto label$35;
+	LEXSKIPTOKEN( 4096ll );
+	if( (*(int64*)((uint8*)&PARSER$ + 296ll) & 4ll) == 0ll ) goto label$39;
 	{
 		struct $7ASTNODE* vr$2 = CFUNCTIONCALL( (struct $8FBSYMBOL*)0ull, SYM$1, (struct $7ASTNODE*)0ull, THISEXPR$1, OPTIONS$1 );
 		EXPR$1 = vr$2;
 	}
-	goto label$34;
-	label$35:;
+	goto label$38;
+	label$39:;
 	{
 		struct $7ASTNODE* vr$3 = CPROCCALL( (struct $8FBSYMBOL*)0ull, SYM$1, (struct $7ASTNODE*)0ull, THISEXPR$1, 0ll, OPTIONS$1 );
 		EXPR$1 = vr$3;
 	}
-	label$34:;
+	label$38:;
 	fb$result$1 = EXPR$1;
-	label$33:;
+	label$37:;
 	return fb$result$1;
 }
 
 struct $7ASTNODE* CCTORCALL( struct $8FBSYMBOL* SYM$1 )
 {
-	$12FB_PARSEROPT TMP$88$1;
+	$12FB_PARSEROPT TMP$95$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$36:;
+	label$40:;
 	struct $8FBSYMBOL* TMP$1;
 	int64 ISPRNT$1;
 	struct $7ASTNODE* PROCEXPR$1;
@@ -1017,64 +1074,64 @@ struct $7ASTNODE* CCTORCALL( struct $8FBSYMBOL* SYM$1 )
 	*(int64*)&ARG_LIST$1 = 0ll;
 	*(struct $11FB_CALL_ARG**)((uint8*)&ARG_LIST$1 + 8ll) = (struct $11FB_CALL_ARG*)0ull;
 	*(struct $11FB_CALL_ARG**)((uint8*)&ARG_LIST$1 + 16ll) = (struct $11FB_CALL_ARG*)0ull;
-	struct $8FBSYMBOL* vr$3 = SYMBADDTEMPVAR( *(int64*)((uint8*)SYM$1 + 48ll) & 511ll, SYM$1 );
+	struct $8FBSYMBOL* vr$3 = SYMBADDTEMPVAR( *(int64*)((uint8*)SYM$1 + 56ll) & 511ll, SYM$1 );
 	TMP$1 = vr$3;
 	ASTDTORLISTADD( TMP$1 );
 	int64 vr$4 = LEXGETTOKEN( 0ll );
-	if( vr$4 != 40ll ) goto label$39;
+	if( vr$4 != 40ll ) goto label$43;
 	{
 		LEXSKIPTOKEN( 0ll );
 		ISPRNT$1 = -1ll;
 	}
-	goto label$38;
-	label$39:;
+	goto label$42;
+	label$43:;
 	{
 		ISPRNT$1 = 0ll;
 	}
-	label$38:;
+	label$42:;
 	struct $11FB_CALL_ARG* ARG$1;
-	struct $11FB_CALL_ARG* vr$7 = SYMBALLOCOVLCALLARG( (struct $5TLIST*)((uint8*)&PARSER$ + 216ll), &ARG_LIST$1, 0ll );
+	struct $11FB_CALL_ARG* vr$7 = SYMBALLOCOVLCALLARG( (struct $5TLIST*)((uint8*)&PARSER$ + 224ll), &ARG_LIST$1, 0ll );
 	ARG$1 = vr$7;
 	struct $7ASTNODE* vr$8 = ASTNEWVAR( TMP$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	*(struct $7ASTNODE**)ARG$1 = vr$8;
 	*($12FB_PARAMMODE*)((uint8*)ARG$1 + 8ll) = -1ll;
-	if( ISPRNT$1 != 0ll ) goto label$40;
-	TMP$88$1 = 32ll;
-	goto label$45;
-	label$40:;
-	TMP$88$1 = 0ll;
-	label$45:;
+	if( ISPRNT$1 != 0ll ) goto label$44;
+	TMP$95$1 = 32ll;
+	goto label$49;
+	label$44:;
+	TMP$95$1 = 0ll;
+	label$49:;
 	struct $8FBSYMBOL* vr$13 = SYMBGETCOMPCTORHEAD( SYM$1 );
-	struct $7ASTNODE* vr$14 = CPROCARGLIST( (struct $8FBSYMBOL*)0ull, vr$13, (struct $7ASTNODE*)0ull, &ARG_LIST$1, TMP$88$1 | 80ll );
+	struct $7ASTNODE* vr$14 = CPROCARGLIST( (struct $8FBSYMBOL*)0ull, vr$13, (struct $7ASTNODE*)0ull, &ARG_LIST$1, TMP$95$1 | 80ll );
 	PROCEXPR$1 = vr$14;
-	if( ISPRNT$1 == 0ll ) goto label$42;
+	if( ISPRNT$1 == 0ll ) goto label$46;
 	{
 		int64 vr$15 = LEXGETTOKEN( 0ll );
-		if( vr$15 == 41ll ) goto label$44;
+		if( vr$15 == 41ll ) goto label$48;
 		{
 			ERRREPORT( 7ll, 0ll, (uint8*)0ull );
 			HSKIPUNTIL( 41ll, -1ll, 0ll, 0ll );
 		}
-		goto label$43;
-		label$44:;
+		goto label$47;
+		label$48:;
 		{
 			LEXSKIPTOKEN( 0ll );
 		}
-		label$43:;
+		label$47:;
 	}
-	label$42:;
-	label$41:;
+	label$46:;
+	label$45:;
 	struct $7ASTNODE* vr$16 = ASTNEWVAR( TMP$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	struct $7ASTNODE* vr$17 = ASTNEWCALLCTOR( PROCEXPR$1, vr$16 );
 	fb$result$1 = vr$17;
-	label$37:;
+	label$41:;
 	return fb$result$1;
 }
 
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
