@@ -37,6 +37,7 @@ __FB_STATIC_ASSERT( sizeof( struct $5TLIST ) == 64 );
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -152,6 +153,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -161,7 +163,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -170,7 +173,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -181,10 +184,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -193,9 +197,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -643,11 +682,11 @@ int64 SYMBCHECKACCESS( struct $8FBSYMBOL* );
 uint8* SYMBGETFULLPROCNAME( struct $8FBSYMBOL* );
 struct $11FB_CALL_ARG* SYMBALLOCOVLCALLARG( struct $5TLIST*, struct $16FB_CALL_ARG_LIST*, int64 );
 void SYMBFREEOVLCALLARGS( struct $5TLIST*, struct $16FB_CALL_ARG_LIST* );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
 int64 LEXGETLOOKAHEAD( int64, $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 struct $7ASTNODE* CEXPRESSION( void );
 void HSKIPUNTIL( int64, int64, $8LEXCHECK, int64 );
 static int64 HPROCARG( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, struct $7ASTNODE**, int64*, int64*, $12FB_PARSEROPT );
@@ -675,10 +714,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -696,20 +736,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
 struct $10TSTACKNODE {
@@ -859,6 +901,7 @@ __FB_STATIC_ASSERT( sizeof( struct $13FBPARSER_STMT ) == 176 );
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -870,20 +913,20 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 void PARSERPROCCALLINIT( void )
 {
 	label$10:;
-	LISTINIT( (struct $5TLIST*)((uint8*)&PARSER$ + 216ll), 128ll, 24ll, 6ll );
+	LISTINIT( (struct $5TLIST*)((uint8*)&PARSER$ + 224ll), 128ll, 24ll, 6ll );
 	label$11:;
 }
 
 void PARSERPROCCALLEND( void )
 {
 	label$12:;
-	LISTEND( (struct $5TLIST*)((uint8*)&PARSER$ + 216ll) );
+	LISTEND( (struct $5TLIST*)((uint8*)&PARSER$ + 224ll) );
 	label$13:;
 }
 
@@ -900,9 +943,9 @@ struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYM
 	struct $7ASTNODE* PROCEXPR$1;
 	struct $7ASTNODE* EXPR$1;
 	struct $11FB_CALL_ARG* ARG$1;
-	if( (*(int64*)((uint8*)PROC$1 + 8ll) & 1024ll) <= 0ll ) goto label$139;
+	if( (*(int64*)((uint8*)PROC$1 + 16ll) & 1ll) <= 0ll ) goto label$139;
 	{
-		if( *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 192ll) == (struct $8FBSYMBOL*)0ull ) goto label$141;
+		if( *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 200ll) == (struct $8FBSYMBOL*)0ull ) goto label$141;
 		{
 			struct $7ASTNODE* vr$4 = HOVLPROCARGLIST( BASE_PARENT$1, PROC$1, ARG_LIST$1, OPTIONS$1 );
 			fb$result$1 = vr$4;
@@ -918,26 +961,26 @@ struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYM
 	int64 vr$5 = SYMBCHECKACCESS( PROC$1 );
 	if( vr$5 != 0ll ) goto label$143;
 	{
-		$9FB_ERRMSG TMP$91$2;
+		$9FB_ERRMSG TMP$96$2;
 		uint8* vr$6 = SYMBGETFULLPROCNAME( PROC$1 );
-		if( (*(int64*)((uint8*)PROC$1 + 8ll) & 4096ll) == 0ll ) goto label$144;
-		TMP$91$2 = 205ll;
+		if( (*(int64*)((uint8*)PROC$1 + 16ll) & 4ll) == 0ll ) goto label$144;
+		TMP$96$2 = 205ll;
 		goto label$192;
 		label$144:;
-		TMP$91$2 = 202ll;
+		TMP$96$2 = 202ll;
 		label$192:;
-		ERRREPORTEX( TMP$91$2, (uint8*)vr$6, 0ll, 1ll, (uint8*)0ull );
+		ERRREPORTEX( TMP$96$2, (uint8*)vr$6, 0ll, 1ll, (uint8*)0ull );
 		struct $7ASTNODE* vr$9 = ASTBUILDFAKECALL( PROC$1 );
 		fb$result$1 = vr$9;
 		goto label$137;
 	}
 	label$143:;
 	label$142:;
-	if( (*(int64*)((uint8*)PROC$1 + 8ll) & 2048ll) == 0ll ) goto label$146;
+	if( (*(int64*)((uint8*)PROC$1 + 16ll) & 2ll) == 0ll ) goto label$146;
 	{
 		if( (OPTIONS$1 & 64ll) != 0ll ) goto label$148;
 		{
-			if( ((int64)-(BASE_PARENT$1 != (struct $8FBSYMBOL*)0ull) | (int64)-((*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) + 8ll) & 2048ll) == 0ll)) == 0ll ) goto label$150;
+			if( ((int64)-(BASE_PARENT$1 != (struct $8FBSYMBOL*)0ull) | (int64)-((*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) + 16ll) & 2ll) == 0ll)) == 0ll ) goto label$150;
 			{
 				ERRREPORT( 214ll, -1ll, (uint8*)0ull );
 				struct $7ASTNODE* vr$18 = ASTBUILDFAKECALL( PROC$1 );
@@ -946,9 +989,9 @@ struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYM
 			}
 			label$150:;
 			label$149:;
-			struct $11FB_CALL_ARG* vr$20 = SYMBALLOCOVLCALLARG( (struct $5TLIST*)((uint8*)&PARSER$ + 216ll), ARG_LIST$1, -1ll );
+			struct $11FB_CALL_ARG* vr$20 = SYMBALLOCOVLCALLARG( (struct $5TLIST*)((uint8*)&PARSER$ + 224ll), ARG_LIST$1, -1ll );
 			ARG$1 = vr$20;
-			struct $7ASTNODE* vr$23 = ASTBUILDVARFIELD( *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) + 128ll) + 96ll), (struct $8FBSYMBOL*)0ull, 0ll );
+			struct $7ASTNODE* vr$23 = ASTBUILDVARFIELD( *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) + 136ll) + 104ll), (struct $8FBSYMBOL*)0ull, 0ll );
 			*(struct $7ASTNODE**)ARG$1 = vr$23;
 			*($12FB_PARAMMODE*)((uint8*)ARG$1 + 8ll) = -1ll;
 		}
@@ -965,7 +1008,7 @@ struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYM
 			ARG$1 = *(struct $11FB_CALL_ARG**)((uint8*)ARG_LIST$1 + 8ll);
 			*(struct $11FB_CALL_ARG**)((uint8*)ARG_LIST$1 + 8ll) = *(struct $11FB_CALL_ARG**)((uint8*)ARG$1 + 16ll);
 			ASTDELTREE( *(struct $7ASTNODE**)ARG$1 );
-			LISTDELNODE( (struct $5TLIST*)((uint8*)&PARSER$ + 216ll), (void*)ARG$1 );
+			LISTDELNODE( (struct $5TLIST*)((uint8*)&PARSER$ + 224ll), (void*)ARG$1 );
 		}
 		label$152:;
 		label$151:;
@@ -973,8 +1016,8 @@ struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYM
 	label$145:;
 	struct $7ASTNODE* vr$35 = ASTNEWCALL( PROC$1, PTREXPR$1 );
 	PROCEXPR$1 = vr$35;
-	PARAMS$1 = (int64)*(int16*)((uint8*)PROC$1 + 112ll);
-	PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 128ll);
+	PARAMS$1 = (int64)*(int16*)((uint8*)PROC$1 + 120ll);
+	PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 136ll);
 	ARG$1 = *(struct $11FB_CALL_ARG**)((uint8*)ARG_LIST$1 + 8ll);
 	label$153:;
 	if( ARG$1 == (struct $11FB_CALL_ARG*)0ull ) goto label$154;
@@ -991,8 +1034,8 @@ struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYM
 		}
 		label$156:;
 		label$155:;
-		LISTDELNODE( (struct $5TLIST*)((uint8*)&PARSER$ + 216ll), (void*)ARG$1 );
-		PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 296ll);
+		LISTDELNODE( (struct $5TLIST*)((uint8*)&PARSER$ + 224ll), (void*)ARG$1 );
+		PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 312ll);
 		ARG$1 = NXT$2;
 		PARAMS$1 = PARAMS$1 + -1ll;
 	}
@@ -1036,7 +1079,7 @@ struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYM
 		{
 			if( ARGS$1 < PARAMS$1 ) goto label$171;
 			{
-				if( *(int64*)((uint8*)PARAM$1 + 88ll) == 4ll ) goto label$173;
+				if( *(int64*)((uint8*)PARAM$1 + 96ll) == 4ll ) goto label$173;
 				{
 					ERRREPORT( 1ll, 0ll, (uint8*)0ull );
 					if( (OPTIONS$1 & 16ll) == 0ll ) goto label$175;
@@ -1087,13 +1130,13 @@ struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYM
 			ARGS$1 = ARGS$1 + 1ll;
 			if( ARGS$1 >= PARAMS$1 ) goto label$183;
 			{
-				PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 296ll);
+				PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 312ll);
 			}
 			label$183:;
 			label$182:;
 		}
 		label$169:;
-		int64 vr$64 = HMATCH( 44ll );
+		int64 vr$64 = HMATCH( 44ll, 0ll );
 		if( vr$64 != 0ll ) goto label$167;
 		label$168:;
 	}
@@ -1103,13 +1146,13 @@ struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYM
 	label$184:;
 	if( ARGS$1 >= PARAMS$1 ) goto label$185;
 	{
-		if( *(int64*)((uint8*)PARAM$1 + 88ll) != 4ll ) goto label$187;
+		if( *(int64*)((uint8*)PARAM$1 + 96ll) != 4ll ) goto label$187;
 		{
 			goto label$185;
 		}
 		label$187:;
 		label$186:;
-		if( *(struct $7ASTNODE**)((uint8*)PARAM$1 + 104ll) != (struct $7ASTNODE*)0ull ) goto label$189;
+		if( *(struct $7ASTNODE**)((uint8*)PARAM$1 + 112ll) != (struct $7ASTNODE*)0ull ) goto label$189;
 		{
 			ERRREPORT( 1ll, 0ll, (uint8*)0ull );
 			ASTDELTREE( PROCEXPR$1 );
@@ -1130,7 +1173,7 @@ struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYM
 		label$191:;
 		label$190:;
 		ARGS$1 = ARGS$1 + 1ll;
-		PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 296ll);
+		PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 312ll);
 	}
 	goto label$184;
 	label$185:;
@@ -1142,7 +1185,7 @@ struct $7ASTNODE* CPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYM
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1156,33 +1199,33 @@ static int64 HPROCARG( struct $8FBSYMBOL* PROC$1, struct $8FBSYMBOL* PARAM$1, in
 	int64 OLD_DTYPE$1;
 	struct $8FBSYMBOL* OLDSYM$1;
 	fb$result$1 = 0ll;
-	PMODE$1 = *(int64*)((uint8*)PARAM$1 + 88ll);
+	PMODE$1 = *(int64*)((uint8*)PARAM$1 + 96ll);
 	*AMODE$1 = -1ll;
 	*EXPR$1 = (struct $7ASTNODE*)0ull;
 	int64 vr$4 = LEXGETTOKEN( 0ll );
 	if( vr$4 != 319ll ) goto label$17;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		*AMODE$1 = 1ll;
 	}
 	label$17:;
 	label$16:;
-	OLDSYM$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll);
-	OLD_DTYPE$1 = *(int64*)((uint8*)&PARSER$ + 296ll);
-	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll) = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 56ll);
-	*(int64*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)PARAM$1 + 48ll) & 511ll;
-	*(int64*)((uint8*)&PARSER$ + 312ll) = 0ll;
+	OLDSYM$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll);
+	OLD_DTYPE$1 = *(int64*)((uint8*)&PARSER$ + 304ll);
+	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll) = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 64ll);
+	*(int64*)((uint8*)&PARSER$ + 304ll) = *(int64*)((uint8*)PARAM$1 + 56ll) & 511ll;
+	*(int64*)((uint8*)&PARSER$ + 320ll) = 0ll;
 	struct $7ASTNODE* vr$9 = CEXPRESSION(  );
 	*EXPR$1 = vr$9;
-	*HAVE_EQ_OUTSIDE_PARENS$1 = *HAVE_EQ_OUTSIDE_PARENS$1 | *(int64*)((uint8*)&PARSER$ + 312ll);
+	*HAVE_EQ_OUTSIDE_PARENS$1 = *HAVE_EQ_OUTSIDE_PARENS$1 | *(int64*)((uint8*)&PARSER$ + 320ll);
 	goto label$19;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 1ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 1ll;
 	}
 	goto label$18;
 	label$19:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -2ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -2ll;
 	}
 	label$18:;
 	if( *EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$21;
@@ -1196,7 +1239,7 @@ static int64 HPROCARG( struct $8FBSYMBOL* PROC$1, struct $8FBSYMBOL* PARAM$1, in
 		{
 			if( ((int64)-(ARGNUM$1 == 0ll) & (int64)-(*AMODE$1 == -1ll)) == 0ll ) goto label$25;
 			{
-				int64 vr$23 = HMATCH( 319ll );
+				int64 vr$23 = HMATCH( 319ll, 2048ll );
 				if( vr$23 == 0ll ) goto label$27;
 				{
 					*AMODE$1 = 1ll;
@@ -1213,11 +1256,11 @@ static int64 HPROCARG( struct $8FBSYMBOL* PROC$1, struct $8FBSYMBOL* PARAM$1, in
 	}
 	label$21:;
 	label$20:;
-	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll) = OLDSYM$1;
-	*(int64*)((uint8*)&PARSER$ + 296ll) = OLD_DTYPE$1;
+	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll) = OLDSYM$1;
+	*(int64*)((uint8*)&PARSER$ + 304ll) = OLD_DTYPE$1;
 	if( *EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$29;
 	{
-		if( *(struct $7ASTNODE**)((uint8*)PARAM$1 + 104ll) != (struct $7ASTNODE*)0ull ) goto label$31;
+		if( *(struct $7ASTNODE**)((uint8*)PARAM$1 + 112ll) != (struct $7ASTNODE*)0ull ) goto label$31;
 		{
 			if( PMODE$1 != 4ll ) goto label$33;
 			{
@@ -1226,7 +1269,7 @@ static int64 HPROCARG( struct $8FBSYMBOL* PROC$1, struct $8FBSYMBOL* PARAM$1, in
 			label$33:;
 			label$32:;
 			ERRREPORT( 1ll, 0ll, (uint8*)0ull );
-			struct $7ASTNODE* vr$32 = ASTNEWCONSTZ( *(int64*)((uint8*)PARAM$1 + 48ll) & 511ll, *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 56ll) );
+			struct $7ASTNODE* vr$32 = ASTNEWCONSTZ( *(int64*)((uint8*)PARAM$1 + 56ll) & 511ll, *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 64ll) );
 			*EXPR$1 = vr$32;
 		}
 		label$31:;
@@ -1302,18 +1345,18 @@ static void HOVLPROCARG( int64 ARGNUM$1, struct $11FB_CALL_ARG* ARG$1, int64* HA
 	int64 OLD_DTYPE$1;
 	*(struct $7ASTNODE**)ARG$1 = (struct $7ASTNODE*)0ull;
 	*($12FB_PARAMMODE*)((uint8*)ARG$1 + 8ll) = -1ll;
-	int64 vr$2 = HMATCH( 319ll );
+	int64 vr$2 = HMATCH( 319ll, 2048ll );
 	if( vr$2 == 0ll ) goto label$55;
 	{
 		*($12FB_PARAMMODE*)((uint8*)ARG$1 + 8ll) = 1ll;
 	}
 	label$55:;
 	label$54:;
-	OLDSYM$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll);
-	OLD_DTYPE$1 = *(int64*)((uint8*)&PARSER$ + 296ll);
-	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll) = (struct $8FBSYMBOL*)0ull;
-	*(int64*)((uint8*)&PARSER$ + 296ll) = 2147483648ll;
-	*(int64*)((uint8*)&PARSER$ + 312ll) = 0ll;
+	OLDSYM$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll);
+	OLD_DTYPE$1 = *(int64*)((uint8*)&PARSER$ + 304ll);
+	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll) = (struct $8FBSYMBOL*)0ull;
+	*(int64*)((uint8*)&PARSER$ + 304ll) = 2147483648ll;
+	*(int64*)((uint8*)&PARSER$ + 320ll) = 0ll;
 	struct $7ASTNODE* vr$4 = CEXPRESSION(  );
 	*(struct $7ASTNODE**)ARG$1 = vr$4;
 	if( *(struct $7ASTNODE**)ARG$1 != (struct $7ASTNODE*)0ull ) goto label$57;
@@ -1327,7 +1370,7 @@ static void HOVLPROCARG( int64 ARGNUM$1, struct $11FB_CALL_ARG* ARG$1, int64* HA
 		{
 			if( ((int64)-(ARGNUM$1 == 0ll) & (int64)-(*(int64*)((uint8*)ARG$1 + 8ll) == -1ll)) == 0ll ) goto label$61;
 			{
-				int64 vr$13 = HMATCH( 319ll );
+				int64 vr$13 = HMATCH( 319ll, 2048ll );
 				if( vr$13 == 0ll ) goto label$63;
 				{
 					*($12FB_PARAMMODE*)((uint8*)ARG$1 + 8ll) = 1ll;
@@ -1344,9 +1387,9 @@ static void HOVLPROCARG( int64 ARGNUM$1, struct $11FB_CALL_ARG* ARG$1, int64* HA
 	}
 	label$57:;
 	label$56:;
-	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll) = OLDSYM$1;
-	*(int64*)((uint8*)&PARSER$ + 296ll) = OLD_DTYPE$1;
-	*HAVE_EQ_OUTSIDE_PARENS$1 = *HAVE_EQ_OUTSIDE_PARENS$1 | *(int64*)((uint8*)&PARSER$ + 312ll);
+	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll) = OLDSYM$1;
+	*(int64*)((uint8*)&PARSER$ + 304ll) = OLD_DTYPE$1;
+	*HAVE_EQ_OUTSIDE_PARENS$1 = *HAVE_EQ_OUTSIDE_PARENS$1 | *(int64*)((uint8*)&PARSER$ + 320ll);
 	if( *(struct $7ASTNODE**)ARG$1 == (struct $7ASTNODE*)0ull ) goto label$65;
 	{
 		int64 vr$21 = LEXGETTOKEN( 0ll );
@@ -1380,21 +1423,21 @@ static void HMAYBEWARNABOUTEQOUTSIDEPARENS( int64 ARGS$1, int64 HAVE_EQ_OUTSIDE_
 {
 	label$72:;
 	int64 WARN$1;
-	WARN$1 = (int64)-((*(int64*)((uint8*)PROC$1 + 8ll) & 33554432ll) != 0ll);
+	WARN$1 = (int64)-((*(int64*)((uint8*)PROC$1 + 16ll) & 2048ll) != 0ll);
 	if( WARN$1 != 0ll ) goto label$75;
 	{
-		if( (*(int64*)((uint8*)PROC$1 + 8ll) & 1024ll) <= 0ll ) goto label$77;
+		if( (*(int64*)((uint8*)PROC$1 + 16ll) & 1ll) <= 0ll ) goto label$77;
 		{
 			label$78:;
 			{
-				PROC$1 = *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 192ll);
+				PROC$1 = *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 200ll);
 				if( PROC$1 != (struct $8FBSYMBOL*)0ull ) goto label$82;
 				{
 					goto label$79;
 				}
 				label$82:;
 				label$81:;
-				WARN$1 = (int64)-((*(int64*)((uint8*)PROC$1 + 8ll) & 33554432ll) != 0ll);
+				WARN$1 = (int64)-((*(int64*)((uint8*)PROC$1 + 16ll) & 2048ll) != 0ll);
 			}
 			label$80:;
 			if( WARN$1 == 0ll ) goto label$78;
@@ -1424,7 +1467,7 @@ static struct $7ASTNODE* HGETVTABLELOOKUPIFNEEDED( struct $8FBSYMBOL* PROC$1, st
 	fb$result$1 = (struct $7ASTNODE*)0ull;
 	if( (OPTIONS$1 & 2048ll) == 0ll ) goto label$88;
 	{
-		if( (*(int64*)((uint8*)PROC$1 + 8ll) & 1073741824ll) == 0ll ) goto label$90;
+		if( (*(int64*)((uint8*)PROC$1 + 16ll) & 512ll) == 0ll ) goto label$90;
 		{
 			ERRREPORT( 307ll, 0ll, (uint8*)0ull );
 		}
@@ -1444,7 +1487,7 @@ static struct $7ASTNODE* HGETVTABLELOOKUPIFNEEDED( struct $8FBSYMBOL* PROC$1, st
 
 static struct $7ASTNODE* HOVLPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, struct $8FBSYMBOL* PROC$1, struct $16FB_CALL_ARG_LIST* ARG_LIST$1, $12FB_PARSEROPT OPTIONS$1 )
 {
-	struct $11FB_CALL_ARG* TMP$88$1;
+	struct $11FB_CALL_ARG* TMP$93$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$91:;
@@ -1460,7 +1503,7 @@ static struct $7ASTNODE* HOVLPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, stru
 	$9FB_ERRMSG ERR_NUM$1;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
 	HAVE_EQ_OUTSIDE_PARENS$1 = 0ll;
-	PARAMS$1 = (int64)*(int16*)((uint8*)PROC$1 + 186ll);
+	PARAMS$1 = (int64)*(int16*)((uint8*)PROC$1 + 194ll);
 	ARGS$1 = *(int64*)ARG_LIST$1;
 	if( (OPTIONS$1 & 64ll) == 0ll ) goto label$94;
 	{
@@ -1492,7 +1535,7 @@ static struct $7ASTNODE* HOVLPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, stru
 			}
 			label$101:;
 			label$100:;
-			struct $11FB_CALL_ARG* vr$10 = SYMBALLOCOVLCALLARG( (struct $5TLIST*)((uint8*)&PARSER$ + 216ll), ARG_LIST$1, 0ll );
+			struct $11FB_CALL_ARG* vr$10 = SYMBALLOCOVLCALLARG( (struct $5TLIST*)((uint8*)&PARSER$ + 224ll), ARG_LIST$1, 0ll );
 			ARG$1 = vr$10;
 			HOVLPROCARG( ARGS$1 - INIT_ARGS$2, ARG$1, &HAVE_EQ_OUTSIDE_PARENS$1, OPTIONS$1 );
 			int64 vr$13 = LEXGETTOKEN( 0ll );
@@ -1520,7 +1563,7 @@ static struct $7ASTNODE* HOVLPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, stru
 	HMAYBEWARNABOUTEQOUTSIDEPARENS( ARGS$1, HAVE_EQ_OUTSIDE_PARENS$1, PROC$1 );
 	$16FB_SYMBLOOKUPOPT LKUP_OPTIONS$1;
 	LKUP_OPTIONS$1 = 0ll;
-	if( (*(int64*)((uint8*)PROC$1 + 8ll) & 32768ll) == 0ll ) goto label$109;
+	if( (*(int64*)((uint8*)PROC$1 + 16ll) & 32ll) == 0ll ) goto label$109;
 	{
 		if( (OPTIONS$1 & 128ll) == 0ll ) goto label$111;
 		{
@@ -1532,16 +1575,16 @@ static struct $7ASTNODE* HOVLPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, stru
 	label$109:;
 	label$108:;
 	if( (OPTIONS$1 & 64ll) == 0ll ) goto label$112;
-	TMP$88$1 = *(struct $11FB_CALL_ARG**)((uint8*)*(struct $11FB_CALL_ARG**)((uint8*)ARG_LIST$1 + 8ll) + 16ll);
+	TMP$93$1 = *(struct $11FB_CALL_ARG**)((uint8*)*(struct $11FB_CALL_ARG**)((uint8*)ARG_LIST$1 + 8ll) + 16ll);
 	goto label$193;
 	label$112:;
-	TMP$88$1 = *(struct $11FB_CALL_ARG**)((uint8*)ARG_LIST$1 + 8ll);
+	TMP$93$1 = *(struct $11FB_CALL_ARG**)((uint8*)ARG_LIST$1 + 8ll);
 	label$193:;
-	struct $8FBSYMBOL* vr$25 = SYMBFINDCLOSESTOVLPROC( PROC$1, ARGS$1, TMP$88$1, &ERR_NUM$1, LKUP_OPTIONS$1 );
+	struct $8FBSYMBOL* vr$25 = SYMBFINDCLOSESTOVLPROC( PROC$1, ARGS$1, TMP$93$1, &ERR_NUM$1, LKUP_OPTIONS$1 );
 	OVLPROC$1 = vr$25;
 	if( OVLPROC$1 != (struct $8FBSYMBOL*)0ull ) goto label$114;
 	{
-		SYMBFREEOVLCALLARGS( (struct $5TLIST*)((uint8*)&PARSER$ + 216ll), ARG_LIST$1 );
+		SYMBFREEOVLCALLARGS( (struct $5TLIST*)((uint8*)&PARSER$ + 224ll), ARG_LIST$1 );
 		if( ERR_NUM$1 != 0ll ) goto label$116;
 		{
 			ERR_NUM$1 = 99ll;
@@ -1559,26 +1602,26 @@ static struct $7ASTNODE* HOVLPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, stru
 	int64 vr$28 = SYMBCHECKACCESS( PROC$1 );
 	if( vr$28 != 0ll ) goto label$118;
 	{
-		$9FB_ERRMSG TMP$89$2;
+		$9FB_ERRMSG TMP$94$2;
 		uint8* vr$29 = SYMBGETFULLPROCNAME( PROC$1 );
-		if( (*(int64*)((uint8*)PROC$1 + 8ll) & 4096ll) == 0ll ) goto label$119;
-		TMP$89$2 = 205ll;
+		if( (*(int64*)((uint8*)PROC$1 + 16ll) & 4ll) == 0ll ) goto label$119;
+		TMP$94$2 = 205ll;
 		goto label$194;
 		label$119:;
-		TMP$89$2 = 202ll;
+		TMP$94$2 = 202ll;
 		label$194:;
-		ERRREPORTEX( TMP$89$2, (uint8*)vr$29, 0ll, 1ll, (uint8*)0ull );
+		ERRREPORTEX( TMP$94$2, (uint8*)vr$29, 0ll, 1ll, (uint8*)0ull );
 		struct $7ASTNODE* vr$32 = ASTBUILDFAKECALL( PROC$1 );
 		fb$result$1 = vr$32;
 		goto label$92;
 	}
 	label$118:;
 	label$117:;
-	if( (*(int64*)((uint8*)PROC$1 + 8ll) & 2048ll) == 0ll ) goto label$121;
+	if( (*(int64*)((uint8*)PROC$1 + 16ll) & 2ll) == 0ll ) goto label$121;
 	{
 		if( (OPTIONS$1 & 64ll) != 0ll ) goto label$123;
 		{
-			if( ((int64)-(BASE_PARENT$1 != (struct $8FBSYMBOL*)0ull) | (int64)-((*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) + 8ll) & 2048ll) == 0ll)) == 0ll ) goto label$125;
+			if( ((int64)-(BASE_PARENT$1 != (struct $8FBSYMBOL*)0ull) | (int64)-((*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) + 16ll) & 2ll) == 0ll)) == 0ll ) goto label$125;
 			{
 				ERRREPORT( 214ll, -1ll, (uint8*)0ull );
 				struct $7ASTNODE* vr$41 = ASTBUILDFAKECALL( PROC$1 );
@@ -1587,9 +1630,9 @@ static struct $7ASTNODE* HOVLPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, stru
 			}
 			label$125:;
 			label$124:;
-			struct $11FB_CALL_ARG* vr$43 = SYMBALLOCOVLCALLARG( (struct $5TLIST*)((uint8*)&PARSER$ + 216ll), ARG_LIST$1, -1ll );
+			struct $11FB_CALL_ARG* vr$43 = SYMBALLOCOVLCALLARG( (struct $5TLIST*)((uint8*)&PARSER$ + 224ll), ARG_LIST$1, -1ll );
 			ARG$1 = vr$43;
-			struct $7ASTNODE* vr$46 = ASTBUILDVARFIELD( *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) + 128ll) + 96ll), (struct $8FBSYMBOL*)0ull, 0ll );
+			struct $7ASTNODE* vr$46 = ASTBUILDVARFIELD( *(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) + 136ll) + 104ll), (struct $8FBSYMBOL*)0ull, 0ll );
 			*(struct $7ASTNODE**)ARG$1 = vr$46;
 			*($12FB_PARAMMODE*)((uint8*)ARG$1 + 8ll) = -1ll;
 		}
@@ -1607,7 +1650,7 @@ static struct $7ASTNODE* HOVLPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, stru
 			ARG$1 = *(struct $11FB_CALL_ARG**)((uint8*)ARG_LIST$1 + 8ll);
 			*(struct $11FB_CALL_ARG**)((uint8*)ARG_LIST$1 + 8ll) = *(struct $11FB_CALL_ARG**)((uint8*)ARG$1 + 16ll);
 			ASTDELTREE( *(struct $7ASTNODE**)ARG$1 );
-			LISTDELNODE( (struct $5TLIST*)((uint8*)&PARSER$ + 216ll), (void*)ARG$1 );
+			LISTDELNODE( (struct $5TLIST*)((uint8*)&PARSER$ + 224ll), (void*)ARG$1 );
 		}
 		label$127:;
 		label$126:;
@@ -1616,12 +1659,12 @@ static struct $7ASTNODE* HOVLPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, stru
 	label$120:;
 	struct $7ASTNODE* vr$59 = ASTNEWCALL( PROC$1, PROCEXPR$1 );
 	PROCEXPR$1 = vr$59;
-	PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 128ll);
+	PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 136ll);
 	ARG$1 = *(struct $11FB_CALL_ARG**)((uint8*)ARG_LIST$1 + 8ll);
 	{
 		I$1 = 0ll;
-		int64 TMP$90$2;
-		TMP$90$2 = ARGS$1 + -1ll;
+		int64 TMP$95$2;
+		TMP$95$2 = ARGS$1 + -1ll;
 		goto label$128;
 		label$131:;
 		{
@@ -1637,23 +1680,23 @@ static struct $7ASTNODE* HOVLPROCARGLIST( struct $8FBSYMBOL* BASE_PARENT$1, stru
 			}
 			label$133:;
 			label$132:;
-			LISTDELNODE( (struct $5TLIST*)((uint8*)&PARSER$ + 216ll), (void*)ARG$1 );
-			PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 296ll);
+			LISTDELNODE( (struct $5TLIST*)((uint8*)&PARSER$ + 224ll), (void*)ARG$1 );
+			PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 312ll);
 			ARG$1 = NXT$1;
 		}
 		label$129:;
 		I$1 = I$1 + 1ll;
 		label$128:;
-		if( I$1 <= TMP$90$2 ) goto label$131;
+		if( I$1 <= TMP$95$2 ) goto label$131;
 		label$130:;
 	}
-	PARAMS$1 = (int64)*(int16*)((uint8*)PROC$1 + 112ll);
+	PARAMS$1 = (int64)*(int16*)((uint8*)PROC$1 + 120ll);
 	label$134:;
 	if( ARGS$1 >= PARAMS$1 ) goto label$135;
 	{
 		ASTNEWARG( PROCEXPR$1, (struct $7ASTNODE*)0ull, 2147483648ll, -1ll );
 		ARGS$1 = ARGS$1 + 1ll;
-		PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 296ll);
+		PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 312ll);
 	}
 	goto label$134;
 	label$135:;
