@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -604,6 +643,17 @@ struct $11TSTRSETITEM {
 	int64 USERDATA;
 };
 __FB_STATIC_ASSERT( sizeof( struct $11TSTRSETITEM ) == 32 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
 static void fb_ctor__parserzquirkzarray( void ) __attribute__(( constructor ));
@@ -619,7 +669,8 @@ struct $7ASTNODE* ASTNEWASSIGN( struct $7ASTNODE*, struct $7ASTNODE*, $9AST_OPOP
 int64 ASTTRYOVLSTRINGCONV( struct $7ASTNODE** );
 struct $7ASTNODE* ASTNEWCONSTI( int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL*, int64, int64, struct $8FBSYMBOL* );
-struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
+typedef int64 $15AST_LINK_RETURN;
+struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, $15AST_LINK_RETURN );
 struct $7ASTNODE* ASTNEWSTACK( int64, struct $7ASTNODE* );
 struct $7ASTNODE* ASTREMOVENIDXARRAY( struct $7ASTNODE* );
 int64 ASTCHECKASSIGN( struct $7ASTNODE*, struct $7ASTNODE* );
@@ -628,10 +679,10 @@ struct $7ASTNODE* ASTMAKEREF( struct $7ASTNODE** );
 struct $7ASTNODE* ASTBUILDARRAYBOUND( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
 struct $8FBSYMBOL* SYMBADDTEMPVAR( int64, struct $8FBSYMBOL* );
 int64 SYMBISARRAY( struct $8FBSYMBOL* );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $13FB_VAREXPROPT;
 struct $7ASTNODE* CVARORDEREF( $13FB_VAREXPROPT );
 void HSKIPUNTIL( int64, int64, $8LEXCHECK, int64 );
@@ -662,21 +713,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -684,20 +725,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -738,8 +781,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -747,8 +793,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -795,6 +842,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -816,16 +864,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 
 int64 CERASESTMT( void )
@@ -833,7 +886,7 @@ int64 CERASESTMT( void )
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	label$12:;
 	{
 		struct $7ASTNODE* EXPR$2;
@@ -877,7 +930,7 @@ int64 CERASESTMT( void )
 				}
 				label$24:;
 				label$23:;
-				if( (*(int64*)((uint8*)S$3 + 8ll) & 65540ll) == 0ll ) goto label$26;
+				if( (*(int64*)((uint8*)S$3 + 8ll) & 16388ll) == 0ll ) goto label$26;
 				{
 					struct $7ASTNODE* vr$9 = RTLARRAYERASE( EXPR$2, -1ll, -1ll );
 					ASTADD( vr$9 );
@@ -895,7 +948,7 @@ int64 CERASESTMT( void )
 		label$15:;
 	}
 	label$14:;
-	int64 vr$11 = HMATCH( 44ll );
+	int64 vr$11 = HMATCH( 44ll, 0ll );
 	if( vr$11 != 0ll ) goto label$12;
 	label$13:;
 	fb$result$1 = -1ll;
@@ -928,12 +981,12 @@ struct $7ASTNODE* CARRAYFUNCT( $8FB_TOKEN TK$1 )
 	struct $8FBSYMBOL* S$1;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
 	{
-		if( TK$1 == 493ll ) goto label$95;
+		if( TK$1 == 494ll ) goto label$95;
 		label$96:;
-		if( TK$1 != 494ll ) goto label$94;
+		if( TK$1 != 495ll ) goto label$94;
 		label$95:;
 		{
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 			int64 vr$1 = LEXGETTOKEN( 0ll );
 			if( vr$1 == 40ll ) goto label$98;
 			{
@@ -982,7 +1035,7 @@ struct $7ASTNODE* CARRAYFUNCT( $8FB_TOKEN TK$1 )
 			}
 			label$106:;
 			label$105:;
-			int64 vr$8 = HMATCH( 44ll );
+			int64 vr$8 = HMATCH( 44ll, 0ll );
 			if( vr$8 == 0ll ) goto label$108;
 			{
 				struct $7ASTNODE* vr$9 = HMATCHEXPR( 8ll );
@@ -1026,23 +1079,23 @@ struct $7ASTNODE* CARRAYFUNCT( $8FB_TOKEN TK$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
 
 static int64 HSCOPEDSWAP( void )
 {
-	int64 TMP$89$1;
-	int64 TMP$90$1;
-	int64 TMP$91$1;
-	int64 TMP$92$1;
-	int64 TMP$93$1;
 	int64 TMP$94$1;
+	int64 TMP$95$1;
+	int64 TMP$96$1;
+	int64 TMP$97$1;
+	int64 TMP$98$1;
+	int64 TMP$99$1;
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$27:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	struct $7ASTNODE* L$1;
 	struct $7ASTNODE* vr$1 = CVARORDEREF( 16ll );
 	L$1 = vr$1;
@@ -1103,7 +1156,7 @@ static int64 HSCOPEDSWAP( void )
 		{
 			struct $8FBSYMBOL* SYM$3;
 			SYM$3 = *(struct $8FBSYMBOL**)((uint8*)L$1 + 16ll);
-			if( ((int64)*(int32*)((uint8*)SYM$3 + 200ll) & 524288ll) == 0ll ) goto label$44;
+			if( ((int64)*(int32*)((uint8*)SYM$3 + 208ll) & 131072ll) == 0ll ) goto label$44;
 			{
 				if( RDTYPE$1 != 4ll ) goto label$46;
 				{
@@ -1115,7 +1168,7 @@ static int64 HSCOPEDSWAP( void )
 			}
 			goto label$43;
 			label$44:;
-			if( ((int64)*(int32*)((uint8*)SYM$3 + 200ll) & 262144ll) == 0ll ) goto label$47;
+			if( ((int64)*(int32*)((uint8*)SYM$3 + 208ll) & 65536ll) == 0ll ) goto label$47;
 			{
 				if( RDTYPE$1 != 7ll ) goto label$49;
 				{
@@ -1134,7 +1187,7 @@ static int64 HSCOPEDSWAP( void )
 		{
 			struct $8FBSYMBOL* SYM$3;
 			SYM$3 = *(struct $8FBSYMBOL**)((uint8*)R$1 + 16ll);
-			if( ((int64)*(int32*)((uint8*)SYM$3 + 200ll) & 524288ll) == 0ll ) goto label$52;
+			if( ((int64)*(int32*)((uint8*)SYM$3 + 208ll) & 131072ll) == 0ll ) goto label$52;
 			{
 				if( LDTYPE$1 != 4ll ) goto label$54;
 				{
@@ -1146,7 +1199,7 @@ static int64 HSCOPEDSWAP( void )
 			}
 			goto label$51;
 			label$52:;
-			if( ((int64)*(int32*)((uint8*)SYM$3 + 200ll) & 262144ll) == 0ll ) goto label$55;
+			if( ((int64)*(int32*)((uint8*)SYM$3 + 208ll) & 65536ll) == 0ll ) goto label$55;
 			{
 				if( LDTYPE$1 != 7ll ) goto label$57;
 				{
@@ -1235,52 +1288,52 @@ static int64 HSCOPEDSWAP( void )
 	USE_PUSHPOP$1 = -1ll;
 	USE_PUSHPOP$1 = USE_PUSHPOP$1 & (int64)-(*(int64*)((uint8*)&ENV$ + 208ll) == 0ll);
 	if( (LDTYPE$1 & 480ll) == 0ll ) goto label$77;
-	TMP$89$1 = 24ll;
+	TMP$94$1 = 24ll;
 	goto label$113;
 	label$77:;
-	TMP$89$1 = LDTYPE$1 & 31ll;
+	TMP$94$1 = LDTYPE$1 & 31ll;
 	label$113:;
 	if( (RDTYPE$1 & 480ll) == 0ll ) goto label$78;
-	TMP$90$1 = 24ll;
+	TMP$95$1 = 24ll;
 	goto label$114;
 	label$78:;
-	TMP$90$1 = RDTYPE$1 & 31ll;
+	TMP$95$1 = RDTYPE$1 & 31ll;
 	label$114:;
-	USE_PUSHPOP$1 = USE_PUSHPOP$1 & (int64)-(*(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$89$1 * 56ll)) + 8ll) == *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$90$1 * 56ll)) + 8ll));
+	USE_PUSHPOP$1 = USE_PUSHPOP$1 & (int64)-(*(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$94$1 * 56ll)) + 8ll) == *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$95$1 * 56ll)) + 8ll));
 	if( (LDTYPE$1 & 480ll) == 0ll ) goto label$79;
-	TMP$91$1 = 24ll;
+	TMP$96$1 = 24ll;
 	goto label$115;
 	label$79:;
-	TMP$91$1 = LDTYPE$1 & 31ll;
+	TMP$96$1 = LDTYPE$1 & 31ll;
 	label$115:;
 	if( (RDTYPE$1 & 480ll) == 0ll ) goto label$80;
-	TMP$92$1 = 24ll;
+	TMP$97$1 = 24ll;
 	goto label$116;
 	label$80:;
-	TMP$92$1 = RDTYPE$1 & 31ll;
+	TMP$97$1 = RDTYPE$1 & 31ll;
 	label$116:;
-	USE_PUSHPOP$1 = USE_PUSHPOP$1 & (int64)-(*(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$91$1 * 56ll)) == *(int64*)((uint8*)SYMB_DTYPETB$ + (TMP$92$1 * 56ll)));
+	USE_PUSHPOP$1 = USE_PUSHPOP$1 & (int64)-(*(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$96$1 * 56ll)) == *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$97$1 * 56ll)));
 	if( *(int64*)L$1 != 19ll ) goto label$81;
-	TMP$93$1 = (int64)-(*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)L$1 + 24ll) + 184ll) > 0ll);
+	TMP$98$1 = (int64)-(*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)L$1 + 24ll) + 192ll) > 0ll);
 	goto label$117;
 	label$81:;
-	TMP$93$1 = 0ll;
+	TMP$98$1 = 0ll;
 	label$117:;
-	USE_PUSHPOP$1 = USE_PUSHPOP$1 & (int64)-(TMP$93$1 == 0ll);
+	USE_PUSHPOP$1 = USE_PUSHPOP$1 & (int64)-(TMP$98$1 == 0ll);
 	if( *(int64*)R$1 != 19ll ) goto label$82;
-	TMP$94$1 = (int64)-(*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)R$1 + 24ll) + 184ll) > 0ll);
+	TMP$99$1 = (int64)-(*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)R$1 + 24ll) + 192ll) > 0ll);
 	goto label$118;
 	label$82:;
-	TMP$94$1 = 0ll;
+	TMP$99$1 = 0ll;
 	label$118:;
-	USE_PUSHPOP$1 = USE_PUSHPOP$1 & (int64)-(TMP$94$1 == 0ll);
+	USE_PUSHPOP$1 = USE_PUSHPOP$1 & (int64)-(TMP$99$1 == 0ll);
 	struct $7ASTNODE* T$1;
 	T$1 = (struct $7ASTNODE*)0ull;
 	int64 vr$77 = ASTHASSIDEFX( L$1 );
 	if( vr$77 == 0ll ) goto label$84;
 	{
 		struct $7ASTNODE* vr$79 = ASTMAKEREF( &L$1 );
-		struct $7ASTNODE* vr$80 = ASTNEWLINK( T$1, vr$79, -1ll );
+		struct $7ASTNODE* vr$80 = ASTNEWLINK( T$1, vr$79, 0ll );
 		T$1 = vr$80;
 	}
 	label$84:;
@@ -1289,7 +1342,7 @@ static int64 HSCOPEDSWAP( void )
 	if( vr$81 == 0ll ) goto label$86;
 	{
 		struct $7ASTNODE* vr$83 = ASTMAKEREF( &R$1 );
-		struct $7ASTNODE* vr$84 = ASTNEWLINK( T$1, vr$83, -1ll );
+		struct $7ASTNODE* vr$84 = ASTNEWLINK( T$1, vr$83, 0ll );
 		T$1 = vr$84;
 	}
 	label$86:;
@@ -1298,14 +1351,14 @@ static int64 HSCOPEDSWAP( void )
 	{
 		struct $7ASTNODE* vr$85 = ASTCLONETREE( L$1 );
 		struct $7ASTNODE* vr$86 = ASTNEWSTACK( 88ll, vr$85 );
-		struct $7ASTNODE* vr$87 = ASTNEWLINK( T$1, vr$86, -1ll );
+		struct $7ASTNODE* vr$87 = ASTNEWLINK( T$1, vr$86, 0ll );
 		T$1 = vr$87;
 		struct $7ASTNODE* vr$88 = ASTCLONETREE( R$1 );
 		struct $7ASTNODE* vr$89 = ASTNEWASSIGN( L$1, vr$88, 0ll );
-		struct $7ASTNODE* vr$90 = ASTNEWLINK( T$1, vr$89, -1ll );
+		struct $7ASTNODE* vr$90 = ASTNEWLINK( T$1, vr$89, 0ll );
 		T$1 = vr$90;
 		struct $7ASTNODE* vr$91 = ASTNEWSTACK( 89ll, R$1 );
-		struct $7ASTNODE* vr$92 = ASTNEWLINK( T$1, vr$91, -1ll );
+		struct $7ASTNODE* vr$92 = ASTNEWLINK( T$1, vr$91, 0ll );
 		T$1 = vr$92;
 	}
 	goto label$87;
@@ -1317,15 +1370,15 @@ static int64 HSCOPEDSWAP( void )
 		struct $7ASTNODE* vr$96 = ASTCLONETREE( L$1 );
 		struct $7ASTNODE* vr$97 = ASTNEWVAR( TEMP$2, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$98 = ASTNEWASSIGN( vr$97, vr$96, 0ll );
-		struct $7ASTNODE* vr$99 = ASTNEWLINK( T$1, vr$98, -1ll );
+		struct $7ASTNODE* vr$99 = ASTNEWLINK( T$1, vr$98, 0ll );
 		T$1 = vr$99;
 		struct $7ASTNODE* vr$100 = ASTCLONETREE( R$1 );
 		struct $7ASTNODE* vr$101 = ASTNEWASSIGN( L$1, vr$100, 0ll );
-		struct $7ASTNODE* vr$102 = ASTNEWLINK( T$1, vr$101, -1ll );
+		struct $7ASTNODE* vr$102 = ASTNEWLINK( T$1, vr$101, 0ll );
 		T$1 = vr$102;
 		struct $7ASTNODE* vr$103 = ASTNEWVAR( TEMP$2, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$104 = ASTNEWASSIGN( R$1, vr$103, 0ll );
-		struct $7ASTNODE* vr$105 = ASTNEWLINK( T$1, vr$104, -1ll );
+		struct $7ASTNODE* vr$105 = ASTNEWLINK( T$1, vr$104, 0ll );
 		T$1 = vr$105;
 	}
 	label$87:;
