@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -618,10 +657,10 @@ void SYMBDELSYMBOL( struct $8FBSYMBOL*, int64 );
 int64 TYPETOSIGNED( int64 );
 int64 TYPETOUNSIGNED( int64 );
 struct $8FBSYMBOL* SYMBGETCOMPCTORHEAD( struct $8FBSYMBOL* );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $9FB_INIOPT;
 struct $7ASTNODE* CINITIALIZER( struct $8FBSYMBOL*, $9FB_INIOPT, int64, struct $8FBSYMBOL* );
 typedef int64 $14FB_SYMBTYPEOPT;
@@ -653,10 +692,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -674,20 +714,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -728,8 +770,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -737,8 +782,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -785,6 +831,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -806,16 +853,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -966,6 +1018,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -977,7 +1030,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 struct $7ASTNODE* CTYPECONVEXPR( $8FB_TOKEN TK$1, int64 ISASM$1 )
@@ -992,8 +1045,8 @@ struct $7ASTNODE* CTYPECONVEXPR( $8FB_TOKEN TK$1, int64 ISASM$1 )
 	DTYPE$1 = 2147483648ll;
 	OP$1 = -1ll;
 	{
-		uint64 TMP$88$2;
-		TMP$88$2 = (uint64)TK$1;
+		uint64 TMP$93$2;
+		TMP$93$2 = (uint64)TK$1;
 		goto label$13;
 		label$14:;
 		{
@@ -1022,7 +1075,7 @@ struct $7ASTNODE* CTYPECONVEXPR( $8FB_TOKEN TK$1, int64 ISASM$1 )
 		goto label$12;
 		label$19:;
 		{
-			DTYPE$1 = *(int64*)((uint8*)&ENV$ + 1256ll);
+			DTYPE$1 = *(int64*)((uint8*)&ENV$ + 1416ll);
 		}
 		goto label$12;
 		label$20:;
@@ -1071,7 +1124,7 @@ struct $7ASTNODE* CTYPECONVEXPR( $8FB_TOKEN TK$1, int64 ISASM$1 )
 		}
 		goto label$12;
 		label$13:;
-		static const void* tmp$89[15ll] = {
+		static const void* tmp$94[15ll] = {
 			&&label$14,
 			&&label$15,
 			&&label$16,
@@ -1088,8 +1141,8 @@ struct $7ASTNODE* CTYPECONVEXPR( $8FB_TOKEN TK$1, int64 ISASM$1 )
 			&&label$27,
 			&&label$28,
 		};
-		if( (TMP$88$2 - 399ull) > 14ull ) goto label$12;
-		goto *tmp$89[TMP$88$2 - 399ull];
+		if( (TMP$93$2 - 400ull) > 14ull ) goto label$12;
+		goto *tmp$94[TMP$93$2 - 400ull];
 		label$12:;
 	}
 	if( DTYPE$1 != 2147483648ll ) goto label$30;
@@ -1104,19 +1157,19 @@ struct $7ASTNODE* CTYPECONVEXPR( $8FB_TOKEN TK$1, int64 ISASM$1 )
 	}
 	label$30:;
 	label$29:;
-	LEXSKIPTOKEN( 0ll );
-	if( ((int64)-(TK$1 == 404ll) | (int64)-(TK$1 == 405ll)) == 0ll ) goto label$34;
+	LEXSKIPTOKEN( 2048ll );
+	if( ((int64)-(TK$1 == 405ll) | (int64)-(TK$1 == 406ll)) == 0ll ) goto label$34;
 	{
-		int64 vr$4 = HMATCH( 301ll );
+		int64 vr$4 = HMATCH( 301ll, 0ll );
 		if( vr$4 == 0ll ) goto label$36;
 		{
 			int64 LGT$3;
 			struct $7ASTNODE* vr$5 = CGTINPARENSONLYEXPR(  );
 			int64 vr$6 = CCONSTINTEXPR( vr$5, 8ll );
 			LGT$3 = vr$6;
-			$11FB_DATATYPE vr$8 = HINTEGERTYPEFROMBITSIZE( LGT$3, (int64)-(TK$1 == 405ll) );
+			$11FB_DATATYPE vr$8 = HINTEGERTYPEFROMBITSIZE( LGT$3, (int64)-(TK$1 == 406ll) );
 			DTYPE$1 = vr$8;
-			int64 vr$9 = HMATCH( 300ll );
+			int64 vr$9 = HMATCH( 300ll, 0ll );
 			if( vr$9 != 0ll ) goto label$38;
 			{
 				ERRREPORT( 309ll, 0ll, (uint8*)0ull );
@@ -1129,7 +1182,7 @@ struct $7ASTNODE* CTYPECONVEXPR( $8FB_TOKEN TK$1, int64 ISASM$1 )
 	}
 	label$34:;
 	label$33:;
-	int64 vr$10 = HMATCH( 40ll );
+	int64 vr$10 = HMATCH( 40ll, 0ll );
 	if( vr$10 != 0ll ) goto label$40;
 	{
 		ERRREPORT( 6ll, 0ll, (uint8*)0ull );
@@ -1212,16 +1265,16 @@ struct $7ASTNODE* CANONTYPE( void )
 	struct $8FBSYMBOL* SUBTYPE$1;
 	int64 DTYPE$1;
 	int64 IS_EXPLICIT$1;
-	LEXSKIPTOKEN( 0ll );
-	int64 vr$1 = HMATCH( 301ll );
+	LEXSKIPTOKEN( 2048ll );
+	int64 vr$1 = HMATCH( 301ll, 0ll );
 	IS_EXPLICIT$1 = vr$1;
 	if( IS_EXPLICIT$1 == 0ll ) goto label$59;
 	{
-		int64 TMP$90$2;
-		int64 TMP$91$2;
-		TMP$91$2 = 0ll;
-		TMP$90$2 = 0ll;
-		int64 vr$6 = CSYMBOLTYPE( &DTYPE$1, &SUBTYPE$1, &TMP$90$2, &TMP$91$2, 1ll );
+		int64 TMP$95$2;
+		int64 TMP$96$2;
+		TMP$96$2 = 0ll;
+		TMP$95$2 = 0ll;
+		int64 vr$6 = CSYMBOLTYPE( &DTYPE$1, &SUBTYPE$1, &TMP$95$2, &TMP$96$2, 1ll );
 		if( vr$6 != 0ll ) goto label$61;
 		{
 			ERRREPORT( 14ll, 0ll, (uint8*)0ull );
@@ -1234,8 +1287,8 @@ struct $7ASTNODE* CANONTYPE( void )
 	goto label$58;
 	label$59:;
 	{
-		SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll);
-		DTYPE$1 = *(int64*)((uint8*)&PARSER$ + 296ll);
+		SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll);
+		DTYPE$1 = *(int64*)((uint8*)&PARSER$ + 304ll);
 		if( DTYPE$1 != 2147483648ll ) goto label$63;
 		{
 			ERRREPORT( 71ll, 0ll, (uint8*)0ull );
@@ -1245,11 +1298,11 @@ struct $7ASTNODE* CANONTYPE( void )
 		label$63:;
 		label$62:;
 		{
-			int64 TMP$92$3;
-			TMP$92$3 = DTYPE$1 & 511ll;
-			if( TMP$92$3 == 0ll ) goto label$66;
+			int64 TMP$97$3;
+			TMP$97$3 = DTYPE$1 & 511ll;
+			if( TMP$97$3 == 0ll ) goto label$66;
 			label$67:;
-			if( TMP$92$3 != 23ll ) goto label$65;
+			if( TMP$97$3 != 23ll ) goto label$65;
 			label$66:;
 			{
 				ERRREPORT( 71ll, 0ll, (uint8*)0ull );
@@ -1264,7 +1317,7 @@ struct $7ASTNODE* CANONTYPE( void )
 	HCOMPLAINIFABSTRACTCLASS( DTYPE$1, SUBTYPE$1 );
 	if( IS_EXPLICIT$1 == 0ll ) goto label$69;
 	{
-		int64 vr$8 = HMATCH( 300ll );
+		int64 vr$8 = HMATCH( 300ll, 0ll );
 		if( vr$8 != 0ll ) goto label$71;
 		{
 			ERRREPORT( 17ll, 0ll, (uint8*)0ull );
@@ -1303,7 +1356,7 @@ struct $7ASTNODE* CANONTYPE( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
