@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -612,11 +651,11 @@ struct $7ASTNODE* ASTADD( struct $7ASTNODE* );
 struct $7ASTNODE* ASTNEWCONSTSTR( uint8* );
 struct $7ASTNODE* ASTNEWCONSTI( int64, int64, struct $8FBSYMBOL* );
 int64 SYMBISSTRING( int64 );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
 int64 LEXGETLOOKAHEAD( int64, $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 struct $7ASTNODE* CEXPRESSION( void );
 void HSKIPUNTIL( int64, int64, $8LEXCHECK, int64 );
 struct $7ASTNODE* HMATCHEXPR( int64 );
@@ -647,10 +686,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -668,24 +708,26 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
 struct $7ASTNODE* CVIEWSTMT( int64 IS_FUNC$1 )
 {
-	int64 TMP$89$1;
+	int64 TMP$94$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
@@ -700,28 +742,28 @@ struct $7ASTNODE* CVIEWSTMT( int64 IS_FUNC$1 )
 	fb$result$1 = (struct $7ASTNODE*)0ull;
 	DEFAULT_VIEW$1 = IS_FUNC$1;
 	if( IS_FUNC$1 == 0ll ) goto label$12;
-	TMP$89$1 = -1ll;
+	TMP$94$1 = -1ll;
 	goto label$33;
 	label$12:;
-	TMP$89$1 = 0ll;
+	TMP$94$1 = 0ll;
 	label$33:;
-	DEFAULT_VIEW_VALUE$1 = TMP$89$1;
+	DEFAULT_VIEW_VALUE$1 = TMP$94$1;
 	int64 vr$5 = LEXGETLOOKAHEAD( 1ll, 0ll );
-	if( vr$5 == 461ll ) goto label$14;
+	if( vr$5 == 462ll ) goto label$14;
 	{
 		goto label$11;
 	}
 	label$14:;
 	label$13:;
-	LEXSKIPTOKEN( 0ll );
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
+	LEXSKIPTOKEN( 2048ll );
 	if( IS_FUNC$1 != 0ll ) goto label$16;
 	{
 		struct $7ASTNODE* vr$6 = CEXPRESSION(  );
 		EXPR1$1 = vr$6;
 		if( EXPR1$1 == (struct $7ASTNODE*)0ull ) goto label$18;
 		{
-			int64 vr$7 = HMATCH( 284ll );
+			int64 vr$7 = HMATCH( 284ll, 2048ll );
 			if( vr$7 != 0ll ) goto label$20;
 			{
 				ERRREPORT( 17ll, 0ll, (uint8*)0ull );
@@ -814,10 +856,10 @@ struct $7ASTNODE* CWIDTHSTMT( int64 ISFUNC$1 )
 	int64 CHECKRPRNT$1;
 	__builtin_memset( &CHECKRPRNT$1, 0, 8ll );
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	if( ISFUNC$1 == 0ll ) goto label$37;
 	{
-		int64 vr$6 = HMATCH( 40ll );
+		int64 vr$6 = HMATCH( 40ll, 0ll );
 		CHECKRPRNT$1 = vr$6;
 	}
 	goto label$36;
@@ -836,7 +878,7 @@ struct $7ASTNODE* CWIDTHSTMT( int64 ISFUNC$1 )
 		}
 		goto label$40;
 		label$41:;
-		int64 vr$8 = HMATCH( 41ll );
+		int64 vr$8 = HMATCH( 41ll, 0ll );
 		if( vr$8 == 0ll ) goto label$42;
 		{
 			struct $7ASTNODE* vr$9 = RTLWIDTHSCREEN( (struct $7ASTNODE*)0ull, (struct $7ASTNODE*)0ull, ISFUNC$1 );
@@ -848,7 +890,7 @@ struct $7ASTNODE* CWIDTHSTMT( int64 ISFUNC$1 )
 	}
 	label$39:;
 	label$38:;
-	int64 vr$10 = HMATCH( 462ll );
+	int64 vr$10 = HMATCH( 463ll, 0ll );
 	if( vr$10 == 0ll ) goto label$44;
 	{
 		struct $7ASTNODE* vr$11 = ASTNEWCONSTSTR( (uint8*)"LPT1:" );
@@ -866,7 +908,7 @@ struct $7ASTNODE* CWIDTHSTMT( int64 ISFUNC$1 )
 	}
 	goto label$43;
 	label$44:;
-	int64 vr$14 = HMATCH( 35ll );
+	int64 vr$14 = HMATCH( 35ll, 0ll );
 	if( vr$14 == 0ll ) goto label$47;
 	{
 		struct $7ASTNODE* vr$15 = HMATCHEXPR( 8ll );
@@ -877,7 +919,7 @@ struct $7ASTNODE* CWIDTHSTMT( int64 ISFUNC$1 )
 		}
 		label$49:;
 		label$48:;
-		int64 vr$16 = HMATCH( 44ll );
+		int64 vr$16 = HMATCH( 44ll, 0ll );
 		if( vr$16 == 0ll ) goto label$51;
 		{
 			struct $7ASTNODE* vr$17 = HMATCHEXPR( 8ll );
@@ -901,7 +943,7 @@ struct $7ASTNODE* CWIDTHSTMT( int64 ISFUNC$1 )
 	}
 	goto label$43;
 	label$47:;
-	int64 vr$20 = HMATCH( 44ll );
+	int64 vr$20 = HMATCH( 44ll, 0ll );
 	if( vr$20 == 0ll ) goto label$54;
 	{
 		struct $7ASTNODE* vr$21 = ASTNEWCONSTI( -1ll, 8ll, (struct $8FBSYMBOL*)0ull );
@@ -931,7 +973,7 @@ struct $7ASTNODE* CWIDTHSTMT( int64 ISFUNC$1 )
 		int64 vr$27 = SYMBISSTRING( *(int64*)((uint8*)DEV_NAME$1 + 8ll) & 511ll );
 		if( vr$27 == 0ll ) goto label$60;
 		{
-			int64 vr$28 = HMATCH( 44ll );
+			int64 vr$28 = HMATCH( 44ll, 0ll );
 			if( vr$28 == 0ll ) goto label$62;
 			{
 				struct $7ASTNODE* vr$29 = HMATCHEXPR( 8ll );
@@ -958,7 +1000,7 @@ struct $7ASTNODE* CWIDTHSTMT( int64 ISFUNC$1 )
 		{
 			WIDTH_ARG$1 = DEV_NAME$1;
 			DEV_NAME$1 = (struct $7ASTNODE*)0ull;
-			int64 vr$32 = HMATCH( 44ll );
+			int64 vr$32 = HMATCH( 44ll, 0ll );
 			if( vr$32 == 0ll ) goto label$66;
 			{
 				struct $7ASTNODE* vr$33 = HMATCHEXPR( 8ll );
@@ -1014,15 +1056,15 @@ struct $7ASTNODE* CCOLORSTMT( int64 ISFUNC$1 )
 	struct $7ASTNODE* BACK_COLOR$1;
 	BACK_COLOR$1 = (struct $7ASTNODE*)0ull;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	if( ISFUNC$1 == 0ll ) goto label$76;
 	{
-		int64 vr$2 = HMATCH( 40ll );
+		int64 vr$2 = HMATCH( 40ll, 0ll );
 		if( vr$2 != -1ll ) goto label$78;
 		{
 			struct $7ASTNODE* vr$3 = CEXPRESSION(  );
 			FORE_COLOR$1 = vr$3;
-			int64 vr$4 = HMATCH( 44ll );
+			int64 vr$4 = HMATCH( 44ll, 0ll );
 			if( vr$4 != -1ll ) goto label$80;
 			{
 				struct $7ASTNODE* vr$5 = HMATCHEXPR( -1ll );
@@ -1055,12 +1097,12 @@ struct $7ASTNODE* CCOLORSTMT( int64 ISFUNC$1 )
 	goto label$75;
 	label$76:;
 	{
-		int64 vr$7 = HMATCH( 40ll );
+		int64 vr$7 = HMATCH( 40ll, 0ll );
 		if( vr$7 != -1ll ) goto label$86;
 		{
 			struct $7ASTNODE* vr$8 = CEXPRESSION(  );
 			FORE_COLOR$1 = vr$8;
-			int64 vr$9 = HMATCH( 44ll );
+			int64 vr$9 = HMATCH( 44ll, 0ll );
 			if( vr$9 != -1ll ) goto label$88;
 			{
 				struct $7ASTNODE* vr$10 = HMATCHEXPR( -1ll );
@@ -1099,7 +1141,7 @@ struct $7ASTNODE* CCOLORSTMT( int64 ISFUNC$1 )
 					LEXSKIPTOKEN( 0ll );
 				}
 				label$93:;
-				int64 vr$13 = HMATCH( 44ll );
+				int64 vr$13 = HMATCH( 44ll, 0ll );
 				if( vr$13 != -1ll ) goto label$96;
 				{
 					struct $7ASTNODE* vr$14 = HMATCHEXPR( -1ll );
@@ -1121,7 +1163,7 @@ struct $7ASTNODE* CCOLORSTMT( int64 ISFUNC$1 )
 		{
 			struct $7ASTNODE* vr$15 = CEXPRESSION(  );
 			FORE_COLOR$1 = vr$15;
-			int64 vr$16 = HMATCH( 44ll );
+			int64 vr$16 = HMATCH( 44ll, 0ll );
 			if( vr$16 != -1ll ) goto label$100;
 			{
 				struct $7ASTNODE* vr$17 = HMATCHEXPR( -1ll );
@@ -1151,7 +1193,7 @@ struct $7ASTNODE* CSCREENFUNCT( void )
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$103:;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	int64 MATCH_PAREN$1;
 	MATCH_PAREN$1 = 0ll;
 	struct $7ASTNODE* YEXPR$1;
@@ -1198,7 +1240,7 @@ struct $7ASTNODE* CSCREENFUNCT( void )
 		label$112:;
 		label$111:;
 		FEXPR$2 = (struct $7ASTNODE*)0ull;
-		int64 vr$8 = HMATCH( 44ll );
+		int64 vr$8 = HMATCH( 44ll, 0ll );
 		if( vr$8 == 0ll ) goto label$114;
 		{
 			struct $7ASTNODE* vr$9 = HMATCHEXPR( 8ll );
@@ -1240,7 +1282,7 @@ struct $7ASTNODE* CSCREENFUNCT( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
