@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $8FB_TOKEN;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -178,7 +179,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -324,6 +325,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -333,7 +335,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -342,7 +345,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -353,10 +356,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -365,9 +369,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -466,14 +470,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -495,7 +501,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -506,9 +538,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -569,6 +607,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -598,7 +637,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -623,12 +662,12 @@ void ASTDATASTMTEND( struct $7ASTNODE* );
 struct $8FBSYMBOL* SYMBFINDBYCLASS( struct $10FBSYMCHAIN*, int64 );
 typedef int64 $10FB_SYMBOPT;
 struct $8FBSYMBOL* SYMBADDLABEL( uint8*, $10FB_SYMBOPT );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 int64 LEXGETCLASS( $8LEXCHECK );
 uint8* LEXGETTEXT( void );
 void LEXSKIPTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $8FB_IDOPT;
 struct $10FBSYMCHAIN* CIDENTIFIER( struct $8FBSYMBOL**, $8FB_IDOPT );
 typedef int64 $15FB_CMPSTMT_MASK;
@@ -659,10 +698,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -680,20 +720,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -734,8 +776,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -743,8 +788,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -791,6 +837,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -812,16 +859,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -971,6 +1023,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -982,7 +1035,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 int64 CDATASTMT( $8FB_TOKEN TK$1 )
@@ -992,21 +1045,21 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 	label$10:;
 	fb$result$1 = 0ll;
 	{
-		if( TK$1 != 443ll ) goto label$13;
+		if( TK$1 != 444ll ) goto label$13;
 		label$14:;
 		{
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 			struct $8FBSYMBOL* SYM$3;
 			SYM$3 = (struct $8FBSYMBOL*)0ull;
 			{
-				int64 TMP$89$4;
+				int64 TMP$94$4;
 				int64 vr$1 = LEXGETCLASS( 0ll );
-				TMP$89$4 = vr$1;
-				if( TMP$89$4 == 0ll ) goto label$17;
+				TMP$94$4 = vr$1;
+				if( TMP$94$4 == 0ll ) goto label$17;
 				label$18:;
-				if( TMP$89$4 == 2ll ) goto label$17;
+				if( TMP$94$4 == 2ll ) goto label$17;
 				label$19:;
-				if( TMP$89$4 != 3ll ) goto label$16;
+				if( TMP$94$4 != 3ll ) goto label$16;
 				label$17:;
 				{
 					struct $10FBSYMCHAIN* CHAIN_$5;
@@ -1032,7 +1085,7 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 					}
 					label$21:;
 					label$20:;
-					LEXSKIPTOKEN( 0ll );
+					LEXSKIPTOKEN( 2048ll );
 				}
 				label$16:;
 				label$15:;
@@ -1042,10 +1095,10 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 		}
 		goto label$12;
 		label$13:;
-		if( TK$1 != 444ll ) goto label$24;
+		if( TK$1 != 445ll ) goto label$24;
 		label$25:;
 		{
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 			struct $7ASTNODE* EXPR$3;
 			EXPR$3 = (struct $7ASTNODE*)0ull;
 			label$26:;
@@ -1071,14 +1124,14 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 				label$29:;
 			}
 			label$28:;
-			int64 vr$10 = HMATCH( 44ll );
+			int64 vr$10 = HMATCH( 44ll, 0ll );
 			if( vr$10 != 0ll ) goto label$26;
 			label$27:;
 			fb$result$1 = -1ll;
 		}
 		goto label$12;
 		label$24:;
-		if( TK$1 != 445ll ) goto label$33;
+		if( TK$1 != 446ll ) goto label$33;
 		label$34:;
 		{
 			if( *(int64*)((uint8*)&ENV$ + 272ll) == 3ll ) goto label$36;
@@ -1091,9 +1144,9 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 				}
 				label$38:;
 				label$37:;
-				if( *(uint64*)((uint8*)&PARSER$ + 184ll) <= 0ull ) goto label$40;
+				if( *(uint64*)((uint8*)&PARSER$ + 192ll) <= 0ull ) goto label$40;
 				{
-					if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) == *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) ) goto label$42;
+					if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) == *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) ) goto label$42;
 					{
 						ERRREPORT( 61ll, 0ll, (uint8*)0ull );
 					}
@@ -1113,7 +1166,7 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 			goto label$35;
 			label$36:;
 			{
-				if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) == *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) ) goto label$44;
+				if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) == *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) ) goto label$44;
 				{
 					ERRREPORT( 61ll, 0ll, (uint8*)0ull );
 					HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
@@ -1131,7 +1184,7 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 			EXPR$3 = (struct $7ASTNODE*)0ull;
 			if( *(int64*)((uint8*)&ENV$ + 272ll) == 3ll ) goto label$46;
 			{
-				LEXSKIPTOKEN( 0ll );
+				LEXSKIPTOKEN( 2048ll );
 				label$47:;
 				{
 					struct $7ASTNODE* vr$13 = HMATCHEXPR( 8ll );
@@ -1154,11 +1207,11 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 						label$55:;
 						{
 							{
-								int64 TMP$90$8;
-								TMP$90$8 = *(int64*)((uint8*)EXPR$3 + 8ll) & 511ll;
-								if( TMP$90$8 == 4ll ) goto label$58;
+								int64 TMP$95$8;
+								TMP$95$8 = *(int64*)((uint8*)EXPR$3 + 8ll) & 511ll;
+								if( TMP$95$8 == 4ll ) goto label$58;
 								label$59:;
-								if( TMP$90$8 != 7ll ) goto label$57;
+								if( TMP$95$8 != 7ll ) goto label$57;
 								label$58:;
 								{
 									struct $8FBSYMBOL* vr$19 = ASTGETSTRLITSYMBOL( EXPR$3 );
@@ -1191,7 +1244,7 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 					label$60:;
 				}
 				label$49:;
-				int64 vr$22 = HMATCH( 44ll );
+				int64 vr$22 = HMATCH( 44ll, 0ll );
 				if( vr$22 != 0ll ) goto label$47;
 				label$48:;
 			}
@@ -1210,11 +1263,11 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 					fb_StrAssign( (void*)&TEXT$4, -1ll, (void*)"", 1ll, 0 );
 					label$67:;
 					{
-						FBSTRING TMP$92$6;
+						FBSTRING TMP$97$6;
 						{
-							uint64 TMP$91$7;
+							uint64 TMP$96$7;
 							int64 vr$25 = LEXGETTOKEN( 62ll );
-							TMP$91$7 = (uint64)vr$25;
+							TMP$96$7 = (uint64)vr$25;
 							goto label$71;
 							label$72:;
 							{
@@ -1234,7 +1287,7 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 							}
 							goto label$70;
 							label$71:;
-							static const void* tmp$94[252ll] = {
+							static const void* tmp$99[252ll] = {
 								&&label$73,
 								&&label$70,
 								&&label$70,
@@ -1488,35 +1541,35 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 								&&label$74,
 								&&label$74,
 							};
-							if( (TMP$91$7 - 9ull) > 251ull ) goto label$70;
-							goto *tmp$94[TMP$91$7 - 9ull];
+							if( (TMP$96$7 - 9ull) > 251ull ) goto label$70;
+							goto *tmp$99[TMP$96$7 - 9ull];
 							label$70:;
 						}
 						uint8* vr$27 = LEXGETTEXT(  );
-						__builtin_memset( &TMP$92$6, 0, 24ll );
-						FBSTRING* vr$31 = fb_StrConcat( &TMP$92$6, (void*)&TEXT$4, -1ll, (void*)vr$27, 0ll );
-						FBSTRING* vr$33 = fb_StrAssign( (void*)&TEXT$4, -1ll, (void*)vr$31, -1ll, 0 );
+						__builtin_memset( &TMP$97$6, 0, 24ll );
+						FBSTRING* vr$31 = fb_StrConcat( &TMP$97$6, (void*)&TEXT$4, -1ll, (void*)vr$27, 0ll );
+						fb_StrAssign( (void*)&TEXT$4, -1ll, (void*)vr$31, -1ll, 0 );
 						LEXSKIPTOKEN( 62ll );
 						TOKENS$5 = TOKENS$5 + 1ll;
 					}
 					label$69:;
 					goto label$67;
 					label$68:;
-					FBSTRING* vr$36 = fb_TRIM( (FBSTRING*)&TEXT$4 );
-					FBSTRING* vr$38 = fb_StrAssign( (void*)&TEXT$4, -1ll, (void*)vr$36, -1ll, 0 );
+					FBSTRING* vr$35 = fb_TRIM( (FBSTRING*)&TEXT$4 );
+					fb_StrAssign( (void*)&TEXT$4, -1ll, (void*)vr$35, -1ll, 0 );
 					if( TOKENS$5 != 1ll ) goto label$76;
 					{
-						int64 vr$40 = fb_StrLen( (void*)&TEXT$4, -1ll );
-						if( vr$40 <= 1ll ) goto label$78;
+						int64 vr$38 = fb_StrLen( (void*)&TEXT$4, -1ll );
+						if( vr$38 <= 1ll ) goto label$78;
 						{
 							if( (uint64)(int64)*(uint8*)*(uint8**)&TEXT$4 != 34ull ) goto label$80;
 							{
-								int64 vr$44 = fb_StrLen( (void*)&TEXT$4, -1ll );
-								if( (uint64)(int64)*(uint8*)((uint8*)((uint8*)*(uint8**)&TEXT$4 + vr$44) + -1ll) != 34ull ) goto label$82;
+								int64 vr$42 = fb_StrLen( (void*)&TEXT$4, -1ll );
+								if( (uint64)(int64)*(uint8*)((uint8*)((uint8*)*(uint8**)&TEXT$4 + vr$42) + -1ll) != 34ull ) goto label$82;
 								{
-									int64 vr$48 = fb_StrLen( (void*)&TEXT$4, -1ll );
-									FBSTRING* vr$51 = fb_StrMid( (FBSTRING*)&TEXT$4, 2ll, vr$48 + -2ll );
-									FBSTRING* vr$53 = fb_StrAssign( (void*)&TEXT$4, -1ll, (void*)vr$51, -1ll, 0 );
+									int64 vr$46 = fb_StrLen( (void*)&TEXT$4, -1ll );
+									FBSTRING* vr$49 = fb_StrMid( (FBSTRING*)&TEXT$4, 2ll, vr$46 + -2ll );
+									fb_StrAssign( (void*)&TEXT$4, -1ll, (void*)vr$49, -1ll, 0 );
 								}
 								label$82:;
 								label$81:;
@@ -1529,9 +1582,9 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 					}
 					label$76:;
 					label$75:;
-					struct $7ASTNODE* vr$54 = ASTNEWCONSTSTR( (uint8*)*(uint8**)&TEXT$4 );
-					struct $7ASTNODE* vr$55 = ASTDATASTMTSTORE( TREE$3, vr$54 );
-					if( vr$55 != (struct $7ASTNODE*)0ull ) goto label$84;
+					struct $7ASTNODE* vr$51 = ASTNEWCONSTSTR( (uint8*)*(uint8**)&TEXT$4 );
+					struct $7ASTNODE* vr$52 = ASTDATASTMTSTORE( TREE$3, vr$51 );
+					if( vr$52 != (struct $7ASTNODE*)0ull ) goto label$84;
 					{
 						fb_StrDelete( (FBSTRING*)&TEXT$4 );
 						goto label$11;
@@ -1559,7 +1612,7 @@ int64 CDATASTMT( $8FB_TOKEN TK$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
