@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $8FB_TOKEN;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -178,7 +179,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -324,6 +325,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -333,7 +335,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -342,7 +345,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -353,10 +356,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -365,9 +369,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -466,14 +470,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -495,7 +501,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -506,9 +538,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -569,6 +607,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -598,7 +637,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -724,12 +763,12 @@ struct $8FBSYMBOL* SYMBFINDBYCLASS( struct $10FBSYMCHAIN*, int64 );
 struct $8FBSYMBOL* SYMBLOOKUPBYNAMEANDCLASS( struct $8FBSYMBOL*, uint8*, int64, int64, int64 );
 typedef int64 $10FB_SYMBOPT;
 struct $8FBSYMBOL* SYMBADDLABEL( uint8*, $10FB_SYMBOPT );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 int64 LEXGETCLASS( $8LEXCHECK );
 uint8* LEXGETTEXT( void );
 void LEXSKIPTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $8FB_IDOPT;
 struct $10FBSYMCHAIN* CIDENTIFIER( struct $8FBSYMBOL**, $8FB_IDOPT );
 int64 CASSIGNFUNCTRESULT( int64 );
@@ -759,10 +798,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -796,6 +836,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -804,11 +848,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -861,7 +906,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -880,20 +925,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -934,8 +981,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -943,8 +993,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -990,6 +1041,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -1011,16 +1063,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $17FBPARSER_STMT_LET {
 	struct $5TLIST LIST;
@@ -1043,6 +1100,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1054,7 +1112,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 int64 CGOTOSTMT( $8FB_TOKEN TK$1 )
@@ -1065,12 +1123,12 @@ int64 CGOTOSTMT( $8FB_TOKEN TK$1 )
 	struct $8FBSYMBOL* L$1;
 	fb$result$1 = 0ll;
 	{
-		uint64 TMP$92$2;
-		TMP$92$2 = (uint64)TK$1;
+		uint64 TMP$97$2;
+		TMP$97$2 = (uint64)TK$1;
 		goto label$52;
 		label$53:;
 		{
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 			struct $8FBSYMBOL* vr$1 = HGETLABELID(  );
 			L$1 = vr$1;
 			if( L$1 == (struct $8FBSYMBOL*)0ull ) goto label$55;
@@ -1084,7 +1142,7 @@ int64 CGOTOSTMT( $8FB_TOKEN TK$1 )
 		goto label$51;
 		label$56:;
 		{
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 65536ll) != 0ll ) goto label$58;
+			if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 65536ll) != 0ll ) goto label$58;
 			{
 				ERRREPORTNOTALLOWED( 65536ll, 146ll, (uint8*)0ull );
 				HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
@@ -1093,7 +1151,7 @@ int64 CGOTOSTMT( $8FB_TOKEN TK$1 )
 			}
 			label$58:;
 			label$57:;
-			if( *(int64*)((uint8*)&ENV$ + 1368ll) == 0ll ) goto label$60;
+			if( *(int64*)((uint8*)&ENV$ + 1528ll) == 0ll ) goto label$60;
 			{
 				HGOSUBBRANCH(  );
 			}
@@ -1110,9 +1168,9 @@ int64 CGOTOSTMT( $8FB_TOKEN TK$1 )
 		goto label$51;
 		label$61:;
 		{
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 65536ll) == 0ll ) goto label$63;
+			if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 65536ll) == 0ll ) goto label$63;
 			{
-				if( *(int64*)((uint8*)&ENV$ + 1368ll) == 0ll ) goto label$65;
+				if( *(int64*)((uint8*)&ENV$ + 1528ll) == 0ll ) goto label$65;
 				{
 					int64 vr$4 = HGOSUBRETURN(  );
 					fb$result$1 = vr$4;
@@ -1130,7 +1188,7 @@ int64 CGOTOSTMT( $8FB_TOKEN TK$1 )
 		goto label$51;
 		label$66:;
 		{
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 134217728ll) != 0ll ) goto label$68;
+			if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 134217728ll) != 0ll ) goto label$68;
 			{
 				ERRREPORTNOTALLOWED( 134217728ll, 146ll, (uint8*)0ull );
 				HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
@@ -1139,14 +1197,14 @@ int64 CGOTOSTMT( $8FB_TOKEN TK$1 )
 			}
 			label$68:;
 			label$67:;
-			LEXSKIPTOKEN( 0ll );
-			int64 vr$7 = HMATCH( 283ll );
+			LEXSKIPTOKEN( 2048ll );
+			int64 vr$7 = HMATCH( 283ll, 2048ll );
 			RTLERRORRESUME( vr$7 );
 			fb$result$1 = -1ll;
 		}
 		goto label$51;
 		label$52:;
-		static const void* tmp$93[111ll] = {
+		static const void* tmp$98[111ll] = {
 			&&label$61,
 			&&label$53,
 			&&label$56,
@@ -1259,8 +1317,8 @@ int64 CGOTOSTMT( $8FB_TOKEN TK$1 )
 			&&label$51,
 			&&label$66,
 		};
-		if( (TMP$92$2 - 390ull) > 110ull ) goto label$51;
-		goto *tmp$93[TMP$92$2 - 390ull];
+		if( (TMP$97$2 - 391ull) > 110ull ) goto label$51;
+		goto *tmp$98[TMP$97$2 - 391ull];
 		label$51:;
 	}
 	label$50:;
@@ -1270,7 +1328,7 @@ int64 CGOTOSTMT( $8FB_TOKEN TK$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1299,8 +1357,8 @@ static int64 HFUNCRETURN( void )
 	}
 	label$15:;
 	label$14:;
-	LEXSKIPTOKEN( 0ll );
-	if( (*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) + 48ll) & 511ll) == 0ll ) goto label$17;
+	LEXSKIPTOKEN( 2048ll );
+	if( (*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) + 56ll) & 511ll) == 0ll ) goto label$17;
 	{
 		CHECKEXPR$1 = -1ll;
 	}
@@ -1308,9 +1366,9 @@ static int64 HFUNCRETURN( void )
 	label$17:;
 	{
 		{
-			uint64 TMP$89$3;
+			uint64 TMP$94$3;
 			int64 vr$4 = LEXGETTOKEN( 0ll );
-			TMP$89$3 = (uint64)vr$4;
+			TMP$94$3 = (uint64)vr$4;
 			goto label$19;
 			label$20:;
 			{
@@ -1323,7 +1381,7 @@ static int64 HFUNCRETURN( void )
 			}
 			goto label$18;
 			label$19:;
-			static const void* tmp$94[85ll] = {
+			static const void* tmp$99[85ll] = {
 				&&label$20,
 				&&label$20,
 				&&label$20,
@@ -1410,8 +1468,8 @@ static int64 HFUNCRETURN( void )
 				&&label$21,
 				&&label$20,
 			};
-			if( (TMP$89$3 - 256ull) > 84ull ) goto label$21;
-			goto *tmp$94[TMP$89$3 - 256ull];
+			if( (TMP$94$3 - 256ull) > 84ull ) goto label$21;
+			goto *tmp$99[TMP$94$3 - 256ull];
 			label$18:;
 		}
 	}
@@ -1441,14 +1499,14 @@ static struct $8FBSYMBOL* HGETLABELID( void )
 	label$26:;
 	struct $8FBSYMBOL* SYM$1;
 	{
-		uint64 TMP$90$2;
+		uint64 TMP$95$2;
 		int64 vr$1 = LEXGETCLASS( 0ll );
-		TMP$90$2 = (uint64)vr$1;
+		TMP$95$2 = (uint64)vr$1;
 		goto label$29;
 		label$30:;
 		{
 			uint8* vr$2 = LEXGETTEXT(  );
-			struct $8FBSYMBOL* vr$3 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll), (uint8*)vr$2, 7ll, 0ll, 0ll );
+			struct $8FBSYMBOL* vr$3 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll), (uint8*)vr$2, 7ll, 0ll, 0ll );
 			SYM$1 = vr$3;
 		}
 		goto label$28;
@@ -1471,14 +1529,14 @@ static struct $8FBSYMBOL* HGETLABELID( void )
 		}
 		goto label$28;
 		label$29:;
-		static const void* tmp$95[4ll] = {
+		static const void* tmp$100[4ll] = {
 			&&label$31,
 			&&label$31,
 			&&label$31,
 			&&label$30,
 		};
-		if( TMP$90$2 > 3ull ) goto label$32;
-		goto *tmp$95[TMP$90$2 - 0ull];
+		if( TMP$95$2 > 3ull ) goto label$32;
+		goto *tmp$100[TMP$95$2 - 0ull];
 		label$28:;
 	}
 	if( SYM$1 != (struct $8FBSYMBOL*)0ull ) goto label$34;
@@ -1495,7 +1553,7 @@ static struct $8FBSYMBOL* HGETLABELID( void )
 	}
 	label$34:;
 	label$33:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	fb$result$1 = SYM$1;
 	label$27:;
 	return fb$result$1;
@@ -1505,12 +1563,12 @@ static void HGOSUBBRANCH( void )
 {
 	label$37:;
 	struct $8FBSYMBOL* L$1;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	struct $8FBSYMBOL* vr$0 = HGETLABELID(  );
 	L$1 = vr$0;
 	if( L$1 == (struct $8FBSYMBOL*)0ull ) goto label$40;
 	{
-		ASTGOSUBADDJMP( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll), L$1 );
+		ASTGOSUBADDJMP( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll), L$1 );
 	}
 	label$40:;
 	label$39:;
@@ -1523,15 +1581,15 @@ static int64 HGOSUBRETURN( void )
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$41:;
 	struct $8FBSYMBOL* L$1;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	{
-		uint64 TMP$91$2;
+		uint64 TMP$96$2;
 		int64 vr$1 = LEXGETTOKEN( 0ll );
-		TMP$91$2 = (uint64)vr$1;
+		TMP$96$2 = (uint64)vr$1;
 		goto label$44;
 		label$45:;
 		{
-			int64 vr$2 = ASTGOSUBADDRETURN( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll), (struct $8FBSYMBOL*)0ull );
+			int64 vr$2 = ASTGOSUBADDRETURN( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll), (struct $8FBSYMBOL*)0ull );
 			fb$result$1 = vr$2;
 		}
 		goto label$43;
@@ -1541,7 +1599,7 @@ static int64 HGOSUBRETURN( void )
 			L$1 = vr$3;
 			if( L$1 == (struct $8FBSYMBOL*)0ull ) goto label$48;
 			{
-				int64 vr$4 = ASTGOSUBADDRETURN( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll), L$1 );
+				int64 vr$4 = ASTGOSUBADDRETURN( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll), L$1 );
 				fb$result$1 = vr$4;
 			}
 			goto label$47;
@@ -1553,7 +1611,7 @@ static int64 HGOSUBRETURN( void )
 		}
 		goto label$43;
 		label$44:;
-		static const void* tmp$96[85ll] = {
+		static const void* tmp$101[85ll] = {
 			&&label$45,
 			&&label$45,
 			&&label$45,
@@ -1640,8 +1698,8 @@ static int64 HGOSUBRETURN( void )
 			&&label$46,
 			&&label$45,
 		};
-		if( (TMP$91$2 - 256ull) > 84ull ) goto label$46;
-		goto *tmp$96[TMP$91$2 - 256ull];
+		if( (TMP$96$2 - 256ull) > 84ull ) goto label$46;
+		goto *tmp$101[TMP$96$2 - 256ull];
 		label$43:;
 	}
 	label$42:;
