@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -604,6 +643,18 @@ struct $11TSTRSETITEM {
 	int64 USERDATA;
 };
 __FB_STATIC_ASSERT( sizeof( struct $11TSTRSETITEM ) == 32 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
+#define fb_D2L( value ) ((int64)__builtin_nearbyint( value ))
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
 int64 fb_WstrLen( uint16* );
@@ -617,11 +668,12 @@ struct $7ASTNODE* ASTNEWCONSTI( int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTREMOVENIDXARRAY( struct $7ASTNODE* );
 struct $8FBSYMBOL* ASTGETSTRLITSYMBOL( struct $7ASTNODE* );
 int64 ASTSIZEOF( struct $7ASTNODE*, int64* );
-uint16* HUNESCAPEW( uint16* );
+uint16* HUNESCAPEW( uint16*, int64* );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
 struct $7ASTNODE* CTYPEOREXPRESSION( int64, int64*, struct $8FBSYMBOL**, int64*, int64* );
+void CUDTTYPEMEMBER( int64*, struct $8FBSYMBOL**, int64*, int64* );
 void HSKIPUNTIL( int64, int64, $8LEXCHECK, int64 );
 struct $7ASTNODE* HMATCHEXPR( int64 );
 struct $7ASTNODE* RTLSTRLEN( struct $7ASTNODE* );
@@ -650,182 +702,175 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
+extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
 	struct $13SYMB_DATATYPE* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
 struct $7ASTNODE* CMATHFUNCT( $8FB_TOKEN TK$1, int64 ISASM$1 )
 {
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$72:;
+	label$83:;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
 	{
-		uint64 TMP$95$2;
-		TMP$95$2 = (uint64)TK$1;
-		goto label$75;
-		label$76:;
+		uint64 TMP$102$2;
+		TMP$102$2 = (uint64)TK$1;
+		goto label$86;
+		label$87:;
 		{
 			struct $7ASTNODE* vr$1 = HMATHOP( 56ll );
 			fb$result$1 = vr$1;
 		}
-		goto label$74;
-		label$77:;
+		goto label$85;
+		label$88:;
 		{
 			struct $7ASTNODE* vr$2 = HMATHOP( 57ll );
 			fb$result$1 = vr$2;
 		}
-		goto label$74;
-		label$78:;
+		goto label$85;
+		label$89:;
 		{
 			struct $7ASTNODE* vr$3 = HMATHOP( 71ll );
 			fb$result$1 = vr$3;
 		}
-		goto label$74;
-		label$79:;
+		goto label$85;
+		label$90:;
 		{
 			struct $7ASTNODE* vr$4 = HMATHOP( 72ll );
 			fb$result$1 = vr$4;
 		}
-		goto label$74;
-		label$80:;
+		goto label$85;
+		label$91:;
 		{
 			struct $7ASTNODE* vr$5 = HMATHOP( 70ll );
 			fb$result$1 = vr$5;
 		}
-		goto label$74;
-		label$81:;
+		goto label$85;
+		label$92:;
 		{
 			struct $7ASTNODE* vr$6 = HMATHOP( 58ll );
 			fb$result$1 = vr$6;
 		}
-		goto label$74;
-		label$82:;
+		goto label$85;
+		label$93:;
 		{
 			struct $7ASTNODE* vr$7 = HMATHOP( 59ll );
 			fb$result$1 = vr$7;
 		}
-		goto label$74;
-		label$83:;
+		goto label$85;
+		label$94:;
 		{
 			struct $7ASTNODE* vr$8 = HMATHOP( 60ll );
 			fb$result$1 = vr$8;
 		}
-		goto label$74;
-		label$84:;
+		goto label$85;
+		label$95:;
 		{
 			struct $7ASTNODE* vr$9 = HMATHOP( 61ll );
 			fb$result$1 = vr$9;
 		}
-		goto label$74;
-		label$85:;
+		goto label$85;
+		label$96:;
 		{
 			struct $7ASTNODE* vr$10 = HMATHOP( 62ll );
 			fb$result$1 = vr$10;
 		}
-		goto label$74;
-		label$86:;
+		goto label$85;
+		label$97:;
 		{
 			struct $7ASTNODE* vr$11 = HMATHOP( 63ll );
 			fb$result$1 = vr$11;
 		}
-		goto label$74;
-		label$87:;
+		goto label$85;
+		label$98:;
 		{
 			struct $7ASTNODE* vr$12 = HMATHOP( 65ll );
 			fb$result$1 = vr$12;
 		}
-		goto label$74;
-		label$88:;
+		goto label$85;
+		label$99:;
 		{
 			struct $7ASTNODE* vr$13 = HMATHOP( 68ll );
 			fb$result$1 = vr$13;
 		}
-		goto label$74;
-		label$89:;
+		goto label$85;
+		label$100:;
 		{
 			struct $7ASTNODE* vr$14 = HMATHOP( 69ll );
 			fb$result$1 = vr$14;
 		}
-		goto label$74;
-		label$90:;
+		goto label$85;
+		label$101:;
 		{
 			struct $7ASTNODE* vr$15 = HATAN2(  );
 			fb$result$1 = vr$15;
 		}
-		goto label$74;
-		label$91:;
+		goto label$85;
+		label$102:;
 		{
 			struct $7ASTNODE* vr$16 = HLENSIZEOF( TK$1, ISASM$1 );
 			fb$result$1 = vr$16;
 		}
-		goto label$74;
-		label$75:;
-		static const void* tmp$96[19ll] = {
-			&&label$76,
-			&&label$77,
-			&&label$78,
-			&&label$79,
-			&&label$81,
-			&&label$82,
-			&&label$83,
-			&&label$84,
-			&&label$85,
-			&&label$86,
+		goto label$85;
+		label$86:;
+		static const void* tmp$103[19ll] = {
 			&&label$87,
 			&&label$88,
 			&&label$89,
-			&&label$80,
 			&&label$90,
-			&&label$74,
-			&&label$74,
-			&&label$91,
+			&&label$92,
+			&&label$93,
+			&&label$94,
+			&&label$95,
+			&&label$96,
+			&&label$97,
+			&&label$98,
+			&&label$99,
+			&&label$100,
 			&&label$91,
+			&&label$101,
+			&&label$85,
+			&&label$85,
+			&&label$102,
+			&&label$102,
 		};
-		if( (TMP$95$2 - 446ull) > 18ull ) goto label$74;
-		goto *tmp$96[TMP$95$2 - 446ull];
-		label$74:;
+		if( (TMP$102$2 - 447ull) > 18ull ) goto label$85;
+		goto *tmp$103[TMP$102$2 - 447ull];
+		label$85:;
 	}
-	label$73:;
+	label$84:;
 	return fb$result$1;
 }
 
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -836,7 +881,7 @@ static struct $7ASTNODE* HMATHOP( $6AST_OP OP$1 )
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
 	struct $7ASTNODE* EXPR$1;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	int64 vr$1 = LEXGETTOKEN( 0ll );
 	if( vr$1 == 40ll ) goto label$13;
 	{
@@ -890,7 +935,7 @@ static struct $7ASTNODE* HATAN2( void )
 	label$20:;
 	struct $7ASTNODE* EXPR$1;
 	struct $7ASTNODE* EXPR2$1;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	int64 vr$1 = LEXGETTOKEN( 0ll );
 	if( vr$1 == 40ll ) goto label$23;
 	{
@@ -964,9 +1009,9 @@ static struct $7ASTNODE* HLEN( struct $7ASTNODE* EXPR$1, int64* LGT$1 )
 	struct $8FBSYMBOL* LITSYM$1;
 	struct $7ASTNODE* LENEXPR$1;
 	{
-		int64 TMP$89$2;
-		TMP$89$2 = *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll;
-		if( TMP$89$2 != 17ll ) goto label$37;
+		int64 TMP$94$2;
+		TMP$94$2 = *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll;
+		if( TMP$94$2 != 17ll ) goto label$37;
 		label$38:;
 		{
 			struct $7ASTNODE* vr$3 = RTLSTRLEN( EXPR$1 );
@@ -975,7 +1020,7 @@ static struct $7ASTNODE* HLEN( struct $7ASTNODE* EXPR$1, int64* LGT$1 )
 		}
 		goto label$36;
 		label$37:;
-		if( TMP$89$2 != 4ll ) goto label$39;
+		if( TMP$94$2 != 4ll ) goto label$39;
 		label$40:;
 		{
 			struct $8FBSYMBOL* vr$4 = ASTGETSTRLITSYMBOL( EXPR$1 );
@@ -988,13 +1033,14 @@ static struct $7ASTNODE* HLEN( struct $7ASTNODE* EXPR$1, int64* LGT$1 )
 			}
 			label$42:;
 			label$41:;
-			*LGT$1 = *(int64*)((uint8*)LITSYM$1 + 72ll) + -1ll;
+			*LGT$1 = *(int64*)((uint8*)LITSYM$1 + 80ll) + -1ll;
 		}
 		goto label$36;
 		label$39:;
-		if( TMP$89$2 != 7ll ) goto label$43;
+		if( TMP$94$2 != 7ll ) goto label$43;
 		label$44:;
 		{
+			int64 TMP$95$3;
 			struct $8FBSYMBOL* vr$9 = ASTGETSTRLITSYMBOL( EXPR$1 );
 			LITSYM$1 = vr$9;
 			if( LITSYM$1 != (struct $8FBSYMBOL*)0ull ) goto label$46;
@@ -1005,28 +1051,29 @@ static struct $7ASTNODE* HLEN( struct $7ASTNODE* EXPR$1, int64* LGT$1 )
 			}
 			label$46:;
 			label$45:;
-			uint16* vr$12 = HUNESCAPEW( *(uint16**)((uint8*)LITSYM$1 + 88ll) );
-			int64 vr$13 = fb_WstrLen( (uint16*)vr$12 );
-			*LGT$1 = vr$13;
+			TMP$95$3 = 0ll;
+			uint16* vr$13 = HUNESCAPEW( *(uint16**)((uint8*)LITSYM$1 + 96ll), &TMP$95$3 );
+			int64 vr$14 = fb_WstrLen( (uint16*)vr$13 );
+			*LGT$1 = vr$14;
 		}
 		goto label$36;
 		label$43:;
-		if( TMP$89$2 != 18ll ) goto label$47;
+		if( TMP$94$2 != 18ll ) goto label$47;
 		label$48:;
 		{
-			int64 TMP$90$3;
-			TMP$90$3 = 0ll;
-			int64 vr$16 = ASTSIZEOF( EXPR$1, &TMP$90$3 );
-			*LGT$1 = vr$16 + -1ll;
+			int64 TMP$96$3;
+			TMP$96$3 = 0ll;
+			int64 vr$17 = ASTSIZEOF( EXPR$1, &TMP$96$3 );
+			*LGT$1 = vr$17 + -1ll;
 		}
 		goto label$36;
 		label$47:;
-		if( TMP$89$2 != 20ll ) goto label$49;
+		if( TMP$94$2 != 20ll ) goto label$49;
 		label$50:;
 		{
-			int64 TMP$91$3;
-			struct $7ASTNODE* vr$19 = ASTNEWUOP( 73ll, EXPR$1 );
-			LENEXPR$1 = vr$19;
+			int64 TMP$97$3;
+			struct $7ASTNODE* vr$20 = ASTNEWUOP( 73ll, EXPR$1 );
+			LENEXPR$1 = vr$20;
 			if( LENEXPR$1 == (struct $7ASTNODE*)0ull ) goto label$52;
 			{
 				fb$result$1 = LENEXPR$1;
@@ -1034,17 +1081,17 @@ static struct $7ASTNODE* HLEN( struct $7ASTNODE* EXPR$1, int64* LGT$1 )
 			}
 			label$52:;
 			label$51:;
-			TMP$91$3 = 0ll;
-			int64 vr$21 = ASTSIZEOF( EXPR$1, &TMP$91$3 );
-			*LGT$1 = vr$21;
+			TMP$97$3 = 0ll;
+			int64 vr$22 = ASTSIZEOF( EXPR$1, &TMP$97$3 );
+			*LGT$1 = vr$22;
 		}
 		goto label$36;
 		label$49:;
 		{
-			int64 TMP$92$3;
-			TMP$92$3 = 0ll;
-			int64 vr$24 = ASTSIZEOF( EXPR$1, &TMP$92$3 );
-			*LGT$1 = vr$24;
+			int64 TMP$98$3;
+			TMP$98$3 = 0ll;
+			int64 vr$25 = ASTSIZEOF( EXPR$1, &TMP$98$3 );
+			*LGT$1 = vr$25;
 		}
 		label$53:;
 		label$36:;
@@ -1058,7 +1105,7 @@ static struct $7ASTNODE* HLEN( struct $7ASTNODE* EXPR$1, int64* LGT$1 )
 
 static struct $7ASTNODE* HLENSIZEOF( int64 TK$1, int64 ISASM$1 )
 {
-	int64 TMP$93$1;
+	int64 TMP$99$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$54:;
@@ -1066,7 +1113,7 @@ static struct $7ASTNODE* HLENSIZEOF( int64 TK$1, int64 ISASM$1 )
 	int64 DTYPE$1;
 	int64 LGT$1;
 	struct $8FBSYMBOL* SUBTYPE$1;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	int64 vr$1 = LEXGETTOKEN( 0ll );
 	if( vr$1 == 40ll ) goto label$57;
 	{
@@ -1078,73 +1125,118 @@ static struct $7ASTNODE* HLENSIZEOF( int64 TK$1, int64 ISASM$1 )
 		LEXSKIPTOKEN( 0ll );
 	}
 	label$56:;
-	TMP$93$1 = 0ll;
-	struct $7ASTNODE* vr$6 = CTYPEOREXPRESSION( TK$1, &DTYPE$1, &SUBTYPE$1, &LGT$1, &TMP$93$1 );
+	TMP$99$1 = 0ll;
+	struct $7ASTNODE* vr$6 = CTYPEOREXPRESSION( TK$1, &DTYPE$1, &SUBTYPE$1, &LGT$1, &TMP$99$1 );
 	EXPR$1 = vr$6;
 	if( EXPR$1 == (struct $7ASTNODE*)0ull ) goto label$59;
 	{
 		if( *(int64*)EXPR$1 != 25ll ) goto label$61;
 		{
-			TK$1 = 464ll;
+			TK$1 = 465ll;
 			struct $7ASTNODE* vr$8 = ASTREMOVENIDXARRAY( EXPR$1 );
 			EXPR$1 = vr$8;
 		}
 		label$61:;
 		label$60:;
 	}
+	goto label$58;
 	label$59:;
-	label$58:;
-	int64 vr$9 = LEXGETTOKEN( 0ll );
-	if( vr$9 == 41ll ) goto label$63;
+	if( TK$1 != 465ll ) goto label$62;
 	{
-		ERRREPORT( 7ll, 0ll, (uint8*)0ull );
-		HSKIPUNTIL( 41ll, -1ll, 0ll, 0ll );
+		int64 IS_FIXLENSTR$2;
+		__builtin_memset( &IS_FIXLENSTR$2, 0, 8ll );
+		CUDTTYPEMEMBER( &DTYPE$1, &SUBTYPE$1, &LGT$1, &IS_FIXLENSTR$2 );
 	}
-	goto label$62;
-	label$63:;
+	goto label$58;
+	label$62:;
+	if( TK$1 != 464ll ) goto label$63;
 	{
-		if( ISASM$1 != 0ll ) goto label$65;
+		int64 IS_FIXLENSTR$2;
+		__builtin_memset( &IS_FIXLENSTR$2, 0, 8ll );
+		CUDTTYPEMEMBER( &DTYPE$1, &SUBTYPE$1, &LGT$1, &IS_FIXLENSTR$2 );
+		if( IS_FIXLENSTR$2 == 0ll ) goto label$65;
 		{
-			LEXSKIPTOKEN( 0ll );
+			{
+				int64 TMP$100$4;
+				TMP$100$4 = DTYPE$1 & 511ll;
+				if( TMP$100$4 == 4ll ) goto label$68;
+				label$69:;
+				if( TMP$100$4 == 17ll ) goto label$68;
+				label$70:;
+				if( TMP$100$4 != 18ll ) goto label$67;
+				label$68:;
+				{
+					LGT$1 = LGT$1 - *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 232ll);
+					LGT$1 = fb_D2L( (double)LGT$1 / (double)*(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 232ll) );
+				}
+				goto label$66;
+				label$67:;
+				if( TMP$100$4 != 7ll ) goto label$71;
+				label$72:;
+				{
+					LGT$1 = LGT$1 - *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 400ll);
+					LGT$1 = fb_D2L( (double)LGT$1 / (double)*(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 400ll) );
+				}
+				label$71:;
+				label$66:;
+			}
 		}
 		label$65:;
 		label$64:;
 	}
-	label$62:;
-	if( EXPR$1 == (struct $7ASTNODE*)0ull ) goto label$67;
+	label$63:;
+	label$58:;
+	int64 vr$30 = LEXGETTOKEN( 0ll );
+	if( vr$30 == 41ll ) goto label$74;
 	{
-		if( TK$1 != 463ll ) goto label$69;
+		ERRREPORT( 7ll, 0ll, (uint8*)0ull );
+		HSKIPUNTIL( 41ll, -1ll, 0ll, 0ll );
+	}
+	goto label$73;
+	label$74:;
+	{
+		if( ISASM$1 != 0ll ) goto label$76;
 		{
-			struct $7ASTNODE* vr$11 = HLEN( EXPR$1, &LGT$1 );
-			EXPR$1 = vr$11;
-			if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$71;
+			LEXSKIPTOKEN( 0ll );
+		}
+		label$76:;
+		label$75:;
+	}
+	label$73:;
+	if( EXPR$1 == (struct $7ASTNODE*)0ull ) goto label$78;
+	{
+		if( TK$1 != 464ll ) goto label$80;
+		{
+			struct $7ASTNODE* vr$32 = HLEN( EXPR$1, &LGT$1 );
+			EXPR$1 = vr$32;
+			if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$82;
 			{
-				struct $7ASTNODE* vr$12 = ASTNEWCONSTI( LGT$1, 8ll, (struct $8FBSYMBOL*)0ull );
-				EXPR$1 = vr$12;
+				struct $7ASTNODE* vr$33 = ASTNEWCONSTI( LGT$1, 8ll, (struct $8FBSYMBOL*)0ull );
+				EXPR$1 = vr$33;
 			}
-			label$71:;
-			label$70:;
+			label$82:;
+			label$81:;
 		}
-		goto label$68;
-		label$69:;
+		goto label$79;
+		label$80:;
 		{
-			int64 TMP$94$3;
-			TMP$94$3 = 0ll;
-			int64 vr$14 = ASTSIZEOF( EXPR$1, &TMP$94$3 );
-			LGT$1 = vr$14;
+			int64 TMP$101$3;
+			TMP$101$3 = 0ll;
+			int64 vr$35 = ASTSIZEOF( EXPR$1, &TMP$101$3 );
+			LGT$1 = vr$35;
 			ASTDELTREE( EXPR$1 );
-			struct $7ASTNODE* vr$15 = ASTNEWCONSTI( LGT$1, 8ll, (struct $8FBSYMBOL*)0ull );
-			EXPR$1 = vr$15;
+			struct $7ASTNODE* vr$36 = ASTNEWCONSTI( LGT$1, 8ll, (struct $8FBSYMBOL*)0ull );
+			EXPR$1 = vr$36;
 		}
-		label$68:;
+		label$79:;
 	}
-	goto label$66;
-	label$67:;
+	goto label$77;
+	label$78:;
 	{
-		struct $7ASTNODE* vr$16 = ASTNEWCONSTI( LGT$1, 8ll, (struct $8FBSYMBOL*)0ull );
-		EXPR$1 = vr$16;
+		struct $7ASTNODE* vr$37 = ASTNEWCONSTI( LGT$1, 8ll, (struct $8FBSYMBOL*)0ull );
+		EXPR$1 = vr$37;
 	}
-	label$66:;
+	label$77:;
 	fb$result$1 = EXPR$1;
 	label$55:;
 	return fb$result$1;
