@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -615,7 +654,8 @@ typedef int64 $11AST_CONVOPT;
 struct $7ASTNODE* ASTNEWCONV( int64, struct $8FBSYMBOL*, struct $7ASTNODE*, $11AST_CONVOPT, int64* );
 struct $7ASTNODE* ASTNEWCONSTI( int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL*, int64, int64, struct $8FBSYMBOL* );
-struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
+typedef int64 $15AST_LINK_RETURN;
+struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, $15AST_LINK_RETURN );
 struct $7ASTNODE* ASTBUILDNEWOP( $6AST_OP, struct $8FBSYMBOL*, struct $7ASTNODE*, struct $7ASTNODE*, int64, struct $8FBSYMBOL*, int64, struct $7ASTNODE* );
 struct $7ASTNODE* ASTBUILDDELETEOP( $6AST_OP, struct $7ASTNODE* );
 struct $8FBSYMBOL* SYMBADDTEMPVAR( int64, struct $8FBSYMBOL* );
@@ -623,13 +663,13 @@ int64 TYPEHASCTOR( int64, struct $8FBSYMBOL* );
 int64 TYPEHASDEFCTOR( int64, struct $8FBSYMBOL* );
 int64 TYPEHASDTOR( int64, struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBGETCOMPDEFCTOR( struct $8FBSYMBOL* );
-struct $8FBSYMBOL* SYMBGETCOMPDTOR( struct $8FBSYMBOL* );
+struct $8FBSYMBOL* SYMBGETCOMPDTOR1( struct $8FBSYMBOL* );
 int64 SYMBCHECKACCESS( struct $8FBSYMBOL* );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
 int64 LEXGETLOOKAHEAD( int64, $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $9FB_INIOPT;
 struct $7ASTNODE* CINITIALIZER( struct $8FBSYMBOL*, $9FB_INIOPT, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* CEXPRESSION( void );
@@ -660,10 +700,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -681,24 +722,26 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
 struct $7ASTNODE* COPERATORNEW( void )
 {
-	int64 TMP$88$1;
+	int64 TMP$93$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
@@ -718,8 +761,8 @@ struct $7ASTNODE* COPERATORNEW( void )
 	ELEMENTSEXPR$1 = (struct $7ASTNODE*)0ull;
 	INITEXPR$1 = (struct $7ASTNODE*)0ull;
 	PLACEMENTEXPR$1 = (struct $7ASTNODE*)0ull;
-	LEXSKIPTOKEN( 0ll );
-	int64 vr$1 = HMATCH( 40ll );
+	LEXSKIPTOKEN( 2048ll );
+	int64 vr$1 = HMATCH( 40ll, 0ll );
 	if( vr$1 == 0ll ) goto label$13;
 	{
 		struct $7ASTNODE* vr$2 = CEXPRESSION(  );
@@ -730,7 +773,7 @@ struct $7ASTNODE* COPERATORNEW( void )
 		}
 		label$15:;
 		label$14:;
-		int64 vr$3 = HMATCH( 41ll );
+		int64 vr$3 = HMATCH( 41ll, 0ll );
 		if( vr$3 != 0ll ) goto label$17;
 		{
 			ERRREPORT( 7ll, 0ll, (uint8*)0ull );
@@ -740,16 +783,16 @@ struct $7ASTNODE* COPERATORNEW( void )
 	}
 	label$13:;
 	label$12:;
-	TMP$88$1 = 0ll;
-	HSYMBOLTYPE( &DTYPE$1, &SUBTYPE$1, &TMP$88$1, 0ll, 0ll );
+	TMP$93$1 = 0ll;
+	HSYMBOLTYPE( &DTYPE$1, &SUBTYPE$1, &TMP$93$1, 0ll, 0ll );
 	{
-		int64 TMP$89$2;
-		TMP$89$2 = DTYPE$1 & 511ll;
-		if( TMP$89$2 == 18ll ) goto label$20;
+		int64 TMP$94$2;
+		TMP$94$2 = DTYPE$1 & 511ll;
+		if( TMP$94$2 == 18ll ) goto label$20;
 		label$21:;
-		if( TMP$89$2 == 4ll ) goto label$20;
+		if( TMP$94$2 == 4ll ) goto label$20;
 		label$22:;
-		if( TMP$89$2 != 7ll ) goto label$19;
+		if( TMP$94$2 != 7ll ) goto label$19;
 		label$20:;
 		{
 			ERRREPORT( 201ll, -1ll, (uint8*)0ull );
@@ -814,7 +857,7 @@ struct $7ASTNODE* COPERATORNEW( void )
 					DO_CLEAR$1 = 0ll;
 				}
 				label$35:;
-				LEXSKIPTOKEN( 0ll );
+				LEXSKIPTOKEN( 2048ll );
 			}
 			goto label$31;
 			label$32:;
@@ -951,7 +994,7 @@ struct $7ASTNODE* COPERATORNEW( void )
 					DO_CLEAR$1 = 0ll;
 				}
 				label$63:;
-				LEXSKIPTOKEN( 0ll );
+				LEXSKIPTOKEN( 2048ll );
 				int64 vr$41 = LEXGETTOKEN( 0ll );
 				if( vr$41 == 41ll ) goto label$66;
 				{
@@ -992,7 +1035,7 @@ struct $7ASTNODE* COPERATORNEW( void )
 	label$70:;
 	label$69:;
 	struct $7ASTNODE* vr$44 = ASTNEWVAR( TMP$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
-	struct $7ASTNODE* vr$45 = ASTNEWLINK( EXPR$1, vr$44, 0ll );
+	struct $7ASTNODE* vr$45 = ASTNEWLINK( EXPR$1, vr$44, 2ll );
 	fb$result$1 = vr$45;
 	label$11:;
 	return fb$result$1;
@@ -1005,7 +1048,7 @@ void COPERATORDELETE( void )
 	int64 DTYPE$1;
 	int64 OP$1;
 	struct $8FBSYMBOL* SUBTYPE$1;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	OP$1 = 80ll;
 	int64 vr$0 = LEXGETTOKEN( 0ll );
 	if( vr$0 != 91ll ) goto label$74;
@@ -1045,16 +1088,16 @@ void COPERATORDELETE( void )
 	label$80:;
 	label$79:;
 	{
-		int64 TMP$90$2;
-		TMP$90$2 = DTYPE$1 & 511ll;
-		if( TMP$90$2 != 32ll ) goto label$82;
+		int64 TMP$95$2;
+		TMP$95$2 = DTYPE$1 & 511ll;
+		if( TMP$95$2 != 32ll ) goto label$82;
 		label$83:;
 		{
 			ERRREPORTWARN( 22ll, (uint8*)0ull, 1ll, (uint8*)0ull );
 		}
 		goto label$81;
 		label$82:;
-		if( TMP$90$2 != 55ll ) goto label$84;
+		if( TMP$95$2 != 55ll ) goto label$84;
 		label$85:;
 		{
 			ERRREPORT( 71ll, -1ll, (uint8*)0ull );
@@ -1065,7 +1108,7 @@ void COPERATORDELETE( void )
 	int64 vr$17 = TYPEHASDTOR( (((DTYPE$1 & 31ll) | ((DTYPE$1 & 480ll) + -32ll)) | (((DTYPE$1 & 261632ll) >> (1ll & 63ll)) & 261632ll)) | (DTYPE$1 & 32505856ll), SUBTYPE$1 );
 	if( vr$17 == 0ll ) goto label$87;
 	{
-		struct $8FBSYMBOL* vr$18 = SYMBGETCOMPDTOR( SUBTYPE$1 );
+		struct $8FBSYMBOL* vr$18 = SYMBGETCOMPDTOR1( SUBTYPE$1 );
 		int64 vr$19 = SYMBCHECKACCESS( vr$18 );
 		if( vr$19 != 0ll ) goto label$89;
 		{
@@ -1084,7 +1127,7 @@ void COPERATORDELETE( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
