@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -609,6 +648,26 @@ struct $16__FB_ARRAYDIMTB$ {
 	int64 UBOUND;
 };
 __FB_STATIC_ASSERT( sizeof( struct $16__FB_ARRAYDIMTB$ ) == 24 );
+struct $8FBARRAY1IyE {
+	uint64* DATA;
+	uint64* PTR;
+	int64 SIZE;
+	int64 ELEMENT_LEN;
+	int64 DIMENSIONS;
+	int64 FLAGS;
+	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
+};
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IyE ) == 72 );
+struct $8FBARRAY1IP8FBSYMBOLE {
+	struct $8FBSYMBOL** DATA;
+	struct $8FBSYMBOL** PTR;
+	int64 SIZE;
+	int64 ELEMENT_LEN;
+	int64 DIMENSIONS;
+	int64 FLAGS;
+	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
+};
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IP8FBSYMBOLE ) == 72 );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
 int32 fb_StrCompare( void*, int64, void*, int64 );
@@ -632,12 +691,12 @@ typedef int64 $10FB_SYMBOPT;
 struct $8FBSYMBOL* SYMBADDLABEL( uint8*, $10FB_SYMBOPT );
 struct $8FBSYMBOL* SYMBADDTEMPVAR( int64, struct $8FBSYMBOL* );
 uint8* SYMBUNIQUELABEL( void );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 int64 LEXGETCLASS( $8LEXCHECK );
 uint8* LEXGETTEXT( void );
 void LEXSKIPTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $8FB_IDOPT;
 struct $10FBSYMCHAIN* CIDENTIFIER( struct $8FBSYMBOL**, $8FB_IDOPT );
 void HSKIPUNTIL( int64, int64, $8LEXCHECK, int64 );
@@ -658,10 +717,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -679,20 +739,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -733,8 +795,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -742,8 +807,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -789,6 +855,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -810,16 +877,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -971,6 +1043,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -982,7 +1055,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 int64 CONSTMT( void )
@@ -998,11 +1071,11 @@ int64 CONSTMT( void )
 	struct $10FBSYMCHAIN* CHAIN_$1;
 	struct $8FBSYMBOL* BASE_PARENT$1;
 	fb$result$1 = 0ll;
-	LEXSKIPTOKEN( 0ll );
-	int64 vr$1 = HMATCH( 498ll );
+	LEXSKIPTOKEN( 2048ll );
+	int64 vr$1 = HMATCH( 499ll, 2048ll );
 	if( vr$1 == 0ll ) goto label$43;
 	{
-		if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) != *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) ) goto label$45;
+		if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) != *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) ) goto label$45;
 		{
 			ERRREPORT( 17ll, -1ll, (uint8*)0ull );
 			goto label$41;
@@ -1019,9 +1092,9 @@ int64 CONSTMT( void )
 	label$42:;
 	EXPR$1 = (struct $7ASTNODE*)0ull;
 	int64 vr$2 = LEXGETTOKEN( 0ll );
-	if( vr$2 != 497ll ) goto label$47;
+	if( vr$2 != 498ll ) goto label$47;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 	}
 	goto label$46;
 	label$47:;
@@ -1037,17 +1110,17 @@ int64 CONSTMT( void )
 	}
 	label$46:;
 	{
-		int64 TMP$94$2;
+		int64 TMP$99$2;
 		int64 vr$4 = LEXGETTOKEN( 0ll );
-		TMP$94$2 = vr$4;
-		if( TMP$94$2 != 391ll ) goto label$51;
+		TMP$99$2 = vr$4;
+		if( TMP$99$2 != 392ll ) goto label$51;
 		label$52:;
 		{
 			ISGOTO$1 = -1ll;
 		}
 		goto label$50;
 		label$51:;
-		if( TMP$94$2 != 392ll ) goto label$53;
+		if( TMP$99$2 != 393ll ) goto label$53;
 		label$54:;
 		{
 			if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$56;
@@ -1058,7 +1131,7 @@ int64 CONSTMT( void )
 			}
 			label$56:;
 			label$55:;
-			if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 65536ll) != 0ll ) goto label$58;
+			if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 65536ll) != 0ll ) goto label$58;
 			{
 				ERRREPORTNOTALLOWED( 65536ll, 146ll, (uint8*)0ull );
 				HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
@@ -1067,7 +1140,7 @@ int64 CONSTMT( void )
 			}
 			label$58:;
 			label$57:;
-			if( *(int64*)((uint8*)&ENV$ + 1368ll) != 0ll ) goto label$60;
+			if( *(int64*)((uint8*)&ENV$ + 1528ll) != 0ll ) goto label$60;
 			{
 				ERRREPORT( 17ll, 0ll, (uint8*)0ull );
 				HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
@@ -1091,7 +1164,7 @@ int64 CONSTMT( void )
 	}
 	if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$63;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		ISRESTORE$1 = 0ll;
 		int64 vr$7 = LEXGETCLASS( 0ll );
 		if( vr$7 != 3ll ) goto label$65;
@@ -1122,7 +1195,7 @@ int64 CONSTMT( void )
 			}
 			label$71:;
 			label$70:;
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 			struct $7ASTNODE* vr$16 = ASTNEWVAR( LABEL$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 			struct $7ASTNODE* vr$17 = ASTNEWADDROF( vr$16 );
 			EXPR$1 = vr$17;
@@ -1151,14 +1224,14 @@ int64 CONSTMT( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
 
 static int64 CGOTBSTMT( struct $7ASTNODE* EXPR$1, int64 ISGOTO$1 )
 {
-	int64 TMP$93$1;
+	int64 TMP$98$1;
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
@@ -1166,43 +1239,27 @@ static int64 CGOTBSTMT( struct $7ASTNODE* EXPR$1, int64 ISGOTO$1 )
 	struct $8FBSYMBOL* SYM$1;
 	struct $8FBSYMBOL* EXITLABEL$1;
 	uint64 VALUES$1[64];
-	struct $8FBARRAY1IyE {
-		uint64* DATA;
-		uint64* PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IyE ) == 64 );
-	struct $8FBARRAY1IyE tmp$89$1;
-	*(uint64**)&tmp$89$1 = (uint64*)VALUES$1;
-	*(uint64**)((uint8*)&tmp$89$1 + 8ll) = (uint64*)VALUES$1;
-	*(int64*)((uint8*)&tmp$89$1 + 16ll) = 512ll;
-	*(int64*)((uint8*)&tmp$89$1 + 24ll) = 8ll;
-	*(int64*)((uint8*)&tmp$89$1 + 32ll) = 1ll;
-	*(int64*)((uint8*)&tmp$89$1 + 40ll) = 64ll;
-	*(int64*)((uint8*)&tmp$89$1 + 48ll) = 0ll;
-	*(int64*)((uint8*)&tmp$89$1 + 56ll) = 63ll;
+	struct $8FBARRAY1IyE tmp$94$1;
+	*(uint64**)&tmp$94$1 = (uint64*)VALUES$1;
+	*(uint64**)((uint8*)&tmp$94$1 + 8ll) = (uint64*)VALUES$1;
+	*(int64*)((uint8*)&tmp$94$1 + 16ll) = 512ll;
+	*(int64*)((uint8*)&tmp$94$1 + 24ll) = 8ll;
+	*(int64*)((uint8*)&tmp$94$1 + 32ll) = 1ll;
+	*(int64*)((uint8*)&tmp$94$1 + 40ll) = 49ll;
+	*(int64*)((uint8*)&tmp$94$1 + 48ll) = 64ll;
+	*(int64*)((uint8*)&tmp$94$1 + 56ll) = 0ll;
+	*(int64*)((uint8*)&tmp$94$1 + 64ll) = 63ll;
 	struct $8FBSYMBOL* LABELS$1[64];
-	struct $8FBARRAY1IP8FBSYMBOLE {
-		struct $8FBSYMBOL** DATA;
-		struct $8FBSYMBOL** PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IP8FBSYMBOLE ) == 64 );
-	struct $8FBARRAY1IP8FBSYMBOLE tmp$90$1;
-	*(struct $8FBSYMBOL***)&tmp$90$1 = (struct $8FBSYMBOL**)LABELS$1;
-	*(struct $8FBSYMBOL***)((uint8*)&tmp$90$1 + 8ll) = (struct $8FBSYMBOL**)LABELS$1;
-	*(int64*)((uint8*)&tmp$90$1 + 16ll) = 512ll;
-	*(int64*)((uint8*)&tmp$90$1 + 24ll) = 8ll;
-	*(int64*)((uint8*)&tmp$90$1 + 32ll) = 1ll;
-	*(int64*)((uint8*)&tmp$90$1 + 40ll) = 64ll;
-	*(int64*)((uint8*)&tmp$90$1 + 48ll) = 0ll;
-	*(int64*)((uint8*)&tmp$90$1 + 56ll) = 63ll;
+	struct $8FBARRAY1IP8FBSYMBOLE tmp$95$1;
+	*(struct $8FBSYMBOL***)&tmp$95$1 = (struct $8FBSYMBOL**)LABELS$1;
+	*(struct $8FBSYMBOL***)((uint8*)&tmp$95$1 + 8ll) = (struct $8FBSYMBOL**)LABELS$1;
+	*(int64*)((uint8*)&tmp$95$1 + 16ll) = 512ll;
+	*(int64*)((uint8*)&tmp$95$1 + 24ll) = 8ll;
+	*(int64*)((uint8*)&tmp$95$1 + 32ll) = 1ll;
+	*(int64*)((uint8*)&tmp$95$1 + 40ll) = 49ll;
+	*(int64*)((uint8*)&tmp$95$1 + 48ll) = 64ll;
+	*(int64*)((uint8*)&tmp$95$1 + 56ll) = 0ll;
+	*(int64*)((uint8*)&tmp$95$1 + 64ll) = 63ll;
 	struct $10FBSYMCHAIN* CHAIN_$1;
 	struct $8FBSYMBOL* BASE_PARENT$1;
 	fb$result$1 = 0ll;
@@ -1221,7 +1278,7 @@ static int64 CGOTBSTMT( struct $7ASTNODE* EXPR$1, int64 ISGOTO$1 )
 	}
 	label$13:;
 	label$12:;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	struct $8FBSYMBOL* vr$8 = SYMBADDTEMPVAR( 9ll, (struct $8FBSYMBOL*)0ull );
 	SYM$1 = vr$8;
 	struct $7ASTNODE* vr$9 = ASTNEWVAR( SYM$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
@@ -1231,12 +1288,12 @@ static int64 CGOTBSTMT( struct $7ASTNODE* EXPR$1, int64 ISGOTO$1 )
 	label$16:;
 	{
 		{
-			int64 TMP$91$3;
+			int64 TMP$96$3;
 			int64 vr$11 = LEXGETCLASS( 0ll );
-			TMP$91$3 = vr$11;
-			if( TMP$91$3 == 3ll ) goto label$21;
+			TMP$96$3 = vr$11;
+			if( TMP$96$3 == 3ll ) goto label$21;
 			label$22:;
-			if( TMP$91$3 != 0ll ) goto label$20;
+			if( TMP$96$3 != 0ll ) goto label$20;
 			label$21:;
 			{
 				struct $10FBSYMCHAIN* vr$13 = CIDENTIFIER( &BASE_PARENT$1, 34ll );
@@ -1244,12 +1301,12 @@ static int64 CGOTBSTMT( struct $7ASTNODE* EXPR$1, int64 ISGOTO$1 )
 				if( L$1 >= 64ll ) goto label$24;
 				{
 					struct $8FBSYMBOL* vr$14 = SYMBFINDBYCLASS( CHAIN_$1, 7ll );
-					*(struct $8FBSYMBOL**)((uint8*)LABELS$1 + (L$1 << (3ll & 63ll))) = vr$14;
-					if( *(struct $8FBSYMBOL**)((uint8*)LABELS$1 + (L$1 << (3ll & 63ll))) != (struct $8FBSYMBOL*)0ull ) goto label$26;
+					*(struct $8FBSYMBOL**)((int64)(struct $8FBSYMBOL**)LABELS$1 + (L$1 << (3ll & 63ll))) = vr$14;
+					if( *(struct $8FBSYMBOL**)((int64)(struct $8FBSYMBOL**)LABELS$1 + (L$1 << (3ll & 63ll))) != (struct $8FBSYMBOL*)0ull ) goto label$26;
 					{
 						uint8* vr$17 = LEXGETTEXT(  );
 						struct $8FBSYMBOL* vr$18 = SYMBADDLABEL( vr$17, 64ll );
-						*(struct $8FBSYMBOL**)((uint8*)LABELS$1 + (L$1 << (3ll & 63ll))) = vr$18;
+						*(struct $8FBSYMBOL**)((int64)(struct $8FBSYMBOL**)LABELS$1 + (L$1 << (3ll & 63ll))) = vr$18;
 					}
 					label$26:;
 					label$25:;
@@ -1262,7 +1319,7 @@ static int64 CGOTBSTMT( struct $7ASTNODE* EXPR$1, int64 ISGOTO$1 )
 				}
 				label$27:;
 				label$23:;
-				LEXSKIPTOKEN( 0ll );
+				LEXSKIPTOKEN( 2048ll );
 			}
 			goto label$19;
 			label$20:;
@@ -1272,7 +1329,7 @@ static int64 CGOTBSTMT( struct $7ASTNODE* EXPR$1, int64 ISGOTO$1 )
 				{
 					uint8* vr$20 = SYMBUNIQUELABEL(  );
 					struct $8FBSYMBOL* vr$21 = SYMBADDLABEL( vr$20, 0ll );
-					*(struct $8FBSYMBOL**)((uint8*)LABELS$1 + (L$1 << (3ll & 63ll))) = vr$21;
+					*(struct $8FBSYMBOL**)((int64)(struct $8FBSYMBOL**)LABELS$1 + (L$1 << (3ll & 63ll))) = vr$21;
 				}
 				label$30:;
 				label$29:;
@@ -1283,7 +1340,7 @@ static int64 CGOTBSTMT( struct $7ASTNODE* EXPR$1, int64 ISGOTO$1 )
 		L$1 = L$1 + 1ll;
 	}
 	label$18:;
-	int64 vr$24 = HMATCH( 44ll );
+	int64 vr$24 = HMATCH( 44ll, 0ll );
 	if( vr$24 != 0ll ) goto label$16;
 	label$17:;
 	if( L$1 < 64ll ) goto label$32;
@@ -1297,26 +1354,26 @@ static int64 CGOTBSTMT( struct $7ASTNODE* EXPR$1, int64 ISGOTO$1 )
 	{
 		int64 I$2;
 		I$2 = 0ll;
-		int64 TMP$92$2;
-		TMP$92$2 = L$1 + -1ll;
+		int64 TMP$97$2;
+		TMP$97$2 = L$1 + -1ll;
 		goto label$33;
 		label$36:;
 		{
-			*(uint64*)((uint8*)VALUES$1 + (I$2 << (3ll & 63ll))) = (uint64)I$2;
+			*(uint64*)((int64)(uint64*)VALUES$1 + (I$2 << (3ll & 63ll))) = (uint64)I$2;
 		}
 		label$34:;
 		I$2 = I$2 + 1ll;
 		label$33:;
-		if( I$2 <= TMP$92$2 ) goto label$36;
+		if( I$2 <= TMP$97$2 ) goto label$36;
 		label$35:;
 	}
 	if( L$1 == 0ll ) goto label$37;
-	TMP$93$1 = L$1 + -1ll;
+	TMP$98$1 = L$1 + -1ll;
 	goto label$72;
 	label$37:;
-	TMP$93$1 = 0ll;
+	TMP$98$1 = 0ll;
 	label$72:;
-	struct $7ASTNODE* vr$32 = ASTBUILDJMPTB( SYM$1, (uint64*)VALUES$1, (struct $8FBSYMBOL**)LABELS$1, L$1, EXITLABEL$1, 1ull, (uint64)TMP$93$1 );
+	struct $7ASTNODE* vr$32 = ASTBUILDJMPTB( SYM$1, (uint64*)VALUES$1, (struct $8FBSYMBOL**)LABELS$1, L$1, EXITLABEL$1, 1ull, (uint64)TMP$98$1 );
 	EXPR$1 = vr$32;
 	if( ISGOTO$1 == 0ll ) goto label$39;
 	{
@@ -1325,7 +1382,7 @@ static int64 CGOTBSTMT( struct $7ASTNODE* EXPR$1, int64 ISGOTO$1 )
 	goto label$38;
 	label$39:;
 	{
-		ASTGOSUBADDJUMPPTR( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll), EXPR$1, EXITLABEL$1 );
+		ASTGOSUBADDJUMPPTR( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll), EXPR$1, EXITLABEL$1 );
 	}
 	label$38:;
 	struct $7ASTNODE* vr$33 = ASTNEWLABEL( EXITLABEL$1, -1ll );
