@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -599,6 +638,16 @@ struct $7ASTNODE {
 };
 __FB_STATIC_ASSERT( sizeof( struct $7ASTNODE ) == 144 );
 typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -646,20 +695,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -667,20 +707,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -721,8 +763,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -730,8 +775,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -778,6 +824,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -799,16 +846,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 
 int64 CPOKESTMT( void )
@@ -821,7 +873,7 @@ int64 CPOKESTMT( void )
 	int64 POKETYPE$1;
 	struct $8FBSYMBOL* SUBTYPE$1;
 	fb$result$1 = 0ll;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	struct $7ASTNODE* vr$3 = HOPTIONALTYPEANDFIRSTEXPR( &POKETYPE$1, &SUBTYPE$1 );
 	EXPR1$1 = vr$3;
 	int64 vr$4 = LEXGETTOKEN( 0ll );
@@ -844,16 +896,16 @@ int64 CPOKESTMT( void )
 	label$27:;
 	label$26:;
 	{
-		int64 TMP$91$2;
-		$12FB_DATACLASS TMP$92$2;
+		int64 TMP$96$2;
+		$12FB_DATACLASS TMP$97$2;
 		if( ((*(int64*)((uint8*)EXPR1$1 + 8ll) & 511ll) & 480ll) == 0ll ) goto label$28;
-		TMP$91$2 = 24ll;
+		TMP$96$2 = 24ll;
 		goto label$42;
 		label$28:;
-		TMP$91$2 = (*(int64*)((uint8*)EXPR1$1 + 8ll) & 511ll) & 31ll;
+		TMP$96$2 = (*(int64*)((uint8*)EXPR1$1 + 8ll) & 511ll) & 31ll;
 		label$42:;
-		TMP$92$2 = *($12FB_DATACLASS*)((uint8*)SYMB_DTYPETB$ + (TMP$91$2 * 56ll));
-		if( TMP$92$2 != 2ll ) goto label$30;
+		TMP$97$2 = *($12FB_DATACLASS*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$96$2 * 56ll));
+		if( TMP$97$2 != 2ll ) goto label$30;
 		label$31:;
 		{
 			ERRREPORT( 24ll, 0ll, (uint8*)0ull );
@@ -862,7 +914,7 @@ int64 CPOKESTMT( void )
 		}
 		goto label$29;
 		label$30:;
-		if( TMP$92$2 != 1ll ) goto label$32;
+		if( TMP$97$2 != 1ll ) goto label$32;
 		label$33:;
 		{
 			struct $7ASTNODE* vr$13 = ASTNEWCONV( 9ll, (struct $8FBSYMBOL*)0ull, EXPR1$1, 0ll, (int64*)0ull );
@@ -871,14 +923,14 @@ int64 CPOKESTMT( void )
 		goto label$29;
 		label$32:;
 		{
-			int64 TMP$93$3;
+			int64 TMP$98$3;
 			if( ((*(int64*)((uint8*)EXPR1$1 + 8ll) & 511ll) & 480ll) == 0ll ) goto label$35;
-			TMP$93$3 = 24ll;
+			TMP$98$3 = 24ll;
 			goto label$43;
 			label$35:;
-			TMP$93$3 = (*(int64*)((uint8*)EXPR1$1 + 8ll) & 511ll) & 31ll;
+			TMP$98$3 = (*(int64*)((uint8*)EXPR1$1 + 8ll) & 511ll) & 31ll;
 			label$43:;
-			if( *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$93$3 * 56ll)) + 8ll) == *(int64*)((uint8*)&ENV$ + 544ll) ) goto label$37;
+			if( *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$98$3 * 56ll)) + 8ll) == *(int64*)((uint8*)&ENV$ + 576ll) ) goto label$37;
 			{
 				ERRREPORT( 24ll, 0ll, (uint8*)0ull );
 				ASTDELTREE( EXPR1$1 );
@@ -925,7 +977,7 @@ struct $7ASTNODE* CPEEKFUNCT( void )
 	int64 DTYPE$1;
 	struct $8FBSYMBOL* SUBTYPE$1;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	LEXSKIPTOKEN( 0ll );
+	LEXSKIPTOKEN( 2048ll );
 	int64 vr$1 = LEXGETTOKEN( 0ll );
 	if( vr$1 == 40ll ) goto label$47;
 	{
@@ -952,16 +1004,16 @@ struct $7ASTNODE* CPEEKFUNCT( void )
 	}
 	label$48:;
 	{
-		int64 TMP$94$2;
-		$12FB_DATACLASS TMP$95$2;
+		int64 TMP$99$2;
+		$12FB_DATACLASS TMP$100$2;
 		if( ((*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 480ll) == 0ll ) goto label$50;
-		TMP$94$2 = 24ll;
+		TMP$99$2 = 24ll;
 		goto label$68;
 		label$50:;
-		TMP$94$2 = (*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 31ll;
+		TMP$99$2 = (*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 31ll;
 		label$68:;
-		TMP$95$2 = *($12FB_DATACLASS*)((uint8*)SYMB_DTYPETB$ + (TMP$94$2 * 56ll));
-		if( TMP$95$2 != 2ll ) goto label$52;
+		TMP$100$2 = *($12FB_DATACLASS*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$99$2 * 56ll));
+		if( TMP$100$2 != 2ll ) goto label$52;
 		label$53:;
 		{
 			ERRREPORT( 24ll, 0ll, (uint8*)0ull );
@@ -970,7 +1022,7 @@ struct $7ASTNODE* CPEEKFUNCT( void )
 		}
 		goto label$51;
 		label$52:;
-		if( TMP$95$2 != 1ll ) goto label$54;
+		if( TMP$100$2 != 1ll ) goto label$54;
 		label$55:;
 		{
 			struct $7ASTNODE* vr$13 = ASTNEWCONV( 9ll, (struct $8FBSYMBOL*)0ull, EXPR$1, 0ll, (int64*)0ull );
@@ -979,14 +1031,14 @@ struct $7ASTNODE* CPEEKFUNCT( void )
 		goto label$51;
 		label$54:;
 		{
-			int64 TMP$96$3;
+			int64 TMP$101$3;
 			if( ((*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 480ll) == 0ll ) goto label$57;
-			TMP$96$3 = 24ll;
+			TMP$101$3 = 24ll;
 			goto label$69;
 			label$57:;
-			TMP$96$3 = (*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 31ll;
+			TMP$101$3 = (*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 31ll;
 			label$69:;
-			if( *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$96$3 * 56ll)) + 8ll) == *(int64*)((uint8*)&ENV$ + 544ll) ) goto label$59;
+			if( *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$101$3 * 56ll)) + 8ll) == *(int64*)((uint8*)&ENV$ + 576ll) ) goto label$59;
 			{
 				ERRREPORT( 24ll, 0ll, (uint8*)0ull );
 				ASTDELTREE( EXPR$1 );
@@ -1041,31 +1093,31 @@ struct $7ASTNODE* CPEEKFUNCT( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
 
 static struct $7ASTNODE* HOPTIONALTYPEANDFIRSTEXPR( int64* DTYPE$1, struct $8FBSYMBOL** SUBTYPE$1 )
 {
-	int64 TMP$88$1;
-	int64 TMP$89$1;
+	int64 TMP$93$1;
+	int64 TMP$94$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
 	struct $7ASTNODE* EXPR$1;
-	TMP$89$1 = 0ll;
-	TMP$88$1 = 0ll;
-	struct $7ASTNODE* vr$3 = CTYPEOREXPRESSION( 464ll, DTYPE$1, SUBTYPE$1, &TMP$88$1, &TMP$89$1 );
+	TMP$94$1 = 0ll;
+	TMP$93$1 = 0ll;
+	struct $7ASTNODE* vr$3 = CTYPEOREXPRESSION( 465ll, DTYPE$1, SUBTYPE$1, &TMP$93$1, &TMP$94$1 );
 	EXPR$1 = vr$3;
 	if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$13;
 	{
 		{
-			int64 TMP$90$3;
-			TMP$90$3 = *DTYPE$1;
-			if( TMP$90$3 == 0ll ) goto label$16;
+			int64 TMP$95$3;
+			TMP$95$3 = *DTYPE$1;
+			if( TMP$95$3 == 0ll ) goto label$16;
 			label$17:;
-			if( TMP$90$3 != 18ll ) goto label$15;
+			if( TMP$95$3 != 18ll ) goto label$15;
 			label$16:;
 			{
 				ERRREPORT( 24ll, -1ll, (uint8*)0ull );
