@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -622,11 +661,10 @@ static void fb_ctor__parserzquirkzthread( void ) __attribute__(( constructor ));
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM*, struct $11TSTRSETITEM* );
 void ERRREPORT( int64, int64, uint8* );
 struct $8FBSYMBOL* SYMBFINDBYCLASS( struct $10FBSYMCHAIN*, int64 );
-struct $8FBSYMBOL* SYMBGETPROCRESULT( struct $8FBSYMBOL* );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $8FB_IDOPT;
 struct $10FBSYMCHAIN* CIDENTIFIER( struct $8FBSYMBOL**, $8FB_IDOPT );
 typedef int64 $12FB_PARSEROPT;
@@ -652,10 +690,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -673,31 +712,31 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
 struct $7ASTNODE* CTHREADCALLFUNC( void )
 {
-	struct $8FBSYMBOL* TMP$89$1;
+	struct $8FBSYMBOL* TMP$94$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
 	struct $8FBSYMBOL* SYM$1;
 	__builtin_memset( &SYM$1, 0, 8ll );
-	struct $8FBSYMBOL* RESULT$1;
-	__builtin_memset( &RESULT$1, 0, 8ll );
 	struct $10FBSYMCHAIN* CHAIN_$1;
 	__builtin_memset( &CHAIN_$1, 0, 8ll );
 	int64 CHECK_PAREN$1;
@@ -709,18 +748,18 @@ struct $7ASTNODE* CTHREADCALLFUNC( void )
 	struct $7ASTNODE* CHILDCALL$1;
 	__builtin_memset( &CHILDCALL$1, 0, 8ll );
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	LEXSKIPTOKEN( 0ll );
-	TMP$89$1 = (struct $8FBSYMBOL*)0ull;
-	struct $10FBSYMCHAIN* vr$7 = CIDENTIFIER( &TMP$89$1, 50ll );
-	CHAIN_$1 = vr$7;
+	LEXSKIPTOKEN( 2048ll );
+	TMP$94$1 = (struct $8FBSYMBOL*)0ull;
+	struct $10FBSYMCHAIN* vr$6 = CIDENTIFIER( &TMP$94$1, 50ll );
+	CHAIN_$1 = vr$6;
 	if( CHAIN_$1 != (struct $10FBSYMCHAIN*)0ull ) goto label$13;
 	{
 		goto label$11;
 	}
 	label$13:;
 	label$12:;
-	struct $8FBSYMBOL* vr$8 = SYMBFINDBYCLASS( CHAIN_$1, 3ll );
-	SYM$1 = vr$8;
+	struct $8FBSYMBOL* vr$7 = SYMBFINDBYCLASS( CHAIN_$1, 3ll );
+	SYM$1 = vr$7;
 	if( SYM$1 != (struct $8FBSYMBOL*)0ull ) goto label$15;
 	{
 		ERRREPORT( 289ll, 0ll, (uint8*)0ull );
@@ -728,59 +767,52 @@ struct $7ASTNODE* CTHREADCALLFUNC( void )
 	}
 	label$15:;
 	label$14:;
-	struct $8FBSYMBOL* vr$9 = SYMBGETPROCRESULT( SYM$1 );
-	RESULT$1 = vr$9;
-	if( RESULT$1 == (struct $8FBSYMBOL*)0ull ) goto label$17;
+	if( (*(int64*)((uint8*)SYM$1 + 56ll) & 511ll) == 0ll ) goto label$17;
 	{
-		if( (*(int64*)((uint8*)RESULT$1 + 48ll) & 511ll) == 0ll ) goto label$19;
-		{
-			ERRREPORT( 289ll, 0ll, (uint8*)0ull );
-			goto label$11;
-		}
-		label$19:;
-		label$18:;
+		ERRREPORT( 289ll, 0ll, (uint8*)0ull );
+		goto label$11;
 	}
 	label$17:;
 	label$16:;
-	LEXSKIPTOKEN( 0ll );
-	int64 vr$12 = HMATCH( 40ll );
-	if( vr$12 != 0ll ) goto label$21;
+	LEXSKIPTOKEN( 2048ll );
+	int64 vr$10 = HMATCH( 40ll, 0ll );
+	if( vr$10 != 0ll ) goto label$19;
 	{
 		int64 PARAMS$2;
 		__builtin_memset( &PARAMS$2, 0, 8ll );
-		PARAMS$2 = (int64)*(int16*)((uint8*)SYM$1 + 112ll);
-		if( PARAMS$2 <= 0ll ) goto label$23;
+		PARAMS$2 = (int64)*(int16*)((uint8*)SYM$1 + 120ll);
+		if( PARAMS$2 <= 0ll ) goto label$21;
 		{
 			ERRREPORT( 6ll, 0ll, (uint8*)0ull );
 			goto label$11;
 		}
-		label$23:;
-		label$22:;
+		label$21:;
+		label$20:;
 	}
-	goto label$20;
-	label$21:;
+	goto label$18;
+	label$19:;
 	{
 		CHECK_PAREN$1 = -1ll;
 	}
-	label$20:;
-	struct $7ASTNODE* vr$17 = CPROCARGLIST( (struct $8FBSYMBOL*)0ull, SYM$1, (struct $7ASTNODE*)0ull, &ARG_LIST$1, 0ll );
-	CHILDCALL$1 = vr$17;
-	if( CHECK_PAREN$1 != -1ll ) goto label$25;
+	label$18:;
+	struct $7ASTNODE* vr$15 = CPROCARGLIST( (struct $8FBSYMBOL*)0ull, SYM$1, (struct $7ASTNODE*)0ull, &ARG_LIST$1, 0ll );
+	CHILDCALL$1 = vr$15;
+	if( CHECK_PAREN$1 != -1ll ) goto label$23;
 	{
-		int64 vr$18 = LEXGETTOKEN( 0ll );
-		if( vr$18 == 41ll ) goto label$27;
+		int64 vr$16 = LEXGETTOKEN( 0ll );
+		if( vr$16 == 41ll ) goto label$25;
 		{
 			ERRREPORT( 7ll, 0ll, (uint8*)0ull );
 			goto label$11;
 		}
-		label$27:;
-		label$26:;
+		label$25:;
+		label$24:;
 		LEXSKIPTOKEN( 0ll );
 	}
-	label$25:;
-	label$24:;
-	struct $7ASTNODE* vr$19 = RTLTHREADCALL( CHILDCALL$1 );
-	fb$result$1 = vr$19;
+	label$23:;
+	label$22:;
+	struct $7ASTNODE* vr$17 = RTLTHREADCALL( CHILDCALL$1 );
+	fb$result$1 = vr$17;
 	label$11:;
 	return fb$result$1;
 }
@@ -788,7 +820,7 @@ struct $7ASTNODE* CTHREADCALLFUNC( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
