@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +341,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +410,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +440,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +590,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -624,7 +663,8 @@ struct $7ASTNODE* ASTNEWCONSTI( int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL*, int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWDEREF( struct $7ASTNODE*, int64, struct $8FBSYMBOL*, int64 );
 struct $7ASTNODE* ASTNEWADDROF( struct $7ASTNODE* );
-struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
+typedef int64 $15AST_LINK_RETURN;
+struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, $15AST_LINK_RETURN );
 struct $7ASTNODE* ASTNEWMACRO( $6AST_OP, struct $7ASTNODE*, struct $7ASTNODE*, int64, struct $8FBSYMBOL* );
 int64 ASTHASSIDEFX( struct $7ASTNODE* );
 int64 ASTCANTAKEADDROF( struct $7ASTNODE* );
@@ -632,10 +672,10 @@ struct $7ASTNODE* ASTMAKEREF( struct $7ASTNODE** );
 struct $7ASTNODE* ASTREMSIDEFX( struct $7ASTNODE** );
 int64 SYMBCALCLEN( int64, struct $8FBSYMBOL* );
 $19FB_CVA_LIST_TYPEDEF SYMBGETVALISTTYPE( int64, struct $8FBSYMBOL* );
-int64 HMATCH( int64 );
 typedef int64 $8LEXCHECK;
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
+int64 HMATCH( int64, $8LEXCHECK );
 typedef int64 $14FB_SYMBTYPEOPT;
 int64 CSYMBOLTYPE( int64*, struct $8FBSYMBOL**, int64*, int64*, $14FB_SYMBTYPEOPT );
 typedef int64 $13FB_VAREXPROPT;
@@ -665,10 +705,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -686,20 +727,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -740,8 +783,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -749,8 +795,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -797,6 +844,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -818,16 +866,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -978,6 +1031,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -989,7 +1043,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 struct $7ASTNODE* CVAFUNCT( void )
@@ -1008,8 +1062,8 @@ struct $7ASTNODE* CVAFUNCT( void )
 	}
 	label$72:;
 	label$71:;
-	LEXSKIPTOKEN( 0ll );
-	int64 vr$5 = HMATCH( 40ll );
+	LEXSKIPTOKEN( 2048ll );
+	int64 vr$5 = HMATCH( 40ll, 0ll );
 	if( vr$5 == 0ll ) goto label$74;
 	{
 		int64 vr$6 = LEXGETTOKEN( 0ll );
@@ -1042,7 +1096,7 @@ struct $7ASTNODE* CVAFUNCT( void )
 		EXPR$2 = vr$9;
 		struct $7ASTNODE* vr$10 = ASTNEWCONV( 32ll, (struct $8FBSYMBOL*)0ull, EXPR$2, 0ll, (int64*)0ull );
 		EXPR$2 = vr$10;
-		struct $7ASTNODE* vr$12 = ASTNEWCONSTI( *(int64*)((uint8*)VARARG_PARAM$1 + 72ll), 9ll, (struct $8FBSYMBOL*)0ull );
+		struct $7ASTNODE* vr$12 = ASTNEWCONSTI( *(int64*)((uint8*)VARARG_PARAM$1 + 80ll), 9ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$13 = ASTNEWBOP( 28ll, EXPR$2, vr$12, (struct $8FBSYMBOL*)0ull, 8ll );
 		fb$result$1 = vr$13;
 	}
@@ -1053,8 +1107,8 @@ struct $7ASTNODE* CVAFUNCT( void )
 
 struct $7ASTNODE* CVALISTFUNCT( $8FB_TOKEN TK$1 )
 {
-	int64 TMP$91$1;
-	int64 TMP$92$1;
+	int64 TMP$96$1;
+	int64 TMP$97$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$79:;
@@ -1065,8 +1119,8 @@ struct $7ASTNODE* CVALISTFUNCT( $8FB_TOKEN TK$1 )
 	struct $8FBSYMBOL* SUBTYPE$1;
 	__builtin_memset( &SUBTYPE$1, 0, 8ll );
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	LEXSKIPTOKEN( 0ll );
-	int64 vr$4 = HMATCH( 40ll );
+	LEXSKIPTOKEN( 2048ll );
+	int64 vr$4 = HMATCH( 40ll, 0ll );
 	if( vr$4 != 0ll ) goto label$82;
 	{
 		ERRREPORT( 6ll, 0ll, (uint8*)0ull );
@@ -1097,9 +1151,9 @@ struct $7ASTNODE* CVALISTFUNCT( $8FB_TOKEN TK$1 )
 		LEXSKIPTOKEN( 0ll );
 	}
 	label$85:;
-	TMP$92$1 = 0ll;
-	TMP$91$1 = 0ll;
-	int64 vr$13 = CSYMBOLTYPE( &DTYPE$1, &SUBTYPE$1, &TMP$91$1, &TMP$92$1, 1ll );
+	TMP$97$1 = 0ll;
+	TMP$96$1 = 0ll;
+	int64 vr$13 = CSYMBOLTYPE( &DTYPE$1, &SUBTYPE$1, &TMP$96$1, &TMP$97$1, 1ll );
 	if( vr$13 != 0ll ) goto label$88;
 	{
 		ERRREPORT( 9ll, 0ll, (uint8*)0ull );
@@ -1111,7 +1165,7 @@ struct $7ASTNODE* CVALISTFUNCT( $8FB_TOKEN TK$1 )
 	}
 	label$88:;
 	label$87:;
-	int64 vr$15 = HMATCH( 41ll );
+	int64 vr$15 = HMATCH( 41ll, 0ll );
 	if( vr$15 != 0ll ) goto label$90;
 	{
 		ERRREPORT( 7ll, 0ll, (uint8*)0ull );
@@ -1151,22 +1205,22 @@ struct $7ASTNODE* CVALISTFUNCT( $8FB_TOKEN TK$1 )
 		label$93:;
 		int64 LGT$2;
 		int64 vr$27 = SYMBCALCLEN( DTYPE$1, SUBTYPE$1 );
-		LGT$2 = ((vr$27 + *(int64*)((uint8*)&ENV$ + 544ll)) + -1ll) & -(*(int64*)((uint8*)&ENV$ + 544ll));
+		LGT$2 = ((vr$27 + *(int64*)((uint8*)&ENV$ + 576ll)) + -1ll) & -(*(int64*)((uint8*)&ENV$ + 576ll));
 		struct $7ASTNODE* EXPR1$2;
 		struct $7ASTNODE* vr$32 = ASTNEWCONSTI( LGT$2, 9ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$33 = ASTCLONETREE( EXPR$1 );
 		struct $7ASTNODE* vr$34 = ASTNEWBOP( 28ll, vr$33, vr$32, (struct $8FBSYMBOL*)0ull, 1ll );
 		EXPR1$2 = vr$34;
 		struct $7ASTNODE* vr$35 = ASTCLONETREE( EXPR$1 );
-		struct $7ASTNODE* vr$36 = ASTNEWASSIGN( vr$35, EXPR1$2, 0ll );
-		struct $7ASTNODE* vr$37 = ASTNEWLINK( TREE$2, vr$36, 16ll );
+		struct $7ASTNODE* vr$36 = ASTNEWASSIGN( vr$35, EXPR1$2, 16ll );
+		struct $7ASTNODE* vr$37 = ASTNEWLINK( TREE$2, vr$36, 0ll );
 		TREE$2 = vr$37;
 		struct $7ASTNODE* EXPR2$2;
 		struct $7ASTNODE* vr$38 = ASTNEWCONSTI( LGT$2, 9ll, (struct $8FBSYMBOL*)0ull );
 		struct $7ASTNODE* vr$39 = ASTNEWBOP( 29ll, EXPR$1, vr$38, (struct $8FBSYMBOL*)0ull, 1ll );
 		EXPR2$2 = vr$39;
 		struct $7ASTNODE* vr$40 = ASTNEWDEREF( EXPR2$2, DTYPE$1, SUBTYPE$1, 0ll );
-		struct $7ASTNODE* vr$41 = ASTNEWLINK( TREE$2, vr$40, 0ll );
+		struct $7ASTNODE* vr$41 = ASTNEWLINK( TREE$2, vr$40, 2ll );
 		TREE$2 = vr$41;
 		fb$result$1 = TREE$2;
 	}
@@ -1189,8 +1243,8 @@ int64 CVALISTSTMT( $8FB_TOKEN TK$1 )
 	struct $8FBSYMBOL* VARARG_PARAM$1;
 	struct $8FBSYMBOL* VARARG_SYM$1;
 	{
-		uint64 TMP$93$2;
-		TMP$93$2 = (uint64)TK$1;
+		uint64 TMP$98$2;
+		TMP$98$2 = (uint64)TK$1;
 		goto label$100;
 		label$101:;
 		{
@@ -1201,8 +1255,8 @@ int64 CVALISTSTMT( $8FB_TOKEN TK$1 )
 			}
 			label$103:;
 			label$102:;
-			LEXSKIPTOKEN( 0ll );
-			int64 vr$7 = HMATCH( 40ll );
+			LEXSKIPTOKEN( 2048ll );
+			int64 vr$7 = HMATCH( 40ll, 0ll );
 			if( vr$7 != 0ll ) goto label$105;
 			{
 				ERRREPORT( 6ll, 0ll, (uint8*)0ull );
@@ -1236,7 +1290,7 @@ int64 CVALISTSTMT( $8FB_TOKEN TK$1 )
 			EXPR2$1 = vr$11;
 			struct $7ASTNODE* vr$12 = HCHECKLASTPARAMETERSYMBOL( EXPR2$1, VARARG_PARAM$1, VARARG_SYM$1 );
 			EXPR2$1 = vr$12;
-			int64 vr$13 = HMATCH( 41ll );
+			int64 vr$13 = HMATCH( 41ll, 0ll );
 			if( vr$13 != 0ll ) goto label$111;
 			{
 				ERRREPORT( 7ll, 0ll, (uint8*)0ull );
@@ -1257,7 +1311,7 @@ int64 CVALISTSTMT( $8FB_TOKEN TK$1 )
 				struct $7ASTNODE* vr$19 = ASTNEWVAR( VARARG_SYM$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 				struct $7ASTNODE* vr$20 = ASTNEWADDROF( vr$19 );
 				EXPR$4 = vr$20;
-				struct $7ASTNODE* vr$22 = ASTNEWCONSTI( *(int64*)((uint8*)VARARG_PARAM$1 + 72ll), 9ll, (struct $8FBSYMBOL*)0ull );
+				struct $7ASTNODE* vr$22 = ASTNEWCONSTI( *(int64*)((uint8*)VARARG_PARAM$1 + 80ll), 9ll, (struct $8FBSYMBOL*)0ull );
 				struct $7ASTNODE* vr$23 = ASTNEWBOP( 28ll, EXPR$4, vr$22, (struct $8FBSYMBOL*)0ull, 1ll );
 				EXPR$4 = vr$23;
 				struct $7ASTNODE* vr$24 = ASTNEWASSIGN( EXPR1$1, EXPR$4, 16ll );
@@ -1269,8 +1323,8 @@ int64 CVALISTSTMT( $8FB_TOKEN TK$1 )
 		goto label$99;
 		label$114:;
 		{
-			LEXSKIPTOKEN( 0ll );
-			int64 vr$25 = HMATCH( 40ll );
+			LEXSKIPTOKEN( 2048ll );
+			int64 vr$25 = HMATCH( 40ll, 0ll );
 			if( vr$25 != 0ll ) goto label$116;
 			{
 				ERRREPORT( 6ll, 0ll, (uint8*)0ull );
@@ -1289,7 +1343,7 @@ int64 CVALISTSTMT( $8FB_TOKEN TK$1 )
 			}
 			label$118:;
 			label$117:;
-			int64 vr$28 = HMATCH( 41ll );
+			int64 vr$28 = HMATCH( 41ll, 0ll );
 			if( vr$28 != 0ll ) goto label$120;
 			{
 				ERRREPORT( 7ll, 0ll, (uint8*)0ull );
@@ -1314,8 +1368,8 @@ int64 CVALISTSTMT( $8FB_TOKEN TK$1 )
 		goto label$99;
 		label$123:;
 		{
-			LEXSKIPTOKEN( 0ll );
-			int64 vr$34 = HMATCH( 40ll );
+			LEXSKIPTOKEN( 2048ll );
+			int64 vr$34 = HMATCH( 40ll, 0ll );
 			if( vr$34 != 0ll ) goto label$125;
 			{
 				ERRREPORT( 6ll, 0ll, (uint8*)0ull );
@@ -1358,7 +1412,7 @@ int64 CVALISTSTMT( $8FB_TOKEN TK$1 )
 			}
 			label$131:;
 			label$130:;
-			int64 vr$40 = HMATCH( 41ll );
+			int64 vr$40 = HMATCH( 41ll, 0ll );
 			if( vr$40 != 0ll ) goto label$133;
 			{
 				ERRREPORT( 7ll, 0ll, (uint8*)0ull );
@@ -1384,14 +1438,14 @@ int64 CVALISTSTMT( $8FB_TOKEN TK$1 )
 		}
 		goto label$99;
 		label$100:;
-		static const void* tmp$94[4ll] = {
+		static const void* tmp$99[4ll] = {
 			&&label$101,
 			&&label$99,
 			&&label$114,
 			&&label$123,
 		};
-		if( (TMP$93$2 - 513ull) > 3ull ) goto label$99;
-		goto *tmp$94[TMP$93$2 - 513ull];
+		if( (TMP$98$2 - 514ull) > 3ull ) goto label$99;
+		goto *tmp$99[TMP$98$2 - 514ull];
 		label$99:;
 	}
 	label$98:;
@@ -1401,7 +1455,7 @@ int64 CVALISTSTMT( $8FB_TOKEN TK$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1412,40 +1466,40 @@ static int64 HGETVARARGPROCPARAM( struct $8FBSYMBOL** PROC$1, struct $8FBSYMBOL*
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
 	fb$result$1 = 0ll;
-	if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) != *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) ) goto label$13;
+	if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) != *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) ) goto label$13;
 	{
 		goto label$11;
 	}
 	label$13:;
 	label$12:;
-	*PROC$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll);
-	if( *(int64*)((uint8*)*PROC$1 + 144ll) == 3ll ) goto label$15;
+	*PROC$1 = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll);
+	if( *(int64*)((uint8*)*PROC$1 + 152ll) == 3ll ) goto label$15;
 	{
 		goto label$11;
 	}
 	label$15:;
 	label$14:;
-	*VARARG_PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)*PROC$1 + 136ll);
+	*VARARG_PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)*PROC$1 + 144ll);
 	if( *VARARG_PARAM$1 != (struct $8FBSYMBOL*)0ull ) goto label$17;
 	{
 		goto label$11;
 	}
 	label$17:;
 	label$16:;
-	if( *(int64*)((uint8*)*VARARG_PARAM$1 + 88ll) == 4ll ) goto label$19;
+	if( *(int64*)((uint8*)*VARARG_PARAM$1 + 96ll) == 4ll ) goto label$19;
 	{
 		goto label$11;
 	}
 	label$19:;
 	label$18:;
-	*VARARG_PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)*VARARG_PARAM$1 + 288ll);
+	*VARARG_PARAM$1 = *(struct $8FBSYMBOL**)((uint8*)*VARARG_PARAM$1 + 304ll);
 	if( *VARARG_PARAM$1 != (struct $8FBSYMBOL*)0ull ) goto label$21;
 	{
 		goto label$11;
 	}
 	label$21:;
 	label$20:;
-	*VARARG_SYM$1 = *(struct $8FBSYMBOL**)((uint8*)*VARARG_PARAM$1 + 96ll);
+	*VARARG_SYM$1 = *(struct $8FBSYMBOL**)((uint8*)*VARARG_PARAM$1 + 104ll);
 	if( *VARARG_SYM$1 != (struct $8FBSYMBOL*)0ull ) goto label$23;
 	{
 		goto label$11;
@@ -1480,11 +1534,11 @@ static int64 HCHECKFORVALISTCOMPATIBLETYPE( struct $7ASTNODE* EXPR$1, int64 ALLO
 	label$29:;
 	label$28:;
 	{
-		int64 TMP$88$2;
-		TMP$88$2 = (*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 31ll;
-		if( TMP$88$2 == 0ll ) goto label$32;
+		int64 TMP$93$2;
+		TMP$93$2 = (*(int64*)((uint8*)EXPR$1 + 8ll) & 511ll) & 31ll;
+		if( TMP$93$2 == 0ll ) goto label$32;
 		label$33:;
-		if( TMP$88$2 != 20ll ) goto label$31;
+		if( TMP$93$2 != 20ll ) goto label$31;
 		label$32:;
 		{
 			fb$result$1 = -1ll;
@@ -1515,9 +1569,9 @@ static struct $7ASTNODE* HCHECKLASTPARAMETERSYMBOL( struct $7ASTNODE* EXPR$1, st
 	label$37:;
 	label$36:;
 	{
-		$13AST_NODECLASS TMP$89$2;
-		TMP$89$2 = *($13AST_NODECLASS*)EXPR$1;
-		if( TMP$89$2 != 17ll ) goto label$39;
+		$13AST_NODECLASS TMP$94$2;
+		TMP$94$2 = *($13AST_NODECLASS*)EXPR$1;
+		if( TMP$94$2 != 17ll ) goto label$39;
 		label$40:;
 		{
 			if( *(struct $8FBSYMBOL**)((uint8*)EXPR$1 + 24ll) != VARARG_SYM$1 ) goto label$42;
@@ -1530,9 +1584,9 @@ static struct $7ASTNODE* HCHECKLASTPARAMETERSYMBOL( struct $7ASTNODE* EXPR$1, st
 		}
 		goto label$38;
 		label$39:;
-		if( TMP$89$2 == 20ll ) goto label$44;
+		if( TMP$94$2 == 20ll ) goto label$44;
 		label$45:;
-		if( TMP$89$2 != 25ll ) goto label$43;
+		if( TMP$94$2 != 25ll ) goto label$43;
 		label$44:;
 		{
 			if( *(int64*)*(struct $7ASTNODE**)((uint8*)EXPR$1 + 112ll) != 17ll ) goto label$47;
@@ -1551,7 +1605,7 @@ static struct $7ASTNODE* HCHECKLASTPARAMETERSYMBOL( struct $7ASTNODE* EXPR$1, st
 		label$43:;
 		label$38:;
 	}
-	ERRREPORTEX( 14ll, (uint8*)*(uint8**)((uint8*)VARARG_PARAM$1 + 24ll), 0ll, 1ll, (uint8*)0ull );
+	ERRREPORTEX( 14ll, (uint8*)*(uint8**)((uint8*)VARARG_PARAM$1 + 32ll), 0ll, 1ll, (uint8*)0ull );
 	ASTDELTREE( EXPR$1 );
 	struct $7ASTNODE* vr$9 = ASTNEWVAR( VARARG_SYM$1, 0ll, 2147483648ll, (struct $8FBSYMBOL*)0ull );
 	fb$result$1 = vr$9;
@@ -1576,24 +1630,24 @@ static void HSOLVEVALISTTYPE( struct $7ASTNODE** N$1 )
 	if( ((*(int64*)((uint8*)*N$1 + 8ll) & 32505856ll) >> (20ll & 63ll)) != 19ll ) goto label$57;
 	{
 		{
-			$19FB_CVA_LIST_TYPEDEF TMP$90$3;
+			$19FB_CVA_LIST_TYPEDEF TMP$95$3;
 			$19FB_CVA_LIST_TYPEDEF vr$18 = SYMBGETVALISTTYPE( *(int64*)((uint8*)*N$1 + 8ll), *(struct $8FBSYMBOL**)((uint8*)*N$1 + 16ll) );
-			TMP$90$3 = vr$18;
-			if( TMP$90$3 == 1ll ) goto label$60;
+			TMP$95$3 = vr$18;
+			if( TMP$95$3 == 1ll ) goto label$60;
 			label$61:;
-			if( TMP$90$3 != 2ll ) goto label$59;
+			if( TMP$95$3 != 2ll ) goto label$59;
 			label$60:;
 			{
 				*(int64*)((uint8*)*N$1 + 8ll) = (((((*(int64*)((uint8*)*N$1 + 8ll) & 31ll) | ((*(int64*)((uint8*)*N$1 + 8ll) & 480ll) + -32ll)) | (((*(int64*)((uint8*)*N$1 + 8ll) & 261632ll) >> (1ll & 63ll)) & 261632ll)) | (*(int64*)((uint8*)*N$1 + 8ll) & 32505856ll)) & -32ll) | 19ll;
 			}
 			goto label$58;
 			label$59:;
-			if( TMP$90$3 != 3ll ) goto label$62;
+			if( TMP$95$3 != 3ll ) goto label$62;
 			label$63:;
 			{
 				if( *(int64*)*N$1 != 17ll ) goto label$65;
 				{
-					if( (*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)*N$1 + 24ll) + 8ll) & 131072ll) == 0ll ) goto label$67;
+					if( (*(int64*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)*N$1 + 24ll) + 8ll) & 32768ll) == 0ll ) goto label$67;
 					{
 						goto label$58;
 					}
