@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $8FB_TOKEN;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -178,7 +179,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -315,6 +316,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -324,7 +326,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -333,7 +336,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -344,10 +347,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -356,9 +360,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -457,14 +461,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -486,7 +492,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -497,9 +529,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -560,6 +598,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -589,7 +628,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $10FBSYMCHAIN {
 	struct $8FBSYMBOL* SYM;
 	struct $10FBSYMCHAIN* NEXT;
@@ -614,29 +653,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -669,7 +698,7 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -749,10 +778,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -770,20 +800,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -824,8 +856,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -833,8 +868,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -881,6 +917,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -902,23 +939,28 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -1068,6 +1110,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1079,7 +1122,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 int64 CQUIRKSTMT( $8FB_TOKEN TK$1 )
@@ -1093,17 +1136,17 @@ int64 CQUIRKSTMT( $8FB_TOKEN TK$1 )
 		int64 vr$1 = LEXGETTOKEN( 0ll );
 		TK$1 = vr$1;
 		{
-			int64 TMP$88$3;
+			int64 TMP$93$3;
 			int64 vr$2 = LEXGETCLASS( 0ll );
-			TMP$88$3 = vr$2;
-			if( TMP$88$3 == 1ll ) goto label$16;
+			TMP$93$3 = vr$2;
+			if( TMP$93$3 == 1ll ) goto label$16;
 			label$17:;
-			if( TMP$88$3 != 2ll ) goto label$15;
+			if( TMP$93$3 != 2ll ) goto label$15;
 			label$16:;
 			{
 				if( *(int64*)((uint8*)&ENV$ + 272ll) != 3ll ) goto label$19;
 				{
-					if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8488ll) + 16ll) == 2147483648ll ) goto label$21;
+					if( *(int64*)((uint8*)*(struct $7FBTOKEN**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8520ll) + 16ll) == 2147483648ll ) goto label$21;
 					{
 						fb$result$1 = 0ll;
 						goto label$11;
@@ -1143,8 +1186,8 @@ int64 CQUIRKSTMT( $8FB_TOKEN TK$1 )
 	int64 RES$1;
 	RES$1 = 0ll;
 	{
-		uint64 TMP$89$2;
-		TMP$89$2 = (uint64)TK$1;
+		uint64 TMP$94$2;
+		TMP$94$2 = (uint64)TK$1;
 		goto label$28;
 		label$29:;
 		{
@@ -1424,7 +1467,7 @@ int64 CQUIRKSTMT( $8FB_TOKEN TK$1 )
 		}
 		goto label$27;
 		label$28:;
-		static const void* tmp$90[257ll] = {
+		static const void* tmp$95[258ll] = {
 			&&label$83,
 			&&label$27,
 			&&label$27,
@@ -1555,6 +1598,7 @@ int64 CQUIRKSTMT( $8FB_TOKEN TK$1 )
 			&&label$27,
 			&&label$27,
 			&&label$27,
+			&&label$27,
 			&&label$29,
 			&&label$29,
 			&&label$29,
@@ -1683,8 +1727,8 @@ int64 CQUIRKSTMT( $8FB_TOKEN TK$1 )
 			&&label$86,
 			&&label$86,
 		};
-		if( (TMP$89$2 - 260ull) > 256ull ) goto label$27;
-		goto *tmp$90[TMP$89$2 - 260ull];
+		if( (TMP$94$2 - 260ull) > 257ull ) goto label$27;
+		goto *tmp$95[TMP$94$2 - 260ull];
 		label$27:;
 	}
 	if( RES$1 != 0ll ) goto label$90;
@@ -1707,22 +1751,22 @@ struct $7ASTNODE* CQUIRKFUNCTION( struct $8FBSYMBOL* SYM$1 )
 	struct $7ASTNODE* FUNCEXPR$1;
 	FUNCEXPR$1 = (struct $7ASTNODE*)0ull;
 	$8FB_TOKEN TK$1;
-	TK$1 = *($8FB_TOKEN*)((uint8*)SYM$1 + 88ll);
-	if( (*(int64*)((uint8*)&PARSER$ + 288ll) & 1024ll) == 0ll ) goto label$94;
+	TK$1 = *($8FB_TOKEN*)((uint8*)SYM$1 + 96ll);
+	if( (*(int64*)((uint8*)&PARSER$ + 296ll) & 1024ll) == 0ll ) goto label$94;
 	{
 		int64 vr$3 = LEXGETLOOKAHEAD( 1ll, 0ll );
 		int64 vr$6 = LEXGETLOOKAHEAD( 1ll, 0ll );
 		if( ((int64)-(vr$3 != 40ll) & ((int64)-(TK$1 != 336ll) | (int64)-(vr$6 != 301ll))) == 0ll ) goto label$96;
 		{
-			FBSTRING TMP$91$3;
-			__builtin_memset( &TMP$91$3, 0, 24ll );
+			FBSTRING TMP$96$3;
+			__builtin_memset( &TMP$96$3, 0, 24ll );
 			uint8* vr$11 = LEXGETTEXT(  );
 			FBSTRING* vr$12 = fb_StrAllocTempDescZ( (uint8*)vr$11 );
 			FBSTRING* vr$13 = fb_StrUcase2( (FBSTRING*)vr$12, 0 );
-			FBSTRING* vr$15 = fb_StrAssign( (void*)&TMP$91$3, -1ll, (void*)vr$13, -1ll, 0 );
-			struct $7ASTNODE* vr$16 = ASTNEWCONSTSTR( (uint8*)*(uint8**)&TMP$91$3 );
-			FUNCEXPR$1 = vr$16;
-			fb_StrDelete( (FBSTRING*)&TMP$91$3 );
+			fb_StrAssign( (void*)&TMP$96$3, -1ll, (void*)vr$13, -1ll, 0 );
+			struct $7ASTNODE* vr$15 = ASTNEWCONSTSTR( (uint8*)*(uint8**)&TMP$96$3 );
+			FUNCEXPR$1 = vr$15;
+			fb_StrDelete( (FBSTRING*)&TMP$96$3 );
 			LEXSKIPTOKEN( 0ll );
 			fb$result$1 = FUNCEXPR$1;
 			goto label$92;
@@ -1733,124 +1777,124 @@ struct $7ASTNODE* CQUIRKFUNCTION( struct $8FBSYMBOL* SYM$1 )
 	label$94:;
 	label$93:;
 	{
-		uint64 TMP$92$2;
-		TMP$92$2 = (uint64)TK$1;
+		uint64 TMP$97$2;
+		TMP$97$2 = (uint64)TK$1;
 		goto label$98;
 		label$99:;
 		{
-			struct $7ASTNODE* vr$18 = CMKXFUNCT( TK$1 );
-			FUNCEXPR$1 = vr$18;
+			struct $7ASTNODE* vr$17 = CMKXFUNCT( TK$1 );
+			FUNCEXPR$1 = vr$17;
 		}
 		goto label$97;
 		label$100:;
 		{
-			struct $7ASTNODE* vr$19 = CCVXFUNCT( TK$1 );
-			FUNCEXPR$1 = vr$19;
+			struct $7ASTNODE* vr$18 = CCVXFUNCT( TK$1 );
+			FUNCEXPR$1 = vr$18;
 		}
 		goto label$97;
 		label$101:;
 		{
-			struct $7ASTNODE* vr$20 = CSTRINGFUNCT( TK$1 );
-			FUNCEXPR$1 = vr$20;
+			struct $7ASTNODE* vr$19 = CSTRINGFUNCT( TK$1 );
+			FUNCEXPR$1 = vr$19;
 		}
 		goto label$97;
 		label$102:;
 		{
-			struct $7ASTNODE* vr$21 = CMATHFUNCT( TK$1, 0ll );
-			FUNCEXPR$1 = vr$21;
+			struct $7ASTNODE* vr$20 = CMATHFUNCT( TK$1, 0ll );
+			FUNCEXPR$1 = vr$20;
 		}
 		goto label$97;
 		label$103:;
 		{
-			struct $7ASTNODE* vr$22 = CPEEKFUNCT(  );
-			FUNCEXPR$1 = vr$22;
+			struct $7ASTNODE* vr$21 = CPEEKFUNCT(  );
+			FUNCEXPR$1 = vr$21;
 		}
 		goto label$97;
 		label$104:;
 		{
-			struct $7ASTNODE* vr$23 = CARRAYFUNCT( TK$1 );
-			FUNCEXPR$1 = vr$23;
+			struct $7ASTNODE* vr$22 = CARRAYFUNCT( TK$1 );
+			FUNCEXPR$1 = vr$22;
 		}
 		goto label$97;
 		label$105:;
 		{
-			struct $7ASTNODE* vr$24 = CFILEFUNCT( TK$1 );
-			FUNCEXPR$1 = vr$24;
+			struct $7ASTNODE* vr$23 = CFILEFUNCT( TK$1 );
+			FUNCEXPR$1 = vr$23;
 		}
 		goto label$97;
 		label$106:;
 		{
-			struct $7ASTNODE* vr$25 = CERRORFUNCT(  );
-			FUNCEXPR$1 = vr$25;
+			struct $7ASTNODE* vr$24 = CERRORFUNCT(  );
+			FUNCEXPR$1 = vr$24;
 		}
 		goto label$97;
 		label$107:;
 		{
-			struct $7ASTNODE* vr$26 = CIIFFUNCT(  );
-			struct $7ASTNODE* vr$27 = CSTRIDXORMEMBERDEREF( vr$26 );
-			fb$result$1 = vr$27;
+			struct $7ASTNODE* vr$25 = CIIFFUNCT(  );
+			struct $7ASTNODE* vr$26 = CSTRIDXORMEMBERDEREF( vr$25 );
+			fb$result$1 = vr$26;
 			goto label$92;
 		}
 		goto label$97;
 		label$108:;
 		{
-			struct $7ASTNODE* vr$28 = CVAFUNCT(  );
-			FUNCEXPR$1 = vr$28;
+			struct $7ASTNODE* vr$27 = CVAFUNCT(  );
+			FUNCEXPR$1 = vr$27;
 		}
 		goto label$97;
 		label$109:;
 		{
-			struct $7ASTNODE* vr$29 = CVALISTFUNCT( TK$1 );
-			FUNCEXPR$1 = vr$29;
+			struct $7ASTNODE* vr$28 = CVALISTFUNCT( TK$1 );
+			FUNCEXPR$1 = vr$28;
 		}
 		goto label$97;
 		label$110:;
 		{
-			struct $7ASTNODE* vr$30 = CTYPECONVEXPR( TK$1, 0ll );
-			fb$result$1 = vr$30;
+			struct $7ASTNODE* vr$29 = CTYPECONVEXPR( TK$1, 0ll );
+			fb$result$1 = vr$29;
 			goto label$92;
 		}
 		goto label$97;
 		label$111:;
 		{
-			struct $7ASTNODE* vr$31 = CANONTYPE(  );
-			struct $7ASTNODE* vr$32 = CSTRIDXORMEMBERDEREF( vr$31 );
-			fb$result$1 = vr$32;
+			struct $7ASTNODE* vr$30 = CANONTYPE(  );
+			struct $7ASTNODE* vr$31 = CSTRIDXORMEMBERDEREF( vr$30 );
+			fb$result$1 = vr$31;
 			goto label$92;
 		}
 		goto label$97;
 		label$112:;
 		{
-			struct $7ASTNODE* vr$33 = CVIEWSTMT( -1ll );
-			FUNCEXPR$1 = vr$33;
+			struct $7ASTNODE* vr$32 = CVIEWSTMT( -1ll );
+			FUNCEXPR$1 = vr$32;
 		}
 		goto label$97;
 		label$113:;
 		{
-			struct $7ASTNODE* vr$34 = CWIDTHSTMT( -1ll );
-			FUNCEXPR$1 = vr$34;
+			struct $7ASTNODE* vr$33 = CWIDTHSTMT( -1ll );
+			FUNCEXPR$1 = vr$33;
 		}
 		goto label$97;
 		label$114:;
 		{
-			struct $7ASTNODE* vr$35 = CCOLORSTMT( -1ll );
-			FUNCEXPR$1 = vr$35;
+			struct $7ASTNODE* vr$34 = CCOLORSTMT( -1ll );
+			FUNCEXPR$1 = vr$34;
 		}
 		goto label$97;
 		label$115:;
 		{
-			struct $7ASTNODE* vr$36 = CSCREENFUNCT(  );
-			FUNCEXPR$1 = vr$36;
+			struct $7ASTNODE* vr$35 = CSCREENFUNCT(  );
+			FUNCEXPR$1 = vr$35;
 		}
 		goto label$97;
 		label$116:;
 		{
-			struct $7ASTNODE* vr$37 = CTHREADCALLFUNC(  );
-			FUNCEXPR$1 = vr$37;
+			struct $7ASTNODE* vr$36 = CTHREADCALLFUNC(  );
+			FUNCEXPR$1 = vr$36;
 		}
 		goto label$97;
 		label$98:;
-		static const void* tmp$93[182ll] = {
+		static const void* tmp$98[183ll] = {
 			&&label$111,
 			&&label$97,
 			&&label$97,
@@ -1914,6 +1958,7 @@ struct $7ASTNODE* CQUIRKFUNCTION( struct $8FBSYMBOL* SYM$1 )
 			&&label$97,
 			&&label$97,
 			&&label$97,
+			&&label$97,
 			&&label$110,
 			&&label$110,
 			&&label$110,
@@ -2034,14 +2079,14 @@ struct $7ASTNODE* CQUIRKFUNCTION( struct $8FBSYMBOL* SYM$1 )
 			&&label$97,
 			&&label$116,
 		};
-		if( (TMP$92$2 - 336ull) > 181ull ) goto label$97;
-		goto *tmp$93[TMP$92$2 - 336ull];
+		if( (TMP$97$2 - 336ull) > 182ull ) goto label$97;
+		goto *tmp$98[TMP$97$2 - 336ull];
 		label$97:;
 	}
 	if( FUNCEXPR$1 != (struct $7ASTNODE*)0ull ) goto label$118;
 	{
-		struct $7ASTNODE* vr$38 = CGFXFUNCT( TK$1 );
-		FUNCEXPR$1 = vr$38;
+		struct $7ASTNODE* vr$37 = CGFXFUNCT( TK$1 );
+		FUNCEXPR$1 = vr$37;
 	}
 	label$118:;
 	label$117:;
@@ -2053,7 +2098,7 @@ struct $7ASTNODE* CQUIRKFUNCTION( struct $8FBSYMBOL* SYM$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
