@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 typedef int64 $11FB_MANGLING;
 typedef int64 $8FB_TOKEN;
 typedef int64 $12FB_PARSEROPT;
@@ -616,29 +655,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -671,7 +700,7 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 typedef int64 $8LEXCHECK;
 struct $11TSTRSETITEM {
 	FBSTRING S;
@@ -693,7 +722,8 @@ void DZSTRRESET( struct $8DZSTRING* );
 int64 LEXGETTOKEN( $8LEXCHECK );
 void LEXSKIPTOKEN( $8LEXCHECK );
 int64 LEXGETLOOKAHEAD( int64, $8LEXCHECK );
-void PARSERINLINEASMEND( void );
+void PARSERASMINIT( void );
+void PARSERASMEND( void );
 int64 CLABEL( void );
 int64 CCOMMENT( $8LEXCHECK );
 void CSTATEMENT( void );
@@ -776,10 +806,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -797,20 +828,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -851,8 +884,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -860,8 +896,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -908,6 +945,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -929,23 +967,28 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -1094,6 +1137,7 @@ __FB_STATIC_ASSERT( sizeof( struct $13FBPARSER_STMT ) == 176 );
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1105,32 +1149,34 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 struct $6PP_CTX {
 	struct $8FBSYMBOL KWDNS;
 	struct $5TLIST ARGTBLIST;
 	int64 LEVEL;
 	int64 SKIPPING;
+	int64 INVOKING;
 };
-__FB_STATIC_ASSERT( sizeof( struct $6PP_CTX ) == 384 );
+__FB_STATIC_ASSERT( sizeof( struct $6PP_CTX ) == 408 );
 extern struct $6PP_CTX PP$;
 struct $9PARSERCTX PARSER$;
 
 void PARSERSETCTX( void )
 {
 	label$10:;
-	*(uint64*)((uint8*)&PARSER$ + 184ll) = 0ull;
-	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) = (struct $8FBSYMBOL*)0ull;
+	*(uint64*)((uint8*)&PARSER$ + 192ll) = 0ull;
 	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) = (struct $8FBSYMBOL*)0ull;
+	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 216ll) = (struct $8FBSYMBOL*)0ull;
 	*(int64*)((uint8*)&PARSER$ + 176ll) = 0ll;
-	*($11FB_MANGLING*)((uint8*)&PARSER$ + 192ll) = 0ll;
+	*(struct $10FBSYMCHAIN**)((uint8*)&PARSER$ + 184ll) = (struct $10FBSYMCHAIN*)0ull;
+	*($11FB_MANGLING*)((uint8*)&PARSER$ + 200ll) = 0ll;
 	*(int64*)((uint8*)&PARSER$ + 56ll) = 0ll;
 	*($8FB_TOKEN*)((uint8*)&PARSER$ + 48ll) = 0ll;
-	*(int64*)((uint8*)&PARSER$ + 280ll) = 0ll;
-	*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = 2ll;
-	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 304ll) = (struct $8FBSYMBOL*)0ull;
-	*(int64*)((uint8*)&PARSER$ + 296ll) = 2147483648ll;
+	*(int64*)((uint8*)&PARSER$ + 288ll) = 0ll;
+	*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = 2ll;
+	*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 312ll) = (struct $8FBSYMBOL*)0ull;
+	*(int64*)((uint8*)&PARSER$ + 304ll) = 2147483648ll;
 	PARSERCOMPOUNDSTMTSETCTX(  );
 	label$11:;
 }
@@ -1141,16 +1187,17 @@ void PARSERINIT( void )
 	PARSERCOMPOUNDSTMTINIT(  );
 	PARSERPROCCALLINIT(  );
 	PARSERLETINIT(  );
+	PARSERASMINIT(  );
 	label$13:;
 }
 
 void PARSEREND( void )
 {
 	label$14:;
+	PARSERASMEND(  );
 	PARSERLETEND(  );
 	PARSERPROCCALLEND(  );
 	PARSERCOMPOUNDSTMTEND(  );
-	PARSERINLINEASMEND(  );
 	label$15:;
 }
 
@@ -1158,570 +1205,608 @@ void CPROGRAM( void )
 {
 	label$24:;
 	int64 STARTLEVEL$1;
-	STARTLEVEL$1 = *(int64*)((uint8*)&PP$ + 368ll);
+	STARTLEVEL$1 = *(int64*)((uint8*)&PP$ + 384ll);
 	label$26:;
 	{
-		struct $7ASTNODE* vr$1 = ASTNEWDBG( 113ll, *(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 8520ll), *(uint8**)((uint8*)&ENV$ + 824ll) );
-		ASTADD( vr$1 );
-		CLABEL(  );
-		CSTATEMENT(  );
-		CCOMMENT( 0ll );
-		int64 vr$2 = FBSHOULDCONTINUE(  );
-		if( vr$2 != 0ll ) goto label$30;
+		int64 vr$0 = LEXGETTOKEN( 0ll );
+		if( vr$0 != 257ll ) goto label$30;
 		{
-			goto label$25;
+			DZSTRRESET( (struct $8DZSTRING*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 25064ll) );
+			LEXSKIPTOKEN( 0ll );
+			int64 vr$3 = FBSHOULDCONTINUE(  );
+			if( vr$3 != 0ll ) goto label$32;
+			{
+				goto label$25;
+			}
+			label$32:;
+			label$31:;
+			*(int64*)((uint8*)&PARSER$ + 56ll) = *(int64*)((uint8*)&PARSER$ + 56ll) + 1ll;
+			goto label$28;
 		}
 		label$30:;
 		label$29:;
-		if( *(int64*)((uint8*)&ENV$ + 296ll) == 0ll ) goto label$32;
+		int64 vr$5 = CCOMMENT( 0ll );
+		if( vr$5 == 0ll ) goto label$34;
 		{
-			if( *(int64*)((uint8*)&ENV$ + 1224ll) != 0ll ) goto label$34;
+			int64 vr$6 = FBSHOULDCONTINUE(  );
+			if( vr$6 != 0ll ) goto label$36;
+			{
+				goto label$25;
+			}
+			label$36:;
+			label$35:;
+			goto label$28;
+		}
+		label$34:;
+		label$33:;
+		int64 vr$7 = FBSHOULDCONTINUE(  );
+		if( vr$7 != 0ll ) goto label$38;
+		{
+			goto label$25;
+		}
+		label$38:;
+		label$37:;
+		struct $7ASTNODE* vr$9 = ASTNEWDBG( 113ll, *(int64*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 8560ll), *(uint8**)((uint8*)&ENV$ + 856ll) );
+		ASTADD( vr$9 );
+		CLABEL(  );
+		CSTATEMENT(  );
+		CCOMMENT( 0ll );
+		int64 vr$10 = FBSHOULDCONTINUE(  );
+		if( vr$10 != 0ll ) goto label$40;
+		{
+			goto label$25;
+		}
+		label$40:;
+		label$39:;
+		if( *(int64*)((uint8*)&ENV$ + 296ll) == 0ll ) goto label$42;
+		{
+			if( *(int64*)((uint8*)&ENV$ + 1256ll) != 0ll ) goto label$44;
 			{
 				HEMITCURRENTLINETEXT(  );
 			}
-			label$34:;
-			label$33:;
+			label$44:;
+			label$43:;
 		}
-		label$32:;
-		label$31:;
+		label$42:;
+		label$41:;
 		{
-			int64 TMP$88$3;
-			int64 vr$3 = LEXGETTOKEN( 0ll );
-			TMP$88$3 = vr$3;
-			if( TMP$88$3 != 257ll ) goto label$36;
-			label$37:;
+			int64 TMP$93$3;
+			int64 vr$11 = LEXGETTOKEN( 0ll );
+			TMP$93$3 = vr$11;
+			if( TMP$93$3 != 257ll ) goto label$46;
+			label$47:;
 			{
 				LEXSKIPTOKEN( 0ll );
 			}
-			goto label$35;
-			label$36:;
-			if( TMP$88$3 != 256ll ) goto label$38;
-			label$39:;
+			goto label$45;
+			label$46:;
+			if( TMP$93$3 != 256ll ) goto label$48;
+			label$49:;
 			{
 			}
-			goto label$35;
-			label$38:;
+			goto label$45;
+			label$48:;
 			{
 				ERRREPORT( 3ll, 0ll, (uint8*)0ull );
 				HSKIPUNTIL( 257ll, -1ll, 0ll, 0ll );
 			}
-			label$40:;
-			label$35:;
+			label$50:;
+			label$45:;
 		}
-		int64 vr$4 = FBSHOULDCONTINUE(  );
-		if( vr$4 != 0ll ) goto label$42;
+		int64 vr$12 = FBSHOULDCONTINUE(  );
+		if( vr$12 != 0ll ) goto label$52;
 		{
 			goto label$25;
 		}
-		label$42:;
-		label$41:;
-		struct $7ASTNODE* vr$5 = ASTNEWDBG( 114ll, 0ll, (uint8*)0ull );
-		ASTADD( vr$5 );
+		label$52:;
+		label$51:;
+		struct $7ASTNODE* vr$13 = ASTNEWDBG( 114ll, 0ll, (uint8*)0ull );
+		ASTADD( vr$13 );
 		*(int64*)((uint8*)&PARSER$ + 56ll) = *(int64*)((uint8*)&PARSER$ + 56ll) + 1ll;
 	}
 	label$28:;
-	int64 vr$7 = LEXGETTOKEN( 0ll );
-	if( vr$7 != 256ll ) goto label$26;
+	int64 vr$15 = LEXGETTOKEN( 0ll );
+	if( vr$15 != 256ll ) goto label$26;
 	label$27:;
-	if( *(int64*)((uint8*)&PP$ + 368ll) == STARTLEVEL$1 ) goto label$44;
+	if( *(int64*)((uint8*)&PP$ + 384ll) == STARTLEVEL$1 ) goto label$54;
 	{
 		ERRREPORT( 290ll, 0ll, (uint8*)0ull );
 	}
-	label$44:;
-	label$43:;
+	label$54:;
+	label$53:;
 	LEXSKIPTOKEN( 0ll );
-	if( *(int64*)((uint8*)&ENV$ + 1224ll) != 0ll ) goto label$46;
+	if( *(int64*)((uint8*)&ENV$ + 1256ll) != 0ll ) goto label$56;
 	{
 		CCOMPSTMTCHECK(  );
 	}
-	label$46:;
-	label$45:;
+	label$56:;
+	label$55:;
 	label$25:;
 }
 
 void HSKIPUNTIL( int64 TOKEN$1, int64 DOEAT$1, $8LEXCHECK FLAGS$1, int64 STOP_ON_COMMA$1 )
 {
-	label$47:;
+	label$57:;
 	int64 PRNTCNT$1;
 	__builtin_memset( &PRNTCNT$1, 0, 8ll );
 	PRNTCNT$1 = 0ll;
-	label$49:;
+	label$59:;
 	{
 		{
-			uint64 TMP$89$3;
+			uint64 TMP$94$3;
 			int64 vr$1 = LEXGETTOKEN( FLAGS$1 );
-			TMP$89$3 = (uint64)vr$1;
-			goto label$53;
-			label$54:;
+			TMP$94$3 = (uint64)vr$1;
+			goto label$63;
+			label$64:;
 			{
-				goto label$50;
+				goto label$60;
 			}
-			goto label$52;
-			label$55:;
+			goto label$62;
+			label$65:;
 			{
-				if( TOKEN$1 == 257ll ) goto label$57;
+				if( TOKEN$1 == 257ll ) goto label$67;
 				{
-					goto label$50;
+					goto label$60;
 				}
-				label$57:;
-				label$56:;
+				label$67:;
+				label$66:;
 			}
-			goto label$52;
-			label$58:;
-			{
-				goto label$48;
-			}
-			goto label$52;
-			label$59:;
-			{
-				if( TOKEN$1 != 40ll ) goto label$61;
-				{
-					goto label$50;
-				}
-				label$61:;
-				label$60:;
-				PRNTCNT$1 = PRNTCNT$1 + 1ll;
-			}
-			goto label$52;
-			label$62:;
-			{
-				PRNTCNT$1 = PRNTCNT$1 + 1ll;
-			}
-			goto label$52;
-			label$63:;
-			{
-				if( PRNTCNT$1 <= 0ll ) goto label$65;
-				{
-					PRNTCNT$1 = PRNTCNT$1 + -1ll;
-				}
-				goto label$64;
-				label$65:;
-				{
-					if( TOKEN$1 != 41ll ) goto label$67;
-					{
-						goto label$50;
-					}
-					label$67:;
-					label$66:;
-				}
-				label$64:;
-			}
-			goto label$52;
+			goto label$62;
 			label$68:;
 			{
-				if( PRNTCNT$1 <= 0ll ) goto label$70;
+				goto label$58;
+			}
+			goto label$62;
+			label$69:;
+			{
+				if( TOKEN$1 != 40ll ) goto label$71;
+				{
+					goto label$60;
+				}
+				label$71:;
+				label$70:;
+				PRNTCNT$1 = PRNTCNT$1 + 1ll;
+			}
+			goto label$62;
+			label$72:;
+			{
+				PRNTCNT$1 = PRNTCNT$1 + 1ll;
+			}
+			goto label$62;
+			label$73:;
+			{
+				if( PRNTCNT$1 <= 0ll ) goto label$75;
 				{
 					PRNTCNT$1 = PRNTCNT$1 + -1ll;
 				}
-				goto label$69;
-				label$70:;
+				goto label$74;
+				label$75:;
 				{
-					if( TOKEN$1 != 125ll ) goto label$72;
+					if( TOKEN$1 != 41ll ) goto label$77;
 					{
-						goto label$50;
-					}
-					label$72:;
-					label$71:;
-				}
-				label$69:;
-			}
-			goto label$52;
-			label$73:;
-			{
-				if( ((int64)-(TOKEN$1 == 44ll) | STOP_ON_COMMA$1) == 0ll ) goto label$75;
-				{
-					if( PRNTCNT$1 != 0ll ) goto label$77;
-					{
-						goto label$50;
+						goto label$60;
 					}
 					label$77:;
 					label$76:;
 				}
-				label$75:;
 				label$74:;
 			}
-			goto label$52;
+			goto label$62;
 			label$78:;
 			{
-				int64 vr$8 = LEXGETTOKEN( FLAGS$1 );
-				if( vr$8 != TOKEN$1 ) goto label$80;
+				if( PRNTCNT$1 <= 0ll ) goto label$80;
 				{
-					goto label$50;
+					PRNTCNT$1 = PRNTCNT$1 + -1ll;
 				}
+				goto label$79;
 				label$80:;
+				{
+					if( TOKEN$1 != 125ll ) goto label$82;
+					{
+						goto label$60;
+					}
+					label$82:;
+					label$81:;
+				}
 				label$79:;
 			}
-			goto label$52;
-			label$53:;
-			static const void* tmp$90[221ll] = {
-				&&label$59,
-				&&label$63,
-				&&label$78,
-				&&label$78,
+			goto label$62;
+			label$83:;
+			{
+				if( ((int64)-(TOKEN$1 == 44ll) | STOP_ON_COMMA$1) == 0ll ) goto label$85;
+				{
+					if( PRNTCNT$1 != 0ll ) goto label$87;
+					{
+						goto label$60;
+					}
+					label$87:;
+					label$86:;
+				}
+				label$85:;
+				label$84:;
+			}
+			goto label$62;
+			label$88:;
+			{
+				int64 vr$8 = LEXGETTOKEN( FLAGS$1 );
+				if( vr$8 != TOKEN$1 ) goto label$90;
+				{
+					goto label$60;
+				}
+				label$90:;
+				label$89:;
+			}
+			goto label$62;
+			label$63:;
+			static const void* tmp$95[221ll] = {
+				&&label$69,
 				&&label$73,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$62,
-				&&label$78,
+				&&label$88,
+				&&label$88,
+				&&label$83,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$72,
+				&&label$88,
+				&&label$78,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
+				&&label$88,
 				&&label$68,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$78,
-				&&label$58,
-				&&label$54,
-				&&label$55,
-				&&label$55,
-				&&label$55,
+				&&label$64,
+				&&label$65,
+				&&label$65,
+				&&label$65,
 			};
-			if( (TMP$89$3 - 40ull) > 220ull ) goto label$78;
-			goto *tmp$90[TMP$89$3 - 40ull];
-			label$52:;
+			if( (TMP$94$3 - 40ull) > 220ull ) goto label$88;
+			goto *tmp$95[TMP$94$3 - 40ull];
+			label$62:;
 		}
 		LEXSKIPTOKEN( FLAGS$1 );
 	}
-	label$51:;
-	goto label$49;
-	label$50:;
-	if( DOEAT$1 == 0ll ) goto label$82;
+	label$61:;
+	goto label$59;
+	label$60:;
+	if( DOEAT$1 == 0ll ) goto label$92;
 	{
 		int64 vr$9 = LEXGETTOKEN( FLAGS$1 );
-		if( TOKEN$1 != vr$9 ) goto label$84;
+		if( TOKEN$1 != vr$9 ) goto label$94;
 		{
 			LEXSKIPTOKEN( FLAGS$1 );
 		}
-		label$84:;
-		label$83:;
+		label$94:;
+		label$93:;
 	}
-	label$82:;
-	label$81:;
-	label$48:;
+	label$92:;
+	label$91:;
+	label$58:;
 }
 
 void HSKIPCOMPOUND( int64 FOR_TOKEN$1, int64 UNTIL_TOKEN$1, $8LEXCHECK FLAGS$1 )
 {
-	label$85:;
+	label$95:;
 	int64 CNT$1;
 	__builtin_memset( &CNT$1, 0, 8ll );
 	int64 ISCOMMENT$1;
 	__builtin_memset( &ISCOMMENT$1, 0, 8ll );
-	if( UNTIL_TOKEN$1 != -1ll ) goto label$88;
+	if( UNTIL_TOKEN$1 != -1ll ) goto label$98;
 	{
 		UNTIL_TOKEN$1 = FOR_TOKEN$1;
 	}
-	label$88:;
-	label$87:;
+	label$98:;
+	label$97:;
 	CNT$1 = 0ll;
 	ISCOMMENT$1 = 0ll;
-	label$89:;
+	label$99:;
 	{
 		{
-			int64 TMP$91$3;
+			int64 TMP$96$3;
 			int64 vr$2 = LEXGETTOKEN( FLAGS$1 );
-			TMP$91$3 = vr$2;
-			if( TMP$91$3 != 256ll ) goto label$93;
-			label$94:;
+			TMP$96$3 = vr$2;
+			if( TMP$96$3 != 256ll ) goto label$103;
+			label$104:;
 			{
-				goto label$86;
+				goto label$96;
 			}
-			goto label$92;
-			label$93:;
-			if( TMP$91$3 != 257ll ) goto label$95;
-			label$96:;
+			goto label$102;
+			label$103:;
+			if( TMP$96$3 != 257ll ) goto label$105;
+			label$106:;
 			{
 				ISCOMMENT$1 = 0ll;
 			}
-			goto label$92;
-			label$95:;
-			if( TMP$91$3 == 259ll ) goto label$98;
-			label$99:;
-			if( TMP$91$3 != 260ll ) goto label$97;
-			label$98:;
+			goto label$102;
+			label$105:;
+			if( TMP$96$3 == 259ll ) goto label$108;
+			label$109:;
+			if( TMP$96$3 != 260ll ) goto label$107;
+			label$108:;
 			{
 				ISCOMMENT$1 = -1ll;
 			}
-			goto label$92;
-			label$97:;
-			if( TMP$91$3 != 340ll ) goto label$100;
-			label$101:;
-			{
-				if( ISCOMMENT$1 != 0ll ) goto label$103;
-				{
-					int64 vr$3 = LEXGETLOOKAHEAD( 1ll, FLAGS$1 );
-					if( vr$3 != UNTIL_TOKEN$1 ) goto label$105;
-					{
-						LEXSKIPTOKEN( FLAGS$1 );
-						if( CNT$1 <= 0ll ) goto label$107;
-						{
-							CNT$1 = CNT$1 + -1ll;
-						}
-						label$107:;
-						label$106:;
-						if( CNT$1 != 0ll ) goto label$109;
-						{
-							goto label$90;
-						}
-						label$109:;
-						label$108:;
-					}
-					label$105:;
-					label$104:;
-				}
-				label$103:;
-				label$102:;
-			}
-			goto label$92;
-			label$100:;
-			if( TMP$91$3 != FOR_TOKEN$1 ) goto label$110;
+			goto label$102;
+			label$107:;
+			if( TMP$96$3 != 340ll ) goto label$110;
 			label$111:;
 			{
 				if( ISCOMMENT$1 != 0ll ) goto label$113;
 				{
-					CNT$1 = CNT$1 + 1ll;
+					int64 vr$3 = LEXGETLOOKAHEAD( 1ll, FLAGS$1 );
+					if( vr$3 != UNTIL_TOKEN$1 ) goto label$115;
+					{
+						LEXSKIPTOKEN( FLAGS$1 );
+						if( CNT$1 <= 0ll ) goto label$117;
+						{
+							CNT$1 = CNT$1 + -1ll;
+						}
+						label$117:;
+						label$116:;
+						if( CNT$1 != 0ll ) goto label$119;
+						{
+							goto label$100;
+						}
+						label$119:;
+						label$118:;
+					}
+					label$115:;
+					label$114:;
 				}
 				label$113:;
 				label$112:;
 			}
+			goto label$102;
 			label$110:;
-			label$92:;
+			if( TMP$96$3 != FOR_TOKEN$1 ) goto label$120;
+			label$121:;
+			{
+				if( ISCOMMENT$1 != 0ll ) goto label$123;
+				{
+					CNT$1 = CNT$1 + 1ll;
+				}
+				label$123:;
+				label$122:;
+			}
+			label$120:;
+			label$102:;
 		}
 		LEXSKIPTOKEN( FLAGS$1 );
 	}
-	label$91:;
-	goto label$89;
-	label$90:;
+	label$101:;
+	goto label$99;
+	label$100:;
 	LEXSKIPTOKEN( FLAGS$1 );
-	label$86:;
+	label$96:;
 }
 
 struct $7ASTNODE* HMATCHEXPR( int64 DTYPE$1 )
 {
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$114:;
+	label$124:;
 	struct $7ASTNODE* EXPR$1;
 	__builtin_memset( &EXPR$1, 0, 8ll );
 	struct $7ASTNODE* vr$2 = CEXPRESSION(  );
 	EXPR$1 = vr$2;
-	if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$117;
+	if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$127;
 	{
 		ERRREPORT( 9ll, 0ll, (uint8*)0ull );
-		if( DTYPE$1 != 2147483648ll ) goto label$119;
+		if( DTYPE$1 != 2147483648ll ) goto label$129;
 		{
 			fb$result$1 = (struct $7ASTNODE*)0ull;
-			goto label$115;
+			goto label$125;
 		}
-		label$119:;
-		label$118:;
+		label$129:;
+		label$128:;
 		struct $7ASTNODE* vr$3 = ASTNEWCONSTZ( DTYPE$1, (struct $8FBSYMBOL*)0ull );
 		EXPR$1 = vr$3;
 	}
-	label$117:;
-	label$116:;
+	label$127:;
+	label$126:;
 	fb$result$1 = EXPR$1;
-	label$115:;
+	label$125:;
 	return fb$result$1;
 }
 
@@ -1734,7 +1819,7 @@ __attribute__(( constructor )) static void fb_ctor__parserztoplevel( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1751,7 +1836,7 @@ static void HEMITCURRENTLINETEXT( void )
 		{
 			if( *(int64*)((uint8*)N$1 + 56ll) != 113ll ) goto label$23;
 			{
-				struct $7ASTNODE* vr$4 = ASTNEWLIT( *(uint8**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 25024ll) );
+				struct $7ASTNODE* vr$4 = ASTNEWLIT( *(uint8**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 25064ll) );
 				ASTADDAFTER( vr$4, N$1 );
 				goto label$19;
 			}
@@ -1764,6 +1849,6 @@ static void HEMITCURRENTLINETEXT( void )
 	}
 	goto label$18;
 	label$19:;
-	DZSTRRESET( (struct $8DZSTRING*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 25024ll) );
+	DZSTRRESET( (struct $8DZSTRING*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 25064ll) );
 	label$17:;
 }
