@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,12 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
+struct $9LEXPP_REC {
+	int64 ISTRUE;
+	int64 ELSECNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_REC ) == 16 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -619,29 +663,19 @@ struct $7FBTOKEN {
 		int64 PRDPOS;
 		int64 HASESC;
 	};
+	int64 SUFFIXCHAR;
 	int64 AFTER_SPACE;
 	struct $7FBTOKEN* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2120 );
-struct $8DZSTRING {
-	uint8* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
-struct $8DWSTRING {
-	uint16* DATA;
-	int64 LEN;
-	int64 SIZE;
-};
-__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBTOKEN ) == 2128 );
 struct $9LEX_TKCTX {
 	struct $7FBTOKEN TOKENTB[4];
 	int64 K;
 	struct $7FBTOKEN* HEAD;
 	struct $7FBTOKEN* TAIL;
 	uint64 CURRCHAR;
-	uint64 LAHDCHAR;
+	uint64 LAHDCHAR1;
+	uint64 LAHDCHAR2;
 	int64 LINENUM;
 	int64 LASTTK_ID;
 	int64 RECLEVEL;
@@ -674,7 +708,7 @@ struct $9LEX_TKCTX {
 	struct $8DZSTRING CURRLINE;
 	int64 AFTER_SPACE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25056 );
+__FB_STATIC_ASSERT( sizeof( struct $9LEX_TKCTX ) == 25096 );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
 static void fb_ctor__ppzcond( void ) __attribute__(( constructor ));
@@ -721,10 +755,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -742,20 +777,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -796,8 +833,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -805,8 +845,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -853,6 +894,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -874,23 +916,28 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $7LEX_CTX {
 	struct $9LEX_TKCTX CTXTB[17];
 	struct $9LEX_TKCTX* CTX;
 	int64 INSIDEMACRO;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 425968 );
+__FB_STATIC_ASSERT( sizeof( struct $7LEX_CTX ) == 426648 );
 extern struct $7LEX_CTX LEX$;
 struct $8TSTACKTB;
 struct $10TSTACKNODE;
@@ -1041,6 +1088,7 @@ __FB_STATIC_ASSERT( sizeof( struct $13FBPARSER_STMT ) == 176 );
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1052,27 +1100,23 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 struct $6PP_CTX {
 	struct $8FBSYMBOL KWDNS;
 	struct $5TLIST ARGTBLIST;
 	int64 LEVEL;
 	int64 SKIPPING;
+	int64 INVOKING;
 };
-__FB_STATIC_ASSERT( sizeof( struct $6PP_CTX ) == 384 );
+__FB_STATIC_ASSERT( sizeof( struct $6PP_CTX ) == 408 );
 extern struct $6PP_CTX PP$;
-struct $9LEXPP_REC {
-	int64 ISTRUE;
-	int64 ELSECNT;
-};
-__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_REC ) == 16 );
 static struct $9LEXPP_REC PPTB$[64];
 
 void PPCONDINIT( void )
 {
 	label$10:;
-	*(int64*)((uint8*)&PP$ + 368ll) = 0ll;
+	*(int64*)((uint8*)&PP$ + 384ll) = 0ll;
 	label$11:;
 }
 
@@ -1089,13 +1133,13 @@ void PPCONDIF( void )
 	struct $8FBSYMBOL* BASE_PARENT$1;
 	ISTRUE$1 = 0ll;
 	{
-		uint64 TMP$89$2;
+		uint64 TMP$94$2;
 		int64 vr$0 = LEXGETTOKEN( 256ll );
-		TMP$89$2 = (uint64)vr$0;
+		TMP$94$2 = (uint64)vr$0;
 		goto label$28;
 		label$29:;
 		{
-			LEXSKIPTOKEN( 2ll );
+			LEXSKIPTOKEN( 2050ll );
 			struct $10FBSYMCHAIN* vr$2 = CIDENTIFIER( &BASE_PARENT$1, 0ll );
 			if( vr$2 == (struct $10FBSYMCHAIN*)0ull ) goto label$31;
 			{
@@ -1108,7 +1152,7 @@ void PPCONDIF( void )
 		goto label$27;
 		label$32:;
 		{
-			LEXSKIPTOKEN( 2ll );
+			LEXSKIPTOKEN( 2050ll );
 			struct $10FBSYMCHAIN* vr$4 = CIDENTIFIER( &BASE_PARENT$1, 0ll );
 			if( vr$4 != (struct $10FBSYMCHAIN*)0ull ) goto label$34;
 			{
@@ -1121,23 +1165,23 @@ void PPCONDIF( void )
 		goto label$27;
 		label$35:;
 		{
-			LEXSKIPTOKEN( 0ll );
+			LEXSKIPTOKEN( 2048ll );
 			int64 vr$5 = PPEXPRESSION(  );
 			ISTRUE$1 = vr$5;
 		}
 		goto label$27;
 		label$28:;
-		static const void* tmp$90[3ll] = {
+		static const void* tmp$95[3ll] = {
 			&&label$35,
 			&&label$29,
 			&&label$32,
 		};
-		if( (TMP$89$2 - 266ull) > 2ull ) goto label$27;
-		goto *tmp$90[TMP$89$2 - 266ull];
+		if( (TMP$94$2 - 266ull) > 2ull ) goto label$27;
+		goto *tmp$95[TMP$94$2 - 266ull];
 		label$27:;
 	}
-	*(int64*)((uint8*)&PP$ + 368ll) = *(int64*)((uint8*)&PP$ + 368ll) + 1ll;
-	if( *(int64*)((uint8*)&PP$ + 368ll) <= 64ll ) goto label$37;
+	*(int64*)((uint8*)&PP$ + 384ll) = *(int64*)((uint8*)&PP$ + 384ll) + 1ll;
+	if( *(int64*)((uint8*)&PP$ + 384ll) <= 64ll ) goto label$37;
 	{
 		ERRREPORT( 27ll, 0ll, (uint8*)0ull );
 		ERRHIDEFURTHERERRORS(  );
@@ -1145,8 +1189,8 @@ void PPCONDIF( void )
 	}
 	label$37:;
 	label$36:;
-	*(int64*)(((uint8*)PPTB$ + (*(int64*)((uint8*)&PP$ + 368ll) << (4ll & 63ll))) + -16ll) = ISTRUE$1;
-	*(int64*)(((uint8*)PPTB$ + (*(int64*)((uint8*)&PP$ + 368ll) << (4ll & 63ll))) + -8ll) = 0ll;
+	*(int64*)(((int64)(struct $9LEXPP_REC*)PPTB$ + (*(int64*)((uint8*)&PP$ + 384ll) << (4ll & 63ll))) + -16ll) = ISTRUE$1;
+	*(int64*)(((int64)(struct $9LEXPP_REC*)PPTB$ + (*(int64*)((uint8*)&PP$ + 384ll) << (4ll & 63ll))) + -8ll) = 0ll;
 	if( ISTRUE$1 != 0ll ) goto label$39;
 	{
 		PPSKIP(  );
@@ -1161,7 +1205,7 @@ void PPCONDELSE( void )
 	label$40:;
 	int64 ISTRUE$1;
 	ISTRUE$1 = 0ll;
-	if( *(int64*)((uint8*)&PP$ + 368ll) != 0ll ) goto label$43;
+	if( *(int64*)((uint8*)&PP$ + 384ll) != 0ll ) goto label$43;
 	{
 		ERRREPORT( 44ll, 0ll, (uint8*)0ull );
 		HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
@@ -1169,7 +1213,7 @@ void PPCONDELSE( void )
 	}
 	label$43:;
 	label$42:;
-	if( *(int64*)(((uint8*)PPTB$ + (*(int64*)((uint8*)&PP$ + 368ll) << (4ll & 63ll))) + -8ll) <= 0ll ) goto label$45;
+	if( *(int64*)(((int64)(struct $9LEXPP_REC*)PPTB$ + (*(int64*)((uint8*)&PP$ + 384ll) << (4ll & 63ll))) + -8ll) <= 0ll ) goto label$45;
 	{
 		ERRREPORT( 17ll, 0ll, (uint8*)0ull );
 		HSKIPUNTIL( -1ll, 0ll, 0ll, 0ll );
@@ -1180,27 +1224,27 @@ void PPCONDELSE( void )
 	int64 vr$1 = LEXGETTOKEN( 256ll );
 	if( vr$1 != 270ll ) goto label$47;
 	{
-		LEXSKIPTOKEN( 0ll );
+		LEXSKIPTOKEN( 2048ll );
 		int64 vr$2 = PPEXPRESSION(  );
 		ISTRUE$1 = vr$2;
-		if( *(int64*)(((uint8*)PPTB$ + (*(int64*)((uint8*)&PP$ + 368ll) << (4ll & 63ll))) + -16ll) == 0ll ) goto label$49;
+		if( *(int64*)(((int64)(struct $9LEXPP_REC*)PPTB$ + (*(int64*)((uint8*)&PP$ + 384ll) << (4ll & 63ll))) + -16ll) == 0ll ) goto label$49;
 		{
 			PPSKIP(  );
 			goto label$41;
 		}
 		label$49:;
 		label$48:;
-		*(int64*)(((uint8*)PPTB$ + (*(int64*)((uint8*)&PP$ + 368ll) << (4ll & 63ll))) + -16ll) = ISTRUE$1;
+		*(int64*)(((int64)(struct $9LEXPP_REC*)PPTB$ + (*(int64*)((uint8*)&PP$ + 384ll) << (4ll & 63ll))) + -16ll) = ISTRUE$1;
 	}
 	goto label$46;
 	label$47:;
 	{
-		LEXSKIPTOKEN( 0ll );
-		*(int64*)(((uint8*)PPTB$ + (*(int64*)((uint8*)&PP$ + 368ll) << (4ll & 63ll))) + -8ll) = *(int64*)(((uint8*)PPTB$ + (*(int64*)((uint8*)&PP$ + 368ll) << (4ll & 63ll))) + -8ll) + 1ll;
-		*(int64*)(((uint8*)PPTB$ + (*(int64*)((uint8*)&PP$ + 368ll) << (4ll & 63ll))) + -16ll) = ~(*(int64*)(((uint8*)PPTB$ + (*(int64*)((uint8*)&PP$ + 368ll) << (4ll & 63ll))) + -16ll));
+		LEXSKIPTOKEN( 2048ll );
+		*(int64*)(((int64)(struct $9LEXPP_REC*)PPTB$ + (*(int64*)((uint8*)&PP$ + 384ll) << (4ll & 63ll))) + -8ll) = *(int64*)(((int64)(struct $9LEXPP_REC*)PPTB$ + (*(int64*)((uint8*)&PP$ + 384ll) << (4ll & 63ll))) + -8ll) + 1ll;
+		*(int64*)(((int64)(struct $9LEXPP_REC*)PPTB$ + (*(int64*)((uint8*)&PP$ + 384ll) << (4ll & 63ll))) + -16ll) = ~(*(int64*)(((int64)(struct $9LEXPP_REC*)PPTB$ + (*(int64*)((uint8*)&PP$ + 384ll) << (4ll & 63ll))) + -16ll));
 	}
 	label$46:;
-	if( *(int64*)(((uint8*)PPTB$ + (*(int64*)((uint8*)&PP$ + 368ll) << (4ll & 63ll))) + -16ll) != 0ll ) goto label$51;
+	if( *(int64*)(((int64)(struct $9LEXPP_REC*)PPTB$ + (*(int64*)((uint8*)&PP$ + 384ll) << (4ll & 63ll))) + -16ll) != 0ll ) goto label$51;
 	{
 		PPSKIP(  );
 	}
@@ -1212,10 +1256,10 @@ void PPCONDELSE( void )
 void PPCONDENDIF( void )
 {
 	label$52:;
-	LEXSKIPTOKEN( 0ll );
-	if( *(int64*)((uint8*)&PP$ + 368ll) <= 0ll ) goto label$55;
+	LEXSKIPTOKEN( 2048ll );
+	if( *(int64*)((uint8*)&PP$ + 384ll) <= 0ll ) goto label$55;
 	{
-		*(int64*)((uint8*)&PP$ + 368ll) = *(int64*)((uint8*)&PP$ + 368ll) + -1ll;
+		*(int64*)((uint8*)&PP$ + 384ll) = *(int64*)((uint8*)&PP$ + 384ll) + -1ll;
 	}
 	goto label$54;
 	label$55:;
@@ -1250,7 +1294,7 @@ __attribute__(( constructor )) static void fb_ctor__ppzcond( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1262,24 +1306,24 @@ static int64 PPEXPRESSION( void )
 	label$14:;
 	struct $7ASTNODE* EXPR$1;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 1024ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 1024ll;
 	}
 	goto label$16;
 	label$17:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -1025ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -1025ll;
 	}
 	label$16:;
 	struct $7ASTNODE* vr$3 = CEXPRESSION(  );
 	EXPR$1 = vr$3;
 	goto label$19;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) | 1024ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) | 1024ll;
 	}
 	goto label$18;
 	label$19:;
 	{
-		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 288ll) = *(int64*)((uint8*)&PARSER$ + 288ll) & -1025ll;
+		*($12FB_PARSEROPT*)((uint8*)&PARSER$ + 296ll) = *(int64*)((uint8*)&PARSER$ + 296ll) & -1025ll;
 	}
 	label$18:;
 	if( EXPR$1 != (struct $7ASTNODE*)0ull ) goto label$21;
@@ -1317,15 +1361,15 @@ static void PPSKIP( void )
 {
 	label$60:;
 	int64 IFLEVEL$1;
-	*(int64*)((uint8*)&PP$ + 376ll) = -1ll;
+	*(int64*)((uint8*)&PP$ + 392ll) = -1ll;
 	CCOMMENT( 0ll );
 	if( *(int64*)((uint8*)&ENV$ + 296ll) == 0ll ) goto label$63;
 	{
-		if( *(int64*)((uint8*)&ENV$ + 1224ll) != 0ll ) goto label$65;
+		if( *(int64*)((uint8*)&ENV$ + 1256ll) != 0ll ) goto label$65;
 		{
-			struct $7ASTNODE* vr$1 = ASTNEWLIT( *(uint8**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 25024ll) );
+			struct $7ASTNODE* vr$1 = ASTNEWLIT( *(uint8**)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 25064ll) );
 			ASTADD( vr$1 );
-			DZSTRRESET( (struct $8DZSTRING*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 425952ll) + 25024ll) );
+			DZSTRRESET( (struct $8DZSTRING*)((uint8*)*(struct $9LEX_TKCTX**)((uint8*)&LEX$ + 426632ll) + 25064ll) );
 		}
 		label$65:;
 		label$64:;
@@ -1344,21 +1388,21 @@ static void PPSKIP( void )
 		LEXSKIPTOKEN( 0ll );
 	}
 	label$66:;
-	IFLEVEL$1 = *(int64*)((uint8*)&PP$ + 368ll);
+	IFLEVEL$1 = *(int64*)((uint8*)&PP$ + 384ll);
 	label$68:;
 	{
 		{
-			int64 TMP$91$3;
+			int64 TMP$96$3;
 			int64 vr$5 = LEXGETTOKEN( 0ll );
-			TMP$91$3 = vr$5;
-			if( TMP$91$3 != 35ll ) goto label$72;
+			TMP$96$3 = vr$5;
+			if( TMP$96$3 != 35ll ) goto label$72;
 			label$73:;
 			{
 				LEXSKIPTOKEN( 256ll );
 				{
-					uint64 TMP$92$5;
+					uint64 TMP$97$5;
 					int64 vr$6 = LEXGETTOKEN( 256ll );
-					TMP$92$5 = (uint64)vr$6;
+					TMP$97$5 = (uint64)vr$6;
 					goto label$75;
 					label$76:;
 					{
@@ -1368,10 +1412,10 @@ static void PPSKIP( void )
 					label$77:;
 					{
 						{
-							if( IFLEVEL$1 != *(int64*)((uint8*)&PP$ + 368ll) ) goto label$79;
+							if( IFLEVEL$1 != *(int64*)((uint8*)&PP$ + 384ll) ) goto label$79;
 							label$80:;
 							{
-								*(int64*)((uint8*)&PP$ + 376ll) = 0ll;
+								*(int64*)((uint8*)&PP$ + 392ll) = 0ll;
 								PPCONDELSE(  );
 								goto label$61;
 							}
@@ -1390,10 +1434,10 @@ static void PPSKIP( void )
 					label$83:;
 					{
 						{
-							if( IFLEVEL$1 != *(int64*)((uint8*)&PP$ + 368ll) ) goto label$85;
+							if( IFLEVEL$1 != *(int64*)((uint8*)&PP$ + 384ll) ) goto label$85;
 							label$86:;
 							{
-								*(int64*)((uint8*)&PP$ + 376ll) = 0ll;
+								*(int64*)((uint8*)&PP$ + 392ll) = 0ll;
 								PPCONDENDIF(  );
 								goto label$61;
 							}
@@ -1424,7 +1468,7 @@ static void PPSKIP( void )
 					}
 					goto label$74;
 					label$75:;
-					static const void* tmp$93[21ll] = {
+					static const void* tmp$98[22ll] = {
 						&&label$76,
 						&&label$76,
 						&&label$76,
@@ -1446,15 +1490,16 @@ static void PPSKIP( void )
 						&&label$90,
 						&&label$90,
 						&&label$90,
+						&&label$90,
 					};
-					if( (TMP$92$5 - 266ull) > 20ull ) goto label$91;
-					goto *tmp$93[TMP$92$5 - 266ull];
+					if( (TMP$97$5 - 266ull) > 21ull ) goto label$91;
+					goto *tmp$98[TMP$97$5 - 266ull];
 					label$74:;
 				}
 			}
 			goto label$71;
 			label$72:;
-			if( TMP$91$3 != 256ll ) goto label$92;
+			if( TMP$96$3 != 256ll ) goto label$92;
 			label$93:;
 			{
 				ERRREPORT( 290ll, 0ll, (uint8*)0ull );
@@ -1475,6 +1520,6 @@ static void PPSKIP( void )
 	label$70:;
 	goto label$68;
 	label$69:;
-	*(int64*)((uint8*)&PP$ + 376ll) = 0ll;
+	*(int64*)((uint8*)&PP$ + 392ll) = 0ll;
 	label$61:;
 }
