@@ -13,6 +13,7 @@ typedef int64 $15IRVREGTYPE_ENUM;
 typedef int64 $11FB_DATATYPE;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -179,7 +180,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -325,6 +326,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -334,7 +336,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -343,7 +346,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -354,10 +357,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -366,9 +370,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -467,14 +471,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -496,7 +502,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -507,9 +515,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -570,6 +584,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -599,7 +614,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 typedef int64 $12IR_REGFAMILY;
 struct $6IRVREG;
 struct $9IRTACVREG;
@@ -644,14 +659,14 @@ struct $6IRVREG {
 	struct $5IRTAC* TACLAST;
 };
 __FB_STATIC_ASSERT( sizeof( struct $6IRVREG ) == 120 );
-typedef int64 (*tmp$79)( struct $8REGCLASS*, struct $6IRVREG*, struct $6IRVREG*, uint64 );
-typedef int64 (*tmp$80)( struct $8REGCLASS*, int64, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$81)( struct $8REGCLASS*, int64 );
-typedef int64 (*tmp$82)( struct $8REGCLASS*, int64 );
-typedef void (*tmp$83)( struct $8REGCLASS*, int64, struct $6IRVREG*, struct $6IRVREG* );
-typedef int64 (*tmp$84)( struct $8REGCLASS* );
-typedef struct $6IRVREG* (*tmp$85)( struct $8REGCLASS*, int64, struct $6IRVREG** );
-typedef void (*tmp$86)( struct $8REGCLASS* );
+typedef int64 (*tmp$83)( struct $8REGCLASS*, struct $6IRVREG*, struct $6IRVREG*, uint64 );
+typedef int64 (*tmp$84)( struct $8REGCLASS*, int64, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$85)( struct $8REGCLASS*, int64 );
+typedef int64 (*tmp$86)( struct $8REGCLASS*, int64 );
+typedef void (*tmp$87)( struct $8REGCLASS*, int64, struct $6IRVREG*, struct $6IRVREG* );
+typedef int64 (*tmp$88)( struct $8REGCLASS* );
+typedef struct $6IRVREG* (*tmp$89)( struct $8REGCLASS*, int64, struct $6IRVREG** );
+typedef void (*tmp$90)( struct $8REGCLASS* );
 struct $7REG_REG;
 struct $7REG_REG {
 	int64 NUM;
@@ -674,19 +689,19 @@ struct $10REG_STKCTX {
 };
 __FB_STATIC_ASSERT( sizeof( struct $10REG_STKCTX ) == 72 );
 struct $8REGCLASS {
-	tmp$79 ENSURE;
-	tmp$79 _ALLOCATE;
-	tmp$80 ALLOCATEREG;
-	tmp$81 FREE;
-	tmp$82 ISFREE;
-	tmp$83 SETOWNER;
-	tmp$84 GETMAXREGS;
-	tmp$84 GETFIRST;
-	tmp$82 GETNEXT;
-	tmp$85 GETVREG;
-	tmp$82 GETREALREG;
-	tmp$86 CLEAR;
-	tmp$86 DUMP;
+	tmp$83 ENSURE;
+	tmp$83 _ALLOCATE;
+	tmp$84 ALLOCATEREG;
+	tmp$85 FREE;
+	tmp$86 ISFREE;
+	tmp$87 SETOWNER;
+	tmp$88 GETMAXREGS;
+	tmp$88 GETFIRST;
+	tmp$86 GETNEXT;
+	tmp$89 GETVREG;
+	tmp$86 GETREALREG;
+	tmp$90 CLEAR;
+	tmp$90 DUMP;
 	int64 CLASS;
 	int64 ISSTACK;
 	int64 REGS;
@@ -708,18 +723,19 @@ struct $7FBARRAYI12REG_SIZEMASKE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[8];
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYI12REG_SIZEMASKE ) == 232 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYI12REG_SIZEMASKE ) == 240 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
 };
 __FB_STATIC_ASSERT( sizeof( struct $11TSTRSETITEM ) == 32 );
-typedef void (*tmp$40)( struct $6IRVREG*, struct $6IRVREG* );
-typedef uint64 (*tmp$72)( struct $6IRVREG* );
-typedef void (*tmp$47)( int64, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$41)( int64 );
+typedef void (*tmp$45)( struct $6IRVREG*, struct $6IRVREG* );
+typedef uint64 (*tmp$76)( struct $6IRVREG* );
+typedef void (*tmp$52)( int64, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$46)( int64 );
 void free( void* );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
@@ -764,121 +780,119 @@ static int64 SREGGETNEXT( struct $8REGCLASS*, int64 );
 static struct $6IRVREG* SREGGETVREG( struct $8REGCLASS*, int64, struct $6IRVREG** );
 static void SREGDUMP( struct $8REGCLASS* );
 static void SREGCLEAR( struct $8REGCLASS* );
-typedef void (*tmp$33)( void );
-typedef int64 (*tmp$34)( void );
+typedef void (*tmp$38)( void );
+typedef int64 (*tmp$39)( void );
 typedef int64 $14IR_OPTIONVALUE;
-typedef int64 (*tmp$35)( $14IR_OPTIONVALUE );
-typedef int64 (*tmp$36)( int64, int64 );
-typedef void (*tmp$37)( struct $8FBSYMBOL* );
-typedef void (*tmp$38)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef uint8* (*tmp$39)( void );
-typedef void (*tmp$42)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
-typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$44)( struct $9ASTASMTOK* );
-typedef void (*tmp$45)( uint8* );
-typedef void (*tmp$46)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
-typedef void (*tmp$48)( struct $6IRVREG* );
-typedef void (*tmp$49)( int64, struct $6IRVREG* );
-typedef void (*tmp$50)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
-typedef void (*tmp$51)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
-typedef void (*tmp$52)( int64, struct $8FBSYMBOL* );
-typedef void (*tmp$53)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
-typedef void (*tmp$54)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
-typedef void (*tmp$55)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
-typedef void (*tmp$56)( int64, struct $8FBSYMBOL*, int64, uint8* );
-typedef void (*tmp$57)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$58)( struct $8FBSYMBOL*, double );
-typedef void (*tmp$59)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$60)( int64, uint8*, int64 );
-typedef void (*tmp$61)( int64, uint16*, int64 );
-typedef void (*tmp$62)( int64 );
-typedef void (*tmp$63)( struct $8FBSYMBOL*, int64 );
-typedef void (*tmp$64)( uint8* );
-typedef struct $6IRVREG* (*tmp$65)( int64, struct $8FBSYMBOL* );
-typedef struct $6IRVREG* (*tmp$66)( int64, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$67)( int64, struct $8FBSYMBOL*, double );
-typedef struct $6IRVREG* (*tmp$68)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
-typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
-typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
-typedef void (*tmp$71)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
+typedef int64 (*tmp$40)( $14IR_OPTIONVALUE );
+typedef int64 (*tmp$41)( int64, int64 );
+typedef void (*tmp$42)( struct $8FBSYMBOL* );
+typedef void (*tmp$43)( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef uint8* (*tmp$44)( void );
+typedef void (*tmp$47)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $8FBSYMBOL* );
+typedef void (*tmp$48)( struct $8FBSYMBOL*, struct $6IRVREG*, int64, int64, struct $6IRVREG* );
+typedef void (*tmp$49)( struct $9ASTASMTOK* );
+typedef void (*tmp$50)( uint8* );
+typedef void (*tmp$51)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG*, struct $8FBSYMBOL* );
+typedef void (*tmp$53)( struct $6IRVREG* );
+typedef void (*tmp$54)( struct $8FBSYMBOL*, int64, struct $6IRVREG*, int64 );
+typedef void (*tmp$55)( struct $8FBSYMBOL*, struct $6IRVREG*, struct $6IRVREG*, int64, int64 );
+typedef void (*tmp$56)( int64, struct $8FBSYMBOL* );
+typedef void (*tmp$57)( struct $6IRVREG*, struct $8FBSYMBOL*, uint64*, struct $8FBSYMBOL**, int64, struct $8FBSYMBOL*, uint64, uint64 );
+typedef void (*tmp$58)( int64, struct $6IRVREG*, struct $6IRVREG*, int64 );
+typedef void (*tmp$59)( int64, struct $6IRVREG*, struct $6IRVREG*, struct $6IRVREG* );
+typedef void (*tmp$60)( int64, struct $8FBSYMBOL*, int64, uint8* );
+typedef void (*tmp$61)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$62)( struct $8FBSYMBOL*, double );
+typedef void (*tmp$63)( struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$64)( int64, uint8*, int64 );
+typedef void (*tmp$65)( int64, uint16*, int64 );
+typedef void (*tmp$66)( int64 );
+typedef void (*tmp$67)( struct $8FBSYMBOL*, int64 );
+typedef void (*tmp$68)( uint8* );
+typedef struct $6IRVREG* (*tmp$69)( int64, struct $8FBSYMBOL* );
+typedef struct $6IRVREG* (*tmp$70)( int64, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$71)( int64, struct $8FBSYMBOL*, double );
+typedef struct $6IRVREG* (*tmp$72)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64 );
+typedef struct $6IRVREG* (*tmp$73)( int64, struct $8FBSYMBOL*, struct $8FBSYMBOL*, int64, int64, struct $6IRVREG* );
+typedef struct $6IRVREG* (*tmp$74)( int64, struct $8FBSYMBOL*, int64, struct $6IRVREG* );
+typedef void (*tmp$75)( struct $6IRVREG*, int64, struct $8FBSYMBOL* );
 struct $7IR_VTBL {
-	tmp$33 INIT;
-	tmp$33 END;
-	tmp$34 EMITBEGIN;
-	tmp$33 EMITEND;
-	tmp$35 GETOPTIONVALUE;
-	tmp$36 SUPPORTSOP;
-	tmp$37 PROCBEGIN;
-	tmp$37 PROCEND;
-	tmp$38 PROCALLOCARG;
-	tmp$38 PROCALLOCLOCAL;
-	tmp$39 PROCGETFRAMEREGNAME;
-	tmp$37 SCOPEBEGIN;
-	tmp$37 SCOPEEND;
-	tmp$37 PROCALLOCSTATICVARS;
-	tmp$40 EMITCONVERT;
-	tmp$37 EMITLABEL;
-	tmp$37 EMITLABELNF;
-	tmp$41 EMITRETURN;
-	tmp$38 EMITPROCBEGIN;
-	tmp$42 EMITPROCEND;
-	tmp$43 EMITPUSHARG;
-	tmp$44 EMITASMLINE;
-	tmp$45 EMITCOMMENT;
-	tmp$46 EMITBOP;
-	tmp$47 EMITUOP;
-	tmp$40 EMITSTORE;
-	tmp$33 EMITSPILLREGS;
-	tmp$48 EMITLOAD;
-	tmp$40 EMITLOADRES;
-	tmp$49 EMITSTACK;
-	tmp$47 EMITADDR;
-	tmp$50 EMITCALL;
-	tmp$51 EMITCALLPTR;
-	tmp$41 EMITSTACKALIGN;
-	tmp$48 EMITJUMPPTR;
-	tmp$52 EMITBRANCH;
-	tmp$53 EMITJMPTB;
-	tmp$54 EMITMEM;
-	tmp$55 EMITMACRO;
-	tmp$37 EMITSCOPEBEGIN;
-	tmp$37 EMITSCOPEEND;
-	tmp$37 EMITDECL;
-	tmp$56 EMITDBG;
-	tmp$37 EMITVARINIBEGIN;
-	tmp$37 EMITVARINIEND;
-	tmp$57 EMITVARINII;
-	tmp$58 EMITVARINIF;
-	tmp$59 EMITVARINIOFS;
-	tmp$60 EMITVARINISTR;
-	tmp$61 EMITVARINIWSTR;
-	tmp$62 EMITVARINIPAD;
-	tmp$63 EMITVARINISCOPEBEGIN;
-	tmp$33 EMITVARINISCOPEEND;
-	tmp$33 EMITFBCTINFBEGIN;
-	tmp$64 EMITFBCTINFSTRING;
-	tmp$33 EMITFBCTINFEND;
-	tmp$65 ALLOCVREG;
-	tmp$66 ALLOCVRIMM;
-	tmp$67 ALLOCVRIMMF;
-	tmp$68 ALLOCVRVAR;
-	tmp$69 ALLOCVRIDX;
-	tmp$70 ALLOCVRPTR;
-	tmp$68 ALLOCVROFS;
-	tmp$71 SETVREGDATATYPE;
-	tmp$72 GETDISTANCE;
-	tmp$47 LOADVR;
-	tmp$40 STOREVR;
-	tmp$41 XCHGTOS;
+	tmp$38 INIT;
+	tmp$38 END;
+	tmp$39 EMITBEGIN;
+	tmp$38 EMITEND;
+	tmp$40 GETOPTIONVALUE;
+	tmp$41 SUPPORTSOP;
+	tmp$42 PROCBEGIN;
+	tmp$42 PROCEND;
+	tmp$43 PROCALLOCARG;
+	tmp$43 PROCALLOCLOCAL;
+	tmp$44 PROCGETFRAMEREGNAME;
+	tmp$42 SCOPEBEGIN;
+	tmp$42 SCOPEEND;
+	tmp$42 PROCALLOCSTATICVARS;
+	tmp$45 EMITCONVERT;
+	tmp$42 EMITLABEL;
+	tmp$42 EMITLABELNF;
+	tmp$46 EMITRETURN;
+	tmp$43 EMITPROCBEGIN;
+	tmp$47 EMITPROCEND;
+	tmp$48 EMITPUSHARG;
+	tmp$49 EMITASMLINE;
+	tmp$50 EMITCOMMENT;
+	tmp$51 EMITBOP;
+	tmp$52 EMITUOP;
+	tmp$45 EMITSTORE;
+	tmp$38 EMITSPILLREGS;
+	tmp$53 EMITLOAD;
+	tmp$45 EMITLOADRES;
+	tmp$52 EMITSTACK;
+	tmp$52 EMITADDR;
+	tmp$54 EMITCALL;
+	tmp$55 EMITCALLPTR;
+	tmp$46 EMITSTACKALIGN;
+	tmp$53 EMITJUMPPTR;
+	tmp$56 EMITBRANCH;
+	tmp$57 EMITJMPTB;
+	tmp$58 EMITMEM;
+	tmp$59 EMITMACRO;
+	tmp$42 EMITSCOPEBEGIN;
+	tmp$42 EMITSCOPEEND;
+	tmp$42 EMITDECL;
+	tmp$60 EMITDBG;
+	tmp$42 EMITVARINIBEGIN;
+	tmp$42 EMITVARINIEND;
+	tmp$61 EMITVARINII;
+	tmp$62 EMITVARINIF;
+	tmp$63 EMITVARINIOFS;
+	tmp$64 EMITVARINISTR;
+	tmp$65 EMITVARINIWSTR;
+	tmp$66 EMITVARINIPAD;
+	tmp$67 EMITVARINISCOPEBEGIN;
+	tmp$38 EMITVARINISCOPEEND;
+	tmp$38 EMITFBCTINFBEGIN;
+	tmp$68 EMITFBCTINFSTRING;
+	tmp$38 EMITFBCTINFEND;
+	tmp$69 ALLOCVREG;
+	tmp$70 ALLOCVRIMM;
+	tmp$71 ALLOCVRIMMF;
+	tmp$72 ALLOCVRVAR;
+	tmp$73 ALLOCVRIDX;
+	tmp$74 ALLOCVRPTR;
+	tmp$72 ALLOCVROFS;
+	tmp$75 SETVREGDATATYPE;
+	tmp$76 GETDISTANCE;
+	tmp$52 LOADVR;
+	tmp$45 STOREVR;
+	tmp$46 XCHGTOS;
 };
 __FB_STATIC_ASSERT( sizeof( struct $7IR_VTBL ) == 544 );
 typedef int64 $6IR_OPT;
 struct $5IRCTX {
-	int64 INITED;
 	struct $7IR_VTBL VTBL;
 	$6IR_OPT OPTIONS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 560 );
+__FB_STATIC_ASSERT( sizeof( struct $5IRCTX ) == 552 );
 extern struct $5IRCTX IR$;
 typedef int64 $11AST_OPFLAGS;
 struct $10AST_OPINFO {
@@ -894,10 +908,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -915,30 +930,33 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 struct $8FBARRAY1IPvE {
 	void** DATA;
 	void** PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IPvE ) == 64 );
-static struct $8FBARRAY1IPvE tmp$99$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IPvE ) == 72 );
+static struct $8FBARRAY1IPvE tmp$104$;
 
 struct $8REGCLASS* REGNEWCLASS( int64 CLASS_$1, int64 REGS$1, struct $7FBARRAYI12REG_SIZEMASKE* SIZETB$1, int64 ISSTACK$1 )
 {
@@ -988,7 +1006,7 @@ int64 REGDELCLASS( struct $8REGCLASS* THIS_$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
@@ -1091,8 +1109,8 @@ static void REGCLEAR( struct $8REGCLASS* THIS_$1 )
 	*(struct $7REG_REG**)((uint8*)THIS_$1 + 264ll) = (struct $7REG_REG*)0ull;
 	{
 		N$1 = 0ll;
-		int64 TMP$101$2;
-		TMP$101$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
+		int64 TMP$106$2;
+		TMP$106$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
 		goto label$38;
 		label$41:;
 		{
@@ -1107,7 +1125,7 @@ static void REGCLEAR( struct $8REGCLASS* THIS_$1 )
 		label$39:;
 		N$1 = N$1 + 1ll;
 		label$38:;
-		if( N$1 <= TMP$101$2 ) goto label$41;
+		if( N$1 <= TMP$106$2 ) goto label$41;
 		label$40:;
 	}
 	label$37:;
@@ -1125,8 +1143,8 @@ static int64 REGFINDFAREST( struct $8REGCLASS* THIS_$1, int64 SIZE$1, int64 RESE
 	{
 		int64 I$2;
 		I$2 = 0ll;
-		int64 TMP$102$2;
-		TMP$102$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
+		int64 TMP$107$2;
+		TMP$107$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
 		goto label$44;
 		label$47:;
 		{
@@ -1151,7 +1169,7 @@ static int64 REGFINDFAREST( struct $8REGCLASS* THIS_$1, int64 SIZE$1, int64 RESE
 		label$45:;
 		I$2 = I$2 + 1ll;
 		label$44:;
-		if( I$2 <= TMP$102$2 ) goto label$47;
+		if( I$2 <= TMP$107$2 ) goto label$47;
 		label$46:;
 	}
 	fb$result$1 = R$1;
@@ -1169,16 +1187,16 @@ static int64 REGALLOCATE( struct $8REGCLASS* THIS_$1, struct $6IRVREG* VREG$1, s
 	R$1 = vr$1;
 	if( R$1 != -1ll ) goto label$57;
 	{
-		int64 TMP$103$2;
+		int64 TMP$108$2;
 		int64 RESERVEDREG$2;
 		RESERVEDREG$2 = -1ll;
 		if( *(struct $6IRVREG**)((uint8*)VREG$1 + 88ll) == (struct $6IRVREG*)0ull ) goto label$58;
-		TMP$103$2 = (int64)-((struct $6IRVREG*)(int64)-(*(int64*)*(struct $6IRVREG**)((uint8*)VREG$1 + 88ll) == 4ll) != (struct $6IRVREG*)0ull);
+		TMP$108$2 = (int64)-((struct $6IRVREG*)(int64)-(*(int64*)*(struct $6IRVREG**)((uint8*)VREG$1 + 88ll) == 4ll) != (struct $6IRVREG*)0ull);
 		goto label$203;
 		label$58:;
-		TMP$103$2 = 0ll;
+		TMP$108$2 = 0ll;
 		label$203:;
-		if( TMP$103$2 == 0ll ) goto label$60;
+		if( TMP$108$2 == 0ll ) goto label$60;
 		{
 			RESERVEDREG$2 = *(int64*)((uint8*)*(struct $6IRVREG**)((uint8*)VREG$1 + 88ll) + 24ll);
 		}
@@ -1186,7 +1204,7 @@ static int64 REGALLOCATE( struct $8REGCLASS* THIS_$1, struct $6IRVREG* VREG$1, s
 		label$59:;
 		int64 vr$9 = REGFINDFAREST( THIS_$1, (int64)SIZE$1, RESERVEDREG$2 );
 		R$1 = vr$9;
-		(*(tmp$40*)((uint8*)&IR$ + 536ll))( *(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 128ll), *(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 192ll) );
+		(*(tmp$45*)((uint8*)&IR$ + 528ll))( *(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 128ll), *(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 192ll) );
 		REGPOPREG( THIS_$1, R$1 );
 	}
 	label$57:;
@@ -1194,7 +1212,7 @@ static int64 REGALLOCATE( struct $8REGCLASS* THIS_$1, struct $6IRVREG* VREG$1, s
 	*(int64*)((uint8*)THIS_$1 + 272ll) = *(int64*)((uint8*)THIS_$1 + 272ll) & ~(1ll << (R$1 & 63ll));
 	*(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 128ll) = VREG$1;
 	*(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 192ll) = VAUXPARENT$1;
-	uint64 vr$23 = (*(tmp$72*)((uint8*)&IR$ + 520ll))( VREG$1 );
+	uint64 vr$23 = (*(tmp$76*)((uint8*)&IR$ + 512ll))( VREG$1 );
 	*(uint64*)((uint8*)((uint8*)((uint8*)THIS_$1 + 256ll) + (R$1 << (3ll & 63ll))) + 216ll) = vr$23;
 	fb$result$1 = R$1;
 	label$55:;
@@ -1215,7 +1233,7 @@ static int64 REGALLOCATEREG( struct $8REGCLASS* THIS_$1, int64 R$1, struct $6IRV
 	label$63:;
 	*(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 128ll) = VREG$1;
 	*(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 192ll) = VAUXPARENT$1;
-	uint64 vr$13 = (*(tmp$72*)((uint8*)&IR$ + 520ll))( VREG$1 );
+	uint64 vr$13 = (*(tmp$76*)((uint8*)&IR$ + 512ll))( VREG$1 );
 	*(uint64*)((uint8*)((uint8*)((uint8*)THIS_$1 + 256ll) + (R$1 << (3ll & 63ll))) + 216ll) = vr$13;
 	fb$result$1 = R$1;
 	label$62:;
@@ -1233,7 +1251,7 @@ static int64 REGENSURE( struct $8REGCLASS* THIS_$1, struct $6IRVREG* VREG$1, str
 	{
 		int64 vr$2 = REGALLOCATE( THIS_$1, VREG$1, VAUXPARENT$1, SIZE$1 );
 		R$1 = vr$2;
-		(*(tmp$47*)((uint8*)&IR$ + 528ll))( R$1, VREG$1, VAUXPARENT$1 );
+		(*(tmp$52*)((uint8*)&IR$ + 520ll))( R$1, VREG$1, VAUXPARENT$1 );
 	}
 	label$68:;
 	label$67:;
@@ -1248,7 +1266,7 @@ static void REGSETOWNER( struct $8REGCLASS* THIS_$1, int64 R$1, struct $6IRVREG*
 	*(int64*)((uint8*)THIS_$1 + 272ll) = *(int64*)((uint8*)THIS_$1 + 272ll) & ~(1ll << (R$1 & 63ll));
 	*(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 128ll) = VREG$1;
 	*(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 192ll) = VAUXPARENT$1;
-	uint64 vr$9 = (*(tmp$72*)((uint8*)&IR$ + 520ll))( VREG$1 );
+	uint64 vr$9 = (*(tmp$76*)((uint8*)&IR$ + 512ll))( VREG$1 );
 	*(uint64*)((uint8*)((uint8*)((uint8*)THIS_$1 + 256ll) + (R$1 << (3ll & 63ll))) + 216ll) = vr$9;
 	label$70:;
 }
@@ -1355,8 +1373,8 @@ static void REGINITCLASS( struct $8REGCLASS* THIS_$1, struct $7FBARRAYI12REG_SIZ
 	REGCLEAR( THIS_$1 );
 	{
 		I$1 = 0ll;
-		int64 TMP$104$2;
-		TMP$104$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
+		int64 TMP$109$2;
+		TMP$109$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
 		goto label$95;
 		label$98:;
 		{
@@ -1365,22 +1383,22 @@ static void REGINITCLASS( struct $8REGCLASS* THIS_$1, struct $7FBARRAYI12REG_SIZ
 		label$96:;
 		I$1 = I$1 + 1ll;
 		label$95:;
-		if( I$1 <= TMP$104$2 ) goto label$98;
+		if( I$1 <= TMP$109$2 ) goto label$98;
 		label$97:;
 	}
-	*(tmp$79*)THIS_$1 = (tmp$79)&REGENSURE;
-	*(tmp$79*)((uint8*)THIS_$1 + 8ll) = (tmp$79)&REGALLOCATE;
-	*(tmp$80*)((uint8*)THIS_$1 + 16ll) = (tmp$80)&REGALLOCATEREG;
-	*(tmp$81*)((uint8*)THIS_$1 + 24ll) = (tmp$81)&REGFREE;
-	*(tmp$82*)((uint8*)THIS_$1 + 32ll) = (tmp$82)&REGISFREE;
-	*(tmp$83*)((uint8*)THIS_$1 + 40ll) = (tmp$83)&REGSETOWNER;
-	*(tmp$84*)((uint8*)THIS_$1 + 48ll) = (tmp$84)&REGGETMAXREGS;
-	*(tmp$84*)((uint8*)THIS_$1 + 56ll) = (tmp$84)&REGGETFIRST;
-	*(tmp$82*)((uint8*)THIS_$1 + 64ll) = (tmp$82)&REGGETNEXT;
-	*(tmp$85*)((uint8*)THIS_$1 + 72ll) = (tmp$85)&REGGETVREG;
-	*(tmp$82*)((uint8*)THIS_$1 + 80ll) = (tmp$82)&REGGETREALREG;
-	*(tmp$86*)((uint8*)THIS_$1 + 88ll) = (tmp$86)&REGCLEAR;
-	*(tmp$86*)((uint8*)THIS_$1 + 96ll) = (tmp$86)&REGDUMP;
+	*(tmp$83*)THIS_$1 = (tmp$83)&REGENSURE;
+	*(tmp$83*)((uint8*)THIS_$1 + 8ll) = (tmp$83)&REGALLOCATE;
+	*(tmp$84*)((uint8*)THIS_$1 + 16ll) = (tmp$84)&REGALLOCATEREG;
+	*(tmp$85*)((uint8*)THIS_$1 + 24ll) = (tmp$85)&REGFREE;
+	*(tmp$86*)((uint8*)THIS_$1 + 32ll) = (tmp$86)&REGISFREE;
+	*(tmp$87*)((uint8*)THIS_$1 + 40ll) = (tmp$87)&REGSETOWNER;
+	*(tmp$88*)((uint8*)THIS_$1 + 48ll) = (tmp$88)&REGGETMAXREGS;
+	*(tmp$88*)((uint8*)THIS_$1 + 56ll) = (tmp$88)&REGGETFIRST;
+	*(tmp$86*)((uint8*)THIS_$1 + 64ll) = (tmp$86)&REGGETNEXT;
+	*(tmp$89*)((uint8*)THIS_$1 + 72ll) = (tmp$89)&REGGETVREG;
+	*(tmp$86*)((uint8*)THIS_$1 + 80ll) = (tmp$86)&REGGETREALREG;
+	*(tmp$90*)((uint8*)THIS_$1 + 88ll) = (tmp$90)&REGCLEAR;
+	*(tmp$90*)((uint8*)THIS_$1 + 96ll) = (tmp$90)&REGDUMP;
 	label$94:;
 }
 
@@ -1399,8 +1417,8 @@ static int64 SREGFINDREG( struct $8REGCLASS* THIS_$1, struct $6IRVREG* VREG$1 )
 	label$101:;
 	{
 		R$1 = 0ll;
-		int64 TMP$105$2;
-		TMP$105$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
+		int64 TMP$110$2;
+		TMP$110$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
 		goto label$103;
 		label$106:;
 		{
@@ -1420,7 +1438,7 @@ static int64 SREGFINDREG( struct $8REGCLASS* THIS_$1, struct $6IRVREG* VREG$1 )
 		label$104:;
 		R$1 = R$1 + 1ll;
 		label$103:;
-		if( R$1 <= TMP$105$2 ) goto label$106;
+		if( R$1 <= TMP$110$2 ) goto label$106;
 		label$105:;
 	}
 	label$100:;
@@ -1432,12 +1450,12 @@ static void SREGXCHG( struct $8REGCLASS* THIS_$1, int64 R1$1 )
 	label$111:;
 	static int64 I$1;
 	static int64 R2$1;
-	(*(tmp$41*)((uint8*)&IR$ + 544ll))( R1$1 );
+	(*(tmp$46*)((uint8*)&IR$ + 536ll))( R1$1 );
 	R2$1 = -1ll;
 	{
 		I$1 = 0ll;
-		int64 TMP$106$2;
-		TMP$106$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
+		int64 TMP$111$2;
+		TMP$111$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
 		goto label$113;
 		label$116:;
 		{
@@ -1452,14 +1470,14 @@ static void SREGXCHG( struct $8REGCLASS* THIS_$1, int64 R1$1 )
 		label$114:;
 		I$1 = I$1 + 1ll;
 		label$113:;
-		if( I$1 <= TMP$106$2 ) goto label$116;
+		if( I$1 <= TMP$111$2 ) goto label$116;
 		label$115:;
 	}
 	{
-		int64 TMP$107$2;
-		TMP$107$2 = *(int64*)((uint8*)((uint8*)THIS_$1 + 536ll) + (R1$1 << (3ll & 63ll)));
+		int64 TMP$112$2;
+		TMP$112$2 = *(int64*)((uint8*)((uint8*)THIS_$1 + 536ll) + (R1$1 << (3ll & 63ll)));
 		*(int64*)((uint8*)((uint8*)THIS_$1 + 536ll) + (R1$1 << (3ll & 63ll))) = *(int64*)((uint8*)((uint8*)THIS_$1 + 536ll) + (R2$1 << (3ll & 63ll)));
-		*(int64*)((uint8*)((uint8*)THIS_$1 + 536ll) + (R2$1 << (3ll & 63ll))) = TMP$107$2;
+		*(int64*)((uint8*)((uint8*)THIS_$1 + 536ll) + (R2$1 << (3ll & 63ll))) = TMP$112$2;
 	}
 	label$112:;
 }
@@ -1479,8 +1497,8 @@ static int64 SREGFINDFREEREG( struct $8REGCLASS* THIS_$1 )
 	label$121:;
 	{
 		R$1 = 0ll;
-		int64 TMP$108$2;
-		TMP$108$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
+		int64 TMP$113$2;
+		TMP$113$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
 		goto label$123;
 		label$126:;
 		{
@@ -1495,7 +1513,7 @@ static int64 SREGFINDFREEREG( struct $8REGCLASS* THIS_$1 )
 		label$124:;
 		R$1 = R$1 + 1ll;
 		label$123:;
-		if( R$1 <= TMP$108$2 ) goto label$126;
+		if( R$1 <= TMP$113$2 ) goto label$126;
 		label$125:;
 	}
 	label$120:;
@@ -1510,8 +1528,8 @@ static int64 SREGFINDTOSREG( struct $8REGCLASS* THIS_$1 )
 	static int64 R$1;
 	{
 		R$1 = 0ll;
-		int64 TMP$110$2;
-		TMP$110$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
+		int64 TMP$115$2;
+		TMP$115$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
 		goto label$141;
 		label$144:;
 		{
@@ -1526,7 +1544,7 @@ static int64 SREGFINDTOSREG( struct $8REGCLASS* THIS_$1 )
 		label$142:;
 		R$1 = R$1 + 1ll;
 		label$141:;
-		if( R$1 <= TMP$110$2 ) goto label$144;
+		if( R$1 <= TMP$115$2 ) goto label$144;
 		label$143:;
 	}
 	fb$result$1 = -1ll;
@@ -1546,7 +1564,7 @@ static int64 SREGALLOCATE( struct $8REGCLASS* THIS_$1, struct $6IRVREG* VREG$1,
 	{
 		int64 vr$2 = SREGFINDTOSREG( THIS_$1 );
 		R$1 = vr$2;
-		(*(tmp$40*)((uint8*)&IR$ + 536ll))( *(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 128ll), *(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 192ll) );
+		(*(tmp$45*)((uint8*)&IR$ + 528ll))( *(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 128ll), *(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 192ll) );
 	}
 	label$150:;
 	label$149:;
@@ -1554,8 +1572,8 @@ static int64 SREGALLOCATE( struct $8REGCLASS* THIS_$1, struct $6IRVREG* VREG$1,
 	{
 		int64 I$2;
 		I$2 = 0ll;
-		int64 TMP$111$2;
-		TMP$111$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
+		int64 TMP$116$2;
+		TMP$116$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
 		goto label$151;
 		label$154:;
 		{
@@ -1569,7 +1587,7 @@ static int64 SREGALLOCATE( struct $8REGCLASS* THIS_$1, struct $6IRVREG* VREG$1,
 		label$152:;
 		I$2 = I$2 + 1ll;
 		label$151:;
-		if( I$2 <= TMP$111$2 ) goto label$154;
+		if( I$2 <= TMP$116$2 ) goto label$154;
 		label$153:;
 	}
 	*(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 128ll) = VREG$1;
@@ -1603,7 +1621,7 @@ static int64 SREGENSURE( struct $8REGCLASS* THIS_$1, struct $6IRVREG* VREG$1, st
 	{
 		int64 vr$2 = SREGALLOCATE( THIS_$1, VREG$1, VAUXPARENT$1, 8ull );
 		R$1 = vr$2;
-		(*(tmp$47*)((uint8*)&IR$ + 528ll))( R$1, VREG$1, VAUXPARENT$1 );
+		(*(tmp$52*)((uint8*)&IR$ + 520ll))( R$1, VREG$1, VAUXPARENT$1 );
 	}
 	goto label$161;
 	label$162:;
@@ -1640,8 +1658,8 @@ static void SREGFREE( struct $8REGCLASS* THIS_$1, int64 R$1 )
 	*(struct $6IRVREG**)((uint8*)((uint8*)THIS_$1 + (R$1 << (3ll & 63ll))) + 192ll) = (struct $6IRVREG*)0ull;
 	{
 		I$1 = 0ll;
-		int64 TMP$112$2;
-		TMP$112$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
+		int64 TMP$117$2;
+		TMP$117$2 = *(int64*)((uint8*)THIS_$1 + 120ll) + -1ll;
 		goto label$169;
 		label$172:;
 		{
@@ -1660,7 +1678,7 @@ static void SREGFREE( struct $8REGCLASS* THIS_$1, int64 R$1 )
 		label$170:;
 		I$1 = I$1 + 1ll;
 		label$169:;
-		if( I$1 <= TMP$112$2 ) goto label$172;
+		if( I$1 <= TMP$117$2 ) goto label$172;
 		label$171:;
 	}
 	*(int64*)((uint8*)THIS_$1 + 600ll) = *(int64*)((uint8*)THIS_$1 + 600ll) + 1ll;
@@ -1760,8 +1778,8 @@ static void SREGCLEAR( struct $8REGCLASS* REG$1 )
 	*(int64*)((uint8*)REG$1 + 600ll) = *(int64*)((uint8*)REG$1 + 120ll);
 	{
 		R$1 = 0ll;
-		int64 TMP$113$2;
-		TMP$113$2 = *(int64*)((uint8*)REG$1 + 120ll) + -1ll;
+		int64 TMP$118$2;
+		TMP$118$2 = *(int64*)((uint8*)REG$1 + 120ll) + -1ll;
 		goto label$197;
 		label$200:;
 		{
@@ -1772,7 +1790,7 @@ static void SREGCLEAR( struct $8REGCLASS* REG$1 )
 		label$198:;
 		R$1 = R$1 + 1ll;
 		label$197:;
-		if( R$1 <= TMP$113$2 ) goto label$200;
+		if( R$1 <= TMP$118$2 ) goto label$200;
 		label$199:;
 	}
 	label$196:;
@@ -1782,18 +1800,18 @@ static void SREGINITCLASS( struct $8REGCLASS* THIS_$1, struct $7FBARRAYI12REG_SI
 {
 	label$201:;
 	SREGCLEAR( THIS_$1 );
-	*(tmp$79*)THIS_$1 = (tmp$79)&SREGENSURE;
-	*(tmp$79*)((uint8*)THIS_$1 + 8ll) = (tmp$79)&SREGALLOCATE;
-	*(tmp$80*)((uint8*)THIS_$1 + 16ll) = (tmp$80)&SREGALLOCATEREG;
-	*(tmp$81*)((uint8*)THIS_$1 + 24ll) = (tmp$81)&SREGFREE;
-	*(tmp$82*)((uint8*)THIS_$1 + 32ll) = (tmp$82)&SREGISFREE;
-	*(tmp$83*)((uint8*)THIS_$1 + 40ll) = (tmp$83)&SREGSETOWNER;
-	*(tmp$84*)((uint8*)THIS_$1 + 48ll) = (tmp$84)&SREGGETMAXREGS;
-	*(tmp$84*)((uint8*)THIS_$1 + 56ll) = (tmp$84)&SREGGETFIRST;
-	*(tmp$82*)((uint8*)THIS_$1 + 64ll) = (tmp$82)&SREGGETNEXT;
-	*(tmp$85*)((uint8*)THIS_$1 + 72ll) = (tmp$85)&SREGGETVREG;
-	*(tmp$82*)((uint8*)THIS_$1 + 80ll) = (tmp$82)&SREGGETREALREG;
-	*(tmp$86*)((uint8*)THIS_$1 + 88ll) = (tmp$86)&SREGCLEAR;
-	*(tmp$86*)((uint8*)THIS_$1 + 96ll) = (tmp$86)&SREGDUMP;
+	*(tmp$83*)THIS_$1 = (tmp$83)&SREGENSURE;
+	*(tmp$83*)((uint8*)THIS_$1 + 8ll) = (tmp$83)&SREGALLOCATE;
+	*(tmp$84*)((uint8*)THIS_$1 + 16ll) = (tmp$84)&SREGALLOCATEREG;
+	*(tmp$85*)((uint8*)THIS_$1 + 24ll) = (tmp$85)&SREGFREE;
+	*(tmp$86*)((uint8*)THIS_$1 + 32ll) = (tmp$86)&SREGISFREE;
+	*(tmp$87*)((uint8*)THIS_$1 + 40ll) = (tmp$87)&SREGSETOWNER;
+	*(tmp$88*)((uint8*)THIS_$1 + 48ll) = (tmp$88)&SREGGETMAXREGS;
+	*(tmp$88*)((uint8*)THIS_$1 + 56ll) = (tmp$88)&SREGGETFIRST;
+	*(tmp$86*)((uint8*)THIS_$1 + 64ll) = (tmp$86)&SREGGETNEXT;
+	*(tmp$89*)((uint8*)THIS_$1 + 72ll) = (tmp$89)&SREGGETVREG;
+	*(tmp$86*)((uint8*)THIS_$1 + 80ll) = (tmp$86)&SREGGETREALREG;
+	*(tmp$90*)((uint8*)THIS_$1 + 88ll) = (tmp$90)&SREGCLEAR;
+	*(tmp$90*)((uint8*)THIS_$1 + 96ll) = (tmp$90)&SREGDUMP;
 	label$202:;
 }
