@@ -12,6 +12,7 @@ typedef int64 $11FB_DATATYPE;
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -178,7 +179,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -324,6 +325,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -333,7 +335,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -342,7 +345,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -353,10 +356,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,27 +636,26 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 typedef int64 $10FB_RTL_OPT;
 struct $15FB_RTL_PARAMDEF {
 	$11FB_DATATYPE DTYPE;
 	$12FB_PARAMMODE MODE;
 	int64 ISOPT;
 	int64 OPTVAL;
-	int64 CHECK_CONST;
 };
-__FB_STATIC_ASSERT( sizeof( struct $15FB_RTL_PARAMDEF ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $15FB_RTL_PARAMDEF ) == 32 );
 struct $14FB_RTL_PROCDEF {
 	uint8* NAME;
 	uint8* ALIAS;
 	$11FB_DATATYPE DTYPE;
 	$11FB_FUNCMODE CALLCONV;
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 	$10FB_RTL_OPT OPTIONS;
 	int64 PARAMS;
 	struct $15FB_RTL_PARAMDEF PARAMTB[16];
 };
-__FB_STATIC_ASSERT( sizeof( struct $14FB_RTL_PROCDEF ) == 696 );
+__FB_STATIC_ASSERT( sizeof( struct $14FB_RTL_PROCDEF ) == 568 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -627,7 +665,9 @@ FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
 static void fb_ctor__rtlzgosub( void ) __attribute__(( constructor ));
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM*, struct $11TSTRSETITEM* );
+int64 FBIS64BIT( void );
 struct $7ASTNODE* ASTADD( struct $7ASTNODE* );
+struct $7ASTNODE* ASTNEWCONSTI( int64, int64, struct $8FBSYMBOL* );
 struct $7ASTNODE* ASTNEWCALL( struct $8FBSYMBOL*, struct $7ASTNODE* );
 struct $7ASTNODE* ASTNEWARG( struct $7ASTNODE*, struct $7ASTNODE*, int64, int64 );
 void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* );
@@ -653,10 +693,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
 	$12FB_DATACLASS CLASS;
@@ -674,20 +715,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -728,8 +771,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -737,8 +783,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -785,6 +832,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -806,30 +854,46 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
-static struct $14FB_RTL_PROCDEF FUNCDATA$[5] = { { (uint8*)"fb_GosubPush", (uint8*)0ull, 32ll, -1ll, (tmp$29)0ull, 0ll, 1ll, { { 64ll, 1ll, 0ll } } }, { (uint8*)"fb_GosubPop", (uint8*)0ull, 11ll, -1ll, (tmp$29)0ull, 0ll, 1ll, { { 64ll, 1ll, 0ll } } }, { (uint8*)"fb_GosubReturn", (uint8*)0ull, 11ll, -1ll, (tmp$29)0ull, 0ll, 1ll, { { 64ll, 1ll, 0ll } } }, { (uint8*)"fb_GosubExit", (uint8*)0ull, 0ll, -1ll, (tmp$29)0ull, 0ll, 1ll, { { 64ll, 1ll, 0ll } } }, { (uint8*)0ull } };
-static struct $14FB_RTL_PROCDEF FUNCDATA1$[2] = { { (uint8*)"fb_SetJmp", (uint8*)"_setjmp", 11ll, 3ll, (tmp$29)0ull, 0ll, 1ll, { { 32ll, 1ll, 0ll } } }, { (uint8*)0ull } };
-static struct $14FB_RTL_PROCDEF FUNCDATA2$[2] = { { (uint8*)"fb_SetJmp", (uint8*)"setjmp", 11ll, 3ll, (tmp$29)0ull, 0ll, 1ll, { { 32ll, 1ll, 0ll } } }, { (uint8*)0ull } };
+static struct $14FB_RTL_PROCDEF FUNCDATA$[5] = { { (uint8*)"fb_GosubPush", (uint8*)0ull, 32ll, -1ll, (tmp$34)0ull, 0ll, 1ll, { { 64ll, 1ll, 0ll } } }, { (uint8*)"fb_GosubPop", (uint8*)0ull, 11ll, -1ll, (tmp$34)0ull, 0ll, 1ll, { { 64ll, 1ll, 0ll } } }, { (uint8*)"fb_GosubReturn", (uint8*)0ull, 11ll, -1ll, (tmp$34)0ull, 0ll, 1ll, { { 64ll, 1ll, 0ll } } }, { (uint8*)"fb_GosubExit", (uint8*)0ull, 0ll, -1ll, (tmp$34)0ull, 0ll, 1ll, { { 64ll, 1ll, 0ll } } }, { (uint8*)0ull } };
+static struct $14FB_RTL_PROCDEF FUNCDATA1_WIN32$[2] = { { (uint8*)"fb_SetJmp", (uint8*)"_setjmp", 11ll, 3ll, (tmp$34)0ull, 0ll, 1ll, { { 32ll, 1ll, 0ll } } }, { (uint8*)0ull } };
+static struct $14FB_RTL_PROCDEF FUNCDATA1_WIN64$[2] = { { (uint8*)"fb_SetJmp", (uint8*)"_setjmp", 11ll, 3ll, (tmp$34)0ull, 0ll, 2ll, { { 32ll, 1ll, 0ll }, { 32ll, 1ll, 0ll } } }, { (uint8*)0ull } };
+static struct $14FB_RTL_PROCDEF FUNCDATA2$[2] = { { (uint8*)"fb_SetJmp", (uint8*)"setjmp", 11ll, 3ll, (tmp$34)0ull, 0ll, 1ll, { { 32ll, 1ll, 0ll } } }, { (uint8*)0ull } };
 
 void RTLGOSUBMODINIT( void )
 {
 	label$10:;
-	if( (*(int64*)((uint8*)&ENV$ + 1248ll) & 65536ll) == 0ll ) goto label$13;
+	if( (*(int64*)((uint8*)&ENV$ + 1408ll) & 65536ll) == 0ll ) goto label$13;
 	{
 		RTLADDINTRINSICPROCS( (struct $14FB_RTL_PROCDEF*)FUNCDATA$ );
 		if( *(int64*)((uint8*)&ENV$ + 216ll) != 0ll ) goto label$15;
 		{
-			RTLADDINTRINSICPROCS( (struct $14FB_RTL_PROCDEF*)FUNCDATA1$ );
+			int64 vr$1 = FBIS64BIT(  );
+			if( vr$1 == 0ll ) goto label$17;
+			{
+				RTLADDINTRINSICPROCS( (struct $14FB_RTL_PROCDEF*)FUNCDATA1_WIN64$ );
+			}
+			goto label$16;
+			label$17:;
+			{
+				RTLADDINTRINSICPROCS( (struct $14FB_RTL_PROCDEF*)FUNCDATA1_WIN32$ );
+			}
+			label$16:;
 		}
 		goto label$14;
 		label$15:;
@@ -845,29 +909,29 @@ void RTLGOSUBMODINIT( void )
 
 void RTLGOSUBMODEND( void )
 {
-	label$16:;
-	label$17:;
+	label$18:;
+	label$19:;
 }
 
 struct $7ASTNODE* RTLGOSUBPUSH( struct $7ASTNODE* CTX$1 )
 {
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$18:;
+	label$20:;
 	struct $7ASTNODE* PROC$1;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	struct $8FBSYMBOL* vr$1 = RTLPROCLOOKUP( (uint8*)"fb_GosubPush", 334ll );
+	struct $8FBSYMBOL* vr$1 = RTLPROCLOOKUP( (uint8*)"fb_GosubPush", 336ll );
 	struct $7ASTNODE* vr$2 = ASTNEWCALL( vr$1, (struct $7ASTNODE*)0ull );
 	PROC$1 = vr$2;
 	struct $7ASTNODE* vr$3 = ASTNEWARG( PROC$1, CTX$1, 2147483648ll, -1ll );
-	if( vr$3 != (struct $7ASTNODE*)0ull ) goto label$21;
+	if( vr$3 != (struct $7ASTNODE*)0ull ) goto label$23;
 	{
-		goto label$19;
+		goto label$21;
 	}
-	label$21:;
-	label$20:;
+	label$23:;
+	label$22:;
 	fb$result$1 = PROC$1;
-	label$19:;
+	label$21:;
 	return fb$result$1;
 }
 
@@ -875,21 +939,21 @@ struct $7ASTNODE* RTLGOSUBPOP( struct $7ASTNODE* CTX$1 )
 {
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$22:;
+	label$24:;
 	struct $7ASTNODE* PROC$1;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	struct $8FBSYMBOL* vr$1 = RTLPROCLOOKUP( (uint8*)"fb_GosubPop", 335ll );
+	struct $8FBSYMBOL* vr$1 = RTLPROCLOOKUP( (uint8*)"fb_GosubPop", 337ll );
 	struct $7ASTNODE* vr$2 = ASTNEWCALL( vr$1, (struct $7ASTNODE*)0ull );
 	PROC$1 = vr$2;
 	struct $7ASTNODE* vr$3 = ASTNEWARG( PROC$1, CTX$1, 2147483648ll, -1ll );
-	if( vr$3 != (struct $7ASTNODE*)0ull ) goto label$25;
+	if( vr$3 != (struct $7ASTNODE*)0ull ) goto label$27;
 	{
-		goto label$23;
+		goto label$25;
 	}
-	label$25:;
-	label$24:;
+	label$27:;
+	label$26:;
 	fb$result$1 = PROC$1;
-	label$23:;
+	label$25:;
 	return fb$result$1;
 }
 
@@ -897,22 +961,22 @@ int64 RTLGOSUBRETURN( struct $7ASTNODE* CTX$1 )
 {
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$26:;
+	label$28:;
 	struct $7ASTNODE* PROC$1;
-	struct $8FBSYMBOL* vr$1 = RTLPROCLOOKUP( (uint8*)"fb_GosubReturn", 336ll );
+	struct $8FBSYMBOL* vr$1 = RTLPROCLOOKUP( (uint8*)"fb_GosubReturn", 338ll );
 	struct $7ASTNODE* vr$2 = ASTNEWCALL( vr$1, (struct $7ASTNODE*)0ull );
 	PROC$1 = vr$2;
 	struct $7ASTNODE* vr$3 = ASTNEWARG( PROC$1, CTX$1, 2147483648ll, -1ll );
-	if( vr$3 != (struct $7ASTNODE*)0ull ) goto label$29;
+	if( vr$3 != (struct $7ASTNODE*)0ull ) goto label$31;
 	{
-		goto label$27;
+		goto label$29;
 	}
-	label$29:;
-	label$28:;
+	label$31:;
+	label$30:;
 	struct $7ASTNODE* vr$4 = RTLERRORCHECK( PROC$1 );
 	ASTADD( vr$4 );
 	fb$result$1 = -1ll;
-	label$27:;
+	label$29:;
 	return fb$result$1;
 }
 
@@ -920,21 +984,21 @@ struct $7ASTNODE* RTLGOSUBEXIT( struct $7ASTNODE* CTX$1 )
 {
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$30:;
+	label$32:;
 	struct $7ASTNODE* PROC$1;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	struct $8FBSYMBOL* vr$1 = RTLPROCLOOKUP( (uint8*)"fb_GosubExit", 337ll );
+	struct $8FBSYMBOL* vr$1 = RTLPROCLOOKUP( (uint8*)"fb_GosubExit", 339ll );
 	struct $7ASTNODE* vr$2 = ASTNEWCALL( vr$1, (struct $7ASTNODE*)0ull );
 	PROC$1 = vr$2;
 	struct $7ASTNODE* vr$3 = ASTNEWARG( PROC$1, CTX$1, 2147483648ll, -1ll );
-	if( vr$3 != (struct $7ASTNODE*)0ull ) goto label$33;
+	if( vr$3 != (struct $7ASTNODE*)0ull ) goto label$35;
 	{
-		goto label$31;
+		goto label$33;
 	}
-	label$33:;
-	label$32:;
+	label$35:;
+	label$34:;
 	fb$result$1 = PROC$1;
-	label$31:;
+	label$33:;
 	return fb$result$1;
 }
 
@@ -942,21 +1006,40 @@ struct $7ASTNODE* RTLSETJMP( struct $7ASTNODE* CTX$1 )
 {
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$34:;
+	label$36:;
 	struct $7ASTNODE* PROC$1;
 	fb$result$1 = (struct $7ASTNODE*)0ull;
-	struct $8FBSYMBOL* vr$1 = RTLPROCLOOKUP( (uint8*)"fb_SetJmp", 338ll );
+	struct $8FBSYMBOL* vr$1 = RTLPROCLOOKUP( (uint8*)"fb_SetJmp", 340ll );
 	struct $7ASTNODE* vr$2 = ASTNEWCALL( vr$1, (struct $7ASTNODE*)0ull );
 	PROC$1 = vr$2;
 	struct $7ASTNODE* vr$3 = ASTNEWARG( PROC$1, CTX$1, 2147483648ll, -1ll );
-	if( vr$3 != (struct $7ASTNODE*)0ull ) goto label$37;
+	if( vr$3 != (struct $7ASTNODE*)0ull ) goto label$39;
 	{
-		goto label$35;
+		goto label$37;
 	}
-	label$37:;
-	label$36:;
+	label$39:;
+	label$38:;
+	if( *(int64*)((uint8*)&ENV$ + 216ll) != 0ll ) goto label$41;
+	{
+		int64 vr$4 = FBIS64BIT(  );
+		if( vr$4 == 0ll ) goto label$43;
+		{
+			struct $7ASTNODE* vr$5 = ASTNEWCONSTI( 0ll, 8ll, (struct $8FBSYMBOL*)0ull );
+			struct $7ASTNODE* vr$6 = ASTNEWARG( PROC$1, vr$5, 2147483648ll, -1ll );
+			if( vr$6 != (struct $7ASTNODE*)0ull ) goto label$45;
+			{
+				goto label$37;
+			}
+			label$45:;
+			label$44:;
+		}
+		label$43:;
+		label$42:;
+	}
+	label$41:;
+	label$40:;
 	fb$result$1 = PROC$1;
-	label$35:;
+	label$37:;
 	return fb$result$1;
 }
 
@@ -969,7 +1052,7 @@ __attribute__(( constructor )) static void fb_ctor__rtlzgosub( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
