@@ -11,6 +11,7 @@ typedef int8 boolean;
 typedef int64 $13AST_NODECLASS;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -127,6 +128,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -136,7 +138,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -145,7 +148,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -156,10 +159,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -168,9 +172,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -269,14 +273,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -298,7 +304,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -309,9 +317,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -372,6 +386,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -401,7 +416,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $12AST_NODE_VAR {
 	int64 OFS;
 };
@@ -551,7 +566,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -604,22 +619,54 @@ struct $16__FB_ARRAYDIMTB$ {
 	int64 UBOUND;
 };
 __FB_STATIC_ASSERT( sizeof( struct $16__FB_ARRAYDIMTB$ ) == 24 );
+struct $8FBARRAY1IP7ASTNODEE {
+	struct $7ASTNODE** DATA;
+	struct $7ASTNODE** PTR;
+	int64 SIZE;
+	int64 ELEMENT_LEN;
+	int64 DIMENSIONS;
+	int64 FLAGS;
+	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
+};
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IP7ASTNODEE ) == 72 );
 struct $7FBARRAYIvE {
 	void* DATA;
 	void* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[8];
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYIvE ) == 232 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYIvE ) == 240 );
+struct $8FBARRAY1Iu7INTEGERE {
+	int64* DATA;
+	int64* PTR;
+	int64 SIZE;
+	int64 ELEMENT_LEN;
+	int64 DIMENSIONS;
+	int64 FLAGS;
+	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
+};
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1Iu7INTEGERE ) == 72 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
 };
 __FB_STATIC_ASSERT( sizeof( struct $11TSTRSETITEM ) == 32 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 int32 fb_ArrayRedimEx( struct $7FBARRAYIvE*, uint64, int32, int32, uint64, ... );
-int32 fb_ArrayErase( struct $7FBARRAYIvE*, int32 );
+int32 fb_ArrayErase( struct $7FBARRAYIvE* );
 void* fb_ErrorThrowAt( int32, uint8*, void*, void* );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
@@ -633,7 +680,8 @@ struct $7ASTNODE* ASTNEWVAR( struct $8FBSYMBOL*, int64, int64, struct $8FBSYMBOL
 struct $7ASTNODE* ASTNEWCALL( struct $8FBSYMBOL*, struct $7ASTNODE* );
 struct $7ASTNODE* ASTNEWARG( struct $7ASTNODE*, struct $7ASTNODE*, int64, int64 );
 struct $7ASTNODE* ASTNEWADDROF( struct $7ASTNODE* );
-struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, int64 );
+typedef int64 $15AST_LINK_RETURN;
+struct $7ASTNODE* ASTNEWLINK( struct $7ASTNODE*, struct $7ASTNODE*, $15AST_LINK_RETURN );
 struct $7ASTNODE* ASTBUILDPROCADDROF( struct $8FBSYMBOL* );
 struct $8FBSYMBOL* SYMBADDTEMPVAR( int64, struct $8FBSYMBOL* );
 int64 SYMBISARRAY( struct $8FBSYMBOL* );
@@ -658,21 +706,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -680,20 +718,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -734,8 +774,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -743,8 +786,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -791,6 +835,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -812,22 +857,27 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 
 struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 {
-	int64 TMP$85$1;
-	struct $8FBSYMBOL* TMP$89$1;
+	int64 TMP$89$1;
+	struct $8FBSYMBOL* TMP$93$1;
 	struct $7ASTNODE* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$89:;
@@ -853,49 +903,33 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 	ARG$1 = *(struct $7ASTNODE**)((uint8*)CALLEXPR$1 + 120ll);
 	int64 ARGUPPER$1;
 	if( ARGS$1 != 0ll ) goto label$91;
-	TMP$85$1 = 1ll;
+	TMP$89$1 = 1ll;
 	goto label$136;
 	label$91:;
-	TMP$85$1 = ARGS$1;
+	TMP$89$1 = ARGS$1;
 	label$136:;
-	ARGUPPER$1 = TMP$85$1;
-	struct $8FBARRAY1IP7ASTNODEE {
-		struct $7ASTNODE** DATA;
-		struct $7ASTNODE** PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IP7ASTNODEE ) == 64 );
+	ARGUPPER$1 = TMP$89$1;
 	struct $8FBARRAY1IP7ASTNODEE ARGEXPR$1;
 	*(struct $7ASTNODE***)&ARGEXPR$1 = (struct $7ASTNODE**)0ull;
 	*(struct $7ASTNODE***)((uint8*)&ARGEXPR$1 + 8ll) = (struct $7ASTNODE**)0ull;
 	*(int64*)((uint8*)&ARGEXPR$1 + 16ll) = 0ll;
 	*(int64*)((uint8*)&ARGEXPR$1 + 24ll) = 8ll;
 	*(int64*)((uint8*)&ARGEXPR$1 + 32ll) = 1ll;
-	__builtin_memset( (void*)((uint8*)&ARGEXPR$1 + 40ll), 0, 24ll );
+	*(int64*)((uint8*)&ARGEXPR$1 + 40ll) = 17ll;
+	__builtin_memset( (void*)((uint8*)&ARGEXPR$1 + 48ll), 0, 24ll );
 	int32 vr$13 = fb_ArrayRedimEx( (struct $7FBARRAYIvE*)&ARGEXPR$1, 8ull, -1, 0, 1ull, 1ll, ARGUPPER$1 );
 	if( (int64)vr$13 == 0ll ) goto label$92;
 	void* vr$15 = fb_ErrorThrowAt( 191, (uint8*)"src/compiler/rtl-system-thread.bas", (void*)0ull, (void*)0ull );
 	goto *vr$15;
 	label$92:;
-	struct $8FBARRAY1Iu7INTEGERE {
-		int64* DATA;
-		int64* PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1Iu7INTEGERE ) == 64 );
 	struct $8FBARRAY1Iu7INTEGERE ARGMODE$1;
 	*(int64**)&ARGMODE$1 = (int64*)0ull;
 	*(int64**)((uint8*)&ARGMODE$1 + 8ll) = (int64*)0ull;
 	*(int64*)((uint8*)&ARGMODE$1 + 16ll) = 0ll;
 	*(int64*)((uint8*)&ARGMODE$1 + 24ll) = 8ll;
 	*(int64*)((uint8*)&ARGMODE$1 + 32ll) = 1ll;
-	__builtin_memset( (void*)((uint8*)&ARGMODE$1 + 40ll), 0, 24ll );
+	*(int64*)((uint8*)&ARGMODE$1 + 40ll) = 17ll;
+	__builtin_memset( (void*)((uint8*)&ARGMODE$1 + 48ll), 0, 24ll );
 	int32 vr$18 = fb_ArrayRedimEx( (struct $7FBARRAYIvE*)&ARGMODE$1, 8ull, -1, 0, 1ull, 1ll, ARGUPPER$1 );
 	if( (int64)vr$18 == 0ll ) goto label$93;
 	void* vr$20 = fb_ErrorThrowAt( 192, (uint8*)"src/compiler/rtl-system-thread.bas", (void*)0ull, (void*)0ull );
@@ -904,15 +938,15 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 	{
 		int64 I$2;
 		I$2 = 1ll;
-		int64 TMP$87$2;
-		TMP$87$2 = ARGS$1;
+		int64 TMP$91$2;
+		TMP$91$2 = ARGS$1;
 		goto label$94;
 		label$97:;
 		{
 			if( ARG$1 != (struct $7ASTNODE*)0ull ) goto label$99;
 			{
-				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1, 0 );
-				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1, 0 );
+				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1 );
+				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1 );
 				goto label$90;
 			}
 			label$99:;
@@ -925,20 +959,20 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 		label$95:;
 		I$2 = I$2 + 1ll;
 		label$94:;
-		if( I$2 <= TMP$87$2 ) goto label$97;
+		if( I$2 <= TMP$91$2 ) goto label$97;
 		label$96:;
 	}
 	ASTDELTREE( CALLEXPR$1 );
 	struct $7ASTNODE* EXPR$1;
-	struct $8FBSYMBOL* vr$34 = RTLPROCLOOKUP( (uint8*)"fb_ThreadCall", 364ll );
+	struct $8FBSYMBOL* vr$34 = RTLPROCLOOKUP( (uint8*)"fb_ThreadCall", 366ll );
 	struct $7ASTNODE* vr$35 = ASTNEWCALL( vr$34, (struct $7ASTNODE*)0ull );
 	EXPR$1 = vr$35;
 	struct $7ASTNODE* vr$36 = ASTBUILDPROCADDROF( PROC$1 );
 	struct $7ASTNODE* vr$37 = ASTNEWARG( EXPR$1, vr$36, 2147483648ll, -1ll );
 	if( vr$37 != (struct $7ASTNODE*)0ull ) goto label$101;
 	{
-		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1, 0 );
-		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1, 0 );
+		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1 );
+		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1 );
 		goto label$90;
 	}
 	label$101:;
@@ -947,10 +981,10 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 	__builtin_memset( &PROCMODE$1, 0, 8ll );
 	int64 PROCMODE_FB$1;
 	__builtin_memset( &PROCMODE_FB$1, 0, 8ll );
-	PROCMODE_FB$1 = *(int64*)((uint8*)PROC$1 + 144ll);
+	PROCMODE_FB$1 = *(int64*)((uint8*)PROC$1 + 152ll);
 	if( PROCMODE_FB$1 != -1ll ) goto label$103;
 	{
-		PROCMODE_FB$1 = *(int64*)((uint8*)&ENV$ + 504ll);
+		PROCMODE_FB$1 = *(int64*)((uint8*)&ENV$ + 536ll);
 		label$103:;
 	}
 	if( PROCMODE_FB$1 != 3ll ) goto label$105;
@@ -967,8 +1001,8 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 	label$106:;
 	{
 		ERRREPORT( 288ll, 0ll, (uint8*)0ull );
-		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1, 0 );
-		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1, 0 );
+		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1 );
+		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1 );
 		goto label$90;
 	}
 	label$104:;
@@ -977,8 +1011,8 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 	struct $7ASTNODE* vr$51 = ASTNEWARG( EXPR$1, PROCMODEEXPR$1, 2147483648ll, -1ll );
 	if( vr$51 != (struct $7ASTNODE*)0ull ) goto label$108;
 	{
-		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1, 0 );
-		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1, 0 );
+		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1 );
+		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1 );
 		goto label$90;
 	}
 	label$108:;
@@ -988,8 +1022,8 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 	struct $7ASTNODE* vr$55 = ASTNEWARG( EXPR$1, STACKSIZEEXPR$1, 2147483648ll, -1ll );
 	if( vr$55 != (struct $7ASTNODE*)0ull ) goto label$110;
 	{
-		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1, 0 );
-		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1, 0 );
+		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1 );
+		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1 );
 		goto label$90;
 	}
 	label$110:;
@@ -999,33 +1033,33 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 	struct $7ASTNODE* vr$59 = ASTNEWARG( EXPR$1, ARGSEXPR$1, 2147483648ll, -1ll );
 	if( vr$59 != (struct $7ASTNODE*)0ull ) goto label$112;
 	{
-		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1, 0 );
-		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1, 0 );
+		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1 );
+		fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1 );
 		goto label$90;
 	}
 	label$112:;
 	label$111:;
-	if( *(int64*)((uint8*)PROC$1 + 144ll) != 4ll ) goto label$113;
-	TMP$89$1 = *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 136ll);
+	if( *(int64*)((uint8*)PROC$1 + 152ll) != 4ll ) goto label$113;
+	TMP$93$1 = *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 144ll);
 	goto label$137;
 	label$113:;
-	TMP$89$1 = *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 128ll);
+	TMP$93$1 = *(struct $8FBSYMBOL**)((uint8*)PROC$1 + 136ll);
 	label$137:;
-	PARAM$1 = TMP$89$1;
+	PARAM$1 = TMP$93$1;
 	{
 		int64 I$2;
 		I$2 = 1ll;
-		int64 TMP$90$2;
-		TMP$90$2 = ARGS$1;
+		int64 TMP$94$2;
+		TMP$94$2 = ARGS$1;
 		goto label$114;
 		label$117:;
 		{
-			struct $8FBSYMBOL* TMP$91$3;
+			struct $8FBSYMBOL* TMP$95$3;
 			$12FB_PARAMMODE MODE$3;
 			__builtin_memset( &MODE$3, 0, 8ll );
 			int64 TCTYPE$3;
 			TCTYPE$3 = -1ll;
-			MODE$3 = *($12FB_PARAMMODE*)((uint8*)PARAM$1 + 88ll);
+			MODE$3 = *($12FB_PARAMMODE*)((uint8*)PARAM$1 + 96ll);
 			int64 vr$67 = HTHREADCALLMAPTYPE( PARAM$1, 0ll );
 			TCTYPE$3 = vr$67;
 			{
@@ -1056,19 +1090,19 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 				label$118:;
 			}
 			struct $8FBSYMBOL* STYPE$3;
-			STYPE$3 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 56ll);
+			STYPE$3 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 64ll);
 			int64 vr$69 = HTHREADCALLPUSHTYPE( EXPR$1, TCTYPE$3, STYPE$3 );
 			if( vr$69 != 0ll ) goto label$128;
 			{
-				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1, 0 );
-				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1, 0 );
+				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1 );
+				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1 );
 				goto label$90;
 			}
 			label$128:;
 			label$127:;
 			PTREXPR$1 = *(struct $7ASTNODE**)((I$2 << (3ll & 63ll)) + *(int64*)&ARGEXPR$1);
 			struct $7ASTNODE* vr$75 = HGETEXPRREF( &PTREXPR$1 );
-			struct $7ASTNODE* vr$76 = ASTNEWLINK( T$1, vr$75, 0ll );
+			struct $7ASTNODE* vr$76 = ASTNEWLINK( T$1, vr$75, 2ll );
 			T$1 = vr$76;
 			int64 ISSTRING$3;
 			__builtin_memset( &ISSTRING$3, 0, 8ll );
@@ -1076,15 +1110,15 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 			if( (((int64)-(MODE$3 == 2ll) & (int64)-(*(int64*)((I$2 << (3ll & 63ll)) + *(int64*)&ARGMODE$1) != 1ll)) & (int64)-(ISSTRING$3 == 0ll)) == 0ll ) goto label$130;
 			{
 				struct $7ASTNODE* vr$91 = HGETEXPRREF( &PTREXPR$1 );
-				struct $7ASTNODE* vr$92 = ASTNEWLINK( T$1, vr$91, 0ll );
+				struct $7ASTNODE* vr$92 = ASTNEWLINK( T$1, vr$91, 2ll );
 				T$1 = vr$92;
 			}
 			label$130:;
 			label$129:;
 			if( PTREXPR$1 != (struct $7ASTNODE*)0ull ) goto label$132;
 			{
-				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1, 0 );
-				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1, 0 );
+				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1 );
+				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1 );
 				goto label$90;
 			}
 			label$132:;
@@ -1092,30 +1126,30 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 			struct $7ASTNODE* vr$95 = ASTNEWARG( EXPR$1, PTREXPR$1, 2147483648ll, -1ll );
 			if( vr$95 != (struct $7ASTNODE*)0ull ) goto label$134;
 			{
-				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1, 0 );
-				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1, 0 );
+				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1 );
+				fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1 );
 				goto label$90;
 			}
 			label$134:;
 			label$133:;
-			if( *(int64*)((uint8*)PROC$1 + 144ll) != 4ll ) goto label$135;
-			TMP$91$3 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 288ll);
+			if( *(int64*)((uint8*)PROC$1 + 152ll) != 4ll ) goto label$135;
+			TMP$95$3 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 304ll);
 			goto label$138;
 			label$135:;
-			TMP$91$3 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 296ll);
+			TMP$95$3 = *(struct $8FBSYMBOL**)((uint8*)PARAM$1 + 312ll);
 			label$138:;
-			PARAM$1 = TMP$91$3;
+			PARAM$1 = TMP$95$3;
 		}
 		label$115:;
 		I$2 = I$2 + 1ll;
 		label$114:;
-		if( I$2 <= TMP$90$2 ) goto label$117;
+		if( I$2 <= TMP$94$2 ) goto label$117;
 		label$116:;
 	}
-	struct $7ASTNODE* vr$102 = ASTNEWLINK( T$1, EXPR$1, 0ll );
+	struct $7ASTNODE* vr$102 = ASTNEWLINK( T$1, EXPR$1, 2ll );
 	fb$result$1 = vr$102;
-	fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1, 0 );
-	fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1, 0 );
+	fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGMODE$1 );
+	fb_ArrayErase( (struct $7FBARRAYIvE*)&ARGEXPR$1 );
 	label$90:;
 	return fb$result$1;
 }
@@ -1123,44 +1157,44 @@ struct $7ASTNODE* RTLTHREADCALL( struct $7ASTNODE* CALLEXPR$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
 
 static int64 HTHREADCALLMAPTYPE( struct $8FBSYMBOL* SYM$1, int64 UDT$1 )
 {
-	int64 TMP$81$1;
+	int64 TMP$85$1;
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
 	fb$result$1 = -1ll;
 	$11FB_DATATYPE DTYPE$1;
-	DTYPE$1 = *(int64*)((uint8*)SYM$1 + 48ll) & 511ll;
+	DTYPE$1 = *(int64*)((uint8*)SYM$1 + 56ll) & 511ll;
 	struct $8FBSYMBOL* SUBTYPE$1;
-	SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 56ll);
+	SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 64ll);
 	int64 vr$4 = SYMBISARRAY( SYM$1 );
 	if( vr$4 == 0ll ) goto label$13;
 	{
-		int64 TMP$80$2;
+		int64 TMP$84$2;
 		if( UDT$1 == 0ll ) goto label$14;
-		TMP$80$2 = -1ll;
+		TMP$84$2 = -1ll;
 		goto label$139;
 		label$14:;
-		TMP$80$2 = 13ll;
+		TMP$84$2 = 13ll;
 		label$139:;
-		fb$result$1 = TMP$80$2;
+		fb$result$1 = TMP$84$2;
 		goto label$11;
 	}
 	label$13:;
 	label$12:;
 	if( *(int64*)SYM$1 != 12ll ) goto label$15;
-	TMP$81$1 = (int64)-(*(int64*)((uint8*)SYM$1 + 184ll) > 0ll);
+	TMP$85$1 = (int64)-(*(int64*)((uint8*)SYM$1 + 192ll) > 0ll);
 	goto label$140;
 	label$15:;
-	TMP$81$1 = 0ll;
+	TMP$85$1 = 0ll;
 	label$140:;
-	if( TMP$81$1 == 0ll ) goto label$17;
+	if( TMP$85$1 == 0ll ) goto label$17;
 	{
 		goto label$11;
 	}
@@ -1177,27 +1211,27 @@ static int64 HTHREADCALLMAPTYPE( struct $8FBSYMBOL* SYM$1, int64 UDT$1 )
 		if( DTYPE$1 != 17ll ) goto label$21;
 		label$22:;
 		{
-			int64 TMP$82$3;
+			int64 TMP$86$3;
 			if( UDT$1 == 0ll ) goto label$23;
-			TMP$82$3 = -1ll;
+			TMP$86$3 = -1ll;
 			goto label$141;
 			label$23:;
-			TMP$82$3 = 13ll;
+			TMP$86$3 = 13ll;
 			label$141:;
-			fb$result$1 = TMP$82$3;
+			fb$result$1 = TMP$86$3;
 		}
 		goto label$20;
 		label$21:;
 		if( DTYPE$1 != 20ll ) goto label$24;
 		label$25:;
 		{
-			if( ((int64)-(((int64)*(int32*)((uint8*)SUBTYPE$1 + 200ll) & 1ll) != 0ll) | (int64)-(((int64)*(int32*)((uint8*)SUBTYPE$1 + 200ll) & 8192ll) != 0ll)) == 0ll ) goto label$27;
+			if( ((int64)-(((int64)*(int32*)((uint8*)SUBTYPE$1 + 208ll) & 1ll) != 0ll) | (int64)-(((int64)*(int32*)((uint8*)SUBTYPE$1 + 208ll) & 8192ll) != 0ll)) == 0ll ) goto label$27;
 			{
 				goto label$11;
 			}
 			label$27:;
 			label$26:;
-			if( (int64)*(uint8*)((uint8*)SUBTYPE$1 + 205ll) == 0ll ) goto label$29;
+			if( (int64)*(uint8*)((uint8*)SUBTYPE$1 + 213ll) == 0ll ) goto label$29;
 			{
 				goto label$11;
 			}
@@ -1253,15 +1287,15 @@ static int64 HTHREADCALLMAPTYPE( struct $8FBSYMBOL* SYM$1, int64 UDT$1 )
 		label$33:;
 		{
 			{
-				int64 TMP$83$4;
-				uint64 TMP$84$4;
+				int64 TMP$87$4;
+				uint64 TMP$88$4;
 				if( (DTYPE$1 & 480ll) == 0ll ) goto label$48;
-				TMP$83$4 = 24ll;
+				TMP$87$4 = 24ll;
 				goto label$142;
 				label$48:;
-				TMP$83$4 = DTYPE$1 & 31ll;
+				TMP$87$4 = DTYPE$1 & 31ll;
 				label$142:;
-				TMP$84$4 = *(uint64*)(((uint8*)SYMB_DTYPETB$ + (TMP$83$4 * 56ll)) + 40ll);
+				TMP$88$4 = *(uint64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$87$4 * 56ll)) + 40ll);
 				goto label$50;
 				label$51:;
 				{
@@ -1318,7 +1352,7 @@ static int64 HTHREADCALLMAPTYPE( struct $8FBSYMBOL* SYM$1, int64 UDT$1 )
 				}
 				goto label$49;
 				label$50:;
-				static const void* tmp$92[10ll] = {
+				static const void* tmp$96[10ll] = {
 					&&label$51,
 					&&label$52,
 					&&label$53,
@@ -1330,8 +1364,8 @@ static int64 HTHREADCALLMAPTYPE( struct $8FBSYMBOL* SYM$1, int64 UDT$1 )
 					&&label$59,
 					&&label$60,
 				};
-				if( (TMP$84$4 - 1ull) > 9ull ) goto label$61;
-				goto *tmp$92[TMP$84$4 - 1ull];
+				if( (TMP$88$4 - 1ull) > 9ull ) goto label$61;
+				goto *tmp$96[TMP$88$4 - 1ull];
 				label$49:;
 			}
 		}
@@ -1379,7 +1413,7 @@ static int64 HTHREADCALLPUSHSTRUCT( struct $7ASTNODE* FUNCEXPR$1, struct $8FBSYM
 	label$70:;
 	{
 		int64 vr$8 = HTHREADCALLMAPTYPE( FLD$1, -1ll );
-		int64 vr$9 = HTHREADCALLPUSHTYPE( FUNCEXPR$1, vr$8, *(struct $8FBSYMBOL**)((uint8*)FLD$1 + 56ll) );
+		int64 vr$9 = HTHREADCALLPUSHTYPE( FUNCEXPR$1, vr$8, *(struct $8FBSYMBOL**)((uint8*)FLD$1 + 64ll) );
 		if( vr$9 != 0ll ) goto label$74;
 		{
 			goto label$64;
