@@ -46,13 +46,15 @@ struct $7FBARRAYIvE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[8];
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYIvE ) == 232 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYIvE ) == 240 );
 typedef int64 $11FB_DATATYPE;
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -218,7 +220,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -364,6 +366,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -373,7 +376,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -382,7 +386,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -393,10 +397,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -404,9 +409,9 @@ struct $8FBS_ENUM {
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -480,14 +485,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -509,7 +516,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -520,9 +529,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -583,6 +598,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -612,27 +628,26 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 typedef int64 $10FB_RTL_OPT;
 struct $15FB_RTL_PARAMDEF {
 	$11FB_DATATYPE DTYPE;
 	$12FB_PARAMMODE MODE;
 	int64 ISOPT;
 	int64 OPTVAL;
-	int64 CHECK_CONST;
 };
-__FB_STATIC_ASSERT( sizeof( struct $15FB_RTL_PARAMDEF ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $15FB_RTL_PARAMDEF ) == 32 );
 struct $14FB_RTL_PROCDEF {
 	uint8* NAME;
 	uint8* ALIAS;
 	$11FB_DATATYPE DTYPE;
 	$11FB_FUNCMODE CALLCONV;
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 	$10FB_RTL_OPT OPTIONS;
 	int64 PARAMS;
 	struct $15FB_RTL_PARAMDEF PARAMTB[16];
 };
-__FB_STATIC_ASSERT( sizeof( struct $14FB_RTL_PROCDEF ) == 696 );
+__FB_STATIC_ASSERT( sizeof( struct $14FB_RTL_PROCDEF ) == 568 );
 typedef int64 $9FB_ERRMSG;
 struct $11FB_CALL_ARG;
 struct $11FB_CALL_ARG {
@@ -647,12 +662,23 @@ struct $16FB_CALL_ARG_LIST {
 	struct $11FB_CALL_ARG* TAIL;
 };
 __FB_STATIC_ASSERT( sizeof( struct $16FB_CALL_ARG_LIST ) == 24 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
 };
 __FB_STATIC_ASSERT( sizeof( struct $11TSTRSETITEM ) == 32 );
-int32 fb_ArrayClear( struct $7FBARRAYIvE*, int32 );
+int32 fb_ArrayClear( struct $7FBARRAYIvE* );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 void fb_StrDelete( FBSTRING* );
 FBSTRING* fb_StrConcat( FBSTRING*, void*, int64, void*, int64 );
@@ -672,11 +698,11 @@ struct $7ASTNODE* ASTNEWARG( struct $7ASTNODE*, struct $7ASTNODE*, int64, int64
 struct $10FBSYMCHAIN* SYMBLOOKUPAT( struct $8FBSYMBOL*, uint8*, int64, int64 );
 typedef int64 $16FB_SYMBLOOKUPOPT;
 struct $8FBSYMBOL* SYMBFINDCLOSESTOVLPROC( struct $8FBSYMBOL*, int64, struct $11FB_CALL_ARG*, $9FB_ERRMSG*, $16FB_SYMBLOOKUPOPT );
-struct $8FBSYMBOL* SYMBADDPROCPARAM( struct $8FBSYMBOL*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, $13FB_SYMBATTRIB );
+struct $8FBSYMBOL* SYMBADDPROCPARAM( struct $8FBSYMBOL*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, $13FB_SYMBATTRIB, $13FB_PROCATTRIB );
 void SYMBMAKEPARAMOPTIONAL( struct $8FBSYMBOL*, struct $8FBSYMBOL*, struct $7ASTNODE* );
 typedef int64 $10FB_SYMBOPT;
-struct $8FBSYMBOL* SYMBADDPROC( struct $8FBSYMBOL*, uint8*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, $10FB_SYMBOPT );
-struct $8FBSYMBOL* SYMBADDPROCPTR( struct $8FBSYMBOL*, int64, struct $8FBSYMBOL*, int64, int64 );
+struct $8FBSYMBOL* SYMBADDPROC( struct $8FBSYMBOL*, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB, $13FB_PROCATTRIB, int64, $10FB_SYMBOPT );
+struct $8FBSYMBOL* SYMBADDPROCPTR( struct $8FBSYMBOL*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB, $13FB_PROCATTRIB, int64 );
 struct $8FBSYMBOL* SYMBPREADDPROC( uint8* );
 int64 SYMBCALCLEN( int64, struct $8FBSYMBOL* );
 struct $11FB_CALL_ARG* SYMBALLOCOVLCALLARG( struct $5TLIST*, struct $16FB_CALL_ARG_LIST*, int64 );
@@ -726,10 +752,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -763,6 +790,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -771,11 +802,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -828,19 +860,8 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -848,20 +869,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -902,8 +925,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -911,8 +937,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -959,6 +986,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -980,33 +1008,39 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 struct $6RTLCTX {
 	struct $5TLIST ARGLIST;
 };
 __FB_STATIC_ASSERT( sizeof( struct $6RTLCTX ) == 64 );
 static struct $6RTLCTX CTX$;
-static struct $8FBSYMBOL* RTLLOOKUPTB$[365];
+static struct $8FBSYMBOL* RTLLOOKUPTB$[367];
 struct $8FBARRAY1IP8FBSYMBOLE {
 	struct $8FBSYMBOL** DATA;
 	struct $8FBSYMBOL** PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IP8FBSYMBOLE ) == 64 );
-static struct $8FBARRAY1IP8FBSYMBOLE tmp$80$ = { (struct $8FBSYMBOL**)RTLLOOKUPTB$, (struct $8FBSYMBOL**)RTLLOOKUPTB$, 2920ll, 8ll, 1ll, { { 365ll, 0ll, 364ll } } };
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1IP8FBSYMBOLE ) == 72 );
+static struct $8FBARRAY1IP8FBSYMBOLE tmp$84$ = { (struct $8FBSYMBOL**)RTLLOOKUPTB$, (struct $8FBSYMBOL**)RTLLOOKUPTB$, 2936ll, 8ll, 1ll, 49ll, { { 367ll, 0ll, 366ll } } };
 
 void RTLINIT( void )
 {
@@ -1049,7 +1083,7 @@ void RTLEND( void )
 	RTLCONSOLEMODEND(  );
 	RTLARRAYMODEND(  );
 	LISTEND( (struct $5TLIST*)&CTX$ );
-	fb_ArrayClear( (struct $7FBARRAYIvE*)&tmp$80$, 0 );
+	fb_ArrayClear( (struct $7FBARRAYIvE*)&tmp$84$ );
 	label$13:;
 }
 
@@ -1069,7 +1103,7 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 		CALLCONV$1 = *(int64*)((uint8*)PROCDEF$1 + 24ll);
 		if( CALLCONV$1 != -1ll ) goto label$22;
 		{
-			CALLCONV$1 = *(int64*)((uint8*)&ENV$ + 504ll);
+			CALLCONV$1 = *(int64*)((uint8*)&ENV$ + 536ll);
 		}
 		label$22:;
 		label$21:;
@@ -1077,7 +1111,7 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 		DOADD$2 = -1ll;
 		if( (*(int64*)((uint8*)PROCDEF$1 + 40ll) & 4ll) == 0ll ) goto label$24;
 		{
-			DOADD$2 = (int64)-((*(int64*)((uint8*)&ENV$ + 1248ll) & 1ll) != 0ll);
+			DOADD$2 = (int64)-((*(int64*)((uint8*)&ENV$ + 1408ll) & 1ll) != 0ll);
 		}
 		label$24:;
 		label$23:;
@@ -1119,24 +1153,24 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 			{
 				int64 I$4;
 				I$4 = 0ll;
-				int64 TMP$81$4;
-				TMP$81$4 = *(int64*)((uint8*)PROCDEF$1 + 48ll) + -1ll;
+				int64 TMP$85$4;
+				TMP$85$4 = *(int64*)((uint8*)PROCDEF$1 + 48ll) + -1ll;
 				goto label$37;
 				label$40:;
 				{
 					{
-						int64 TMP$89$6;
-						struct $15FB_RTL_PARAMDEF* TMP$82$6;
-						TMP$82$6 = (struct $15FB_RTL_PARAMDEF*)((uint8*)((uint8*)PROCDEF$1 + (I$4 * 40ll)) + 56ll);
+						int64 TMP$93$6;
+						struct $15FB_RTL_PARAMDEF* TMP$86$6;
+						TMP$86$6 = (struct $15FB_RTL_PARAMDEF*)((uint8*)((uint8*)PROCDEF$1 + (I$4 << (5ll & 63ll))) + 56ll);
 						struct $8FBSYMBOL* SUBTYPE$6;
 						SUBTYPE$6 = (struct $8FBSYMBOL*)0ull;
 						int64 DTYPE$6;
 						struct $7ASTNODE* PARAM_OPTVAL$6;
-						if( *(int64*)((uint8*)TMP$82$6 + 16ll) == 0ll ) goto label$42;
+						if( *(int64*)((uint8*)TMP$86$6 + 16ll) == 0ll ) goto label$42;
 						{
 							{
-								uint64 TMP$83$8;
-								TMP$83$8 = (uint64)(*(int64*)TMP$82$6 & 511ll);
+								uint64 TMP$87$8;
+								TMP$87$8 = (uint64)(*(int64*)TMP$86$6 & 511ll);
 								goto label$44;
 								label$45:;
 								{
@@ -1146,7 +1180,7 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 								goto label$43;
 								label$46:;
 								{
-									struct $7ASTNODE* vr$33 = ASTNEWCONSTF( (double)*(int64*)((uint8*)TMP$82$6 + 24ll), *(int64*)TMP$82$6 );
+									struct $7ASTNODE* vr$33 = ASTNEWCONSTF( (double)*(int64*)((uint8*)TMP$86$6 + 24ll), *(int64*)TMP$86$6 );
 									PARAM_OPTVAL$6 = vr$33;
 								}
 								goto label$43;
@@ -1159,21 +1193,21 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 									{
 										int64 FUNC_ARG$10;
 										FUNC_ARG$10 = 0ll;
-										int64 TMP$84$10;
-										TMP$84$10 = *(int64*)((uint8*)TMP$82$6 + 24ll) + -1ll;
+										int64 TMP$88$10;
+										TMP$88$10 = *(int64*)((uint8*)TMP$86$6 + 24ll) + -1ll;
 										goto label$48;
 										label$51:;
 										{
 											I$4 = I$4 + 1ll;
 											{
-												int64 TMP$87$12;
-												struct $15FB_RTL_PARAMDEF* TMP$85$12;
-												TMP$85$12 = (struct $15FB_RTL_PARAMDEF*)((uint8*)((uint8*)PROCDEF$1 + (I$4 * 40ll)) + 56ll);
-												if( *(int64*)((uint8*)TMP$85$12 + 16ll) == 0ll ) goto label$53;
+												int64 TMP$91$12;
+												struct $15FB_RTL_PARAMDEF* TMP$89$12;
+												TMP$89$12 = (struct $15FB_RTL_PARAMDEF*)((uint8*)((uint8*)PROCDEF$1 + (I$4 << (5ll & 63ll))) + 56ll);
+												if( *(int64*)((uint8*)TMP$89$12 + 16ll) == 0ll ) goto label$53;
 												{
 													{
-														uint64 TMP$86$14;
-														TMP$86$14 = (uint64)(*(int64*)TMP$85$12 & 511ll);
+														uint64 TMP$90$14;
+														TMP$90$14 = (uint64)(*(int64*)TMP$89$12 & 511ll);
 														goto label$55;
 														label$56:;
 														{
@@ -1183,24 +1217,24 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 														goto label$54;
 														label$57:;
 														{
-															struct $7ASTNODE* vr$48 = ASTNEWCONSTF( (double)*(int64*)((uint8*)TMP$85$12 + 24ll), *(int64*)TMP$85$12 );
+															struct $7ASTNODE* vr$48 = ASTNEWCONSTF( (double)*(int64*)((uint8*)TMP$89$12 + 24ll), *(int64*)TMP$89$12 );
 															INNER_PARAM_OPTVAL$9 = vr$48;
 														}
 														goto label$54;
 														label$58:;
 														{
-															struct $7ASTNODE* vr$51 = ASTNEWCONSTI( *(int64*)((uint8*)TMP$85$12 + 24ll), *(int64*)TMP$85$12, (struct $8FBSYMBOL*)0ull );
+															struct $7ASTNODE* vr$51 = ASTNEWCONSTI( *(int64*)((uint8*)TMP$89$12 + 24ll), *(int64*)TMP$89$12, (struct $8FBSYMBOL*)0ull );
 															INNER_PARAM_OPTVAL$9 = vr$51;
 														}
 														goto label$54;
 														label$55:;
-														static const void* tmp$92[3ll] = {
+														static const void* tmp$96[3ll] = {
 															&&label$57,
 															&&label$57,
 															&&label$56,
 														};
-														if( (TMP$86$14 - 15ull) > 2ull ) goto label$58;
-														goto *tmp$92[TMP$86$14 - 15ull];
+														if( (TMP$90$14 - 15ull) > 2ull ) goto label$58;
+														goto *tmp$96[TMP$90$14 - 15ull];
 														label$54:;
 													}
 												}
@@ -1210,13 +1244,13 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 													INNER_PARAM_OPTVAL$9 = (struct $7ASTNODE*)0ull;
 												}
 												label$52:;
-												if( *(int64*)((uint8*)TMP$85$12 + 8ll) != 3ll ) goto label$59;
-												TMP$87$12 = -1ll;
+												if( *(int64*)((uint8*)TMP$89$12 + 8ll) != 3ll ) goto label$59;
+												TMP$91$12 = -1ll;
 												goto label$82;
 												label$59:;
-												TMP$87$12 = 0ll;
+												TMP$91$12 = 0ll;
 												label$82:;
-												struct $8FBSYMBOL* vr$55 = SYMBADDPROCPARAM( INNER_PROC$9, (uint8*)0ull, *(int64*)TMP$85$12, (struct $8FBSYMBOL*)0ull, TMP$87$12, *(int64*)((uint8*)TMP$85$12 + 8ll), 0ll );
+												struct $8FBSYMBOL* vr$55 = SYMBADDPROCPARAM( INNER_PROC$9, (uint8*)0ull, *(int64*)TMP$89$12, (struct $8FBSYMBOL*)0ull, TMP$91$12, *(int64*)((uint8*)TMP$89$12 + 8ll), 0ll, 0ll );
 												PARAM$1 = vr$55;
 												SYMBMAKEPARAMOPTIONAL( INNER_PROC$9, PARAM$1, INNER_PARAM_OPTVAL$9 );
 											}
@@ -1224,14 +1258,14 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 										label$49:;
 										FUNC_ARG$10 = FUNC_ARG$10 + 1ll;
 										label$48:;
-										if( FUNC_ARG$10 <= TMP$84$10 ) goto label$51;
+										if( FUNC_ARG$10 <= TMP$88$10 ) goto label$51;
 										label$50:;
 									}
 									I$4 = I$4 + 1ll;
 									{
-										struct $15FB_RTL_PARAMDEF* TMP$88$10;
-										TMP$88$10 = (struct $15FB_RTL_PARAMDEF*)((uint8*)((uint8*)PROCDEF$1 + (I$4 * 40ll)) + 56ll);
-										struct $8FBSYMBOL* vr$62 = SYMBADDPROCPTR( INNER_PROC$9, *(int64*)TMP$88$10, (struct $8FBSYMBOL*)0ull, 0ll, *(int64*)((uint8*)&ENV$ + 504ll) );
+										struct $15FB_RTL_PARAMDEF* TMP$92$10;
+										TMP$92$10 = (struct $15FB_RTL_PARAMDEF*)((uint8*)((uint8*)PROCDEF$1 + (I$4 << (5ll & 63ll))) + 56ll);
+										struct $8FBSYMBOL* vr$62 = SYMBADDPROCPTR( INNER_PROC$9, *(int64*)TMP$92$10, (struct $8FBSYMBOL*)0ull, 0ll, 0ll, *(int64*)((uint8*)&ENV$ + 536ll) );
 										SUBTYPE$6 = vr$62;
 									}
 									PARAM_OPTVAL$6 = (struct $7ASTNODE*)0ull;
@@ -1239,12 +1273,12 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 								goto label$43;
 								label$60:;
 								{
-									struct $7ASTNODE* vr$65 = ASTNEWCONSTI( *(int64*)((uint8*)TMP$82$6 + 24ll), *(int64*)TMP$82$6, (struct $8FBSYMBOL*)0ull );
+									struct $7ASTNODE* vr$65 = ASTNEWCONSTI( *(int64*)((uint8*)TMP$86$6 + 24ll), *(int64*)TMP$86$6, (struct $8FBSYMBOL*)0ull );
 									PARAM_OPTVAL$6 = vr$65;
 								}
 								goto label$43;
 								label$44:;
-								static const void* tmp$93[40ll] = {
+								static const void* tmp$97[40ll] = {
 									&&label$46,
 									&&label$46,
 									&&label$45,
@@ -1286,8 +1320,8 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 									&&label$60,
 									&&label$47,
 								};
-								if( (TMP$83$8 - 15ull) > 39ull ) goto label$60;
-								goto *tmp$93[TMP$83$8 - 15ull];
+								if( (TMP$87$8 - 15ull) > 39ull ) goto label$60;
+								goto *tmp$97[TMP$87$8 - 15ull];
 								label$43:;
 							}
 						}
@@ -1297,20 +1331,20 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 							PARAM_OPTVAL$6 = (struct $7ASTNODE*)0ull;
 						}
 						label$41:;
-						DTYPE$6 = *(int64*)TMP$82$6;
+						DTYPE$6 = *(int64*)TMP$86$6;
 						if( DTYPE$6 != 2147483648ll ) goto label$62;
 						{
 							DTYPE$6 = 32ll;
 						}
 						label$62:;
 						label$61:;
-						if( *(int64*)((uint8*)TMP$82$6 + 8ll) != 3ll ) goto label$63;
-						TMP$89$6 = -1ll;
+						if( *(int64*)((uint8*)TMP$86$6 + 8ll) != 3ll ) goto label$63;
+						TMP$93$6 = -1ll;
 						goto label$83;
 						label$63:;
-						TMP$89$6 = 0ll;
+						TMP$93$6 = 0ll;
 						label$83:;
-						struct $8FBSYMBOL* vr$69 = SYMBADDPROCPARAM( PROC$3, (uint8*)0ull, DTYPE$6, SUBTYPE$6, TMP$89$6, *(int64*)((uint8*)TMP$82$6 + 8ll), 0ll );
+						struct $8FBSYMBOL* vr$69 = SYMBADDPROCPARAM( PROC$3, (uint8*)0ull, DTYPE$6, SUBTYPE$6, TMP$93$6, *(int64*)((uint8*)TMP$86$6 + 8ll), 0ll, 0ll );
 						PARAM$1 = vr$69;
 						SYMBMAKEPARAMOPTIONAL( PROC$3, PARAM$1, PARAM_OPTVAL$6 );
 					}
@@ -1318,20 +1352,22 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 				label$38:;
 				I$4 = I$4 + 1ll;
 				label$37:;
-				if( I$4 <= TMP$81$4 ) goto label$40;
+				if( I$4 <= TMP$85$4 ) goto label$40;
 				label$39:;
 			}
 			$13FB_SYMBATTRIB ATTRIB$3;
 			ATTRIB$3 = 0ll;
+			$13FB_PROCATTRIB PATTRIB$3;
+			PATTRIB$3 = 0ll;
 			if( (*(int64*)((uint8*)PROCDEF$1 + 40ll) & 1ll) == 0ll ) goto label$65;
 			{
-				ATTRIB$3 = 1024ll;
+				PATTRIB$3 = 1ll;
 			}
 			label$65:;
 			label$64:;
 			if( (*(int64*)((uint8*)PROCDEF$1 + 40ll) & 64ll) == 0ll ) goto label$67;
 			{
-				ATTRIB$3 = ATTRIB$3 | 268435456ll;
+				ATTRIB$3 = ATTRIB$3 | 1048576ll;
 			}
 			label$67:;
 			label$66:;
@@ -1343,7 +1379,7 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 			{
 				if( *(int64*)((uint8*)&ENV$ + 272ll) != 3ll ) goto label$71;
 				{
-					FBSTRING TMP$91$5;
+					FBSTRING TMP$95$5;
 					if( PALIAS$3 != (uint8*)0ull ) goto label$73;
 					{
 						static FBSTRING TMP_ALIAS$6;
@@ -1353,9 +1389,9 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 					label$73:;
 					label$72:;
 					static FBSTRING TMP_NAME$5;
-					__builtin_memset( &TMP$91$5, 0, 24ll );
-					FBSTRING* vr$82 = fb_StrConcat( &TMP$91$5, (void*)"__", 3ll, (void*)PNAME$3, 0ll );
-					FBSTRING* vr$83 = fb_StrAssign( (void*)&TMP_NAME$5, -1ll, (void*)vr$82, -1ll, 0 );
+					__builtin_memset( &TMP$95$5, 0, 24ll );
+					FBSTRING* vr$82 = fb_StrConcat( &TMP$95$5, (void*)"__", 3ll, (void*)PNAME$3, 0ll );
+					fb_StrAssign( (void*)&TMP_NAME$5, -1ll, (void*)vr$82, -1ll, 0 );
 					PNAME$3 = (uint8*)*(uint8**)&TMP_NAME$5;
 				}
 				label$71:;
@@ -1369,20 +1405,20 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 			}
 			label$75:;
 			label$74:;
-			struct $8FBSYMBOL* vr$85 = SYMBADDPROC( PROC$3, PNAME$3, PALIAS$3, *(int64*)((uint8*)PROCDEF$1 + 16ll), (struct $8FBSYMBOL*)0ull, ATTRIB$3, CALLCONV$1, 20ll );
-			PROC$3 = vr$85;
+			struct $8FBSYMBOL* vr$84 = SYMBADDPROC( PROC$3, PNAME$3, PALIAS$3, *(int64*)((uint8*)PROCDEF$1 + 16ll), (struct $8FBSYMBOL*)0ull, ATTRIB$3, PATTRIB$3, CALLCONV$1, 20ll );
+			PROC$3 = vr$84;
 			if( PROC$3 == (struct $8FBSYMBOL*)0ull ) goto label$77;
 			{
-				*(tmp$29*)((uint8*)PROC$3 + 176ll) = (tmp$29)*(tmp$29*)((uint8*)PROCDEF$1 + 32ll);
+				*(tmp$34*)((uint8*)PROC$3 + 184ll) = (tmp$34)*(tmp$34*)((uint8*)PROCDEF$1 + 32ll);
 				if( (*(int64*)((uint8*)PROCDEF$1 + 40ll) & 2ll) == 0ll ) goto label$79;
 				{
-					*($12FB_SYMBSTATS*)((uint8*)PROC$3 + 16ll) = *(int64*)((uint8*)PROC$3 + 16ll) | 64ll;
+					*($12FB_SYMBSTATS*)((uint8*)PROC$3 + 24ll) = *(int64*)((uint8*)PROC$3 + 24ll) | 64ll;
 				}
 				label$79:;
 				label$78:;
 				if( (*(int64*)((uint8*)PROCDEF$1 + 40ll) & 2048ll) == 0ll ) goto label$81;
 				{
-					*($12FB_SYMBSTATS*)((uint8*)PROC$3 + 16ll) = *(int64*)((uint8*)PROC$3 + 16ll) | 524288ll;
+					*($12FB_SYMBSTATS*)((uint8*)PROC$3 + 24ll) = *(int64*)((uint8*)PROC$3 + 24ll) | 524288ll;
 				}
 				label$81:;
 				label$80:;
@@ -1396,7 +1432,7 @@ void RTLADDINTRINSICPROCS( struct $14FB_RTL_PROCDEF* PROCDEF$1 )
 		}
 		label$36:;
 		label$35:;
-		PROCDEF$1 = (struct $14FB_RTL_PROCDEF*)((uint8*)PROCDEF$1 + 696ll);
+		PROCDEF$1 = (struct $14FB_RTL_PROCDEF*)((uint8*)PROCDEF$1 + 568ll);
 	}
 	label$18:;
 	goto label$16;
@@ -1410,7 +1446,7 @@ struct $8FBSYMBOL* RTLPROCLOOKUP( uint8* PNAME$1, int64 PIDX$1 )
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$84:;
 	struct $10FBSYMCHAIN* CHAIN_$1;
-	if( *(struct $8FBSYMBOL**)((uint8*)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll))) != (struct $8FBSYMBOL*)0ull ) goto label$87;
+	if( *(struct $8FBSYMBOL**)((int64)(struct $8FBSYMBOL**)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll))) != (struct $8FBSYMBOL*)0ull ) goto label$87;
 	{
 		struct $10FBSYMCHAIN* vr$3 = SYMBLOOKUPAT( (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll), PNAME$1, 0ll, 0ll );
 		CHAIN_$1 = vr$3;
@@ -1418,23 +1454,23 @@ struct $8FBSYMBOL* RTLPROCLOOKUP( uint8* PNAME$1, int64 PIDX$1 )
 		{
 			if( *(int64*)((uint8*)&ENV$ + 272ll) != 3ll ) goto label$91;
 			{
-				FBSTRING TMP$94$4;
+				FBSTRING TMP$98$4;
 				static FBSTRING TMP_NAME$4;
-				__builtin_memset( &TMP$94$4, 0, 24ll );
-				FBSTRING* vr$6 = fb_StrConcat( &TMP$94$4, (void*)"__", 3ll, (void*)PNAME$1, 0ll );
-				FBSTRING* vr$7 = fb_StrAssign( (void*)&TMP_NAME$4, -1ll, (void*)vr$6, -1ll, 0 );
+				__builtin_memset( &TMP$98$4, 0, 24ll );
+				FBSTRING* vr$6 = fb_StrConcat( &TMP$98$4, (void*)"__", 3ll, (void*)PNAME$1, 0ll );
+				fb_StrAssign( (void*)&TMP_NAME$4, -1ll, (void*)vr$6, -1ll, 0 );
 				PNAME$1 = (uint8*)*(uint8**)&TMP_NAME$4;
-				struct $10FBSYMCHAIN* vr$9 = SYMBLOOKUPAT( (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll), PNAME$1, 0ll, 0ll );
-				CHAIN_$1 = vr$9;
+				struct $10FBSYMCHAIN* vr$8 = SYMBLOOKUPAT( (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll), PNAME$1, 0ll, 0ll );
+				CHAIN_$1 = vr$8;
 				if( CHAIN_$1 != (struct $10FBSYMCHAIN*)0ull ) goto label$93;
 				{
 					ERRREPORTEX( 8ll, PNAME$1, 0ll, 1ll, (uint8*)0ull );
-					*(struct $8FBSYMBOL**)((uint8*)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll))) = (struct $8FBSYMBOL*)0ull;
+					*(struct $8FBSYMBOL**)((int64)(struct $8FBSYMBOL**)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll))) = (struct $8FBSYMBOL*)0ull;
 				}
 				goto label$92;
 				label$93:;
 				{
-					*(struct $8FBSYMBOL**)((uint8*)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll))) = *(struct $8FBSYMBOL**)CHAIN_$1;
+					*(struct $8FBSYMBOL**)((int64)(struct $8FBSYMBOL**)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll))) = *(struct $8FBSYMBOL**)CHAIN_$1;
 				}
 				label$92:;
 			}
@@ -1442,20 +1478,20 @@ struct $8FBSYMBOL* RTLPROCLOOKUP( uint8* PNAME$1, int64 PIDX$1 )
 			label$91:;
 			{
 				ERRREPORTEX( 8ll, PNAME$1, 0ll, 1ll, (uint8*)0ull );
-				*(struct $8FBSYMBOL**)((uint8*)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll))) = (struct $8FBSYMBOL*)0ull;
+				*(struct $8FBSYMBOL**)((int64)(struct $8FBSYMBOL**)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll))) = (struct $8FBSYMBOL*)0ull;
 			}
 			label$90:;
 		}
 		goto label$88;
 		label$89:;
 		{
-			*(struct $8FBSYMBOL**)((uint8*)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll))) = *(struct $8FBSYMBOL**)CHAIN_$1;
+			*(struct $8FBSYMBOL**)((int64)(struct $8FBSYMBOL**)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll))) = *(struct $8FBSYMBOL**)CHAIN_$1;
 		}
 		label$88:;
 	}
 	label$87:;
 	label$86:;
-	fb$result$1 = *(struct $8FBSYMBOL**)((uint8*)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll)));
+	fb$result$1 = *(struct $8FBSYMBOL**)((int64)(struct $8FBSYMBOL**)RTLLOOKUPTB$ + (PIDX$1 << (3ll & 63ll)));
 	label$85:;
 	return fb$result$1;
 }
@@ -1535,8 +1571,8 @@ int64 RTLCALCEXPRLEN( struct $7ASTNODE* EXPR$1 )
 	int64 DTYPE$1;
 	DTYPE$1 = *(int64*)((uint8*)EXPR$1 + 8ll) & 511ll;
 	{
-		uint64 TMP$95$2;
-		TMP$95$2 = (uint64)DTYPE$1;
+		uint64 TMP$99$2;
+		TMP$99$2 = (uint64)DTYPE$1;
 		goto label$107;
 		label$108:;
 		{
@@ -1551,7 +1587,7 @@ int64 RTLCALCEXPRLEN( struct $7ASTNODE* EXPR$1 )
 		}
 		goto label$106;
 		label$107:;
-		static const void* tmp$96[15ll] = {
+		static const void* tmp$100[15ll] = {
 			&&label$108,
 			&&label$109,
 			&&label$109,
@@ -1568,8 +1604,8 @@ int64 RTLCALCEXPRLEN( struct $7ASTNODE* EXPR$1 )
 			&&label$109,
 			&&label$108,
 		};
-		if( (TMP$95$2 - 4ull) > 14ull ) goto label$109;
-		goto *tmp$96[TMP$95$2 - 4ull];
+		if( (TMP$99$2 - 4ull) > 14ull ) goto label$109;
+		goto *tmp$100[TMP$99$2 - 4ull];
 		label$106:;
 	}
 	label$105:;
@@ -1584,15 +1620,15 @@ int64 RTLCALCSTRLEN( struct $7ASTNODE* EXPR$1, int64 DTYPE$1 )
 	struct $8FBSYMBOL* S$1;
 	__builtin_memset( &S$1, 0, 8ll );
 	{
-		int64 TMP$97$2;
-		uint64 TMP$98$2;
+		int64 TMP$101$2;
+		uint64 TMP$102$2;
 		if( (DTYPE$1 & 480ll) == 0ll ) goto label$112;
-		TMP$97$2 = 24ll;
+		TMP$101$2 = 24ll;
 		goto label$127;
 		label$112:;
-		TMP$97$2 = DTYPE$1 & 31ll;
+		TMP$101$2 = DTYPE$1 & 31ll;
 		label$127:;
-		TMP$98$2 = (uint64)TMP$97$2;
+		TMP$102$2 = (uint64)TMP$101$2;
 		goto label$114;
 		label$115:;
 		{
@@ -1609,14 +1645,14 @@ int64 RTLCALCSTRLEN( struct $7ASTNODE* EXPR$1, int64 DTYPE$1 )
 			goto label$117;
 			label$118:;
 			{
-				if( (*(int64*)((uint8*)S$1 + 48ll) & 511ll) == (DTYPE$1 & 511ll) ) goto label$120;
+				if( (*(int64*)((uint8*)S$1 + 56ll) & 511ll) == (DTYPE$1 & 511ll) ) goto label$120;
 				{
 					fb$result$1 = 0ll;
 				}
 				goto label$119;
 				label$120:;
 				{
-					fb$result$1 = *(int64*)((uint8*)S$1 + 72ll);
+					fb$result$1 = *(int64*)((uint8*)S$1 + 80ll);
 				}
 				label$119:;
 			}
@@ -1633,14 +1669,14 @@ int64 RTLCALCSTRLEN( struct $7ASTNODE* EXPR$1, int64 DTYPE$1 )
 			goto label$122;
 			label$123:;
 			{
-				if( (*(int64*)((uint8*)S$1 + 48ll) & 511ll) == (DTYPE$1 & 511ll) ) goto label$125;
+				if( (*(int64*)((uint8*)S$1 + 56ll) & 511ll) == (DTYPE$1 & 511ll) ) goto label$125;
 				{
 					fb$result$1 = 0ll;
 				}
 				goto label$124;
 				label$125:;
 				{
-					fb$result$1 = *(int64*)((uint8*)S$1 + 72ll) / *(int64*)((uint8*)SYMB_DTYPETB$ + 400ll);
+					fb$result$1 = *(int64*)((uint8*)S$1 + 80ll) / *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 400ll);
 				}
 				label$124:;
 			}
@@ -1653,7 +1689,7 @@ int64 RTLCALCSTRLEN( struct $7ASTNODE* EXPR$1, int64 DTYPE$1 )
 		}
 		goto label$113;
 		label$114:;
-		static const void* tmp$99[17ll] = {
+		static const void* tmp$103[17ll] = {
 			&&label$115,
 			&&label$115,
 			&&label$116,
@@ -1672,8 +1708,8 @@ int64 RTLCALCSTRLEN( struct $7ASTNODE* EXPR$1, int64 DTYPE$1 )
 			&&label$126,
 			&&label$116,
 		};
-		if( (TMP$98$2 - 2ull) > 16ull ) goto label$126;
-		goto *tmp$99[TMP$98$2 - 2ull];
+		if( (TMP$102$2 - 2ull) > 16ull ) goto label$126;
+		goto *tmp$103[TMP$102$2 - 2ull];
 		label$113:;
 	}
 	label$111:;
@@ -1689,7 +1725,7 @@ __attribute__(( constructor )) static void fb_ctor__rtl( void )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
