@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,9 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+typedef FBSTRING* (*tmp$29)( void*, int64* );
+typedef uint16* (*tmp$30)( void*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +513,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +582,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,22 +612,56 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
+typedef int64 $12FB_DATACLASS;
+struct $13SYMB_DATATYPE {
+	$12FB_DATACLASS CLASS;
+	int64 SIZE;
+	int64 SIGNED;
+	int64 INTRANK;
+	$11FB_DATATYPE REMAPTYPE;
+	int64 SIZETYPE;
+	uint8* NAME;
+};
+__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 struct $16__FB_ARRAYDIMTB$ {
 	int64 ELEMENTS;
 	int64 LBOUND;
 	int64 UBOUND;
 };
 __FB_STATIC_ASSERT( sizeof( struct $16__FB_ARRAYDIMTB$ ) == 24 );
+struct $8FBARRAY1I10FBARRAYDIME {
+	struct $10FBARRAYDIM* DATA;
+	struct $10FBARRAYDIM* PTR;
+	int64 SIZE;
+	int64 ELEMENT_LEN;
+	int64 DIMENSIONS;
+	int64 FLAGS;
+	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
+};
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10FBARRAYDIME ) == 72 );
 struct $7FBARRAYI10FBARRAYDIME {
 	struct $10FBARRAYDIM* DATA;
 	struct $10FBARRAYDIM* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[8];
 };
-__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYI10FBARRAYDIME ) == 232 );
+__FB_STATIC_ASSERT( sizeof( struct $7FBARRAYI10FBARRAYDIME ) == 240 );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -622,6 +671,7 @@ FBSTRING* fb_StrInit( void*, int64, void*, int64, int32 );
 FBSTRING* fb_StrAssign( void*, int64, void*, int64, int32 );
 uint16* fb_WstrAssign( uint16*, int64, uint16* );
 void fb_StrDelete( FBSTRING* );
+void fb_WstrDelete( uint16* );
 FBSTRING* fb_StrConcat( FBSTRING*, void*, int64, void*, int64 );
 FBSTRING* fb_StrConcatAssign( void*, int64, void*, int64, int32 );
 FBSTRING* fb_StrAllocTempResult( FBSTRING* );
@@ -629,8 +679,10 @@ FBSTRING* fb_LongintToStr( int64 );
 FBSTRING* fb_ULongintToStr( uint64 );
 FBSTRING* fb_FloatToStr( float );
 FBSTRING* fb_DoubleToStr( double );
+uint16* fb_StrToWstr( uint8* );
 int64 fb_StrLen( void*, int64 );
 int64 fb_WstrLen( uint16* );
+FBSTRING* fb_HEXEx_i( uint32, int32 );
 FBSTRING* fb_HEXEx_l( uint64, int32 );
 static void fb_ctor__symbzconst( void ) __attribute__(( constructor ));
 void* XALLOCATE( int32 );
@@ -639,14 +691,20 @@ typedef int64 $12FB_ERRMSGOPT;
 void ERRREPORTWARN( int64, uint8*, $12FB_ERRMSGOPT, uint8* );
 struct $8FBSYMBOL* SYMBLOOKUPBYNAMEANDCLASS( struct $8FBSYMBOL*, uint8*, int64, int64, int64 );
 typedef int64 $10FB_SYMBOPT;
-struct $8FBSYMBOL* SYMBADDVAR( uint8*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, struct $7FBARRAYI10FBARRAYDIME*, int64, $10FB_SYMBOPT );
-struct $8FBSYMBOL* SYMBADDCONST( uint8*, int64, struct $8FBSYMBOL*, union $7FBVALUE*, int64 );
-struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB );
+struct $8FBSYMBOL* SYMBADDVAR( uint8*, uint8*, int64, struct $8FBSYMBOL*, int64, int64, struct $7FBARRAYI10FBARRAYDIME*, $13FB_SYMBATTRIB, $10FB_SYMBOPT );
+struct $8FBSYMBOL* SYMBADDCONST( uint8*, int64, struct $8FBSYMBOL*, union $7FBVALUE*, $13FB_SYMBATTRIB );
+struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB, $13FB_PROCATTRIB );
 void SYMBFREESYMBOL( struct $8FBSYMBOL* );
 void SYMBDELFROMHASH( struct $8FBSYMBOL* );
-uint8* SYMBUNIQUEID( void );
+uint8* SYMBUNIQUEID( boolean );
 FBSTRING* HFLOATTOHEX( double, int64 );
 uint8* HESCAPEW( uint16* );
+uint8* HUNESCAPE( uint8*, int64* );
+uint16* HUNESCAPEW( uint16*, int64* );
+void DZSTRASSIGN( struct $8DZSTRING*, uint8* );
+void DZSTRCONCATASSIGN( struct $8DZSTRING*, uint8* );
+void DWSTRASSIGN( struct $8DWSTRING*, uint16* );
+void DWSTRCONCATASSIGN( struct $8DWSTRING*, uint16* );
 static struct $8FBSYMBOL* HALLOCINTORFLOATCONST( FBSTRING*, int64 );
 typedef int64 $11AST_OPFLAGS;
 struct $10AST_OPINFO {
@@ -662,10 +720,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -699,6 +758,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -707,11 +770,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -764,19 +828,8 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
-typedef int64 $12FB_DATACLASS;
-struct $13SYMB_DATATYPE {
-	$12FB_DATACLASS CLASS;
-	int64 SIZE;
-	int64 SIGNED;
-	int64 INTRANK;
-	$11FB_DATATYPE REMAPTYPE;
-	int64 SIZETYPE;
-	uint8* NAME;
-};
-__FB_STATIC_ASSERT( sizeof( struct $13SYMB_DATATYPE ) == 56 );
 extern struct $13SYMB_DATATYPE SYMB_DTYPETB$[26];
 struct $8FBARRAY1I13SYMB_DATATYPEE {
 	struct $13SYMB_DATATYPE* DATA;
@@ -784,29 +837,31 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
-struct $8FBSYMBOL* SYMBADDCONST( uint8* SYMBOL$1, int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, union $7FBVALUE* VALUE$1, int64 ATTRIB$1 )
+struct $8FBSYMBOL* SYMBADDCONST( uint8* SYMBOL$1, int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, union $7FBVALUE* VALUE$1, $13FB_SYMBATTRIB ATTRIB$1 )
 {
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
 	struct $8FBSYMBOL* SYM$1;
 	fb$result$1 = (struct $8FBSYMBOL*)0ull;
-	struct $8FBSYMBOL* vr$1 = SYMBNEWSYMBOL( 32ll, (struct $8FBSYMBOL*)0ull, (struct $10FBSYMBOLTB*)0ull, (struct $8FBHASHTB*)0ull, 2ll, (uint8*)SYMBOL$1, (uint8*)0ull, DTYPE$1, SUBTYPE$1, ATTRIB$1 );
+	struct $8FBSYMBOL* vr$1 = SYMBNEWSYMBOL( 32ll, (struct $8FBSYMBOL*)0ull, (struct $10FBSYMBOLTB*)0ull, (struct $8FBHASHTB*)0ull, 2ll, (uint8*)SYMBOL$1, (uint8*)0ull, DTYPE$1, SUBTYPE$1, ATTRIB$1, 0ll );
 	SYM$1 = vr$1;
 	if( SYM$1 != (struct $8FBSYMBOL*)0ull ) goto label$13;
 	{
@@ -814,13 +869,13 @@ struct $8FBSYMBOL* SYMBADDCONST( uint8* SYMBOL$1, int64 DTYPE$1, struct $8FBSYMB
 	}
 	label$13:;
 	label$12:;
-	__builtin_memcpy( (union $7FBVALUE*)((uint8*)SYM$1 + 88ll), VALUE$1, 8 );
+	__builtin_memcpy( (union $7FBVALUE*)((uint8*)SYM$1 + 96ll), VALUE$1, 8 );
 	fb$result$1 = SYM$1;
 	label$11:;
 	return fb$result$1;
 }
 
-struct $8FBSYMBOL* SYMBREUSEORADDCONST( uint8* ID$1, int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, union $7FBVALUE* VALUE$1, int64 ATTRIB$1 )
+struct $8FBSYMBOL* SYMBREUSEORADDCONST( uint8* ID$1, int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1, union $7FBVALUE* VALUE$1, $13FB_SYMBATTRIB ATTRIB$1 )
 {
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
@@ -831,7 +886,7 @@ struct $8FBSYMBOL* SYMBREUSEORADDCONST( uint8* ID$1, int64 DTYPE$1, struct $8FBS
 	SYM$1 = vr$1;
 	if( SYM$1 != (struct $8FBSYMBOL*)0ull ) goto label$17;
 	{
-		struct $8FBSYMBOL* vr$2 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll), (uint8*)ID$1, 2ll, 0ll, 0ll );
+		struct $8FBSYMBOL* vr$2 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll), (uint8*)ID$1, 2ll, 0ll, 0ll );
 		SYM$1 = vr$2;
 		if( SYM$1 != (struct $8FBSYMBOL*)0ull ) goto label$19;
 		{
@@ -841,33 +896,33 @@ struct $8FBSYMBOL* SYMBREUSEORADDCONST( uint8* ID$1, int64 DTYPE$1, struct $8FBS
 		label$18:;
 		int64 IS_SAME$2;
 		IS_SAME$2 = 0ll;
-		if( ((int64)-(*(int64*)((uint8*)SYM$1 + 48ll) == DTYPE$1) & (int64)-(*(struct $8FBSYMBOL**)((uint8*)SYM$1 + 56ll) == SUBTYPE$1)) == 0ll ) goto label$21;
+		if( ((int64)-(*(int64*)((uint8*)SYM$1 + 56ll) == DTYPE$1) & (int64)-(*(struct $8FBSYMBOL**)((uint8*)SYM$1 + 64ll) == SUBTYPE$1)) == 0ll ) goto label$21;
 		{
 			{
-				int64 TMP$79$4;
-				TMP$79$4 = DTYPE$1 & 511ll;
-				if( TMP$79$4 == 17ll ) goto label$24;
+				int64 TMP$83$4;
+				TMP$83$4 = DTYPE$1 & 511ll;
+				if( TMP$83$4 == 17ll ) goto label$24;
 				label$25:;
-				if( TMP$79$4 == 4ll ) goto label$24;
+				if( TMP$83$4 == 4ll ) goto label$24;
 				label$26:;
-				if( TMP$79$4 != 7ll ) goto label$23;
+				if( TMP$83$4 != 7ll ) goto label$23;
 				label$24:;
 				{
-					IS_SAME$2 = (int64)-(*(struct $8FBSYMBOL**)VALUE$1 == *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 88ll));
+					IS_SAME$2 = (int64)-(*(struct $8FBSYMBOL**)VALUE$1 == *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 96ll));
 				}
 				goto label$22;
 				label$23:;
-				if( TMP$79$4 == 15ll ) goto label$28;
+				if( TMP$83$4 == 15ll ) goto label$28;
 				label$29:;
-				if( TMP$79$4 != 16ll ) goto label$27;
+				if( TMP$83$4 != 16ll ) goto label$27;
 				label$28:;
 				{
-					IS_SAME$2 = (int64)-(*(uint64*)VALUE$1 == *(uint64*)((uint8*)SYM$1 + 88ll));
+					IS_SAME$2 = (int64)-(*(uint64*)VALUE$1 == *(uint64*)((uint8*)SYM$1 + 96ll));
 				}
 				goto label$22;
 				label$27:;
 				{
-					IS_SAME$2 = (int64)-(*(int64*)VALUE$1 == *(int64*)((uint8*)SYM$1 + 88ll));
+					IS_SAME$2 = (int64)-(*(int64*)VALUE$1 == *(int64*)((uint8*)SYM$1 + 96ll));
 				}
 				label$30:;
 				label$22:;
@@ -877,7 +932,7 @@ struct $8FBSYMBOL* SYMBREUSEORADDCONST( uint8* ID$1, int64 DTYPE$1, struct $8FBS
 		label$20:;
 		if( IS_SAME$2 != 0ll ) goto label$32;
 		{
-			if( (*(int64*)((uint8*)SYM$1 + 16ll) & 1048576ll) == 0ll ) goto label$34;
+			if( (*(int64*)((uint8*)SYM$1 + 24ll) & 1048576ll) == 0ll ) goto label$34;
 			{
 				ERRREPORTWARN( 39ll, (uint8*)0ull, 1ll, (uint8*)0ull );
 				SYMBDELFROMHASH( SYM$1 );
@@ -894,7 +949,7 @@ struct $8FBSYMBOL* SYMBREUSEORADDCONST( uint8* ID$1, int64 DTYPE$1, struct $8FBS
 		goto label$31;
 		label$32:;
 		{
-			*($12FB_SYMBSTATS*)((uint8*)SYM$1 + 16ll) = *(int64*)((uint8*)SYM$1 + 16ll) & -1048577ll;
+			*($12FB_SYMBSTATS*)((uint8*)SYM$1 + 24ll) = *(int64*)((uint8*)SYM$1 + 24ll) & -1048577ll;
 		}
 		label$31:;
 	}
@@ -907,48 +962,48 @@ struct $8FBSYMBOL* SYMBREUSEORADDCONST( uint8* ID$1, int64 DTYPE$1, struct $8FBS
 
 struct $8FBSYMBOL* SYMBALLOCFLOATCONST( double VALUE$1, int64 DTYPE$1 )
 {
-	FBSTRING TMP$83$1;
+	FBSTRING TMP$87$1;
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$39:;
-	__builtin_memset( &TMP$83$1, 0, 24ll );
+	__builtin_memset( &TMP$87$1, 0, 24ll );
 	FBSTRING* vr$2 = HFLOATTOHEX( VALUE$1, DTYPE$1 );
-	FBSTRING* vr$4 = fb_StrAssign( (void*)&TMP$83$1, -1ll, (void*)vr$2, -1ll, 0 );
-	struct $8FBSYMBOL* vr$6 = HALLOCINTORFLOATCONST( &TMP$83$1, DTYPE$1 );
-	fb$result$1 = vr$6;
-	fb_StrDelete( (FBSTRING*)&TMP$83$1 );
+	fb_StrAssign( (void*)&TMP$87$1, -1ll, (void*)vr$2, -1ll, 0 );
+	struct $8FBSYMBOL* vr$5 = HALLOCINTORFLOATCONST( &TMP$87$1, DTYPE$1 );
+	fb$result$1 = vr$5;
+	fb_StrDelete( (FBSTRING*)&TMP$87$1 );
 	label$40:;
 	return fb$result$1;
 }
 
 struct $8FBSYMBOL* SYMBALLOCINTCONST( int64 VALUE$1, int64 DTYPE$1 )
 {
-	int64 TMP$85$1;
+	int64 TMP$89$1;
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$41:;
 	FBSTRING SVALUE$1;
-	FBSTRING* vr$2 = fb_StrInit( (void*)&SVALUE$1, -1ll, (void*)"0x", 3ll, 0 );
+	fb_StrInit( (void*)&SVALUE$1, -1ll, (void*)"0x", 3ll, 0 );
 	if( (DTYPE$1 & 480ll) == 0ll ) goto label$43;
-	TMP$85$1 = 24ll;
+	TMP$89$1 = 24ll;
 	goto label$46;
 	label$43:;
-	TMP$85$1 = DTYPE$1 & 31ll;
+	TMP$89$1 = DTYPE$1 & 31ll;
 	label$46:;
-	if( *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$85$1 * 56ll)) + 8ll) != 8ll ) goto label$45;
+	if( *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$89$1 * 56ll)) + 8ll) != 8ll ) goto label$45;
 	{
-		FBSTRING* vr$6 = fb_HEXEx_l( (uint64)VALUE$1, 16 );
-		FBSTRING* vr$8 = fb_StrConcatAssign( (void*)&SVALUE$1, -1ll, (void*)vr$6, -1ll, 0 );
+		FBSTRING* vr$5 = fb_HEXEx_l( (uint64)VALUE$1, 16 );
+		fb_StrConcatAssign( (void*)&SVALUE$1, -1ll, (void*)vr$5, -1ll, 0 );
 	}
 	goto label$44;
 	label$45:;
 	{
-		FBSTRING* vr$11 = fb_HEXEx_l( (uint64)(uint32)VALUE$1, 8 );
-		FBSTRING* vr$13 = fb_StrConcatAssign( (void*)&SVALUE$1, -1ll, (void*)vr$11, -1ll, 0 );
+		FBSTRING* vr$9 = fb_HEXEx_l( (uint64)(uint32)VALUE$1, 8 );
+		fb_StrConcatAssign( (void*)&SVALUE$1, -1ll, (void*)vr$9, -1ll, 0 );
 	}
 	label$44:;
-	struct $8FBSYMBOL* vr$15 = HALLOCINTORFLOATCONST( &SVALUE$1, DTYPE$1 );
-	fb$result$1 = vr$15;
+	struct $8FBSYMBOL* vr$12 = HALLOCINTORFLOATCONST( &SVALUE$1, DTYPE$1 );
+	fb$result$1 = vr$12;
 	fb_StrDelete( (FBSTRING*)&SVALUE$1 );
 	label$42:;
 	return fb$result$1;
@@ -962,16 +1017,7 @@ struct $8FBSYMBOL* SYMBALLOCSTRCONST( uint8* SNAME$1, int64 STRLENGTH$1 )
 	static uint8 ID$1[134];
 	static uint8 ID_ALIAS$1[134];
 	static struct $10FBARRAYDIM DTB$1[1];
-	struct $8FBARRAY1I10FBARRAYDIME {
-		struct $10FBARRAYDIM* DATA;
-		struct $10FBARRAYDIM* PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10FBARRAYDIME ) == 64 );
-	static struct $8FBARRAY1I10FBARRAYDIME tmp$86$1 = { (struct $10FBARRAYDIM*)DTB$1, (struct $10FBARRAYDIM*)DTB$1, 16ll, 16ll, 1ll, { { 1ll, 0ll, 0ll } } };
+	static struct $8FBARRAY1I10FBARRAYDIME tmp$90$1 = { (struct $10FBARRAYDIM*)DTB$1, (struct $10FBARRAYDIM*)DTB$1, 16ll, 16ll, 1ll, 49ll, { { 1ll, 0ll, 0ll } } };
 	struct $8FBSYMBOL* S$1;
 	fb$result$1 = (struct $8FBSYMBOL*)0ull;
 	int64 INTERNALSTRLEN$1;
@@ -985,16 +1031,16 @@ struct $8FBSYMBOL* SYMBALLOCSTRCONST( uint8* SNAME$1, int64 STRLENGTH$1 )
 	label$49:;
 	if( INTERNALSTRLEN$1 > 122ll ) goto label$52;
 	{
-		FBSTRING TMP$88$2;
+		FBSTRING TMP$92$2;
 		fb_StrAssign( (void*)ID$1, 134ll, (void*)"{fbsc}", 7ll, 0 );
-		__builtin_memset( &TMP$88$2, 0, 24ll );
-		FBSTRING* vr$4 = fb_StrConcat( &TMP$88$2, (void*)ID$1, 134ll, (void*)SNAME$1, 0ll );
+		__builtin_memset( &TMP$92$2, 0, 24ll );
+		FBSTRING* vr$4 = fb_StrConcat( &TMP$92$2, (void*)ID$1, 134ll, (void*)SNAME$1, 0ll );
 		fb_StrAssign( (void*)ID$1, 134ll, (void*)vr$4, -1ll, 0 );
 	}
 	goto label$51;
 	label$52:;
 	{
-		uint8* vr$5 = SYMBUNIQUEID(  );
+		uint8* vr$5 = SYMBUNIQUEID( (boolean)0ll );
 		fb_StrAssign( (void*)ID$1, 134ll, (void*)vr$5, 0ll, 0 );
 	}
 	label$51:;
@@ -1007,15 +1053,15 @@ struct $8FBSYMBOL* SYMBALLOCSTRCONST( uint8* SNAME$1, int64 STRLENGTH$1 )
 	}
 	label$54:;
 	label$53:;
-	uint8* vr$8 = SYMBUNIQUEID(  );
+	uint8* vr$8 = SYMBUNIQUEID( (boolean)0ll );
 	fb_StrAssign( (void*)ID_ALIAS$1, 134ll, (void*)vr$8, 0ll, 0 );
 	int64 STRSIZE$1;
 	STRSIZE$1 = STRLENGTH$1 + 1ll;
-	struct $8FBSYMBOL* vr$10 = SYMBADDVAR( (uint8*)ID$1, (uint8*)ID_ALIAS$1, 4ll, (struct $8FBSYMBOL*)0ull, STRSIZE$1, 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$86$1, 1572865ll, 137ll );
+	struct $8FBSYMBOL* vr$10 = SYMBADDVAR( (uint8*)ID$1, (uint8*)ID_ALIAS$1, 4ll, (struct $8FBSYMBOL*)0ull, STRSIZE$1, 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$90$1, 3073ll, 137ll );
 	S$1 = vr$10;
 	void* vr$13 = XALLOCATE( (int32)(INTERNALSTRLEN$1 + 1ll) );
-	*(uint8**)((uint8*)S$1 + 88ll) = (uint8*)vr$13;
-	fb_StrAssign( *(void**)((uint8*)S$1 + 88ll), 0ll, (void*)SNAME$1, 0ll, 0 );
+	*(uint8**)((uint8*)S$1 + 96ll) = (uint8*)vr$13;
+	fb_StrAssign( *(void**)((uint8*)S$1 + 96ll), 0ll, (void*)SNAME$1, 0ll, 0 );
 	fb$result$1 = S$1;
 	label$48:;
 	return fb$result$1;
@@ -1029,16 +1075,7 @@ struct $8FBSYMBOL* SYMBALLOCWSTRCONST( uint16* SNAME$1, int64 STRLENGTH$1 )
 	static uint8 ID$1[134];
 	static uint8 ID_ALIAS$1[134];
 	static struct $10FBARRAYDIM DTB$1[1];
-	struct $8FBARRAY1I10FBARRAYDIME {
-		struct $10FBARRAYDIM* DATA;
-		struct $10FBARRAYDIM* PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10FBARRAYDIME ) == 64 );
-	static struct $8FBARRAY1I10FBARRAYDIME tmp$89$1 = { (struct $10FBARRAYDIM*)DTB$1, (struct $10FBARRAYDIM*)DTB$1, 16ll, 16ll, 1ll, { { 1ll, 0ll, 0ll } } };
+	static struct $8FBARRAY1I10FBARRAYDIME tmp$93$1 = { (struct $10FBARRAYDIM*)DTB$1, (struct $10FBARRAYDIM*)DTB$1, 16ll, 16ll, 1ll, 49ll, { { 1ll, 0ll, 0ll } } };
 	struct $8FBSYMBOL* S$1;
 	fb$result$1 = (struct $8FBSYMBOL*)0ull;
 	int64 INTERNALSTRLEN$1;
@@ -1052,17 +1089,17 @@ struct $8FBSYMBOL* SYMBALLOCWSTRCONST( uint16* SNAME$1, int64 STRLENGTH$1 )
 	label$57:;
 	if( (INTERNALSTRLEN$1 << (3ll & 63ll)) > 122ll ) goto label$60;
 	{
-		FBSTRING TMP$91$2;
+		FBSTRING TMP$95$2;
 		fb_StrAssign( (void*)ID$1, 134ll, (void*)"{fbwc}", 7ll, 0 );
-		uint8* vr$3 = HESCAPEW( SNAME$1 );
-		__builtin_memset( &TMP$91$2, 0, 24ll );
-		FBSTRING* vr$6 = fb_StrConcat( &TMP$91$2, (void*)ID$1, 134ll, (void*)vr$3, 0ll );
+		uint8* vr$3 = HESCAPEW( (uint16*)SNAME$1 );
+		__builtin_memset( &TMP$95$2, 0, 24ll );
+		FBSTRING* vr$6 = fb_StrConcat( &TMP$95$2, (void*)ID$1, 134ll, (void*)vr$3, 0ll );
 		fb_StrAssign( (void*)ID$1, 134ll, (void*)vr$6, -1ll, 0 );
 	}
 	goto label$59;
 	label$60:;
 	{
-		uint8* vr$7 = SYMBUNIQUEID(  );
+		uint8* vr$7 = SYMBUNIQUEID( (boolean)0ll );
 		fb_StrAssign( (void*)ID$1, 134ll, (void*)vr$7, 0ll, 0 );
 	}
 	label$59:;
@@ -1075,15 +1112,15 @@ struct $8FBSYMBOL* SYMBALLOCWSTRCONST( uint16* SNAME$1, int64 STRLENGTH$1 )
 	}
 	label$62:;
 	label$61:;
-	uint8* vr$10 = SYMBUNIQUEID(  );
+	uint8* vr$10 = SYMBUNIQUEID( (boolean)0ll );
 	fb_StrAssign( (void*)ID_ALIAS$1, 134ll, (void*)vr$10, 0ll, 0 );
 	int64 STRSIZE$1;
-	STRSIZE$1 = (STRLENGTH$1 + 1ll) * *(int64*)((uint8*)SYMB_DTYPETB$ + 400ll);
-	struct $8FBSYMBOL* vr$13 = SYMBADDVAR( (uint8*)ID$1, (uint8*)ID_ALIAS$1, 7ll, (struct $8FBSYMBOL*)0ull, STRSIZE$1, 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$89$1, 1572865ll, 137ll );
+	STRSIZE$1 = (STRLENGTH$1 + 1ll) * *(int64*)((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + 400ll);
+	struct $8FBSYMBOL* vr$13 = SYMBADDVAR( (uint8*)ID$1, (uint8*)ID_ALIAS$1, 7ll, (struct $8FBSYMBOL*)0ull, STRSIZE$1, 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$93$1, 3073ll, 137ll );
 	S$1 = vr$13;
 	void* vr$17 = XALLOCATE( (int32)((INTERNALSTRLEN$1 << (1ll & 63ll)) + 2ll) );
-	*(uint16**)((uint8*)S$1 + 88ll) = (uint16*)vr$17;
-	uint16* vr$20 = fb_WstrAssign( *(uint16**)((uint8*)S$1 + 88ll), 0ll, (uint16*)SNAME$1 );
+	*(uint16**)((uint8*)S$1 + 96ll) = (uint16*)vr$17;
+	fb_WstrAssign( *(uint16**)((uint8*)S$1 + 96ll), 0ll, (uint16*)SNAME$1 );
 	fb$result$1 = S$1;
 	label$56:;
 	return fb$result$1;
@@ -1108,53 +1145,53 @@ FBSTRING* SYMBGETCONSTVALUEASSTR( struct $8FBSYMBOL* S$1 )
 	__builtin_memset( &fb$result$1, 0, 24ll );
 	label$67:;
 	{
-		int64 TMP$92$2;
-		TMP$92$2 = *(int64*)((uint8*)S$1 + 48ll) & 511ll;
-		if( TMP$92$2 == 17ll ) goto label$71;
+		int64 TMP$96$2;
+		TMP$96$2 = *(int64*)((uint8*)S$1 + 56ll) & 511ll;
+		if( TMP$96$2 == 17ll ) goto label$71;
 		label$72:;
-		if( TMP$92$2 == 18ll ) goto label$71;
+		if( TMP$96$2 == 18ll ) goto label$71;
 		label$73:;
-		if( TMP$92$2 != 4ll ) goto label$70;
+		if( TMP$96$2 != 4ll ) goto label$70;
 		label$71:;
 		{
-			fb_StrAssign( (void*)&fb$result$1, -1ll, *(void**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)S$1 + 88ll) + 88ll), 0ll, 0 );
+			fb_StrAssign( (void*)&fb$result$1, -1ll, *(void**)((uint8*)*(struct $8FBSYMBOL**)((uint8*)S$1 + 96ll) + 96ll), 0ll, 0 );
 		}
 		goto label$69;
 		label$70:;
-		if( TMP$92$2 != 16ll ) goto label$74;
+		if( TMP$96$2 != 16ll ) goto label$74;
 		label$75:;
 		{
-			FBSTRING* vr$7 = fb_DoubleToStr( *(double*)((uint8*)S$1 + 88ll) );
-			FBSTRING* vr$9 = fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$7, -1ll, 0 );
+			FBSTRING* vr$7 = fb_DoubleToStr( *(double*)((uint8*)S$1 + 96ll) );
+			fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$7, -1ll, 0 );
 		}
 		goto label$69;
 		label$74:;
-		if( TMP$92$2 != 15ll ) goto label$76;
+		if( TMP$96$2 != 15ll ) goto label$76;
 		label$77:;
 		{
-			FBSTRING* vr$12 = fb_FloatToStr( (float)*(double*)((uint8*)S$1 + 88ll) );
-			FBSTRING* vr$14 = fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$12, -1ll, 0 );
+			FBSTRING* vr$11 = fb_FloatToStr( (float)*(double*)((uint8*)S$1 + 96ll) );
+			fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$11, -1ll, 0 );
 		}
 		goto label$69;
 		label$76:;
 		{
-			int64 TMP$93$3;
-			if( (*(int64*)((uint8*)S$1 + 48ll) & 480ll) == 0ll ) goto label$79;
-			TMP$93$3 = 24ll;
+			int64 TMP$97$3;
+			if( (*(int64*)((uint8*)S$1 + 56ll) & 480ll) == 0ll ) goto label$79;
+			TMP$97$3 = 24ll;
 			goto label$82;
 			label$79:;
-			TMP$93$3 = *(int64*)((uint8*)S$1 + 48ll) & 31ll;
+			TMP$97$3 = *(int64*)((uint8*)S$1 + 56ll) & 31ll;
 			label$82:;
-			if( *(int64*)(((uint8*)SYMB_DTYPETB$ + (TMP$93$3 * 56ll)) + 16ll) == 0ll ) goto label$81;
+			if( *(int64*)(((int64)(struct $13SYMB_DATATYPE*)SYMB_DTYPETB$ + (TMP$97$3 * 56ll)) + 16ll) == 0ll ) goto label$81;
 			{
-				FBSTRING* vr$21 = fb_LongintToStr( *(int64*)((uint8*)S$1 + 88ll) );
-				FBSTRING* vr$23 = fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$21, -1ll, 0 );
+				FBSTRING* vr$19 = fb_LongintToStr( *(int64*)((uint8*)S$1 + 96ll) );
+				fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$19, -1ll, 0 );
 			}
 			goto label$80;
 			label$81:;
 			{
-				FBSTRING* vr$25 = fb_ULongintToStr( *(uint64*)((uint8*)S$1 + 88ll) );
-				FBSTRING* vr$27 = fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$25, -1ll, 0 );
+				FBSTRING* vr$22 = fb_ULongintToStr( *(uint64*)((uint8*)S$1 + 96ll) );
+				fb_StrAssign( (void*)&fb$result$1, -1ll, (void*)vr$22, -1ll, 0 );
 			}
 			label$80:;
 		}
@@ -1162,8 +1199,8 @@ FBSTRING* SYMBGETCONSTVALUEASSTR( struct $8FBSYMBOL* S$1 )
 		label$69:;
 	}
 	label$68:;
-	FBSTRING* vr$29 = fb_StrAllocTempResult( (FBSTRING*)&fb$result$1 );
-	return vr$29;
+	FBSTRING* vr$25 = fb_StrAllocTempResult( (FBSTRING*)&fb$result$1 );
+	return vr$25;
 }
 
 struct $8FBSYMBOL* SYMBCLONECONST( struct $8FBSYMBOL* SYM$1 )
@@ -1171,51 +1208,259 @@ struct $8FBSYMBOL* SYMBCLONECONST( struct $8FBSYMBOL* SYM$1 )
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$83:;
-	struct $8FBSYMBOL* vr$7 = SYMBADDCONST( (uint8*)0ull, *(int64*)((uint8*)SYM$1 + 48ll) & 511ll, *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 56ll), (union $7FBVALUE*)((uint8*)SYM$1 + 88ll), *(int64*)((uint8*)SYM$1 + 8ll) );
+	struct $8FBSYMBOL* vr$7 = SYMBADDCONST( (uint8*)0ull, *(int64*)((uint8*)SYM$1 + 56ll) & 511ll, *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 64ll), (union $7FBVALUE*)((uint8*)SYM$1 + 96ll), *($13FB_SYMBATTRIB*)((uint8*)SYM$1 + 8ll) );
 	fb$result$1 = vr$7;
 	label$84:;
 	return fb$result$1;
 }
 
+uint8* SYMBGETCONSTSTRASSTR( struct $8FBSYMBOL* S$1 )
+{
+	uint8* fb$result$1;
+	__builtin_memset( &fb$result$1, 0, 8ll );
+	label$85:;
+	static struct $8DZSTRING RES$1;
+	DZSTRASSIGN( &RES$1, (uint8*)0ull );
+	if( (*(int64*)((uint8*)S$1 + 56ll) & 511ll) == 7ll ) goto label$88;
+	{
+		int64 TEXTLEN$2;
+		__builtin_memset( &TEXTLEN$2, 0, 8ll );
+		uint8* TEXT$2;
+		uint8* vr$6 = HUNESCAPE( *(uint8**)((uint8*)S$1 + 96ll), &TEXTLEN$2 );
+		TEXT$2 = vr$6;
+		int64 vr$7 = fb_StrLen( (void*)TEXT$2, 0ll );
+		if( vr$7 == TEXTLEN$2 ) goto label$90;
+		{
+			DZSTRCONCATASSIGN( &RES$1, (uint8*)"!\x22" );
+			{
+				int64 I$4;
+				I$4 = 0ll;
+				int64 TMP$101$4;
+				TMP$101$4 = TEXTLEN$2 + -1ll;
+				goto label$91;
+				label$94:;
+				{
+					FBSTRING TMP$103$5;
+					FBSTRING TMP$104$5;
+					__builtin_memset( &TMP$104$5, 0, 24ll );
+					FBSTRING* vr$12 = fb_HEXEx_i( (uint32)*(uint8*)((uint8*)TEXT$2 + I$4), 2 );
+					__builtin_memset( &TMP$103$5, 0, 24ll );
+					FBSTRING* vr$15 = fb_StrConcat( &TMP$103$5, (void*)"\x5Cx", 3ll, (void*)vr$12, -1ll );
+					fb_StrAssign( (void*)&TMP$104$5, -1ll, (void*)vr$15, -1ll, 0 );
+					DZSTRCONCATASSIGN( &RES$1, (uint8*)*(uint8**)&TMP$104$5 );
+					fb_StrDelete( (FBSTRING*)&TMP$104$5 );
+				}
+				label$92:;
+				I$4 = I$4 + 1ll;
+				label$91:;
+				if( I$4 <= TMP$101$4 ) goto label$94;
+				label$93:;
+			}
+		}
+		goto label$89;
+		label$90:;
+		{
+			DZSTRCONCATASSIGN( &RES$1, (uint8*)"$\x22" );
+			DZSTRCONCATASSIGN( &RES$1, (uint8*)TEXT$2 );
+		}
+		label$89:;
+		DZSTRCONCATASSIGN( &RES$1, (uint8*)"\x22" );
+	}
+	goto label$87;
+	label$88:;
+	{
+		int64 TEXTLEN$2;
+		__builtin_memset( &TEXTLEN$2, 0, 8ll );
+		uint16* TEXT$2;
+		uint16* vr$22 = HUNESCAPEW( *(uint16**)((uint8*)S$1 + 96ll), &TEXTLEN$2 );
+		TEXT$2 = vr$22;
+		DZSTRCONCATASSIGN( &RES$1, (uint8*)"!\x22" );
+		{
+			int64 I$3;
+			I$3 = 0ll;
+			int64 TMP$107$3;
+			TMP$107$3 = TEXTLEN$2 + -1ll;
+			goto label$95;
+			label$98:;
+			{
+				FBSTRING TMP$109$4;
+				FBSTRING TMP$110$4;
+				__builtin_memset( &TMP$110$4, 0, 24ll );
+				FBSTRING* vr$28 = fb_HEXEx_i( (uint32)*(uint16*)((uint8*)TEXT$2 + (I$3 << (1ll & 63ll))), 4 );
+				__builtin_memset( &TMP$109$4, 0, 24ll );
+				FBSTRING* vr$31 = fb_StrConcat( &TMP$109$4, (void*)"\x5Cu", 3ll, (void*)vr$28, -1ll );
+				fb_StrAssign( (void*)&TMP$110$4, -1ll, (void*)vr$31, -1ll, 0 );
+				DZSTRCONCATASSIGN( &RES$1, (uint8*)*(uint8**)&TMP$110$4 );
+				fb_StrDelete( (FBSTRING*)&TMP$110$4 );
+			}
+			label$96:;
+			I$3 = I$3 + 1ll;
+			label$95:;
+			if( I$3 <= TMP$107$3 ) goto label$98;
+			label$97:;
+		}
+		DZSTRCONCATASSIGN( &RES$1, (uint8*)"\x22" );
+	}
+	label$87:;
+	fb$result$1 = *(uint8**)&RES$1;
+	goto label$86;
+	label$86:;
+	return fb$result$1;
+}
+
+uint16* SYMBGETCONSTSTRASWSTR( struct $8FBSYMBOL* S$1 )
+{
+	uint16* fb$result$1;
+	__builtin_memset( &fb$result$1, 0, 8ll );
+	label$99:;
+	static struct $8DWSTRING RES$1;
+	DWSTRASSIGN( &RES$1, (uint16*)0ull );
+	if( (*(int64*)((uint8*)S$1 + 56ll) & 511ll) != 7ll ) goto label$102;
+	{
+		uint16* TMP$117$2;
+		int64 TEXTLEN$2;
+		__builtin_memset( &TEXTLEN$2, 0, 8ll );
+		uint16* TEXT$2;
+		uint16* vr$6 = HUNESCAPEW( *(uint16**)((uint8*)S$1 + 96ll), &TEXTLEN$2 );
+		TEXT$2 = vr$6;
+		int64 vr$7 = fb_WstrLen( (uint16*)TEXT$2 );
+		if( vr$7 == TEXTLEN$2 ) goto label$104;
+		{
+			uint16* TMP$111$3;
+			uint16* vr$8 = fb_StrToWstr( (uint8*)"!\x22" );
+			TMP$111$3 = vr$8;
+			DWSTRCONCATASSIGN( &RES$1, (uint16*)TMP$111$3 );
+			fb_WstrDelete( (uint16*)TMP$111$3 );
+			{
+				int64 I$4;
+				I$4 = 0ll;
+				int64 TMP$112$4;
+				TMP$112$4 = TEXTLEN$2 + -1ll;
+				goto label$105;
+				label$108:;
+				{
+					FBSTRING TMP$113$5;
+					FBSTRING TMP$114$5;
+					uint16* TMP$115$5;
+					__builtin_memset( &TMP$114$5, 0, 24ll );
+					FBSTRING* vr$14 = fb_HEXEx_i( (uint32)*(uint16*)((uint8*)TEXT$2 + (I$4 << (1ll & 63ll))), 4 );
+					__builtin_memset( &TMP$113$5, 0, 24ll );
+					FBSTRING* vr$17 = fb_StrConcat( &TMP$113$5, (void*)"\x5Cu", 3ll, (void*)vr$14, -1ll );
+					fb_StrAssign( (void*)&TMP$114$5, -1ll, (void*)vr$17, -1ll, 0 );
+					uint16* vr$19 = fb_StrToWstr( (uint8*)*(uint8**)&TMP$114$5 );
+					TMP$115$5 = vr$19;
+					DWSTRCONCATASSIGN( &RES$1, (uint16*)TMP$115$5 );
+					fb_WstrDelete( (uint16*)TMP$115$5 );
+					fb_StrDelete( (FBSTRING*)&TMP$114$5 );
+				}
+				label$106:;
+				I$4 = I$4 + 1ll;
+				label$105:;
+				if( I$4 <= TMP$112$4 ) goto label$108;
+				label$107:;
+			}
+		}
+		goto label$103;
+		label$104:;
+		{
+			uint16* TMP$116$3;
+			uint16* vr$22 = fb_StrToWstr( (uint8*)"$\x22" );
+			TMP$116$3 = vr$22;
+			DWSTRCONCATASSIGN( &RES$1, (uint16*)TMP$116$3 );
+			fb_WstrDelete( (uint16*)TMP$116$3 );
+			DWSTRCONCATASSIGN( &RES$1, (uint16*)TEXT$2 );
+		}
+		label$103:;
+		uint16* vr$23 = fb_StrToWstr( (uint8*)"\x22" );
+		TMP$117$2 = vr$23;
+		DWSTRCONCATASSIGN( &RES$1, (uint16*)TMP$117$2 );
+		fb_WstrDelete( (uint16*)TMP$117$2 );
+	}
+	goto label$101;
+	label$102:;
+	{
+		uint16* TMP$118$2;
+		uint16* TMP$123$2;
+		int64 TEXTLEN$2;
+		__builtin_memset( &TEXTLEN$2, 0, 8ll );
+		uint8* TEXT$2;
+		uint8* vr$27 = HUNESCAPE( *(uint8**)((uint8*)S$1 + 96ll), &TEXTLEN$2 );
+		TEXT$2 = vr$27;
+		uint16* vr$28 = fb_StrToWstr( (uint8*)"!\x22" );
+		TMP$118$2 = vr$28;
+		DWSTRCONCATASSIGN( &RES$1, (uint16*)TMP$118$2 );
+		fb_WstrDelete( (uint16*)TMP$118$2 );
+		{
+			int64 I$3;
+			I$3 = 0ll;
+			int64 TMP$119$3;
+			TMP$119$3 = TEXTLEN$2 + -1ll;
+			goto label$109;
+			label$112:;
+			{
+				FBSTRING TMP$120$4;
+				FBSTRING TMP$121$4;
+				uint16* TMP$122$4;
+				__builtin_memset( &TMP$121$4, 0, 24ll );
+				FBSTRING* vr$33 = fb_HEXEx_i( (uint32)*(uint8*)((uint8*)TEXT$2 + I$3), 4 );
+				__builtin_memset( &TMP$120$4, 0, 24ll );
+				FBSTRING* vr$36 = fb_StrConcat( &TMP$120$4, (void*)"\x5Cu", 3ll, (void*)vr$33, -1ll );
+				fb_StrAssign( (void*)&TMP$121$4, -1ll, (void*)vr$36, -1ll, 0 );
+				uint16* vr$38 = fb_StrToWstr( (uint8*)*(uint8**)&TMP$121$4 );
+				TMP$122$4 = vr$38;
+				DWSTRCONCATASSIGN( &RES$1, (uint16*)TMP$122$4 );
+				fb_WstrDelete( (uint16*)TMP$122$4 );
+				fb_StrDelete( (FBSTRING*)&TMP$121$4 );
+			}
+			label$110:;
+			I$3 = I$3 + 1ll;
+			label$109:;
+			if( I$3 <= TMP$119$3 ) goto label$112;
+			label$111:;
+		}
+		uint16* vr$41 = fb_StrToWstr( (uint8*)"\x22" );
+		TMP$123$2 = vr$41;
+		DWSTRCONCATASSIGN( &RES$1, (uint16*)TMP$123$2 );
+		fb_WstrDelete( (uint16*)TMP$123$2 );
+	}
+	label$101:;
+	fb$result$1 = *(uint16**)&RES$1;
+	goto label$100;
+	label$100:;
+	return fb$result$1;
+}
+
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
 
 static struct $8FBSYMBOL* HALLOCINTORFLOATCONST( FBSTRING* SVALUE$1, int64 DTYPE$1 )
 {
-	FBSTRING TMP$82$1;
+	FBSTRING TMP$86$1;
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$35:;
 	static uint8 ID$1[134];
 	struct $10FBARRAYDIM DTB$1[1];
 	__builtin_memset( (struct $10FBARRAYDIM*)DTB$1, 0, 16ll );
-	struct $8FBARRAY1I10FBARRAYDIME {
-		struct $10FBARRAYDIM* DATA;
-		struct $10FBARRAYDIM* PTR;
-		int64 SIZE;
-		int64 ELEMENT_LEN;
-		int64 DIMENSIONS;
-		struct $16__FB_ARRAYDIMTB$ DIMTB[1];
-	};
-	__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10FBARRAYDIME ) == 64 );
-	struct $8FBARRAY1I10FBARRAYDIME tmp$80$1;
-	*(struct $10FBARRAYDIM**)&tmp$80$1 = (struct $10FBARRAYDIM*)DTB$1;
-	*(struct $10FBARRAYDIM**)((uint8*)&tmp$80$1 + 8ll) = (struct $10FBARRAYDIM*)DTB$1;
-	*(int64*)((uint8*)&tmp$80$1 + 16ll) = 16ll;
-	*(int64*)((uint8*)&tmp$80$1 + 24ll) = 16ll;
-	*(int64*)((uint8*)&tmp$80$1 + 32ll) = 1ll;
-	*(int64*)((uint8*)&tmp$80$1 + 40ll) = 1ll;
-	*(int64*)((uint8*)&tmp$80$1 + 48ll) = 0ll;
-	*(int64*)((uint8*)&tmp$80$1 + 56ll) = 0ll;
+	struct $8FBARRAY1I10FBARRAYDIME tmp$84$1;
+	*(struct $10FBARRAYDIM**)&tmp$84$1 = (struct $10FBARRAYDIM*)DTB$1;
+	*(struct $10FBARRAYDIM**)((uint8*)&tmp$84$1 + 8ll) = (struct $10FBARRAYDIM*)DTB$1;
+	*(int64*)((uint8*)&tmp$84$1 + 16ll) = 16ll;
+	*(int64*)((uint8*)&tmp$84$1 + 24ll) = 16ll;
+	*(int64*)((uint8*)&tmp$84$1 + 32ll) = 1ll;
+	*(int64*)((uint8*)&tmp$84$1 + 40ll) = 49ll;
+	*(int64*)((uint8*)&tmp$84$1 + 48ll) = 1ll;
+	*(int64*)((uint8*)&tmp$84$1 + 56ll) = 0ll;
+	*(int64*)((uint8*)&tmp$84$1 + 64ll) = 0ll;
 	fb$result$1 = (struct $8FBSYMBOL*)0ull;
 	fb_StrAssign( (void*)ID$1, 134ll, (void*)"{fbnc}", 7ll, 0 );
-	__builtin_memset( &TMP$82$1, 0, 24ll );
-	FBSTRING* vr$6 = fb_StrConcat( &TMP$82$1, (void*)ID$1, 134ll, (void*)SVALUE$1, -1ll );
+	__builtin_memset( &TMP$86$1, 0, 24ll );
+	FBSTRING* vr$6 = fb_StrConcat( &TMP$86$1, (void*)ID$1, 134ll, (void*)SVALUE$1, -1ll );
 	fb_StrAssign( (void*)ID$1, 134ll, (void*)vr$6, -1ll, 0 );
 	struct $8FBSYMBOL* S$1;
 	struct $8FBSYMBOL* vr$8 = SYMBLOOKUPBYNAMEANDCLASS( (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll), (uint8*)ID$1, 1ll, -1ll, 0ll );
@@ -1227,13 +1472,13 @@ static struct $8FBSYMBOL* HALLOCINTORFLOATCONST( FBSTRING* SVALUE$1, int64 DTYPE
 	}
 	label$38:;
 	label$37:;
-	uint8* vr$10 = SYMBUNIQUEID(  );
-	struct $8FBSYMBOL* vr$11 = SYMBADDVAR( (uint8*)ID$1, (uint8*)vr$10, DTYPE$1, (struct $8FBSYMBOL*)0ull, 0ll, 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$80$1, 1572865ll, 137ll );
+	uint8* vr$10 = SYMBUNIQUEID( (boolean)0ll );
+	struct $8FBSYMBOL* vr$11 = SYMBADDVAR( (uint8*)ID$1, (uint8*)vr$10, DTYPE$1, (struct $8FBSYMBOL*)0ull, 0ll, 0ll, (struct $7FBARRAYI10FBARRAYDIME*)&tmp$84$1, 3073ll, 137ll );
 	S$1 = vr$11;
 	int64 vr$12 = fb_StrLen( (void*)SVALUE$1, -1ll );
 	void* vr$15 = XALLOCATE( (int32)(vr$12 + 1ll) );
-	*(uint8**)((uint8*)S$1 + 88ll) = (uint8*)vr$15;
-	fb_StrAssign( *(void**)((uint8*)S$1 + 88ll), 0ll, (void*)SVALUE$1, -1ll, 0 );
+	*(uint8**)((uint8*)S$1 + 96ll) = (uint8*)vr$15;
+	fb_StrAssign( *(void**)((uint8*)S$1 + 96ll), 0ll, (void*)SVALUE$1, -1ll, 0 );
 	fb$result$1 = S$1;
 	label$36:;
 	return fb$result$1;
