@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -609,10 +648,10 @@ void fb_StrDelete( FBSTRING* );
 static void fb_ctor__symbzenum( void ) __attribute__(( constructor ));
 void HASHINIT( struct $5THASH*, int64, int64 );
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM*, struct $11TSTRSETITEM* );
-struct $8FBSYMBOL* SYMBADDCONST( uint8*, int64, struct $8FBSYMBOL*, union $7FBVALUE*, int64 );
+struct $8FBSYMBOL* SYMBADDCONST( uint8*, int64, struct $8FBSYMBOL*, union $7FBVALUE*, $13FB_SYMBATTRIB );
 void SYMBDELNAMESPACEMEMBERS( struct $8FBSYMBOL*, int64 );
 typedef int64 $10FB_SYMBOPT;
-struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB );
+struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB, $13FB_PROCATTRIB );
 void SYMBFREESYMBOL( struct $8FBSYMBOL* );
 void SYMBCHECKFWDREF( struct $8FBSYMBOL* );
 typedef int64 $11AST_OPFLAGS;
@@ -635,10 +674,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -672,6 +712,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -680,11 +724,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -737,7 +782,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -756,20 +801,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $8FB_TOKEN;
 typedef int64 $15FB_CMPSTMT_MASK;
 struct $17FB_CMPSTMT_FORELM {
@@ -898,6 +945,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -909,10 +957,10 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
-struct $8FBSYMBOL* SYMBADDENUM( uint8* ID$1, uint8* ID_ALIAS$1, int64 ATTRIB$1, int64 USE_HASHTB$1 )
+struct $8FBSYMBOL* SYMBADDENUM( uint8* ID$1, uint8* ID_ALIAS$1, $13FB_SYMBATTRIB ATTRIB$1, int64 USE_HASHTB$1 )
 {
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
@@ -920,7 +968,7 @@ struct $8FBSYMBOL* SYMBADDENUM( uint8* ID$1, uint8* ID_ALIAS$1, int64 ATTRIB$1,
 	struct $8FBSYMBOL* E$1;
 	if( ID_ALIAS$1 != (uint8*)0ull ) goto label$13;
 	{
-		if( *(int64*)((uint8*)&PARSER$ + 192ll) == 0ll ) goto label$15;
+		if( *(int64*)((uint8*)&PARSER$ + 200ll) == 0ll ) goto label$15;
 		{
 			ID_ALIAS$1 = ID$1;
 		}
@@ -929,7 +977,7 @@ struct $8FBSYMBOL* SYMBADDENUM( uint8* ID$1, uint8* ID_ALIAS$1, int64 ATTRIB$1,
 	}
 	label$13:;
 	label$12:;
-	struct $8FBSYMBOL* vr$1 = SYMBNEWSYMBOL( 32ll, (struct $8FBSYMBOL*)0ull, (struct $10FBSYMBOLTB*)0ull, (struct $8FBHASHTB*)0ull, 9ll, (uint8*)ID$1, (uint8*)ID_ALIAS$1, 10ll, (struct $8FBSYMBOL*)0ull, ATTRIB$1 );
+	struct $8FBSYMBOL* vr$1 = SYMBNEWSYMBOL( 32ll, (struct $8FBSYMBOL*)0ull, (struct $10FBSYMBOLTB*)0ull, (struct $8FBHASHTB*)0ull, 9ll, (uint8*)ID$1, (uint8*)ID_ALIAS$1, 10ll, (struct $8FBSYMBOL*)0ull, ATTRIB$1, 0ll );
 	E$1 = vr$1;
 	if( E$1 != (struct $8FBSYMBOL*)0ull ) goto label$17;
 	{
@@ -938,46 +986,46 @@ struct $8FBSYMBOL* SYMBADDENUM( uint8* ID$1, uint8* ID_ALIAS$1, int64 ATTRIB$1,
 	}
 	label$17:;
 	label$16:;
-	*(struct $8FBSYMBOL**)((uint8*)E$1 + 88ll) = E$1;
-	*(struct $8FBSYMBOL**)((uint8*)E$1 + 96ll) = (struct $8FBSYMBOL*)0ull;
+	*(struct $8FBSYMBOL**)((uint8*)E$1 + 96ll) = E$1;
 	*(struct $8FBSYMBOL**)((uint8*)E$1 + 104ll) = (struct $8FBSYMBOL*)0ull;
+	*(struct $8FBSYMBOL**)((uint8*)E$1 + 112ll) = (struct $8FBSYMBOL*)0ull;
 	if( USE_HASHTB$1 == 0ll ) goto label$19;
 	{
-		*(struct $8FBSYMBOL**)((uint8*)E$1 + 112ll) = E$1;
-		*(struct $8FBHASHTB**)((uint8*)E$1 + 144ll) = (struct $8FBHASHTB*)0ull;
+		*(struct $8FBSYMBOL**)((uint8*)E$1 + 120ll) = E$1;
 		*(struct $8FBHASHTB**)((uint8*)E$1 + 152ll) = (struct $8FBHASHTB*)0ull;
+		*(struct $8FBHASHTB**)((uint8*)E$1 + 160ll) = (struct $8FBHASHTB*)0ull;
 		{
-			HASHINIT( (struct $5THASH*)((uint8*)E$1 + 120ll), 16ll, 0ll );
+			HASHINIT( (struct $5THASH*)((uint8*)E$1 + 128ll), 16ll, 0ll );
 		}
 		goto label$20;
 		label$21:;
 		{
-			memset( (void*)((uint8*)E$1 + 120ll), 0, 24ull );
+			memset( (void*)((uint8*)E$1 + 128ll), 0, 24ull );
 		}
 		label$20:;
 	}
 	goto label$18;
 	label$19:;
 	{
-		*(struct $8FBSYMBOL**)((uint8*)E$1 + 112ll) = E$1;
-		*(struct $8FBHASHTB**)((uint8*)E$1 + 144ll) = (struct $8FBHASHTB*)0ull;
+		*(struct $8FBSYMBOL**)((uint8*)E$1 + 120ll) = E$1;
 		*(struct $8FBHASHTB**)((uint8*)E$1 + 152ll) = (struct $8FBHASHTB*)0ull;
+		*(struct $8FBHASHTB**)((uint8*)E$1 + 160ll) = (struct $8FBHASHTB*)0ull;
 		goto label$23;
 		{
-			HASHINIT( (struct $5THASH*)((uint8*)E$1 + 120ll), 0ll, 0ll );
+			HASHINIT( (struct $5THASH*)((uint8*)E$1 + 128ll), 0ll, 0ll );
 		}
 		goto label$22;
 		label$23:;
 		{
-			memset( (void*)((uint8*)E$1 + 120ll), 0, 24ull );
+			memset( (void*)((uint8*)E$1 + 128ll), 0, 24ull );
 		}
 		label$22:;
 	}
 	label$18:;
-	*(struct $13FBNAMESPC_EXT**)((uint8*)E$1 + 160ll) = (struct $13FBNAMESPC_EXT*)0ull;
-	*(int64*)((uint8*)E$1 + 168ll) = 0ll;
-	*(int64*)((uint8*)E$1 + 176ll) = -1ll;
-	if( *(int64*)((uint8*)&SYMB$ + 197320ll) <= 0ll ) goto label$25;
+	*(struct $13FBNAMESPC_EXT**)((uint8*)E$1 + 168ll) = (struct $13FBNAMESPC_EXT*)0ull;
+	*(int64*)((uint8*)E$1 + 176ll) = 0ll;
+	*(int64*)((uint8*)E$1 + 184ll) = -1ll;
+	if( *(int64*)((uint8*)&SYMB$ + 197336ll) <= 0ll ) goto label$25;
 	{
 		SYMBCHECKFWDREF( E$1 );
 	}
@@ -988,7 +1036,7 @@ struct $8FBSYMBOL* SYMBADDENUM( uint8* ID$1, uint8* ID_ALIAS$1, int64 ATTRIB$1,
 	return fb$result$1;
 }
 
-struct $8FBSYMBOL* SYMBADDENUMELEMENT( struct $8FBSYMBOL* PARENT$1, uint8* ID$1, int64 INTVAL$1, int64 ATTRIB$1 )
+struct $8FBSYMBOL* SYMBADDENUMELEMENT( struct $8FBSYMBOL* PARENT$1, uint8* ID$1, int64 INTVAL$1, $13FB_SYMBATTRIB ATTRIB$1 )
 {
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
@@ -999,7 +1047,7 @@ struct $8FBSYMBOL* SYMBADDENUMELEMENT( struct $8FBSYMBOL* PARENT$1, uint8* ID$1,
 	*(int64*)&V$1 = INTVAL$1;
 	struct $8FBSYMBOL* vr$3 = SYMBADDCONST( ID$1, 10ll, PARENT$1, &V$1, ATTRIB$1 );
 	S$1 = vr$3;
-	*(int64*)((uint8*)PARENT$1 + 168ll) = *(int64*)((uint8*)PARENT$1 + 168ll) + 1ll;
+	*(int64*)((uint8*)PARENT$1 + 176ll) = *(int64*)((uint8*)PARENT$1 + 176ll) + 1ll;
 	fb$result$1 = S$1;
 	label$27:;
 	return fb$result$1;
@@ -1008,7 +1056,7 @@ struct $8FBSYMBOL* SYMBADDENUMELEMENT( struct $8FBSYMBOL* PARENT$1, uint8* ID$1,
 void SYMBDELENUM( struct $8FBSYMBOL* S$1 )
 {
 	label$28:;
-	SYMBDELNAMESPACEMEMBERS( S$1, (int64)-(*(int64*)((uint8*)S$1 + 128ll) != 0ll) );
+	SYMBDELNAMESPACEMEMBERS( S$1, (int64)-(*(int64*)((uint8*)S$1 + 136ll) != 0ll) );
 	SYMBFREESYMBOL( S$1 );
 	label$29:;
 }
@@ -1019,7 +1067,7 @@ struct $8FBSYMBOL* SYMBGETENUMFIRSTELM( struct $8FBSYMBOL* PARENT$1 )
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$30:;
 	struct $8FBSYMBOL* SYM$1;
-	SYM$1 = *(struct $8FBSYMBOL**)((uint8*)PARENT$1 + 96ll);
+	SYM$1 = *(struct $8FBSYMBOL**)((uint8*)PARENT$1 + 104ll);
 	label$32:;
 	if( SYM$1 == (struct $8FBSYMBOL*)0ull ) goto label$33;
 	{
@@ -1030,7 +1078,7 @@ struct $8FBSYMBOL* SYMBGETENUMFIRSTELM( struct $8FBSYMBOL* PARENT$1 )
 		}
 		label$35:;
 		label$34:;
-		SYM$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 296ll);
+		SYM$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 312ll);
 	}
 	goto label$32;
 	label$33:;
@@ -1044,7 +1092,7 @@ struct $8FBSYMBOL* SYMBGETENUMNEXTELM( struct $8FBSYMBOL* SYM$1 )
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$36:;
-	SYM$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 296ll);
+	SYM$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 312ll);
 	label$38:;
 	if( SYM$1 == (struct $8FBSYMBOL*)0ull ) goto label$39;
 	{
@@ -1055,7 +1103,7 @@ struct $8FBSYMBOL* SYMBGETENUMNEXTELM( struct $8FBSYMBOL* SYM$1 )
 		}
 		label$41:;
 		label$40:;
-		SYM$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 296ll);
+		SYM$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 312ll);
 	}
 	goto label$38;
 	label$39:;
@@ -1067,7 +1115,7 @@ struct $8FBSYMBOL* SYMBGETENUMNEXTELM( struct $8FBSYMBOL* SYM$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
