@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 typedef int64 $10FB_SYMBOPT;
 struct $11TSTRSETITEM {
 	FBSTRING S;
@@ -612,7 +651,7 @@ typedef int64 $12FB_ERRMSGOPT;
 void ERRREPORTEX( int64, uint8*, int64, $12FB_ERRMSGOPT, uint8* );
 struct $8FBSYMBOL* SYMBLOOKUPBYNAMEANDCLASS( struct $8FBSYMBOL*, uint8*, int64, int64, int64 );
 struct $8FBSYMBOL* SYMBADDLABEL( uint8*, $10FB_SYMBOPT );
-struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB );
+struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB, $13FB_PROCATTRIB );
 void SYMBFREESYMBOL( struct $8FBSYMBOL* );
 uint8* SYMBUNIQUELABEL( void );
 typedef int64 $11AST_OPFLAGS;
@@ -635,10 +674,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -672,6 +712,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -680,11 +724,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -737,7 +782,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -756,20 +801,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $10FB_OUTTYPE;
 typedef int64 $10FB_BACKEND;
 typedef int64 $13FB_COMPTARGET;
@@ -810,8 +857,11 @@ struct $12FBCMMLINEOPT {
 	$10FB_PDCHECK PDCHECKOPT;
 	int64 GOSUBSETJMP;
 	int64 VALISTASPTR;
+	int64 NOTHISCALL;
+	int64 FBRT;
 	int64 EXPORT;
 	int64 MSBITFIELDS;
+	int64 LOOKUP108;
 	int64 MULTITHREADED;
 	int64 GFX;
 	int64 PIC;
@@ -819,8 +869,9 @@ struct $12FBCMMLINEOPT {
 	int64 OBJINFO;
 	int64 SHOWINCLUDES;
 	$11FB_MODEVIEW MODEVIEW;
+	int64 NOCMDLINE;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 296 );
+__FB_STATIC_ASSERT( sizeof( struct $12FBCMMLINEOPT ) == 328 );
 typedef int64 $12FB_TARGETOPT;
 struct $8FBTARGET {
 	uint8* ID;
@@ -867,6 +918,7 @@ struct $8FBOPTION {
 	int64 GOSUB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $8FBOPTION ) == 56 );
+typedef int64 $16FB_RESTART_FLAGS;
 struct $7TSTRSET {
 	struct $5TLIST LIST;
 	struct $5THASH HASH;
@@ -888,16 +940,21 @@ struct $5FBENV {
 	struct $5THASH INCFILEHASH;
 	struct $5THASH INCONCEHASH;
 	int64 INCLUDEREC;
+	uint8 ENTRY[128];
 	struct $6FBMAIN MAIN;
 	struct $11FB_LANG_CTX LANG;
 	struct $8FBOPTION OPT;
-	int64 RESTARTS;
-	int64 DORESTART;
+	int64 INITED;
+	int64 MODULE_COUNT;
+	$16FB_RESTART_FLAGS RESTART_REQUEST;
+	$16FB_RESTART_FLAGS RESTART_ACTION;
+	$16FB_RESTART_FLAGS RESTART_STATUS;
+	int64 RESTART_COUNT;
 	struct $7TSTRSET LIBS;
 	struct $7TSTRSET LIBPATHS;
 	int64 FBCTINF_STARTED;
 };
-__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1576 );
+__FB_STATIC_ASSERT( sizeof( struct $5FBENV ) == 1768 );
 extern struct $5FBENV ENV$;
 typedef int64 $8FB_TOKEN;
 typedef int64 $15FB_CMPSTMT_MASK;
@@ -1027,6 +1084,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -1038,13 +1096,13 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 struct $8FBSYMBOL* SYMBADDLABEL( uint8* SYMBOL$1, $10FB_SYMBOPT OPTIONS$1 )
 {
-	$10FB_SYMBOPT TMP$88$1;
-	$13FB_SYMBATTRIB TMP$89$1;
+	$10FB_SYMBOPT TMP$93$1;
+	$13FB_SYMBATTRIB TMP$94$1;
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$10:;
@@ -1057,22 +1115,22 @@ struct $8FBSYMBOL* SYMBADDLABEL( uint8* SYMBOL$1, $10FB_SYMBOPT OPTIONS$1 )
 	fb$result$1 = (struct $8FBSYMBOL*)0ull;
 	if( SYMBOL$1 == (uint8*)0ull ) goto label$13;
 	{
-		struct $8FBSYMBOL* vr$1 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll), (uint8*)SYMBOL$1, 7ll, 0ll, -1ll );
+		struct $8FBSYMBOL* vr$1 = SYMBLOOKUPBYNAMEANDCLASS( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll), (uint8*)SYMBOL$1, 7ll, 0ll, -1ll );
 		L$1 = vr$1;
 		if( L$1 == (struct $8FBSYMBOL*)0ull ) goto label$15;
 		{
 			if( (OPTIONS$1 & 4ll) == 0ll ) goto label$17;
 			{
-				if( *(int64*)((uint8*)L$1 + 96ll) == 0ll ) goto label$19;
+				if( *(int64*)((uint8*)L$1 + 104ll) == 0ll ) goto label$19;
 				{
 					goto label$11;
 				}
 				label$19:;
 				label$18:;
-				*(int64*)((uint8*)L$1 + 96ll) = -1ll;
-				*(struct $8FBSYMBOL**)((uint8*)L$1 + 88ll) = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll);
-				*(int64*)((uint8*)L$1 + 104ll) = *(int64*)((uint8*)&PARSER$ + 56ll);
-				*(uint16*)((uint8*)L$1 + 64ll) = (uint16)*(uint64*)((uint8*)&PARSER$ + 184ll);
+				*(int64*)((uint8*)L$1 + 104ll) = -1ll;
+				*(struct $8FBSYMBOL**)((uint8*)L$1 + 96ll) = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 216ll);
+				*(int64*)((uint8*)L$1 + 112ll) = *(int64*)((uint8*)&PARSER$ + 56ll);
+				*(uint16*)((uint8*)L$1 + 72ll) = (uint16)*(uint64*)((uint8*)&PARSER$ + 192ll);
 				fb$result$1 = L$1;
 				goto label$11;
 			}
@@ -1110,25 +1168,25 @@ struct $8FBSYMBOL* SYMBADDLABEL( uint8* SYMBOL$1, $10FB_SYMBOPT OPTIONS$1 )
 	if( (OPTIONS$1 & 8ll) == 0ll ) goto label$23;
 	{
 		ISGLOBAL$1 = -1ll;
-		SYMTB$1 = (struct $10FBSYMBOLTB*)((uint8*)&SYMB$ + 196792ll);
-		HASHTB$1 = (struct $8FBHASHTB*)((uint8*)&SYMB$ + 196816ll);
+		SYMTB$1 = (struct $10FBSYMBOLTB*)((uint8*)&SYMB$ + 196800ll);
+		HASHTB$1 = (struct $8FBHASHTB*)((uint8*)&SYMB$ + 196824ll);
 	}
 	goto label$22;
 	label$23:;
 	{
-		if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) != *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1232ll) ) goto label$25;
+		if( *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) != *(struct $8FBSYMBOL**)((uint8*)&ENV$ + 1392ll) ) goto label$25;
 		{
 			ISGLOBAL$1 = -1ll;
-			if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$27;
+			if( *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll) == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$27;
 			{
-				SYMTB$1 = *(struct $10FBSYMBOLTB**)((uint8*)&SYMB$ + 197024ll);
-				HASHTB$1 = *(struct $8FBHASHTB**)((uint8*)&SYMB$ + 197016ll);
+				SYMTB$1 = *(struct $10FBSYMBOLTB**)((uint8*)&SYMB$ + 197040ll);
+				HASHTB$1 = *(struct $8FBHASHTB**)((uint8*)&SYMB$ + 197032ll);
 			}
 			goto label$26;
 			label$27:;
 			{
-				SYMTB$1 = (struct $10FBSYMBOLTB*)((uint8*)&SYMB$ + 196792ll);
-				HASHTB$1 = (struct $8FBHASHTB*)((uint8*)&SYMB$ + 196816ll);
+				SYMTB$1 = (struct $10FBSYMBOLTB*)((uint8*)&SYMB$ + 196800ll);
+				HASHTB$1 = (struct $8FBHASHTB*)((uint8*)&SYMB$ + 196824ll);
 			}
 			label$26:;
 		}
@@ -1136,25 +1194,25 @@ struct $8FBSYMBOL* SYMBADDLABEL( uint8* SYMBOL$1, $10FB_SYMBOPT OPTIONS$1 )
 		label$25:;
 		{
 			ISGLOBAL$1 = 0ll;
-			SYMTB$1 = (struct $10FBSYMBOLTB*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 200ll) + 88ll);
-			HASHTB$1 = *(struct $8FBHASHTB**)((uint8*)&SYMB$ + 197016ll);
+			SYMTB$1 = (struct $10FBSYMBOLTB*)((uint8*)*(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll) + 96ll);
+			HASHTB$1 = *(struct $8FBHASHTB**)((uint8*)&SYMB$ + 197032ll);
 		}
 		label$24:;
 	}
 	label$22:;
 	if( ISGLOBAL$1 == 0ll ) goto label$29;
-	TMP$89$1 = 0ll;
+	TMP$94$1 = 0ll;
 	goto label$34;
 	label$29:;
-	TMP$89$1 = 128ll;
+	TMP$94$1 = 128ll;
 	label$34:;
 	if( SYMBOL$1 != (uint8*)0ull ) goto label$28;
-	TMP$88$1 = 0ll;
+	TMP$93$1 = 0ll;
 	goto label$35;
 	label$28:;
-	TMP$88$1 = 32ll;
+	TMP$93$1 = 32ll;
 	label$35:;
-	struct $8FBSYMBOL* vr$20 = SYMBNEWSYMBOL( TMP$88$1, (struct $8FBSYMBOL*)0ull, SYMTB$1, HASHTB$1, 7ll, (uint8*)ID$1, (uint8*)ID_ALIAS$1, 2147483648ll, (struct $8FBSYMBOL*)0ull, TMP$89$1 );
+	struct $8FBSYMBOL* vr$20 = SYMBNEWSYMBOL( TMP$93$1, (struct $8FBSYMBOL*)0ull, SYMTB$1, HASHTB$1, 7ll, (uint8*)ID$1, (uint8*)ID_ALIAS$1, 2147483648ll, (struct $8FBSYMBOL*)0ull, TMP$94$1, 0ll );
 	L$1 = vr$20;
 	if( L$1 != (struct $8FBSYMBOL*)0ull ) goto label$31;
 	{
@@ -1164,16 +1222,17 @@ struct $8FBSYMBOL* SYMBADDLABEL( uint8* SYMBOL$1, $10FB_SYMBOPT OPTIONS$1 )
 	label$30:;
 	if( (OPTIONS$1 & 4ll) == 0ll ) goto label$33;
 	{
-		*(struct $8FBSYMBOL**)((uint8*)L$1 + 88ll) = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 208ll);
-		*(int64*)((uint8*)L$1 + 104ll) = *(int64*)((uint8*)&PARSER$ + 56ll);
-		*(int64*)((uint8*)L$1 + 96ll) = -1ll;
+		*(struct $8FBSYMBOL**)((uint8*)L$1 + 96ll) = *(struct $8FBSYMBOL**)((uint8*)&PARSER$ + 216ll);
+		*(int64*)((uint8*)L$1 + 112ll) = *(int64*)((uint8*)&PARSER$ + 56ll);
+		*(int64*)((uint8*)L$1 + 104ll) = -1ll;
 	}
 	goto label$32;
 	label$33:;
 	{
-		*(int64*)((uint8*)L$1 + 96ll) = 0ll;
+		*(int64*)((uint8*)L$1 + 104ll) = 0ll;
 	}
 	label$32:;
+	*(boolean*)((uint8*)L$1 + 120ll) = (boolean)0ll;
 	fb$result$1 = L$1;
 	label$11:;
 	return fb$result$1;
@@ -1217,11 +1276,11 @@ int64 SYMBCHECKLABELS( struct $8FBSYMBOL* SYMTBHEAD$1 )
 	{
 		if( *(int64*)S$1 != 7ll ) goto label$47;
 		{
-			if( *(int64*)((uint8*)S$1 + 96ll) != 0ll ) goto label$49;
+			if( *(int64*)((uint8*)S$1 + 104ll) != 0ll ) goto label$49;
 			{
-				if( *(uint8**)((uint8*)S$1 + 24ll) == (uint8*)0ull ) goto label$51;
+				if( *(uint8**)((uint8*)S$1 + 32ll) == (uint8*)0ull ) goto label$51;
 				{
-					ERRREPORTEX( 48ll, (uint8*)*(uint8**)((uint8*)S$1 + 24ll), -1ll, 1ll, (uint8*)0ull );
+					ERRREPORTEX( 48ll, (uint8*)*(uint8**)((uint8*)S$1 + 32ll), -1ll, 1ll, (uint8*)0ull );
 					COUNT$1 = COUNT$1 + 1ll;
 				}
 				label$51:;
@@ -1232,7 +1291,7 @@ int64 SYMBCHECKLABELS( struct $8FBSYMBOL* SYMTBHEAD$1 )
 		}
 		label$47:;
 		label$46:;
-		S$1 = *(struct $8FBSYMBOL**)((uint8*)S$1 + 296ll);
+		S$1 = *(struct $8FBSYMBOL**)((uint8*)S$1 + 312ll);
 	}
 	goto label$44;
 	label$45:;
@@ -1245,7 +1304,7 @@ int64 SYMBCHECKLABELS( struct $8FBSYMBOL* SYMTBHEAD$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
