@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -615,7 +654,7 @@ static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM*, struct $11TSTRSETIT
 void SYMBDELSYMBOL( struct $8FBSYMBOL*, int64 );
 void SYMBDELNAMESPACEMEMBERS( struct $8FBSYMBOL*, int64 );
 typedef int64 $10FB_SYMBOPT;
-struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB );
+struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB, $13FB_PROCATTRIB );
 void SYMBFREESYMBOL( struct $8FBSYMBOL* );
 int64 SYMBNAMESPACEIMPORTEX( struct $8FBSYMBOL*, struct $8FBSYMBOL* );
 void SYMBCOMPDELIMPORTLIST( struct $8FBSYMBOL* );
@@ -650,10 +689,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -687,6 +727,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -695,11 +739,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -752,7 +797,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -771,20 +816,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 typedef int64 $8FB_TOKEN;
 typedef int64 $15FB_CMPSTMT_MASK;
 struct $17FB_CMPSTMT_FORELM {
@@ -913,6 +960,7 @@ typedef int64 $12FB_PARSEROPT;
 struct $9PARSERCTX {
 	struct $13FBPARSER_STMT STMT;
 	int64 NSPCREC;
+	struct $10FBSYMCHAIN* NSPREFIX;
 	uint64 SCOPE;
 	$11FB_MANGLING MANGLING;
 	struct $8FBSYMBOL* CURRPROC;
@@ -924,7 +972,7 @@ struct $9PARSERCTX {
 	struct $8FBSYMBOL* CTXSYM;
 	int64 HAVE_EQ_OUTSIDE_PARENS;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 320 );
+__FB_STATIC_ASSERT( sizeof( struct $9PARSERCTX ) == 328 );
 extern struct $9PARSERCTX PARSER$;
 
 struct $8FBSYMBOL* SYMBADDNAMESPACE( uint8* ID$1, uint8* ID_ALIAS$1 )
@@ -935,7 +983,7 @@ struct $8FBSYMBOL* SYMBADDNAMESPACE( uint8* ID$1, uint8* ID_ALIAS$1 )
 	struct $8FBSYMBOL* S$1;
 	if( ID_ALIAS$1 != (uint8*)0ull ) goto label$13;
 	{
-		if( *(int64*)((uint8*)&PARSER$ + 192ll) == 0ll ) goto label$15;
+		if( *(int64*)((uint8*)&PARSER$ + 200ll) == 0ll ) goto label$15;
 		{
 			ID_ALIAS$1 = ID$1;
 		}
@@ -944,7 +992,7 @@ struct $8FBSYMBOL* SYMBADDNAMESPACE( uint8* ID$1, uint8* ID_ALIAS$1 )
 	}
 	label$13:;
 	label$12:;
-	struct $8FBSYMBOL* vr$1 = SYMBNEWSYMBOL( 32ll, (struct $8FBSYMBOL*)0ull, (struct $10FBSYMBOLTB*)0ull, (struct $8FBHASHTB*)0ull, 8ll, (uint8*)ID$1, (uint8*)ID_ALIAS$1, 21ll, (struct $8FBSYMBOL*)0ull, 0ll );
+	struct $8FBSYMBOL* vr$1 = SYMBNEWSYMBOL( 32ll, (struct $8FBSYMBOL*)0ull, (struct $10FBSYMBOLTB*)0ull, (struct $8FBHASHTB*)0ull, 8ll, (uint8*)ID$1, (uint8*)ID_ALIAS$1, 21ll, (struct $8FBSYMBOL*)0ull, 0ll, 0ll );
 	S$1 = vr$1;
 	if( S$1 != (struct $8FBSYMBOL*)0ull ) goto label$17;
 	{
@@ -953,24 +1001,24 @@ struct $8FBSYMBOL* SYMBADDNAMESPACE( uint8* ID$1, uint8* ID_ALIAS$1 )
 	}
 	label$17:;
 	label$16:;
-	*(struct $8FBSYMBOL**)((uint8*)S$1 + 88ll) = S$1;
-	*(struct $8FBSYMBOL**)((uint8*)S$1 + 96ll) = (struct $8FBSYMBOL*)0ull;
+	*(struct $8FBSYMBOL**)((uint8*)S$1 + 96ll) = S$1;
 	*(struct $8FBSYMBOL**)((uint8*)S$1 + 104ll) = (struct $8FBSYMBOL*)0ull;
-	*(struct $8FBSYMBOL**)((uint8*)S$1 + 112ll) = S$1;
-	*(struct $8FBHASHTB**)((uint8*)S$1 + 144ll) = (struct $8FBHASHTB*)0ull;
+	*(struct $8FBSYMBOL**)((uint8*)S$1 + 112ll) = (struct $8FBSYMBOL*)0ull;
+	*(struct $8FBSYMBOL**)((uint8*)S$1 + 120ll) = S$1;
 	*(struct $8FBHASHTB**)((uint8*)S$1 + 152ll) = (struct $8FBHASHTB*)0ull;
+	*(struct $8FBHASHTB**)((uint8*)S$1 + 160ll) = (struct $8FBHASHTB*)0ull;
 	{
-		HASHINIT( (struct $5THASH*)((uint8*)S$1 + 120ll), 800ll, 0ll );
+		HASHINIT( (struct $5THASH*)((uint8*)S$1 + 128ll), 800ll, 0ll );
 	}
 	goto label$18;
 	label$19:;
 	{
-		memset( (void*)((uint8*)S$1 + 120ll), 0, 24ull );
+		memset( (void*)((uint8*)S$1 + 128ll), 0, 24ull );
 	}
 	label$18:;
-	*(struct $13FBNAMESPC_EXT**)((uint8*)S$1 + 160ll) = (struct $13FBNAMESPC_EXT*)0ull;
-	*(int64*)((uint8*)S$1 + 168ll) = 0ll;
-	*(struct $8FBSYMBOL**)((uint8*)S$1 + 176ll) = (struct $8FBSYMBOL*)0ull;
+	*(struct $13FBNAMESPC_EXT**)((uint8*)S$1 + 168ll) = (struct $13FBNAMESPC_EXT*)0ull;
+	*(int64*)((uint8*)S$1 + 176ll) = 0ll;
+	*(struct $8FBSYMBOL**)((uint8*)S$1 + 184ll) = (struct $8FBSYMBOL*)0ull;
 	fb$result$1 = S$1;
 	label$11:;
 	return fb$result$1;
@@ -981,22 +1029,22 @@ void SYMBDELNAMESPACEMEMBERS( struct $8FBSYMBOL* S$1, int64 DELETE_HASHTB$1 )
 	label$20:;
 	SYMBCOMPDELIMPORTLIST( S$1 );
 	label$22:;
-	if( *(struct $8FBSYMBOL**)((uint8*)S$1 + 104ll) == (struct $8FBSYMBOL*)0ull ) goto label$23;
+	if( *(struct $8FBSYMBOL**)((uint8*)S$1 + 112ll) == (struct $8FBSYMBOL*)0ull ) goto label$23;
 	{
-		SYMBDELSYMBOL( *(struct $8FBSYMBOL**)((uint8*)S$1 + 104ll), -1ll );
+		SYMBDELSYMBOL( *(struct $8FBSYMBOL**)((uint8*)S$1 + 112ll), -1ll );
 	}
 	goto label$22;
 	label$23:;
-	if( *(struct $13FBNAMESPC_EXT**)((uint8*)S$1 + 160ll) == (struct $13FBNAMESPC_EXT*)0ull ) goto label$25;
+	if( *(struct $13FBNAMESPC_EXT**)((uint8*)S$1 + 168ll) == (struct $13FBNAMESPC_EXT*)0ull ) goto label$25;
 	{
-		LISTDELNODE( (struct $5TLIST*)((uint8*)&SYMB$ + 197256ll), *(void**)((uint8*)S$1 + 160ll) );
-		*(struct $13FBNAMESPC_EXT**)((uint8*)S$1 + 160ll) = (struct $13FBNAMESPC_EXT*)0ull;
+		LISTDELNODE( (struct $5TLIST*)((uint8*)&SYMB$ + 197272ll), *(void**)((uint8*)S$1 + 168ll) );
+		*(struct $13FBNAMESPC_EXT**)((uint8*)S$1 + 168ll) = (struct $13FBNAMESPC_EXT*)0ull;
 	}
 	label$25:;
 	label$24:;
 	if( DELETE_HASHTB$1 == 0ll ) goto label$27;
 	{
-		HASHEND( (struct $5THASH*)((uint8*)S$1 + 120ll) );
+		HASHEND( (struct $5THASH*)((uint8*)S$1 + 128ll) );
 	}
 	label$27:;
 	label$26:;
@@ -1015,54 +1063,54 @@ int64 SYMBNAMESPACEIMPORTEX( struct $8FBSYMBOL* NS$1, struct $8FBSYMBOL* TO_NS$1
 {
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$56:;
+	label$57:;
 	int64 vr$1 = HISONPARENTLIST( NS$1, TO_NS$1 );
-	if( vr$1 == 0ll ) goto label$59;
+	if( vr$1 == 0ll ) goto label$60;
 	{
 		fb$result$1 = 0ll;
-		goto label$57;
+		goto label$58;
 	}
-	label$59:;
-	label$58:;
-	if( *(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll) != (struct $13FBNAMESPC_EXT*)0ull ) goto label$61;
-	{
-		void* vr$4 = LISTNEWNODE( (struct $5TLIST*)((uint8*)&SYMB$ + 197256ll) );
-		*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll) = (struct $13FBNAMESPC_EXT*)vr$4;
-	}
-	label$61:;
 	label$60:;
+	label$59:;
+	if( *(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll) != (struct $13FBNAMESPC_EXT*)0ull ) goto label$62;
+	{
+		void* vr$4 = LISTNEWNODE( (struct $5TLIST*)((uint8*)&SYMB$ + 197272ll) );
+		*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll) = (struct $13FBNAMESPC_EXT*)vr$4;
+	}
+	label$62:;
+	label$61:;
 	int64 vr$6 = HISONIMPORTLIST( NS$1, TO_NS$1 );
-	if( vr$6 != 0ll ) goto label$63;
+	if( vr$6 != 0ll ) goto label$64;
 	{
 		struct $8FBSYMBOL* IMP_$2;
 		struct $8FBSYMBOL* vr$7 = HADDIMPORT( TO_NS$1 );
 		IMP_$2 = vr$7;
-		if( IMP_$2 != (struct $8FBSYMBOL*)0ull ) goto label$65;
+		if( IMP_$2 != (struct $8FBSYMBOL*)0ull ) goto label$66;
 		{
 			fb$result$1 = 0ll;
-			goto label$57;
+			goto label$58;
 		}
+		label$66:;
 		label$65:;
-		label$64:;
-		*(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 88ll) = NS$1;
-		*(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 112ll) = TO_NS$1;
+		*(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 96ll) = NS$1;
+		*(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 120ll) = TO_NS$1;
 		SYMBCOMPADDTOIMPORTLIST( IMP_$2 );
 		SYMBCOMPADDTOEXPORTLIST( IMP_$2 );
-		IMP_$2 = *(struct $8FBSYMBOL**)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll);
-		label$66:;
-		if( IMP_$2 == (struct $8FBSYMBOL*)0ull ) goto label$67;
-		{
-			SYMBNAMESPACEIMPORTEX( *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 88ll), TO_NS$1 );
-			IMP_$2 = *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 104ll);
-		}
-		goto label$66;
+		IMP_$2 = *(struct $8FBSYMBOL**)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll);
 		label$67:;
+		if( IMP_$2 == (struct $8FBSYMBOL*)0ull ) goto label$68;
+		{
+			SYMBNAMESPACEIMPORTEX( *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 96ll), TO_NS$1 );
+			IMP_$2 = *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 112ll);
+		}
+		goto label$67;
+		label$68:;
 		HADDTOHASHTBLIST( NS$1 );
 	}
+	label$64:;
 	label$63:;
-	label$62:;
 	fb$result$1 = -1ll;
-	label$57:;
+	label$58:;
 	return fb$result$1;
 }
 
@@ -1070,99 +1118,100 @@ int64 SYMBNAMESPACEIMPORT( struct $8FBSYMBOL* NS$1 )
 {
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$68:;
-	int64 vr$1 = SYMBNAMESPACEIMPORTEX( NS$1, *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll) );
-	fb$result$1 = vr$1;
 	label$69:;
+	int64 vr$1 = SYMBNAMESPACEIMPORTEX( NS$1, *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll) );
+	fb$result$1 = vr$1;
+	label$70:;
 	return fb$result$1;
 }
 
 void SYMBNAMESPACEREMOVE( struct $8FBSYMBOL* IMP_$1, int64 HASHONLY$1 )
 {
-	label$70:;
-	if( *(struct $8FBSYMBOL**)((uint8*)IMP_$1 + 88ll) == (struct $8FBSYMBOL*)0ull ) goto label$73;
+	label$71:;
+	if( *(struct $8FBSYMBOL**)((uint8*)IMP_$1 + 96ll) == (struct $8FBSYMBOL*)0ull ) goto label$74;
 	{
-		HDELFROMHASHTBLIST( *(struct $8FBSYMBOL**)((uint8*)IMP_$1 + 88ll) );
+		HDELFROMHASHTBLIST( *(struct $8FBSYMBOL**)((uint8*)IMP_$1 + 96ll) );
 		SYMBCOMPDELFROMEXPORTLIST( IMP_$1 );
 		SYMBCOMPDELFROMIMPORTLIST( IMP_$1 );
-		*(struct $8FBSYMBOL**)((uint8*)IMP_$1 + 88ll) = (struct $8FBSYMBOL*)0ull;
+		*(struct $8FBSYMBOL**)((uint8*)IMP_$1 + 96ll) = (struct $8FBSYMBOL*)0ull;
 	}
+	label$74:;
 	label$73:;
-	label$72:;
-	if( HASHONLY$1 != 0ll ) goto label$75;
+	if( HASHONLY$1 != 0ll ) goto label$76;
 	{
 		SYMBFREESYMBOL( IMP_$1 );
 	}
+	label$76:;
 	label$75:;
-	label$74:;
-	label$71:;
+	label$72:;
 }
 
 void SYMBNAMESPACEREIMPORT( struct $8FBSYMBOL* NS$1 )
 {
-	label$76:;
-	if( *(struct $10FBSYMCHAIN**)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll) + 40ll) == (struct $10FBSYMCHAIN*)0ull ) goto label$79;
+	label$77:;
+	if( *(struct $10FBSYMCHAIN**)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll) + 40ll) == (struct $10FBSYMCHAIN*)0ull ) goto label$80;
 	{
 		struct $8FBSYMBOL* HEAD$2;
-		HEAD$2 = *(struct $8FBSYMBOL**)((uint8*)NS$1 + 176ll);
-		if( HEAD$2 != (struct $8FBSYMBOL*)0ull ) goto label$81;
+		HEAD$2 = *(struct $8FBSYMBOL**)((uint8*)NS$1 + 184ll);
+		if( HEAD$2 != (struct $8FBSYMBOL*)0ull ) goto label$82;
 		{
-			HEAD$2 = *(struct $8FBSYMBOL**)((uint8*)NS$1 + 96ll);
+			HEAD$2 = *(struct $8FBSYMBOL**)((uint8*)NS$1 + 104ll);
+		}
+		goto label$81;
+		label$82:;
+		{
+			HEAD$2 = *(struct $8FBSYMBOL**)((uint8*)HEAD$2 + 312ll);
 		}
-		goto label$80;
 		label$81:;
-		{
-			HEAD$2 = *(struct $8FBSYMBOL**)((uint8*)HEAD$2 + 296ll);
-		}
-		label$80:;
-		if( HEAD$2 == (struct $8FBSYMBOL*)0ull ) goto label$83;
+		if( HEAD$2 == (struct $8FBSYMBOL*)0ull ) goto label$84;
 		{
 			SYMBHASHLISTINSERTNAMESPACE( NS$1, HEAD$2 );
 		}
+		label$84:;
 		label$83:;
-		label$82:;
 	}
+	label$80:;
 	label$79:;
-	label$78:;
 	struct $8FBSYMBOL* EXP_$1;
-	EXP_$1 = *(struct $8FBSYMBOL**)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll) + 16ll);
-	label$84:;
-	if( EXP_$1 == (struct $8FBSYMBOL*)0ull ) goto label$85;
+	EXP_$1 = *(struct $8FBSYMBOL**)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll) + 16ll);
+	label$85:;
+	if( EXP_$1 == (struct $8FBSYMBOL*)0ull ) goto label$86;
 	{
 		struct $8FBSYMBOL* IMP_$2;
-		IMP_$2 = *(struct $8FBSYMBOL**)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll);
-		label$86:;
-		if( IMP_$2 == (struct $8FBSYMBOL*)0ull ) goto label$87;
-		{
-			SYMBNAMESPACEIMPORTEX( *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 88ll), *(struct $8FBSYMBOL**)((uint8*)EXP_$1 + 112ll) );
-			IMP_$2 = *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 104ll);
-		}
-		goto label$86;
+		IMP_$2 = *(struct $8FBSYMBOL**)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll);
 		label$87:;
-		EXP_$1 = *(struct $8FBSYMBOL**)((uint8*)EXP_$1 + 128ll);
+		if( IMP_$2 == (struct $8FBSYMBOL*)0ull ) goto label$88;
+		{
+			SYMBNAMESPACEIMPORTEX( *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 96ll), *(struct $8FBSYMBOL**)((uint8*)EXP_$1 + 120ll) );
+			IMP_$2 = *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 112ll);
+		}
+		goto label$87;
+		label$88:;
+		EXP_$1 = *(struct $8FBSYMBOL**)((uint8*)EXP_$1 + 136ll);
 	}
-	goto label$84;
-	label$85:;
-	label$77:;
+	goto label$85;
+	label$86:;
+	label$78:;
 }
 
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
 
 static struct $8FBSYMBOL* HADDIMPORT( struct $8FBSYMBOL* DST_NS$1 )
 {
+	$13FB_SYMBATTRIB TMP$93$1;
 	struct $8FBSYMBOL* fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$30:;
 	struct $10FBSYMBOLTB* SYMBTB$1;
 	struct $8FBHASHTB* HASHTB$1;
 	int64 IS_LOCAL$1;
-	if( DST_NS$1 != *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197008ll) ) goto label$33;
+	if( DST_NS$1 != *(struct $8FBSYMBOL**)((uint8*)&SYMB$ + 197024ll) ) goto label$33;
 	{
 		SYMBTB$1 = (struct $10FBSYMBOLTB*)0ull;
 		HASHTB$1 = (struct $8FBHASHTB*)0ull;
@@ -1171,12 +1220,18 @@ static struct $8FBSYMBOL* HADDIMPORT( struct $8FBSYMBOL* DST_NS$1 )
 	goto label$32;
 	label$33:;
 	{
-		SYMBTB$1 = (struct $10FBSYMBOLTB*)((uint8*)DST_NS$1 + 88ll);
-		HASHTB$1 = (struct $8FBHASHTB*)((uint8*)DST_NS$1 + 112ll);
+		SYMBTB$1 = (struct $10FBSYMBOLTB*)((uint8*)DST_NS$1 + 96ll);
+		HASHTB$1 = (struct $8FBHASHTB*)((uint8*)DST_NS$1 + 120ll);
 		IS_LOCAL$1 = (int64)-((*(int64*)((uint8*)DST_NS$1 + 8ll) & 128ll) != 0ll);
 	}
 	label$32:;
-	struct $8FBSYMBOL* vr$8 = SYMBNEWSYMBOL( 0ll, (struct $8FBSYMBOL*)0ull, SYMBTB$1, HASHTB$1, 16ll, (uint8*)0ull, (uint8*)0ull, 2147483648ll, (struct $8FBSYMBOL*)0ull, IS_LOCAL$1 );
+	if( IS_LOCAL$1 == 0ll ) goto label$34;
+	TMP$93$1 = 128ll;
+	goto label$89;
+	label$34:;
+	TMP$93$1 = 0ll;
+	label$89:;
+	struct $8FBSYMBOL* vr$8 = SYMBNEWSYMBOL( 0ll, (struct $8FBSYMBOL*)0ull, SYMBTB$1, HASHTB$1, 17ll, (uint8*)0ull, (uint8*)0ull, 2147483648ll, (struct $8FBSYMBOL*)0ull, TMP$93$1, 0ll );
 	fb$result$1 = vr$8;
 	label$31:;
 	return fb$result$1;
@@ -1184,53 +1239,53 @@ static struct $8FBSYMBOL* HADDIMPORT( struct $8FBSYMBOL* DST_NS$1 )
 
 static void HADDTOHASHTBLIST( struct $8FBSYMBOL* NS$1 )
 {
-	label$34:;
-	*(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll) + 32ll) = *(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll) + 32ll) + 1ll;
-	if( *(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll) + 32ll) != 1ll ) goto label$37;
+	label$35:;
+	*(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll) + 32ll) = *(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll) + 32ll) + 1ll;
+	if( *(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll) + 32ll) != 1ll ) goto label$38;
 	{
-		SYMBHASHLISTINSERTNAMESPACE( NS$1, *(struct $8FBSYMBOL**)((uint8*)NS$1 + 96ll) );
+		SYMBHASHLISTINSERTNAMESPACE( NS$1, *(struct $8FBSYMBOL**)((uint8*)NS$1 + 104ll) );
 	}
+	label$38:;
 	label$37:;
 	label$36:;
-	label$35:;
 }
 
 static void HDELFROMHASHTBLIST( struct $8FBSYMBOL* NS$1 )
 {
-	label$38:;
-	*(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll) + 32ll) = *(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll) + 32ll) + -1ll;
-	if( *(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 160ll) + 32ll) != 0ll ) goto label$41;
+	label$39:;
+	*(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll) + 32ll) = *(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll) + 32ll) + -1ll;
+	if( *(int64*)((uint8*)*(struct $13FBNAMESPC_EXT**)((uint8*)NS$1 + 168ll) + 32ll) != 0ll ) goto label$42;
 	{
 		SYMBHASHLISTREMOVENAMESPACE( NS$1 );
 	}
+	label$42:;
 	label$41:;
 	label$40:;
-	label$39:;
 }
 
 static int64 HISONPARENTLIST( struct $8FBSYMBOL* SRC_NS$1, struct $8FBSYMBOL* DST_NS$1 )
 {
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$42:;
+	label$43:;
 	struct $8FBSYMBOL* PARENT$1;
 	PARENT$1 = DST_NS$1;
-	label$44:;
-	if( PARENT$1 == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$45;
+	label$45:;
+	if( PARENT$1 == (struct $8FBSYMBOL*)((uint8*)&SYMB$ + 196704ll) ) goto label$46;
 	{
-		if( SRC_NS$1 != PARENT$1 ) goto label$47;
+		if( SRC_NS$1 != PARENT$1 ) goto label$48;
 		{
 			fb$result$1 = -1ll;
-			goto label$43;
+			goto label$44;
 		}
+		label$48:;
 		label$47:;
-		label$46:;
-		PARENT$1 = *(struct $8FBSYMBOL**)*(struct $8FBHASHTB**)((uint8*)PARENT$1 + 232ll);
+		PARENT$1 = *(struct $8FBSYMBOL**)*(struct $8FBHASHTB**)((uint8*)PARENT$1 + 248ll);
 	}
-	goto label$44;
-	label$45:;
+	goto label$45;
+	label$46:;
 	fb$result$1 = 0ll;
-	label$43:;
+	label$44:;
 	return fb$result$1;
 }
 
@@ -1238,29 +1293,29 @@ static int64 HISONIMPORTLIST( struct $8FBSYMBOL* SRC_NS$1, struct $8FBSYMBOL* DS
 {
 	int64 fb$result$1;
 	__builtin_memset( &fb$result$1, 0, 8ll );
-	label$48:;
-	if( *(struct $13FBNAMESPC_EXT**)((uint8*)DST_NS$1 + 160ll) == (struct $13FBNAMESPC_EXT*)0ull ) goto label$51;
+	label$49:;
+	if( *(struct $13FBNAMESPC_EXT**)((uint8*)DST_NS$1 + 168ll) == (struct $13FBNAMESPC_EXT*)0ull ) goto label$52;
 	{
 		struct $8FBSYMBOL* IMP_$2;
-		IMP_$2 = *(struct $8FBSYMBOL**)*(struct $13FBNAMESPC_EXT**)((uint8*)DST_NS$1 + 160ll);
-		label$52:;
-		if( IMP_$2 == (struct $8FBSYMBOL*)0ull ) goto label$53;
+		IMP_$2 = *(struct $8FBSYMBOL**)*(struct $13FBNAMESPC_EXT**)((uint8*)DST_NS$1 + 168ll);
+		label$53:;
+		if( IMP_$2 == (struct $8FBSYMBOL*)0ull ) goto label$54;
 		{
-			if( *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 88ll) != SRC_NS$1 ) goto label$55;
+			if( *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 96ll) != SRC_NS$1 ) goto label$56;
 			{
 				fb$result$1 = -1ll;
-				goto label$49;
+				goto label$50;
 			}
+			label$56:;
 			label$55:;
-			label$54:;
-			IMP_$2 = *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 104ll);
+			IMP_$2 = *(struct $8FBSYMBOL**)((uint8*)IMP_$2 + 112ll);
 		}
-		goto label$52;
-		label$53:;
+		goto label$53;
+		label$54:;
 	}
+	label$52:;
 	label$51:;
-	label$50:;
 	fb$result$1 = 0ll;
-	label$49:;
+	label$50:;
 	return fb$result$1;
 }
