@@ -10,6 +10,7 @@ typedef struct { char *data; int64 len; int64 size; } FBSTRING;
 typedef int8 boolean;
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -177,7 +178,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -323,6 +324,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -332,7 +334,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -341,7 +344,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -352,10 +355,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -364,9 +368,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -609,7 +648,7 @@ static void fb_ctor__symbzscope( void ) __attribute__(( constructor ));
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM*, struct $11TSTRSETITEM* );
 void SYMBDELSYMBOL( struct $8FBSYMBOL*, int64 );
 typedef int64 $10FB_SYMBOPT;
-struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB );
+struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB, $13FB_PROCATTRIB );
 void SYMBFREESYMBOL( struct $8FBSYMBOL* );
 void SYMBDELFROMHASH( struct $8FBSYMBOL* );
 void SYMBNAMESPACEREMOVE( struct $8FBSYMBOL*, int64 );
@@ -633,10 +672,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -670,6 +710,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -678,11 +722,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -735,7 +780,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -754,20 +799,22 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
 struct $8FBSYMBOL* SYMBADDSCOPE( struct $7ASTNODE* BACKNODE$1 )
 {
@@ -776,12 +823,12 @@ struct $8FBSYMBOL* SYMBADDSCOPE( struct $7ASTNODE* BACKNODE$1 )
 	label$10:;
 	struct $8FBSYMBOL* S$1;
 	__builtin_memset( &S$1, 0, 8ll );
-	struct $8FBSYMBOL* vr$2 = SYMBNEWSYMBOL( 0ll, (struct $8FBSYMBOL*)0ull, *(struct $10FBSYMBOLTB**)((uint8*)&SYMB$ + 197024ll), (struct $8FBHASHTB*)0ull, 15ll, (uint8*)0ull, (uint8*)0ull, 2147483648ll, (struct $8FBSYMBOL*)0ull, 0ll );
+	struct $8FBSYMBOL* vr$2 = SYMBNEWSYMBOL( 0ll, (struct $8FBSYMBOL*)0ull, *(struct $10FBSYMBOLTB**)((uint8*)&SYMB$ + 197040ll), (struct $8FBHASHTB*)0ull, 15ll, (uint8*)0ull, (uint8*)0ull, 2147483648ll, (struct $8FBSYMBOL*)0ull, 0ll, 0ll );
 	S$1 = vr$2;
-	*(struct $8FBSYMBOL**)((uint8*)S$1 + 96ll) = S$1;
-	*(struct $8FBSYMBOL**)((uint8*)S$1 + 104ll) = (struct $8FBSYMBOL*)0ull;
+	*(struct $8FBSYMBOL**)((uint8*)S$1 + 104ll) = S$1;
 	*(struct $8FBSYMBOL**)((uint8*)S$1 + 112ll) = (struct $8FBSYMBOL*)0ull;
-	*(struct $7ASTNODE**)((uint8*)S$1 + 88ll) = BACKNODE$1;
+	*(struct $8FBSYMBOL**)((uint8*)S$1 + 120ll) = (struct $8FBSYMBOL*)0ull;
+	*(struct $7ASTNODE**)((uint8*)S$1 + 96ll) = BACKNODE$1;
 	fb$result$1 = S$1;
 	label$11:;
 	return fb$result$1;
@@ -799,7 +846,7 @@ void SYMBDELSCOPE( struct $8FBSYMBOL* SCP$1 )
 	label$16:;
 	{
 		struct $8FBSYMBOL* S$2;
-		S$2 = *(struct $8FBSYMBOL**)((uint8*)SCP$1 + 112ll);
+		S$2 = *(struct $8FBSYMBOL**)((uint8*)SCP$1 + 120ll);
 		if( S$2 != (struct $8FBSYMBOL*)0ull ) goto label$20;
 		{
 			goto label$17;
@@ -819,11 +866,11 @@ void SYMBDELSCOPETB( struct $8FBSYMBOL* SCP$1 )
 {
 	label$21:;
 	struct $8FBSYMBOL* S$1;
-	S$1 = *(struct $8FBSYMBOL**)((uint8*)SCP$1 + 112ll);
+	S$1 = *(struct $8FBSYMBOL**)((uint8*)SCP$1 + 120ll);
 	label$23:;
 	if( S$1 == (struct $8FBSYMBOL*)0ull ) goto label$24;
 	{
-		if( *(int64*)S$1 == 16ll ) goto label$26;
+		if( *(int64*)S$1 == 17ll ) goto label$26;
 		{
 			SYMBDELFROMHASH( S$1 );
 		}
@@ -833,7 +880,7 @@ void SYMBDELSCOPETB( struct $8FBSYMBOL* SCP$1 )
 			SYMBNAMESPACEREMOVE( S$1, -1ll );
 		}
 		label$25:;
-		S$1 = *(struct $8FBSYMBOL**)((uint8*)S$1 + 288ll);
+		S$1 = *(struct $8FBSYMBOL**)((uint8*)S$1 + 304ll);
 	}
 	goto label$23;
 	label$24:;
@@ -843,7 +890,7 @@ void SYMBDELSCOPETB( struct $8FBSYMBOL* SCP$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
