@@ -36,6 +36,7 @@ struct $5TLIST {
 __FB_STATIC_ASSERT( sizeof( struct $5TLIST ) == 64 );
 typedef int64 $12FB_SYMBCLASS;
 typedef int64 $13FB_SYMBATTRIB;
+typedef int64 $13FB_PROCATTRIB;
 typedef int64 $12FB_SYMBSTATS;
 struct $9FB_SYMBID {
 	uint8* NAME;
@@ -202,7 +203,7 @@ struct $17AST_NODE_DATASTMT {
 };
 __FB_STATIC_ASSERT( sizeof( struct $17AST_NODE_DATASTMT ) == 8 );
 struct $13AST_NODE_LINK {
-	int64 RET_LEFT;
+	int64 RET;
 };
 __FB_STATIC_ASSERT( sizeof( struct $13AST_NODE_LINK ) == 8 );
 struct $13AST_NODE_CAST {
@@ -348,6 +349,7 @@ struct $9FBNAMESPC {
 	struct $13FBNAMESPC_EXT* EXT;
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FBNAMESPC ) == 80 );
+typedef int64 $15FB_STRUCT_INREG;
 struct $13FB_STRUCT_DBG {
 	int64 TYPENUM;
 };
@@ -357,7 +359,8 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* DEFCTOR;
 	struct $8FBSYMBOL* COPYCTOR;
 	struct $8FBSYMBOL* COPYCTORCONST;
-	struct $8FBSYMBOL* DTOR;
+	struct $8FBSYMBOL* DTOR1;
+	struct $8FBSYMBOL* DTOR0;
 	struct $8FBSYMBOL* COPYLETOP;
 	struct $8FBSYMBOL* COPYLETOPCONST;
 	struct $8FBSYMBOL* OPOVLTB[28];
@@ -366,7 +369,7 @@ struct $12FB_STRUCTEXT {
 	struct $8FBSYMBOL* RTTI;
 	int64 ABSTRACTCOUNT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 312 );
+__FB_STATIC_ASSERT( sizeof( struct $12FB_STRUCTEXT ) == 320 );
 struct $10FBS_STRUCT {
 	struct $9FBNAMESPC NS;
 	struct $8FBSYMBOL* BASE;
@@ -377,10 +380,11 @@ struct $10FBS_STRUCT {
 	uint8 BITPOS;
 	uint8 ALIGN;
 	$11FB_DATATYPE RETDTYPE;
+	$15FB_STRUCT_INREG RETIN2REGS;
 	struct $13FB_STRUCT_DBG DBG;
 	struct $12FB_STRUCTEXT* EXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 144 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_STRUCT ) == 152 );
 struct $8FBS_ENUM {
 	struct $9FBNAMESPC NS;
 	int64 ELEMENTS;
@@ -389,9 +393,9 @@ struct $8FBS_ENUM {
 __FB_STATIC_ASSERT( sizeof( struct $8FBS_ENUM ) == 96 );
 typedef int64 $11FB_FUNCMODE;
 typedef int64 $21FB_PROC_RETURN_METHOD;
-typedef int64 (*tmp$29)( struct $8FBSYMBOL* );
+typedef int64 (*tmp$34)( struct $8FBSYMBOL* );
 struct $10FB_PROCRTL {
-	tmp$29 CALLBACK;
+	tmp$34 CALLBACK;
 };
 __FB_STATIC_ASSERT( sizeof( struct $10FB_PROCRTL ) == 8 );
 struct $10FB_PROCOVL {
@@ -465,14 +469,16 @@ struct $9FBS_PARAM {
 	struct $7ASTNODE* OPTEXPR;
 	int64 BYDESCDIMENSIONS;
 	struct $8FBSYMBOL* BYDESCREALSUBTYPE;
+	int64 ARGNUM;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 40 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_PARAM ) == 48 );
 struct $9FBS_LABEL {
 	struct $8FBSYMBOL* PARENT;
 	int64 DECLARED;
 	int64 STMTNUM;
+	boolean GOSUB;
 };
-__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 24 );
+__FB_STATIC_ASSERT( sizeof( struct $9FBS_LABEL ) == 32 );
 struct $11FB_DEFPARAM;
 struct $11FB_DEFPARAM {
 	uint8* NAME;
@@ -494,7 +500,33 @@ struct $9FB_DEFTOK {
 };
 __FB_STATIC_ASSERT( sizeof( struct $9FB_DEFTOK ) == 32 );
 typedef int64 $15FB_DEFINE_FLAGS;
-typedef FBSTRING* (*tmp$27)( void );
+typedef FBSTRING* (*tmp$28)( void );
+struct $8DZSTRING {
+	uint8* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DZSTRING ) == 24 );
+struct $8DWSTRING {
+	uint16* DATA;
+	int64 LEN;
+	int64 SIZE;
+};
+__FB_STATIC_ASSERT( sizeof( struct $8DWSTRING ) == 24 );
+struct $9LEXPP_ARG {
+	union {
+		struct $8DZSTRING TEXT;
+		struct $8DWSTRING TEXTW;
+	};
+};
+__FB_STATIC_ASSERT( sizeof( struct $9LEXPP_ARG ) == 24 );
+struct $11LEXPP_ARGTB {
+	struct $9LEXPP_ARG TB[32];
+	int64 COUNT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $11LEXPP_ARGTB ) == 776 );
+typedef FBSTRING* (*tmp$29)( struct $11LEXPP_ARGTB*, int64* );
+typedef uint16* (*tmp$30)( struct $11LEXPP_ARGTB*, int64* );
 struct $10FBS_DEFINE {
 	int64 PARAMS;
 	struct $11FB_DEFPARAM* PARAMHEAD;
@@ -505,9 +537,15 @@ struct $10FBS_DEFINE {
 	};
 	int64 ISARGLESS;
 	$15FB_DEFINE_FLAGS FLAGS;
-	tmp$27 PROC;
+	union {
+		tmp$28 DPROCZ;
+		tmp$29 MPROCZ;
+	};
+	union {
+		tmp$30 MPROCW;
+	};
 };
-__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 48 );
+__FB_STATIC_ASSERT( sizeof( struct $10FBS_DEFINE ) == 56 );
 typedef int64 $10FB_TKCLASS;
 struct $11FBS_KEYWORD {
 	int64 ID;
@@ -568,6 +606,7 @@ __FB_STATIC_ASSERT( sizeof( struct $9FBSYMHASH ) == 40 );
 struct $8FBSYMBOL {
 	$12FB_SYMBCLASS CLASS;
 	$13FB_SYMBATTRIB ATTRIB;
+	$13FB_PROCATTRIB PATTRIB;
 	$12FB_SYMBSTATS STATS;
 	struct $9FB_SYMBID ID;
 	$11FB_DATATYPE TYP;
@@ -597,7 +636,7 @@ struct $8FBSYMBOL {
 	struct $8FBSYMBOL* PREV;
 	struct $8FBSYMBOL* NEXT;
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 304 );
+__FB_STATIC_ASSERT( sizeof( struct $8FBSYMBOL ) == 320 );
 struct $11TSTRSETITEM {
 	FBSTRING S;
 	int64 USERDATA;
@@ -613,7 +652,7 @@ void LISTDELNODE( struct $5TLIST*, void* );
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM*, struct $11TSTRSETITEM* );
 void ASTREPLACEFWDREF( struct $7ASTNODE*, struct $8FBSYMBOL*, int64, struct $8FBSYMBOL* );
 typedef int64 $10FB_SYMBOPT;
-struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB );
+struct $8FBSYMBOL* SYMBNEWSYMBOL( $10FB_SYMBOPT, struct $8FBSYMBOL*, struct $10FBSYMBOLTB*, struct $8FBHASHTB*, $12FB_SYMBCLASS, uint8*, uint8*, int64, struct $8FBSYMBOL*, $13FB_SYMBATTRIB, $13FB_PROCATTRIB );
 void SYMBFREESYMBOL( struct $8FBSYMBOL* );
 void SYMBSETTYPE( struct $8FBSYMBOL*, int64, struct $8FBSYMBOL* );
 void SYMBCHECKFWDREF( struct $8FBSYMBOL* );
@@ -640,10 +679,11 @@ struct $8FBARRAY1I10AST_OPINFOE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 64 );
-static struct $8FBARRAY1I10AST_OPINFOE tmp$76$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I10AST_OPINFOE ) == 72 );
+static struct $8FBARRAY1I10AST_OPINFOE tmp$80$;
 struct $12FBHASHTBLIST {
 	struct $8FBHASHTB* HEAD;
 	struct $8FBHASHTB* TAIL;
@@ -677,6 +717,10 @@ struct $5TPOOL {
 	struct $5TLIST* CHUNKTB;
 };
 __FB_STATIC_ASSERT( sizeof( struct $5TPOOL ) == 24 );
+struct $17SYMB_DEF_UNIQUEID {
+	struct $5THASH DICT;
+};
+__FB_STATIC_ASSERT( sizeof( struct $17SYMB_DEF_UNIQUEID ) == 24 );
 struct $14SYMB_DEF_PARAM {
 	struct $8HASHITEM* ITEM;
 	uint64 INDEX;
@@ -685,11 +729,12 @@ __FB_STATIC_ASSERT( sizeof( struct $14SYMB_DEF_PARAM ) == 16 );
 struct $12SYMB_DEF_CTX {
 	struct $5TLIST PARAMLIST;
 	struct $5TLIST TOKLIST;
+	struct $17SYMB_DEF_UNIQUEID UNIQUEID;
 	int64 PARAM;
 	struct $5THASH PARAMHASH;
 	struct $14SYMB_DEF_PARAM HASH[32];
 };
-__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 672 );
+__FB_STATIC_ASSERT( sizeof( struct $12SYMB_DEF_CTX ) == 696 );
 struct $20FB_GLOBCTORLIST_ITEM;
 struct $20FB_GLOBCTORLIST_ITEM {
 	struct $8FBSYMBOL* SYM;
@@ -742,7 +787,7 @@ struct $7SYMBCTX {
 	int64 FBARRAYDIM_UBOUND;
 	struct $10FB_RTTICTX RTTI;
 };
-__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199208 );
+__FB_STATIC_ASSERT( sizeof( struct $7SYMBCTX ) == 199248 );
 extern struct $7SYMBCTX SYMB$;
 typedef int64 $12FB_DATACLASS;
 struct $13SYMB_DATATYPE {
@@ -761,33 +806,35 @@ struct $8FBARRAY1I13SYMB_DATATYPEE {
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[1];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 64 );
-static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$77$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY1I13SYMB_DATATYPEE ) == 72 );
+static struct $8FBARRAY1I13SYMB_DATATYPEE tmp$81$;
 struct $8FBARRAY2Iu7INTEGERE {
 	int64* DATA;
 	int64* PTR;
 	int64 SIZE;
 	int64 ELEMENT_LEN;
 	int64 DIMENSIONS;
+	int64 FLAGS;
 	struct $16__FB_ARRAYDIMTB$ DIMTB[2];
 };
-__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 88 );
-static struct $8FBARRAY2Iu7INTEGERE tmp$78$;
+__FB_STATIC_ASSERT( sizeof( struct $8FBARRAY2Iu7INTEGERE ) == 96 );
+static struct $8FBARRAY2Iu7INTEGERE tmp$82$;
 
 void SYMBFWDREFINIT( void )
 {
 	label$10:;
-	LISTINIT( (struct $5TLIST*)((uint8*)&SYMB$ + 197192ll), 500ll, 16ll, 6ll );
-	*(int64*)((uint8*)&SYMB$ + 197320ll) = 0ll;
+	LISTINIT( (struct $5TLIST*)((uint8*)&SYMB$ + 197208ll), 500ll, 16ll, 6ll );
+	*(int64*)((uint8*)&SYMB$ + 197336ll) = 0ll;
 	label$11:;
 }
 
 void SYMBFWDREFEND( void )
 {
 	label$12:;
-	LISTEND( (struct $5TLIST*)((uint8*)&SYMB$ + 197192ll) );
+	LISTEND( (struct $5TLIST*)((uint8*)&SYMB$ + 197208ll) );
 	label$13:;
 }
 
@@ -795,11 +842,11 @@ void SYMBADDTOFWDREF( struct $8FBSYMBOL* F$1, struct $8FBSYMBOL* REF$1 )
 {
 	label$14:;
 	struct $8FBFWDREF* N$1;
-	void* vr$1 = LISTNEWNODE( (struct $5TLIST*)((uint8*)&SYMB$ + 197192ll) );
+	void* vr$1 = LISTNEWNODE( (struct $5TLIST*)((uint8*)&SYMB$ + 197208ll) );
 	N$1 = (struct $8FBFWDREF*)vr$1;
 	*(struct $8FBSYMBOL**)N$1 = REF$1;
-	*(struct $8FBFWDREF**)((uint8*)N$1 + 8ll) = *(struct $8FBFWDREF**)((uint8*)F$1 + 88ll);
-	*(struct $8FBFWDREF**)((uint8*)F$1 + 88ll) = N$1;
+	*(struct $8FBFWDREF**)((uint8*)N$1 + 8ll) = *(struct $8FBFWDREF**)((uint8*)F$1 + 96ll);
+	*(struct $8FBFWDREF**)((uint8*)F$1 + 96ll) = N$1;
 	label$15:;
 }
 
@@ -807,7 +854,7 @@ void SYMBREMOVEFROMFWDREF( struct $8FBSYMBOL* F$1, struct $8FBSYMBOL* REF$1 )
 {
 	label$16:;
 	struct $8FBFWDREF* N$1;
-	N$1 = *(struct $8FBFWDREF**)((uint8*)F$1 + 88ll);
+	N$1 = *(struct $8FBFWDREF**)((uint8*)F$1 + 96ll);
 	struct $8FBFWDREF* NXT$1;
 	NXT$1 = (struct $8FBFWDREF*)0ull;
 	label$18:;
@@ -826,7 +873,7 @@ void SYMBREMOVEFROMFWDREF( struct $8FBSYMBOL* F$1, struct $8FBSYMBOL* REF$1 )
 	label$19:;
 	if( NXT$1 != (struct $8FBFWDREF*)0ull ) goto label$24;
 	{
-		*(struct $8FBFWDREF**)((uint8*)F$1 + 88ll) = *(struct $8FBFWDREF**)((uint8*)N$1 + 8ll);
+		*(struct $8FBFWDREF**)((uint8*)F$1 + 96ll) = *(struct $8FBFWDREF**)((uint8*)N$1 + 8ll);
 	}
 	goto label$23;
 	label$24:;
@@ -834,7 +881,7 @@ void SYMBREMOVEFROMFWDREF( struct $8FBSYMBOL* F$1, struct $8FBSYMBOL* REF$1 )
 		*(struct $8FBFWDREF**)((uint8*)NXT$1 + 8ll) = *(struct $8FBFWDREF**)((uint8*)N$1 + 8ll);
 	}
 	label$23:;
-	LISTDELNODE( (struct $5TLIST*)((uint8*)&SYMB$ + 197192ll), (void*)N$1 );
+	LISTDELNODE( (struct $5TLIST*)((uint8*)&SYMB$ + 197208ll), (void*)N$1 );
 	label$17:;
 }
 
@@ -852,12 +899,12 @@ void SYMBCHECKFWDREF( struct $8FBSYMBOL* SYM$1 )
 		}
 		label$45:;
 		label$44:;
-		FWD$1 = *(struct $8FBSYMBOL**)((uint8*)FWD$1 + 264ll);
+		FWD$1 = *(struct $8FBSYMBOL**)((uint8*)FWD$1 + 280ll);
 	}
 	label$43:;
 	if( FWD$1 != (struct $8FBSYMBOL*)0ull ) goto label$41;
 	label$42:;
-	FWD$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 256ll);
+	FWD$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 272ll);
 	label$46:;
 	if( FWD$1 == (struct $8FBSYMBOL*)0ull ) goto label$47;
 	{
@@ -868,7 +915,7 @@ void SYMBCHECKFWDREF( struct $8FBSYMBOL* SYM$1 )
 		}
 		label$49:;
 		label$48:;
-		FWD$1 = *(struct $8FBSYMBOL**)((uint8*)FWD$1 + 256ll);
+		FWD$1 = *(struct $8FBSYMBOL**)((uint8*)FWD$1 + 272ll);
 	}
 	goto label$46;
 	label$47:;
@@ -881,7 +928,7 @@ struct $8FBSYMBOL* SYMBADDTYPEDEF( uint8* ID$1, int64 DTYPE$1, struct $8FBSYMBOL
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$50:;
 	struct $8FBSYMBOL* T$1;
-	struct $8FBSYMBOL* vr$1 = SYMBNEWSYMBOL( 32ll, (struct $8FBSYMBOL*)0ull, (struct $10FBSYMBOLTB*)0ull, (struct $8FBHASHTB*)0ull, 13ll, (uint8*)ID$1, (uint8*)0ull, DTYPE$1, SUBTYPE$1, 0ll );
+	struct $8FBSYMBOL* vr$1 = SYMBNEWSYMBOL( 32ll, (struct $8FBSYMBOL*)0ull, (struct $10FBSYMBOLTB*)0ull, (struct $8FBHASHTB*)0ull, 13ll, (uint8*)ID$1, (uint8*)0ull, DTYPE$1, SUBTYPE$1, 0ll, 0ll );
 	T$1 = vr$1;
 	if( T$1 != (struct $8FBSYMBOL*)0ull ) goto label$53;
 	{
@@ -890,8 +937,8 @@ struct $8FBSYMBOL* SYMBADDTYPEDEF( uint8* ID$1, int64 DTYPE$1, struct $8FBSYMBOL
 	}
 	label$53:;
 	label$52:;
-	*(int64*)((uint8*)T$1 + 72ll) = LGT$1;
-	if( *(int64*)((uint8*)&SYMB$ + 197320ll) <= 0ll ) goto label$55;
+	*(int64*)((uint8*)T$1 + 80ll) = LGT$1;
+	if( *(int64*)((uint8*)&SYMB$ + 197336ll) <= 0ll ) goto label$55;
 	{
 		SYMBCHECKFWDREF( T$1 );
 	}
@@ -908,7 +955,7 @@ struct $8FBSYMBOL* SYMBADDFWDREF( uint8* ID$1 )
 	__builtin_memset( &fb$result$1, 0, 8ll );
 	label$56:;
 	struct $8FBSYMBOL* F$1;
-	struct $8FBSYMBOL* vr$1 = SYMBNEWSYMBOL( 33ll, (struct $8FBSYMBOL*)0ull, (struct $10FBSYMBOLTB*)0ull, (struct $8FBHASHTB*)0ull, 14ll, (uint8*)ID$1, (uint8*)0ull, 2147483648ll, (struct $8FBSYMBOL*)0ull, 0ll );
+	struct $8FBSYMBOL* vr$1 = SYMBNEWSYMBOL( 33ll, (struct $8FBSYMBOL*)0ull, (struct $10FBSYMBOLTB*)0ull, (struct $8FBHASHTB*)0ull, 14ll, (uint8*)ID$1, (uint8*)0ull, 2147483648ll, (struct $8FBSYMBOL*)0ull, 0ll, 0ll );
 	F$1 = vr$1;
 	if( F$1 != (struct $8FBSYMBOL*)0ull ) goto label$59;
 	{
@@ -917,8 +964,8 @@ struct $8FBSYMBOL* SYMBADDFWDREF( uint8* ID$1 )
 	}
 	label$59:;
 	label$58:;
-	*(struct $8FBFWDREF**)((uint8*)F$1 + 88ll) = (struct $8FBFWDREF*)0ull;
-	*(int64*)((uint8*)&SYMB$ + 197320ll) = *(int64*)((uint8*)&SYMB$ + 197320ll) + 1ll;
+	*(struct $8FBFWDREF**)((uint8*)F$1 + 96ll) = (struct $8FBFWDREF*)0ull;
+	*(int64*)((uint8*)&SYMB$ + 197336ll) = *(int64*)((uint8*)&SYMB$ + 197336ll) + 1ll;
 	fb$result$1 = F$1;
 	label$57:;
 	return fb$result$1;
@@ -927,28 +974,28 @@ struct $8FBSYMBOL* SYMBADDFWDREF( uint8* ID$1 )
 static void _ZN11TSTRSETITEMaSERKS_( struct $11TSTRSETITEM* THIS$1, struct $11TSTRSETITEM* __FB_RHS__$1 )
 {
 	label$4:;
-	FBSTRING* vr$4 = fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
+	fb_StrAssign( (void*)THIS$1, -1ll, (void*)__FB_RHS__$1, -1ll, 0 );
 	*(int64*)((uint8*)THIS$1 + 24ll) = *(int64*)((uint8*)__FB_RHS__$1 + 24ll);
 	label$5:;
 }
 
 static void SYMBREPLACEFORWARDREF( struct $8FBSYMBOL* S$1, int64 DTYPE$1, struct $8FBSYMBOL* SUBTYPE$1 )
 {
-	int64 TMP$88$1;
+	int64 TMP$93$1;
 	label$25:;
 	if( *(int64*)S$1 != 4ll ) goto label$27;
-	TMP$88$1 = (int64)-(*(struct $7ASTNODE**)((uint8*)S$1 + 104ll) != (struct $7ASTNODE*)0ull);
+	TMP$93$1 = (int64)-(*(struct $7ASTNODE**)((uint8*)S$1 + 112ll) != (struct $7ASTNODE*)0ull);
 	goto label$60;
 	label$27:;
-	TMP$88$1 = 0ll;
+	TMP$93$1 = 0ll;
 	label$60:;
-	if( TMP$88$1 == 0ll ) goto label$29;
+	if( TMP$93$1 == 0ll ) goto label$29;
 	{
-		ASTREPLACEFWDREF( *(struct $7ASTNODE**)((uint8*)S$1 + 104ll), *(struct $8FBSYMBOL**)((uint8*)S$1 + 56ll), DTYPE$1, SUBTYPE$1 );
+		ASTREPLACEFWDREF( *(struct $7ASTNODE**)((uint8*)S$1 + 112ll), *(struct $8FBSYMBOL**)((uint8*)S$1 + 64ll), DTYPE$1, SUBTYPE$1 );
 	}
 	label$29:;
 	label$28:;
-	int64 vr$6 = TYPEMERGE( *(int64*)((uint8*)S$1 + 48ll), DTYPE$1 );
+	int64 vr$6 = TYPEMERGE( *(int64*)((uint8*)S$1 + 56ll), DTYPE$1 );
 	DTYPE$1 = vr$6;
 	SYMBSETTYPE( S$1, DTYPE$1, SUBTYPE$1 );
 	label$26:;
@@ -962,8 +1009,8 @@ static void HFIXFORWARDREF( struct $8FBSYMBOL* FWD$1, struct $8FBSYMBOL* SYM$1 )
 	struct $8FBSYMBOL* SUBTYPE$1;
 	int64 DTYPE$1;
 	{
-		uint64 TMP$89$2;
-		TMP$89$2 = *(uint64*)SYM$1;
+		uint64 TMP$94$2;
+		TMP$94$2 = *(uint64*)SYM$1;
 		goto label$33;
 		label$34:;
 		{
@@ -979,31 +1026,31 @@ static void HFIXFORWARDREF( struct $8FBSYMBOL* FWD$1, struct $8FBSYMBOL* SYM$1 )
 		goto label$32;
 		label$36:;
 		{
-			DTYPE$1 = *(int64*)((uint8*)SYM$1 + 48ll);
-			SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 56ll);
+			DTYPE$1 = *(int64*)((uint8*)SYM$1 + 56ll);
+			SUBTYPE$1 = *(struct $8FBSYMBOL**)((uint8*)SYM$1 + 64ll);
 		}
 		goto label$32;
 		label$33:;
-		static const void* tmp$90[2ll] = {
+		static const void* tmp$95[2ll] = {
 			&&label$35,
 			&&label$34,
 		};
-		if( (TMP$89$2 - 9ull) > 1ull ) goto label$36;
-		goto *tmp$90[TMP$89$2 - 9ull];
+		if( (TMP$94$2 - 9ull) > 1ull ) goto label$36;
+		goto *tmp$95[TMP$94$2 - 9ull];
 		label$32:;
 	}
-	NODE$1 = *(struct $8FBFWDREF**)((uint8*)FWD$1 + 88ll);
+	NODE$1 = *(struct $8FBFWDREF**)((uint8*)FWD$1 + 96ll);
 	label$37:;
 	if( NODE$1 == (struct $8FBFWDREF*)0ull ) goto label$38;
 	{
 		SYMBREPLACEFORWARDREF( *(struct $8FBSYMBOL**)NODE$1, DTYPE$1, SUBTYPE$1 );
 		PREV$1 = *(struct $8FBFWDREF**)((uint8*)NODE$1 + 8ll);
-		LISTDELNODE( (struct $5TLIST*)((uint8*)&SYMB$ + 197192ll), (void*)NODE$1 );
+		LISTDELNODE( (struct $5TLIST*)((uint8*)&SYMB$ + 197208ll), (void*)NODE$1 );
 		NODE$1 = PREV$1;
 	}
 	goto label$37;
 	label$38:;
 	SYMBFREESYMBOL( FWD$1 );
-	*(int64*)((uint8*)&SYMB$ + 197320ll) = *(int64*)((uint8*)&SYMB$ + 197320ll) + -1ll;
+	*(int64*)((uint8*)&SYMB$ + 197336ll) = *(int64*)((uint8*)&SYMB$ + 197336ll) + -1ll;
 	label$31:;
 }
